//
//  ContentView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

struct ContentView: View {
    @StateObject private var pluginManager = PluginManager()
    @StateObject private var batchOperationManager = BatchOperationManager()
    @State private var selectedSourceType: PluginType = .user
    @State private var selectedSubType: PluginSubType?
    @State private var selectedCategoryPath: String?

    var body: some View {
        VStack(spacing: 0) {
            // 兼容性警告
            CompatibilityWarningView()

            // 显示启动加载状态
            if !pluginManager.isGlobalScanComplete && pluginManager.plugins.isEmpty {
                startupLoadingView
            } else {
                mainContentView
            }

            // 底部权限状态栏
            VStack(spacing: 0) {
                Divider()
                AuthorizationStatusView()
                    .padding(.horizontal, 16)
                    .padding(.vertical, 8)
                    .background(Color(NSColor.controlBackgroundColor))
            }
        }
        .navigationTitle("FCPX插件管理器")
        .environmentObject(pluginManager)
        .onAppear {
            // 延迟启动插件扫描，避免初始化卡住
            let manager = pluginManager
            Task {
                // 等待UI完全加载后再开始扫描
                try? await Task.sleep(nanoseconds: 500_000_000) // 0.5秒延迟
                await startDelayedPluginScan(manager: manager)
            }
        }
        .toolbar {
            ToolbarItemGroup(placement: .primaryAction) {
                Button("刷新") {
                    let manager = pluginManager
                    manager.isGlobalScanComplete = false
                    Task {
                        // 清空所有缓存并重新扫描所有插件源
                        manager.clearAllCache()
                        await manager.scanAllPluginSources()
                    }
                }
                .keyboardShortcut("r", modifiers: .command)
            }
        }
    }

    // MARK: - 启动加载视图
    private var startupLoadingView: some View {
        VStack(spacing: 20) {
            Spacer()

            ProgressView()
                .scaleEffect(1.5)

            Text("正在初始化插件管理器...")
                .font(.headline)
                .foregroundColor(.secondary)

            Text("首次启动可能需要一些时间")
                .font(.caption)
                .foregroundColor(.secondary)

            Spacer()
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
        .background(Color(NSColor.controlBackgroundColor))
    }

    // MARK: - 主要内容视图
    private var mainContentView: some View {
        HStack(spacing: 0) {
            NavigationView {
                    // 左侧插件源类型栏
                    PluginSourceTypeView(
                        selectedSourceType: $selectedSourceType,
                        pluginManager: pluginManager
                    )
                    .frame(minWidth: 180, maxWidth: 180)

                    // 中央插件类型和类别栏
                    PluginTypeAndCategoryView(
                        selectedSourceType: selectedSourceType,
                        selectedSubType: $selectedSubType,
                        selectedCategoryPath: $selectedCategoryPath,
                        pluginManager: pluginManager
                    )
                    .frame(minWidth: 250, maxWidth: 300)

                    // 主内容区域
                    PluginContentView(
                        selectedSourceType: selectedSourceType,
                        selectedSubType: selectedSubType,
                        selectedCategoryPath: selectedCategoryPath,
                        pluginManager: pluginManager,
                        batchOperationManager: batchOperationManager
                    )
                    .frame(minWidth: 400)
                }

                // 右侧批量操作缓冲区
                if !batchOperationManager.bufferedPlugins.isEmpty {
                    Divider()

                    BatchOperationView(
                        batchOperationManager: batchOperationManager,
                        pluginManager: pluginManager
                    )
                    .frame(width: 300)
                    .transition(.move(edge: .trailing).combined(with: .opacity))
                    .animation(.easeInOut(duration: 0.3), value: batchOperationManager.bufferedPlugins.isEmpty)
                }
        }
    }

    // MARK: - 延迟启动插件扫描
    private func startDelayedPluginScan(manager: PluginManager) async {
        
        // 检查是否已经完成扫描，避免重复扫描
        guard !manager.isGlobalScanComplete else {
            print("📱 插件扫描已完成，跳过重复扫描")
            return
        }

        print("📱 开始延迟插件扫描...")

        // 使用超时机制，避免无限等待
        do {
            try await withTimeout(seconds: 30) {
                // 使用后台优先级进行扫描，避免阻塞UI
                await Task.detached(priority: .background) {
                    await manager.scanAllPluginSources()
                }.value
            }
            print("📱 延迟插件扫描完成")
        } catch {
            print("⚠️ 插件扫描超时或失败: \(error)")
            // 即使扫描失败，也要确保UI可用
            await MainActor.run {
                manager.isGlobalScanComplete = true
                manager.isLoading = false
                manager.errorMessage = "插件扫描超时，请尝试手动刷新"
            }
        }
    }

    // MARK: - 超时辅助函数
    private func withTimeout<T>(seconds: TimeInterval, operation: @escaping () async throws -> T) async throws -> T {
        return try await withThrowingTaskGroup(of: T.self) { group in
            group.addTask {
                try await operation()
            }

            group.addTask {
                try await Task.sleep(nanoseconds: UInt64(seconds * 1_000_000_000))
                throw TimeoutError()
            }

            guard let result = try await group.next() else {
                throw TimeoutError()
            }

            group.cancelAll()
            return result
        }
    }

    private struct TimeoutError: Error {}
}

#Preview {
    ContentView()
}
