//
//  BatchMergeManager.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import Foundation
import SwiftUI

// MARK: - 插件冲突
struct PluginConflict {
    let pluginName: String
    let plugins: [FCPXPlugin]
}

// MARK: - 合并分析结果
struct MergeAnalysis {
    let totalPlugins: Int
    let categoryCount: Int
    let conflicts: [PluginConflict]
    let suggestedNames: [String]
    let primarySubType: PluginSubType
    let allPlugins: [FCPXPlugin]
}

// MARK: - 批量合并管理器
@MainActor
class BatchMergeManager: ObservableObject {
    private let fileManager = FileManager.default
    
    // MARK: - 公开属性
    @Published var availableCategories: [(displayName: String, originalPath: String)] = []
    
    // MARK: - 加载可用类别
    func loadAvailableCategories(pluginManager: PluginManager) async {
        var categories: [(displayName: String, originalPath: String)] = []

        //print("🔍 开始扫描可用类别目录...")

        // 扫描所有插件源和插件类型
        for pluginSource in [PluginType.user, PluginType.system] { // 只扫描支持合并的插件源
            for pluginType in PluginSubType.allCases.filter({ $0 != .compositions }) {
                let basePath = pluginSource.basePath

                // 构建正确的模板目录路径
                let motionTemplatesPath: String
                if basePath.hasSuffix("Templates.localized") {
                    // 系统插件目录：/Library/Application Support/Final Cut Pro/Templates.localized
                    motionTemplatesPath = basePath
                } else if basePath.hasSuffix("Motion Templates.localized") {
                    // 用户插件目录：~/Movies/Motion Templates.localized
                    motionTemplatesPath = basePath
                } else {
                    // 其他情况，尝试添加Motion Templates.localized子目录
                    motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
                }

                let subTypePath = URL(fileURLWithPath: motionTemplatesPath).appendingPathComponent(pluginType.rawValue).path

                //print("🔍 扫描路径: \(subTypePath)")

                if fileManager.fileExists(atPath: subTypePath) {
                    do {
                        let contents = try fileManager.contentsOfDirectory(atPath: subTypePath)
                        //print("   找到 \(contents.count) 个项目")

                        for item in contents {
                            let itemPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(item).path
                            var isDirectory: ObjCBool = false

                            if fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory) && isDirectory.boolValue {
                                // 跳过隐藏目录
                                if !item.hasPrefix(".") {
                                    // 处理FxFactory插件的显示名称
                                    let displayName: String
                                    let fxfactoryPlistPath = itemPath + "/.fxfactory.plist"
                                    if fileManager.fileExists(atPath: fxfactoryPlistPath) {
                                        // FxFactory插件，尝试获取真实名称
                                        let realName = await getFxFactoryDisplayName(path: itemPath, uuid: item)
                                        displayName = "\(pluginSource.displayName) - \(pluginType.displayName) - \(realName)"
                                    } else {
                                        // 普通插件
                                        displayName = "\(pluginSource.displayName) - \(pluginType.displayName) - \(item)"
                                    }

                                    categories.append((displayName: displayName, originalPath: itemPath))
                                    //print("   ✅ 添加类别: \(displayName)")
                                }
                            }
                        }
                    } catch {
                        //print("❌ 扫描类别目录失败: \(subTypePath) - \(error)")
                    }
                } else {
                    //print("   ⚠️ 路径不存在: \(subTypePath)")
                }
            }
        }

        //print("📊 总共找到 \(categories.count) 个可用类别")

        await MainActor.run {
            self.availableCategories = categories.sorted { $0.displayName.localizedStandardCompare($1.displayName) == .orderedAscending }
            //print("✅ 类别列表已更新，共 \(self.availableCategories.count) 个类别")
        }
    }

    // MARK: - 辅助方法

    /// 检查字符串是否为UUID格式
    private func isUUID(_ string: String) -> Bool {
        return UUID(uuidString: string) != nil
    }

    /// 获取FxFactory插件的显示名称
    private func getFxFactoryDisplayName(path: String, uuid: String) async -> String {
        let stringsPath = path + "/.localized/en.strings"

        guard fileManager.fileExists(atPath: stringsPath),
              let data = fileManager.contents(atPath: stringsPath),
              let content = String(data: data, encoding: .utf8) else {
            return uuid
        }

        // 解析strings文件格式: "UUID" = "Display Name";
        let pattern = "\"\(uuid)\"\\s*=\\s*\"([^\"]+)\""
        if let regex = try? NSRegularExpression(pattern: pattern),
           let match = regex.firstMatch(in: content, range: NSRange(content.startIndex..., in: content)),
           let range = Range(match.range(at: 1), in: content) {
            return String(content[range])
        }

        return uuid
    }
    
    // MARK: - 执行批量合并（简化版本）
    func performBatchMerge(
        plugins: [FCPXPlugin],
        targetCategory: String,
        pluginManager: PluginManager,
        completion: @escaping () async -> Void
    ) async {
        guard let firstPlugin = plugins.first,
              let subType = firstPlugin.subType else {
            //print("❌ 无法确定插件类型")
            await completion()
            return
        }

        // 构建目标路径
        let targetPath: String
        if targetCategory.contains("/") {
            // 如果包含路径分隔符，说明是完整路径
            targetPath = targetCategory
        } else {
            // 否则构建路径
            let basePath = firstPlugin.type.basePath

            // 构建正确的模板目录路径
            let motionTemplatesPath: String
            if basePath.hasSuffix("Templates.localized") {
                // 系统插件目录：/Library/Application Support/Final Cut Pro/Templates.localized
                motionTemplatesPath = basePath
            } else if basePath.hasSuffix("Motion Templates.localized") {
                // 用户插件目录：~/Movies/Motion Templates.localized
                motionTemplatesPath = basePath
            } else {
                // 其他情况，尝试添加Motion Templates.localized子目录
                motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
            }

            let subTypePath = URL(fileURLWithPath: motionTemplatesPath).appendingPathComponent(subType.rawValue).path
            targetPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(targetCategory).path
        }

        //print("🔄 开始批量合并 \(plugins.count) 个插件到: \(targetPath)")

        // 确保目标目录存在
        if !fileManager.fileExists(atPath: targetPath) {
            do {
                try fileManager.createDirectory(atPath: targetPath, withIntermediateDirectories: true, attributes: nil)
                //print("✅ 创建目标目录: \(targetPath)")
            } catch {
                //print("❌ 创建目标目录失败: \(error)")
                await completion()
                return
            }
        }

        // 执行合并
        var successCount = 0
        for (_, plugin) in plugins.enumerated() {
            do {
                let pluginName = plugin.displayName
                let finalTargetPath = generateUniquePluginPath(basePath: targetPath, pluginName: pluginName)

                //print("🔄 正在移动插件 \(index + 1)/\(plugins.count): \(pluginName)")
                //print("   源路径: \(plugin.path)")
                //print("   目标路径: \(finalTargetPath)")

                // 检查源路径是否存在
                if !fileManager.fileExists(atPath: plugin.path) {
                    //print("❌ 源插件路径不存在: \(plugin.path)")
                    continue
                }

                // 移动插件目录
                try fileManager.moveItem(atPath: plugin.path, toPath: finalTargetPath)
                successCount += 1
                //print("✅ 插件合并成功: \(pluginName)")

            } catch {
                //print("❌ 插件合并失败: \(plugin.displayName) - \(error)")
                // 继续处理下一个插件，不要因为一个失败就停止
            }
        }

        //print("📊 批量合并完成: 成功 \(successCount)/\(plugins.count) 个插件")

        // 清理空的源目录
        for plugin in plugins {
            try? await cleanupCategoryDirectoryIfEmpty(plugin.categoryPath)
        }

        await completion()
    }
    
    // MARK: - 分析缓冲区项目
    func analyzeBufferItems(_ items: [MergeBufferItem]) async -> MergeAnalysis {
        var allPlugins: [FCPXPlugin] = []
        var categoryNames: Set<String> = []
        var subTypeCounts: [PluginSubType: Int] = [:]
        
        // 收集所有插件和类别信息
        for item in items {
            switch item.type {
            case .plugin(let plugin):
                allPlugins.append(plugin)
                if let subType = plugin.subType {
                    subTypeCounts[subType, default: 0] += 1
                }
                
            case .category(let categoryInfo):
                // 扫描类别目录获取插件列表
                let categoryPlugins = scanCategoryForPlugins(at: categoryInfo.path)
                allPlugins.append(contentsOf: categoryPlugins)
                categoryNames.insert(categoryInfo.displayName)
                if let subType = categoryInfo.subType {
                    subTypeCounts[subType, default: 0] += categoryPlugins.count
                }
            }
        }
        
        // 检测冲突
        let conflicts = detectConflicts(in: allPlugins)
        
        // 确定主要插件类型
        let primarySubType = subTypeCounts.max(by: { $0.value < $1.value })?.key ?? .effects
        
        // 生成建议的类别名称
        let suggestedNames = generateSuggestedNames(from: categoryNames, subType: primarySubType)
        
        return MergeAnalysis(
            totalPlugins: allPlugins.count,
            categoryCount: categoryNames.count + (items.filter { 
                if case .plugin = $0.type { return true }
                return false
            }.count > 0 ? 1 : 0), // 如果有单独的插件，算作一个额外类别
            conflicts: conflicts,
            suggestedNames: suggestedNames,
            primarySubType: primarySubType,
            allPlugins: allPlugins
        )
    }
    
    // MARK: - 执行批量合并
    func performBatchMerge(
        analysis: MergeAnalysis,
        targetName: String,
        conflictResolutions: [String: ConflictResolution]
    ) async throws {
        
        // 1. 创建目标目录
        let targetPath = try await createTargetDirectory(
            name: targetName,
            subType: analysis.primarySubType
        )
        
        // 2. 处理冲突
        let resolvedPlugins = try await resolveConflicts(
            plugins: analysis.allPlugins,
            conflicts: analysis.conflicts,
            resolutions: conflictResolutions
        )
        
        // 3. 移动插件到目标目录
        try await movePluginsToTarget(
            plugins: resolvedPlugins,
            targetPath: targetPath
        )

        // 4. 清理空的源类别目录
        try await cleanupEmptySourceDirectories(plugins: resolvedPlugins)

        //print("批量合并完成: \(resolvedPlugins.count) 个插件合并到 \(targetName)")
    }
    
    // MARK: - 私有方法
    
    private func detectConflicts(in plugins: [FCPXPlugin]) -> [PluginConflict] {
        var pluginGroups: [String: [FCPXPlugin]] = [:]
        
        // 按名称分组
        for plugin in plugins {
            let name = plugin.displayName
            pluginGroups[name, default: []].append(plugin)
        }
        
        // 找出有冲突的组
        var conflicts: [PluginConflict] = []
        for (name, group) in pluginGroups {
            if group.count > 1 {
                conflicts.append(PluginConflict(pluginName: name, plugins: group))
            }
        }
        
        return conflicts
    }
    
    private func generateSuggestedNames(from categoryNames: Set<String>, subType: PluginSubType) -> [String] {
        // 只返回现有类别名称，不添加预置建议
        return categoryNames.sorted { $0.localizedStandardCompare($1) == .orderedAscending }
    }
    
    private func createTargetDirectory(name: String, subType: PluginSubType) async throws -> String {
        // 默认使用用户插件目录
        let basePath = PluginType.user.basePath
        let subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(subType.rawValue).path
        let targetPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(name).path
        
        // 确保子类型目录存在
        if !fileManager.fileExists(atPath: subTypePath) {
            try fileManager.createDirectory(atPath: subTypePath, withIntermediateDirectories: true)
        }
        
        // 创建目标目录（如果不存在）
        if !fileManager.fileExists(atPath: targetPath) {
            try fileManager.createDirectory(atPath: targetPath, withIntermediateDirectories: true)
        }
        
        return targetPath
    }
    
    private func resolveConflicts(
        plugins: [FCPXPlugin],
        conflicts: [PluginConflict],
        resolutions: [String: ConflictResolution]
    ) async throws -> [FCPXPlugin] {
        
        var resolvedPlugins: [FCPXPlugin] = []
        var conflictPluginIds: Set<UUID> = []
        
        // 收集所有冲突插件的ID
        for conflict in conflicts {
            for plugin in conflict.plugins {
                conflictPluginIds.insert(plugin.id)
            }
        }
        
        // 添加非冲突插件
        for plugin in plugins {
            if !conflictPluginIds.contains(plugin.id) {
                resolvedPlugins.append(plugin)
            }
        }
        
        // 处理冲突插件
        for conflict in conflicts {
            let resolution = resolutions[conflict.pluginName] ?? .keepBoth
            
            switch resolution {
            case .keepFirst:
                if let firstPlugin = conflict.plugins.first {
                    resolvedPlugins.append(firstPlugin)
                }
                
            case .keepSecond:
                if conflict.plugins.count > 1 {
                    resolvedPlugins.append(conflict.plugins[1])
                }
                
            case .keepBoth:
                // 保留所有插件，但重命名除第一个外的其他插件
                for (index, plugin) in conflict.plugins.enumerated() {
                    if index == 0 {
                        resolvedPlugins.append(plugin)
                    } else {
                        var renamedPlugin = plugin
                        renamedPlugin.realName = "\(plugin.displayName) (\(index + 1))"
                        resolvedPlugins.append(renamedPlugin)
                    }
                }
                
            case .rename:
                // TODO: 实现自定义重命名逻辑
                // 暂时使用keepBoth策略
                for (index, plugin) in conflict.plugins.enumerated() {
                    if index == 0 {
                        resolvedPlugins.append(plugin)
                    } else {
                        var renamedPlugin = plugin
                        renamedPlugin.realName = "\(plugin.displayName) (\(index + 1))"
                        resolvedPlugins.append(renamedPlugin)
                    }
                }
            }
        }
        
        return resolvedPlugins
    }
    
    private func movePluginsToTarget(plugins: [FCPXPlugin], targetPath: String) async throws {
        // 分组处理：需要权限的操作和普通操作
        var systemMoves: [(from: String, to: String)] = []
        var normalMoves: [(from: String, to: String)] = []

        for plugin in plugins {
            let pluginName = plugin.realName ?? plugin.displayName

            // 确保我们复制的是插件目录而不是单个文件
            let sourcePluginPath = plugin.path

            // 验证源路径是一个目录
            var isDirectory: ObjCBool = false
            guard fileManager.fileExists(atPath: sourcePluginPath, isDirectory: &isDirectory),
                  isDirectory.boolValue else {
                //print("警告: 插件路径不是目录: \(sourcePluginPath)")
                continue
            }

            // 生成唯一的目标路径
            let finalTargetPath = generateUniquePluginPath(basePath: targetPath, pluginName: pluginName)

            // 根据是否需要权限分组
            if SudoPermissionManager.shared.needsSudoPermission(for: sourcePluginPath) {
                systemMoves.append((from: sourcePluginPath, to: finalTargetPath))
            } else {
                normalMoves.append((from: sourcePluginPath, to: finalTargetPath))
            }
        }

        // 批量执行需要权限的移动操作（一次性请求权限）
        if !systemMoves.isEmpty {
            let moveCommands = systemMoves.map { "mv '\($0.from)' '\($0.to)'" }.joined(separator: " && ")
            try await SudoPermissionManager.shared.executeAppleScriptCommand(moveCommands)
            print("✅ 成功批量移动 \(systemMoves.count) 个系统插件")
        }

        // 执行普通移动操作
        for move in normalMoves {
            do {
                try fileManager.moveItem(atPath: move.from, toPath: move.to)
                //print("插件目录移动成功: \(URL(fileURLWithPath: move.from).lastPathComponent)")

                // 验证移动的内容
                _ = try fileManager.contentsOfDirectory(atPath: move.to)
                //print("  移动的文件数量: \(movedContents.count)")
            } catch {
                //print("插件目录移动失败: \(URL(fileURLWithPath: move.from).lastPathComponent) - \(error)")
                throw error
            }
        }
    }

    private func cleanupEmptySourceDirectories(plugins: [FCPXPlugin]) async throws {
        // 收集所有源类别目录
        var sourceCategoryPaths: Set<String> = []

        for plugin in plugins {
            let categoryPath = plugin.categoryPath
            sourceCategoryPaths.insert(categoryPath)
        }

        // 检查并删除空的类别目录
        for categoryPath in sourceCategoryPaths {
            try await cleanupCategoryDirectoryIfEmpty(categoryPath)
        }
    }

    private func cleanupCategoryDirectoryIfEmpty(_ categoryPath: String) async throws {
        guard fileManager.fileExists(atPath: categoryPath) else { return }

        do {
            let contents = try fileManager.contentsOfDirectory(atPath: categoryPath)

            // 过滤掉系统文件
            let relevantContents = contents.filter { !$0.hasPrefix(".") }

            if relevantContents.isEmpty {
                // 目录为空，可以删除
                try fileManager.removeItem(atPath: categoryPath)
                //print("已删除空的源类别目录: \(categoryPath)")
            } else {
                //print("源类别目录不为空，保留: \(categoryPath) (剩余 \(relevantContents.count) 个项目)")
            }
        } catch {
            //print("检查类别目录失败: \(categoryPath) - \(error)")
        }
    }

    private func generateUniquePluginPath(basePath: String, pluginName: String) -> String {
        var counter = 1
        var targetPath = URL(fileURLWithPath: basePath).appendingPathComponent(pluginName).path
        
        while fileManager.fileExists(atPath: targetPath) {
            let uniqueName = "\(pluginName) (\(counter))"
            targetPath = URL(fileURLWithPath: basePath).appendingPathComponent(uniqueName).path
            counter += 1
        }
        
        return targetPath
    }
    
    private func scanCategoryForPlugins(at categoryPath: String) -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []
        
        do {
            let contents = try fileManager.contentsOfDirectory(atPath: categoryPath)
            
            for item in contents {
                let itemPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(item).path
                var isDirectory: ObjCBool = false
                
                if fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory) {
                    if isDirectory.boolValue {
                        // 检查是否为有效的插件目录
                        if isValidPluginDirectory(itemPath) {
                            // 创建插件对象
                            if let plugin = createPluginFromDirectory(itemPath) {
                                plugins.append(plugin)
                            }
                        } else {
                            // 递归扫描主题目录
                            let themePlugins = scanCategoryForPlugins(at: itemPath)
                            plugins.append(contentsOf: themePlugins)
                        }
                    }
                }
            }
        } catch {
            //print("扫描类别目录失败: \(error)")
        }
        
        return plugins
    }
    
    private func isValidPluginDirectory(_ path: String) -> Bool {
        let motionFiles = [".motn", ".moef", ".motr", ".moti", ".mocp"]
        
        do {
            let contents = try fileManager.contentsOfDirectory(atPath: path)
            
            // 检查是否包含Motion模板文件
            for file in contents {
                let fileExtension = URL(fileURLWithPath: file).pathExtension.lowercased()
                if motionFiles.contains(".\(fileExtension)") {
                    return true
                }
            }
            
            // 检查是否包含Media目录
            let mediaPath = URL(fileURLWithPath: path).appendingPathComponent("Media").path
            var isDirectory: ObjCBool = false
            if fileManager.fileExists(atPath: mediaPath, isDirectory: &isDirectory) && isDirectory.boolValue {
                return true
            }
        } catch {
            return false
        }
        
        return false
    }
    
    private func createPluginFromDirectory(_ path: String) -> FCPXPlugin? {
        // 这里需要根据目录路径创建FCPXPlugin对象
        // 简化实现，实际应该解析插件的详细信息
        let pluginName = URL(fileURLWithPath: path).lastPathComponent
        
        // 获取文件信息
        do {
            let attributes = try fileManager.attributesOfItem(atPath: path)
            let _ = attributes[.size] as? Int64 ?? 0
            let _ = attributes[.creationDate] as? Date ?? Date()
            let _ = attributes[.modificationDate] as? Date ?? Date()
            
            // 根据路径推断插件类型和子类型
            let pathComponents = path.components(separatedBy: "/")
            var pluginType: PluginType = .user
            var pluginSubType: PluginSubType = .effects
            
            // 简化的类型推断逻辑
            if pathComponents.contains("Effects") {
                pluginSubType = .effects
            } else if pathComponents.contains("Generators") {
                pluginSubType = .generators
            } else if pathComponents.contains("Titles") {
                pluginSubType = .titles
            } else if pathComponents.contains("Transitions") {
                pluginSubType = .transitions
            }
            
            if pathComponents.contains("System") {
                pluginType = .system
            } else if pathComponents.contains("Built-in") {
                pluginType = .builtin
            }
            
            return FCPXPlugin(
                name: pluginName,
                path: path,
                type: pluginType,
                subType: pluginSubType,
                categoryPath: URL(fileURLWithPath: path).deletingLastPathComponent().path
            )
        } catch {
            //print("创建插件对象失败: \(error)")
            return nil
        }
    }
}
