//
//  BatchOperationManager.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-14.
//

import Foundation
import SwiftUI

// MARK: - 批量操作管理器
@MainActor
class BatchOperationManager: ObservableObject {
    @Published var bufferedPlugins: [FCPXPlugin] = []
    
    /// 添加插件到缓冲区
    func addPlugin(_ plugin: FCPXPlugin) {
        // 检查插件是否已经在缓冲区中
        if !bufferedPlugins.contains(where: { $0.id == plugin.id }) {
            bufferedPlugins.append(plugin)
            print("✅ 插件已添加到批量操作缓冲区: \(plugin.displayName)")
        } else {
            print("ℹ️ 插件已在缓冲区中: \(plugin.displayName)")
        }
    }
    
    /// 从缓冲区移除插件
    func removePlugin(_ plugin: FCPXPlugin) {
        bufferedPlugins.removeAll { $0.id == plugin.id }
        print("🗑️ 插件已从批量操作缓冲区移除: \(plugin.displayName)")
    }
    
    /// 清空缓冲区
    func clearBuffer() {
        let count = bufferedPlugins.count
        bufferedPlugins.removeAll()
        print("🧹 批量操作缓冲区已清空，移除了 \(count) 个插件")
    }
    
    /// 检查插件是否在缓冲区中
    func contains(_ plugin: FCPXPlugin) -> Bool {
        return bufferedPlugins.contains(where: { $0.id == plugin.id })
    }
    
    /// 获取缓冲区中指定类型的插件
    func getPlugins(ofSubType subType: PluginSubType) -> [FCPXPlugin] {
        return bufferedPlugins.filter { $0.subType == subType }
    }
    
    /// 获取缓冲区中的插件类型统计
    func getPluginTypeStats() -> [PluginSubType: Int] {
        var stats: [PluginSubType: Int] = [:]
        for plugin in bufferedPlugins {
            if let subType = plugin.subType {
                stats[subType, default: 0] += 1
            }
        }
        return stats
    }
    
    /// 检查缓冲区中的插件是否都是同一类型
    func areAllPluginsSameType() -> Bool {
        guard !bufferedPlugins.isEmpty else { return true }
        
        let firstSubType = bufferedPlugins.first?.subType
        return bufferedPlugins.allSatisfy { $0.subType == firstSubType }
    }
    
    /// 获取主要插件类型（数量最多的类型）
    func getPrimaryPluginType() -> PluginSubType? {
        let stats = getPluginTypeStats()
        return stats.max(by: { $0.value < $1.value })?.key
    }
    
    /// 检查是否可以进行合并操作
    func canPerformMerge() -> Bool {
        return bufferedPlugins.count >= 2 && areAllPluginsSameType()
    }
    
    /// 检查是否可以进行卸载操作
    func canPerformUninstall() -> Bool {
        return !bufferedPlugins.isEmpty
    }
    
    /// 获取缓冲区总大小
    func getTotalSize() -> Int64 {
        return bufferedPlugins.reduce(0) { $0 + $1.fileSize }
    }
    
    /// 格式化总大小显示
    func getFormattedTotalSize() -> String {
        let totalSize = getTotalSize()
        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: totalSize)
    }
}
