//
//  CategoryMergeManager.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import Foundation
import SwiftUI

// MARK: - 类别合并管理器
@MainActor
class CategoryMergeManager: ObservableObject {
    private let fileManager = FileManager.default
    
    // MARK: - 分析文件冲突
    func analyzeConflicts(
        sourceCategory: String,
        targetCategory: String,
        sourceType: PluginType,
        subType: PluginSubType,
        categoryMapping: [String: String]
    ) async -> [FileConflict] {
        var conflicts: [FileConflict] = []
        
        // 获取源和目标路径
        let sourcePath = buildCategoryPath(
            category: sourceCategory,
            sourceType: sourceType,
            subType: subType,
            categoryMapping: categoryMapping
        )
        
        let targetPath = buildCategoryPath(
            category: targetCategory,
            sourceType: sourceType,
            subType: subType,
            categoryMapping: categoryMapping
        )
        
        guard fileManager.fileExists(atPath: sourcePath),
              fileManager.fileExists(atPath: targetPath) else {
            return conflicts
        }
        
        do {
            // 获取源目录中的所有插件
            let sourcePlugins = try getPluginsInCategory(at: sourcePath)
            let targetPlugins = try getPluginsInCategory(at: targetPath)
            
            // 检查冲突
            for sourcePlugin in sourcePlugins {
                if targetPlugins.contains(where: { $0.name == sourcePlugin.name }) {
                    conflicts.append(FileConflict(
                        fileName: sourcePlugin.name,
                        sourcePath: sourcePlugin.path,
                        targetPath: targetPath + "/" + sourcePlugin.name
                    ))
                }
            }
        } catch {
            print("分析冲突失败: \(error)")
        }
        
        return conflicts
    }
    
    // MARK: - 执行合并操作
    func performMerge(
        operation: CategoryMergeOperation,
        conflicts: [FileConflict],
        finalCategoryName: String,
        categoryMapping: [String: String]
    ) async throws {
        
        let sourcePath = buildCategoryPath(
            category: operation.sourceCategory,
            sourceType: operation.sourceType,
            subType: operation.subType,
            categoryMapping: categoryMapping
        )
        
        let targetPath = buildCategoryPath(
            category: operation.targetCategory,
            sourceType: operation.sourceType,
            subType: operation.subType,
            categoryMapping: categoryMapping
        )
        
        // 1. 处理文件冲突
        try await resolveConflicts(conflicts: conflicts, targetPath: targetPath)
        
        // 2. 移动非冲突文件
        try await moveNonConflictingFiles(from: sourcePath, to: targetPath, conflicts: conflicts)
        
        // 3. 重命名目标类别（如果需要）
        if finalCategoryName != operation.targetCategory {
            try await renameCategory(
                from: targetPath,
                newName: finalCategoryName,
                sourceType: operation.sourceType,
                subType: operation.subType
            )
        }
        
        // 4. 删除源类别目录
        // 检查是否需要管理员权限（系统插件类别）
        if SudoPermissionManager.shared.needsSudoPermission(for: sourcePath) {
            // 系统插件类别需要管理员权限删除
            try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: sourcePath)
        } else {
            // 用户插件类别可以直接删除
            try fileManager.removeItem(atPath: sourcePath)
        }

        // FxFactory缓存已移除，无需清理

        print("合并完成: \(operation.sourceCategory) -> \(finalCategoryName)")
    }
    
    // MARK: - 私有方法
    
    private func buildCategoryPath(
        category: String,
        sourceType: PluginType,
        subType: PluginSubType,
        categoryMapping: [String: String]
    ) -> String {
        let originalCategoryName = categoryMapping[category] ?? category
        let basePath = sourceType.basePath
        let subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(subType.rawValue).path
        return URL(fileURLWithPath: subTypePath).appendingPathComponent(originalCategoryName).path
    }
    
    private func getPluginsInCategory(at categoryPath: String) throws -> [(name: String, path: String)] {
        let contents = try fileManager.contentsOfDirectory(atPath: categoryPath)
        var plugins: [(name: String, path: String)] = []
        
        for item in contents {
            if item.hasPrefix(".") { continue }
            
            let itemPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(item).path
            var isDirectory: ObjCBool = false
            
            if fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory) && isDirectory.boolValue {
                plugins.append((name: item, path: itemPath))
            }
        }
        
        return plugins
    }
    
    private func resolveConflicts(conflicts: [FileConflict], targetPath: String) async throws {
        for conflict in conflicts {
            guard let resolution = conflict.resolution else { continue }
            
            switch resolution {
            case .keepSource:
                // 删除目标文件，保留源文件
                let targetFilePath = URL(fileURLWithPath: targetPath).appendingPathComponent(conflict.fileName).path
                if fileManager.fileExists(atPath: targetFilePath) {
                    try fileManager.removeItem(atPath: targetFilePath)
                }
                
            case .keepTarget:
                // 跳过源文件，保留目标文件
                continue
                
            case .keepBoth:
                // 重命名源文件
                let sourceName = conflict.fileName
                let newName = generateUniqueFileName(baseName: sourceName, in: targetPath)
                let sourceURL = URL(fileURLWithPath: conflict.sourcePath)
                let newSourcePath = sourceURL.deletingLastPathComponent().appendingPathComponent(newName).path
                try fileManager.moveItem(atPath: conflict.sourcePath, toPath: newSourcePath)
                
            case .askEachTime:
                // 这种情况应该在UI层处理
                break
            }
        }
    }
    
    private func moveNonConflictingFiles(from sourcePath: String, to targetPath: String, conflicts: [FileConflict]) async throws {
        let sourcePlugins = try getPluginsInCategory(at: sourcePath)
        let conflictNames = Set(conflicts.map { $0.fileName })

        for plugin in sourcePlugins {
            if !conflictNames.contains(plugin.name) {
                // 检查是否为FxFactory插件
                let fxfactoryPlistPath = plugin.path + "/.fxfactory.plist"
                let isFxFactoryPlugin = FileManager.default.fileExists(atPath: fxfactoryPlistPath)
                var finalPluginName = plugin.name

                var currentPluginPath = plugin.path

                if isFxFactoryPlugin {
                    print("🔄 处理FxFactory插件合并: \(plugin.name)")

                    // 1. 获取真实文件名
                    finalPluginName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: plugin.path)
                    print("✅ 获取到真实文件名: \(plugin.name) -> \(finalPluginName)")

                    // 2. 还原主插件文件名为真实名称
                    if let restoredName = try await FxFactoryProtectionManager.shared.restoreRealFileName(at: plugin.path) {
                        finalPluginName = restoredName
                        // 更新当前插件路径为还原后的路径
                        let parentURL = URL(fileURLWithPath: plugin.path).deletingLastPathComponent()
                        currentPluginPath = parentURL.appendingPathComponent(restoredName).path
                        print("✅ 已还原文件名: \(plugin.name) -> \(restoredName)")
                    }

                    // 3. 删除特征文件和隐藏文件（.localized、.fxfactory.plist等）
                    try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: currentPluginPath)
                    print("✅ 已删除特征文件和隐藏文件")

                    // 4. 删除FxFactory管理文件（.fxpack和.fxtemplates）
                    let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                        categoryRealName: finalPluginName,
                        operation: .merge
                    )
                    print("✅ 已删除FxFactory管理文件")
                }

                let targetPluginPath = URL(fileURLWithPath: targetPath).appendingPathComponent(finalPluginName).path

                // 如果目标路径已存在，生成唯一名称
                var finalTargetPath = targetPluginPath
                if fileManager.fileExists(atPath: targetPluginPath) {
                    finalTargetPath = generateUniqueFileName(baseName: finalPluginName, in: targetPath)
                }

                // 检查是否需要管理员权限
                if SudoPermissionManager.shared.needsSudoPermission(for: currentPluginPath) {
                    // 系统插件需要管理员权限移动
                    try await SudoPermissionManager.shared.executeAppleScriptCommand("mv '\(currentPluginPath)' '\(finalTargetPath)'")
                    print("✅ 已移动系统插件: \(finalPluginName) -> \(finalTargetPath)")
                } else {
                    // 用户插件可以直接移动
                    try fileManager.moveItem(atPath: currentPluginPath, toPath: finalTargetPath)
                    print("✅ 已移动插件: \(finalPluginName) -> \(finalTargetPath)")
                }
            }
        }
    }
    
    private func renameCategory(from currentPath: String, newName: String, sourceType: PluginType, subType: PluginSubType) async throws {
        let parentPath = URL(fileURLWithPath: currentPath).deletingLastPathComponent().path
        let newPath = URL(fileURLWithPath: parentPath).appendingPathComponent(newName).path

        // 检查是否需要管理员权限（系统插件类别）
        if SudoPermissionManager.shared.needsSudoPermission(for: currentPath) {
            // 系统插件类别需要管理员权限进行重命名
            try await SudoPermissionManager.shared.renameFileWithSudoPermission(
                from: currentPath,
                to: newPath
            )
        } else {
            // 用户插件类别可以直接重命名
            try fileManager.moveItem(atPath: currentPath, toPath: newPath)
        }
    }
    
    private func generateUniqueFileName(baseName: String, in directoryPath: String) -> String {
        var counter = 1
        var newName = baseName

        while fileManager.fileExists(atPath: URL(fileURLWithPath: directoryPath).appendingPathComponent(newName).path) {
            let nameWithoutExtension = URL(fileURLWithPath: baseName).deletingPathExtension().lastPathComponent
            let pathExtension = URL(fileURLWithPath: baseName).pathExtension

            if pathExtension.isEmpty {
                newName = "\(nameWithoutExtension) \(counter)"
            } else {
                newName = "\(nameWithoutExtension) \(counter).\(pathExtension)"
            }
            counter += 1
        }

        return newName
    }



    /// 删除目录中的所有隐藏文件
    private func removeHiddenFiles(in directoryURL: URL) async throws {
        print("🔄 删除隐藏文件: \(directoryURL.path)")

        let contents = try fileManager.contentsOfDirectory(at: directoryURL, includingPropertiesForKeys: nil, options: [])

        for itemURL in contents {
            let fileName = itemURL.lastPathComponent

            // 删除以.开头的隐藏文件（但保留.motn等必要文件）
            if fileName.hasPrefix(".") && !fileName.hasSuffix(".motn") && !fileName.hasSuffix(".moef") && !fileName.hasSuffix(".moti") && !fileName.hasSuffix(".motr") {
                try fileManager.removeItem(at: itemURL)
                print("✅ 已删除隐藏文件: \(fileName)")
            }

            // 递归处理子目录
            var isDirectory: ObjCBool = false
            if fileManager.fileExists(atPath: itemURL.path, isDirectory: &isDirectory), isDirectory.boolValue {
                try await removeHiddenFiles(in: itemURL)
            }
        }
    }
}

// MARK: - 合并预览信息
struct MergePreview {
    let sourcePluginCount: Int
    let targetPluginCount: Int
    let conflictCount: Int
    let finalPluginCount: Int
    
    var hasConflicts: Bool {
        conflictCount > 0
    }
    
    var summary: String {
        if hasConflicts {
            return "将合并 \(sourcePluginCount) 个插件，发现 \(conflictCount) 个冲突"
        } else {
            return "将合并 \(sourcePluginCount) 个插件，无冲突"
        }
    }
}

// MARK: - 合并结果
struct MergeResult {
    let success: Bool
    let movedFiles: Int
    let conflictsResolved: Int
    let errors: [Error]

    var summary: String {
        if success {
            return "成功合并 \(movedFiles) 个插件，解决 \(conflictsResolved) 个冲突"
        } else {
            return "合并失败，遇到 \(errors.count) 个错误"
        }
    }
}
