//
//  CategorySelectionManager.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-14.
//

import Foundation
import SwiftUI

/// 类别多选管理器
class CategorySelectionManager: ObservableObject {
    @Published var selectedCategories: Set<CategoryInfo> = []
    @Published var isMultiSelectMode: Bool = false
    
    /// 类别信息结构
    struct CategoryInfo: Hashable, Identifiable {
        let id = UUID()
        let categoryPath: String
        let displayName: String
        let subType: PluginSubType
        let sourceType: PluginType
        let pluginCount: Int
        
        func hash(into hasher: inout Hasher) {
            hasher.combine(categoryPath)
            hasher.combine(subType)
            hasher.combine(sourceType)
        }
        
        static func == (lhs: CategoryInfo, rhs: CategoryInfo) -> Bool {
            return lhs.categoryPath == rhs.categoryPath &&
                   lhs.subType == rhs.subType &&
                   lhs.sourceType == rhs.sourceType
        }
    }
    
    /// 切换多选模式
    func toggleMultiSelectMode() {
        isMultiSelectMode.toggle()
        if !isMultiSelectMode {
            selectedCategories.removeAll()
        }
    }
    
    /// 切换类别选择状态
    func toggleSelection(for category: CategoryInfo) {
        if selectedCategories.contains(category) {
            selectedCategories.remove(category)
            print("🔄 取消选择类别: \(category.displayName)")
        } else {
            selectedCategories.insert(category)
            print("🔄 选择类别: \(category.displayName) (路径: \(category.categoryPath))")
        }
        print("📊 当前选中 \(selectedCategories.count) 个类别")
    }
    
    /// 清空选择
    func clearSelection() {
        selectedCategories.removeAll()
    }
    
    /// 检查类别是否被选中
    func isSelected(_ category: CategoryInfo) -> Bool {
        return selectedCategories.contains(category)
    }
    
    /// 检查是否可以进行批量合并
    func canPerformBatchMerge() -> Bool {
        guard selectedCategories.count >= 2 else { return false }
        
        // 检查所有选中的类别是否为相同类型
        let firstCategory = selectedCategories.first!
        return selectedCategories.allSatisfy { category in
            category.subType == firstCategory.subType &&
            category.sourceType == firstCategory.sourceType
        }
    }
    
    /// 检查是否可以进行批量卸载
    func canPerformBatchUninstall() -> Bool {
        return !selectedCategories.isEmpty
    }
    
    /// 获取选中类别的总插件数量
    func getTotalPluginCount() -> Int {
        return selectedCategories.reduce(0) { $0 + $1.pluginCount }
    }
    
    /// 获取选中类别的类型统计
    func getTypeStats() -> [PluginSubType: Int] {
        var stats: [PluginSubType: Int] = [:]
        for category in selectedCategories {
            stats[category.subType, default: 0] += 1
        }
        return stats
    }
}
