//
//  FxFactoryProtectionManager.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/5.
//

import Foundation
import AppKit

// MARK: - FxFactory防护管理器（新的简化版本）
@MainActor
class FxFactoryProtectionManager: ObservableObject {
    /// FxFactory状态
    enum FxFactoryStatus {
        case notInstalled
        case running
        case ready
        case disabled
    }

    // MARK: - 单例
    static let shared = FxFactoryProtectionManager()

    // MARK: - 属性
    private let fileManager = FileManager.default
    @Published var isProcessing = false
    @Published var progressMessage = ""
    @Published var currentStatus: FxFactoryStatus = .notInstalled

    // FxFactory相关路径
    private let fxFactoryPath = "/Library/Application Support/FxFactory"

    private init() {}

    // MARK: - 公共接口

    /// 检查FxFactory状态
    func checkFxFactoryStatus() async -> FxFactoryStatus {
        // 检查FxFactory是否安装
        guard fileManager.fileExists(atPath: "/Applications/FxFactory.app") else {
            currentStatus = .notInstalled
            return currentStatus
        }

        // 检查FxFactory是否正在运行
        let runningApps = NSWorkspace.shared.runningApplications
        let isFxFactoryRunning = runningApps.contains { app in
            app.bundleIdentifier == "com.fxfactory.FxFactory" ||
            app.localizedName?.contains("FxFactory") == true
        }

        if isFxFactoryRunning {
            currentStatus = .running
        } else {
            currentStatus = .ready
        }

        return currentStatus
    }

    /// 对FxFactory插件执行防护操作（新的简化版本）
    /// - Parameters:
    ///   - categoryRealName: 类别目录的真实文件名（从.localized/en.strings获取）
    ///   - operation: 操作类型（重命名、卸载、合并）
    /// - Returns: 操作结果
    func protectFxFactoryPlugin(categoryRealName: String, operation: FxFactoryOperation) async throws -> FxFactoryProtectionResult {
        print("🛡️ ========== FxFactory防护操作开始 ==========")
        print("🛡️ 类别真实名称: \(categoryRealName)")
        print("🛡️ 操作类型: \(operation)")

        isProcessing = true
        progressMessage = "正在进行FxFactory自动重装防护..."
        defer {
            isProcessing = false
            print("🛡️ ========== FxFactory防护操作结束 ==========")
        }

        // 1. 查找FxFactory管理文件
        let fxFactoryFiles = findFxFactoryFiles(for: categoryRealName)
        print("🔍 找到 \(fxFactoryFiles.count) 个FxFactory管理文件")

        if fxFactoryFiles.isEmpty {
            print("ℹ️ 未找到相关的FxFactory管理文件，可能不是FxFactory插件")
            return FxFactoryProtectionResult(
                success: true,
                removedFiles: [],
                message: "未找到相关的FxFactory管理文件"
            )
        }

        // 2. 批量删除FxFactory管理文件（一次性请求管理员权限）
        var removedFiles: [String] = []
        if !fxFactoryFiles.isEmpty {
            do {
                // 使用AppleScript进行批量删除
                let escapedPaths = fxFactoryFiles.map { "'\($0)'" }.joined(separator: " ")
                try await executeAppleScriptCommand("rm -rf \(escapedPaths)")
                removedFiles = fxFactoryFiles
                for filePath in fxFactoryFiles {
                    print("✅ 成功删除FxFactory管理文件: \(filePath)")
                }
            } catch {
                print("❌ 批量删除FxFactory管理文件失败: \(error)")
            }
        }

        let result = FxFactoryProtectionResult(
            success: true,
            removedFiles: removedFiles,
            message: "成功删除 \(removedFiles.count) 个FxFactory管理文件"
        )

        print("🎉 FxFactory防护操作完成！删除了 \(removedFiles.count) 个文件")
        return result
    }

    /// 从FxFactory插件路径获取类别的真实名称
    /// - Parameter pluginPath: FxFactory插件路径
    /// - Returns: 类别的真实名称，如果无法获取则返回原始文件名
    func getCategoryRealName(from pluginPath: String) async -> String {
        print("🔍 开始获取FxFactory插件的真实名称: \(pluginPath)")

        let pluginURL = URL(fileURLWithPath: pluginPath)
        let pluginName = pluginURL.lastPathComponent

        // 检查是否为FxFactory插件（检查.fxfactory.plist文件）
        let fxfactoryPlistPath = pluginURL.appendingPathComponent(".fxfactory.plist").path
        guard fileManager.fileExists(atPath: fxfactoryPlistPath) else {
            print("ℹ️ 不是FxFactory插件，返回原始名称")
            return pluginName
        }

        let uuid = pluginName.replacingOccurrences(of: ".localized", with: "")

        // 读取 .localized/en.strings 文件获取真实名称
        let stringsPath = pluginURL.appendingPathComponent(".localized").appendingPathComponent("en.strings").path

        guard fileManager.fileExists(atPath: stringsPath) else {
            print("❌ 未找到 en.strings 文件: \(stringsPath)")
            return uuid
        }

        guard let data = fileManager.contents(atPath: stringsPath),
              let content = String(data: data, encoding: .utf8) else {
            print("❌ 无法读取 en.strings 文件内容")
            return uuid
        }

        // 解析strings文件格式: "UUID" = "Display Name";
        let pattern = "\"\(uuid)\"\\s*=\\s*\"([^\"]+)\""
        if let regex = try? NSRegularExpression(pattern: pattern),
           let match = regex.firstMatch(in: content, range: NSRange(content.startIndex..., in: content)),
           let range = Range(match.range(at: 1), in: content) {
            let realName = String(content[range])
            print("✅ 获取到真实名称: \(realName)")
            return realName
        }

        print("⚠️ 无法解析真实名称，返回UUID")
        return uuid
    }

    /// 还原FxFactory插件的真实文件名
    /// - Parameter pluginPath: FxFactory插件路径
    /// - Returns: 还原后的真实文件名，如果失败则返回nil
    func restoreRealFileName(at pluginPath: String) async throws -> String? {
        print("🔄 开始还原FxFactory插件真实文件名: \(pluginPath)")

        let pluginURL = URL(fileURLWithPath: pluginPath)
        let pluginName = pluginURL.lastPathComponent

        // 检查是否为FxFactory插件（检查.fxfactory.plist文件）
        let fxfactoryPlistPath = pluginURL.appendingPathComponent(".fxfactory.plist").path
        guard fileManager.fileExists(atPath: fxfactoryPlistPath) else {
            print("ℹ️ 不是FxFactory插件，无需还原")
            return nil
        }

        // 获取真实名称
        let realName = await getCategoryRealName(from: pluginPath)
        let uuid = pluginName.replacingOccurrences(of: ".localized", with: "")

        // 如果真实名称和UUID相同，说明没有获取到真实名称
        if realName == uuid {
            print("⚠️ 无法获取真实名称，跳过还原")
            return nil
        }

        // 构建新的路径
        let parentURL = pluginURL.deletingLastPathComponent()
        let newPluginURL = parentURL.appendingPathComponent(realName)

        // 检查目标路径是否已存在
        if fileManager.fileExists(atPath: newPluginURL.path) {
            print("⚠️ 目标路径已存在，跳过还原: \(newPluginURL.path)")
            return nil
        }

        // 重命名插件目录
        do {
            try fileManager.moveItem(at: pluginURL, to: newPluginURL)
            print("✅ 成功还原文件名: \(pluginName) -> \(realName)")
            return realName
        } catch {
            print("❌ 还原文件名失败: \(error)")
            throw error
        }
    }

    /// 将FxFactory插件还原为普通插件
    /// - Parameter pluginPath: 插件路径
    func restoreToNormalPlugin(at pluginPath: String) async throws {
        print("🔄 开始还原FxFactory插件为普通插件: \(pluginPath)")

        let pluginURL = URL(fileURLWithPath: pluginPath)

        // 1. 删除.localized目录
        let localizedURL = pluginURL.appendingPathComponent(".localized")
        if fileManager.fileExists(atPath: localizedURL.path) {
            try fileManager.removeItem(at: localizedURL)
            print("✅ 已删除.localized目录")
        }

        // 2. 删除.fxfactory.plist文件
        let plistURL = pluginURL.appendingPathComponent(".fxfactory.plist")
        if fileManager.fileExists(atPath: plistURL.path) {
            try fileManager.removeItem(at: plistURL)
            print("✅ 已删除.fxfactory.plist文件")
        }

        // 3. 删除所有隐藏文件（以.开头的文件）
        try await removeHiddenFiles(in: pluginURL)

        print("✅ FxFactory插件还原为普通插件完成")
    }

    /// 删除目录中的所有隐藏文件
    private func removeHiddenFiles(in directoryURL: URL) async throws {
        print("🔄 删除隐藏文件: \(directoryURL.path)")

        let contents = try fileManager.contentsOfDirectory(at: directoryURL, includingPropertiesForKeys: nil, options: [])

        for itemURL in contents {
            let fileName = itemURL.lastPathComponent

            // 删除以.开头的隐藏文件（但保留.motn等必要文件）
            if fileName.hasPrefix(".") && !fileName.hasSuffix(".motn") && !fileName.hasSuffix(".moef") && !fileName.hasSuffix(".moti") && !fileName.hasSuffix(".motr") {
                try fileManager.removeItem(at: itemURL)
                print("✅ 已删除隐藏文件: \(fileName)")
            }

            // 递归处理子目录
            var isDirectory: ObjCBool = false
            if fileManager.fileExists(atPath: itemURL.path, isDirectory: &isDirectory), isDirectory.boolValue {
                try await removeHiddenFiles(in: itemURL)
            }
        }
    }

    // MARK: - 私有方法

    /// 查找与插件相关的FxFactory管理文件
    /// - Parameter categoryRealName: 类别的真实文件名
    /// - Returns: 找到的FxFactory管理文件路径数组
    private func findFxFactoryFiles(for categoryRealName: String) -> [String] {
        var foundFiles: [String] = []

        guard fileManager.fileExists(atPath: fxFactoryPath) else {
            print("❌ FxFactory目录不存在: \(fxFactoryPath)")
            return foundFiles
        }

        do {
            let contents = try fileManager.contentsOfDirectory(atPath: fxFactoryPath)

            for item in contents {
                let itemPath = fxFactoryPath + "/" + item

                // 查找 .fxpack 和 .fxtemplates 文件，确保完全匹配文件名
                let expectedFxpackName = "\(categoryRealName).fxpack"
                let expectedFxtemplatesName = "\(categoryRealName).fxtemplates"

                if item == expectedFxpackName || item == expectedFxtemplatesName {
                    foundFiles.append(itemPath)
                    print("🔍 找到FxFactory管理文件: \(item)")
                }
            }
        } catch {
            print("❌ 读取FxFactory目录失败: \(error)")
        }

        return foundFiles
    }

    /// 执行需要管理员权限的AppleScript命令
    private func executeAppleScriptCommand(_ command: String) async throws {
        return try await withCheckedThrowingContinuation { continuation in
            DispatchQueue.main.async {
                let script = """
                do shell script "\(command)" with administrator privileges
                """

                guard let appleScript = NSAppleScript(source: script) else {
                    continuation.resume(throwing: FxFactoryError.deletionFailed("无法创建AppleScript"))
                    return
                }

                var errorDict: NSDictionary?
                _ = appleScript.executeAndReturnError(&errorDict)

                if let error = errorDict {
                    let errorMessage = error["NSAppleScriptErrorMessage"] as? String ?? "未知错误"
                    if errorMessage.contains("User canceled") {
                        continuation.resume(throwing: FxFactoryError.userCancelled)
                    } else {
                        continuation.resume(throwing: FxFactoryError.deletionFailed(errorMessage))
                    }
                    return
                }

                continuation.resume()
            }
        }
    }

}

// MARK: - 枚举和结构体定义

/// FxFactory操作类型
enum FxFactoryOperation {
    case rename     // 重命名
    case remove     // 移除/卸载
    case merge      // 合并
}

/// FxFactory防护操作结果
struct FxFactoryProtectionResult {
    let success: Bool
    let removedFiles: [String]
    let message: String
}

/// FxFactory错误类型
enum FxFactoryError: LocalizedError, Equatable {
    case adminPrivilegesRequired
    case userCancelled
    case deletionFailed(String)
    case notFxFactoryPlugin

    var errorDescription: String? {
        switch self {
        case .adminPrivilegesRequired:
            return "需要管理员权限来删除FxFactory管理文件"
        case .userCancelled:
            return "用户取消了权限请求"
        case .deletionFailed(let message):
            return "删除失败: \(message)"
        case .notFxFactoryPlugin:
            return "不是FxFactory插件"
        }
    }

    var recoverySuggestion: String? {
        switch self {
        case .adminPrivilegesRequired:
            return "请在权限对话框中点击允许"
        case .userCancelled:
            return "请重新尝试并在权限对话框中点击允许"
        case .deletionFailed:
            return "请检查文件是否被其他程序占用"
        case .notFxFactoryPlugin:
            return "此操作仅适用于FxFactory插件"
        }
    }

    // 实现 Equatable 协议
    static func == (lhs: FxFactoryError, rhs: FxFactoryError) -> Bool {
        switch (lhs, rhs) {
        case (.adminPrivilegesRequired, .adminPrivilegesRequired):
            return true
        case (.userCancelled, .userCancelled):
            return true
        case (.deletionFailed(let lhsMessage), .deletionFailed(let rhsMessage)):
            return lhsMessage == rhsMessage
        case (.notFxFactoryPlugin, .notFxFactoryPlugin):
            return true
        default:
            return false
        }
    }
}
