//
//  SimpleAuthorizationManager.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-15.
//

import Foundation
import AppKit

// MARK: - 简化的权限会话管理器
@MainActor
class SimpleAuthorizationManager: ObservableObject {
    static let shared = SimpleAuthorizationManager()

    @Published var isAuthorized = false
    @Published var isRequestingPermission = false
    @Published var lastError: String?

    private var sessionStartTime: Date?
    private let sessionTimeout: TimeInterval = 300 // 5分钟会话超时
    // private var refreshTimer: Timer? // 移除定时器

    // 存储已授权的AppleScript，避免重复请求密码
    private var authorizedScript: NSAppleScript?

    private init() {}
    
    // MARK: - 权限管理
    
    /// 检查权限会话是否有效
    private func isSessionValid() -> Bool {
        guard let sessionStartTime = sessionStartTime else {
            return false
        }
        
        // 检查会话是否超时
        let elapsed = Date().timeIntervalSince(sessionStartTime)
        if elapsed > sessionTimeout {
            print("⏰ 权限会话已超时，需要重新授权")
            _invalidateSession()  // 直接调用内部方法，因为我们已经在主线程上
            return false
        }
        
        return isAuthorized
    }
    
    /// 请求管理员权限（使用Authorization Services）
    func requestAuthorization() async throws {
        // 检查现有会话是否仍然有效
        if isSessionValid() {
            print("✅ 使用现有的权限会话")
            return
        }

        isRequestingPermission = true
        defer { isRequestingPermission = false }

        do {
            try await createAuthorizationRef()
            sessionStartTime = Date()
            isAuthorized = true
            lastError = nil
            // startRefreshTimer() // 移除定时刷新
            print("✅ 权限授权成功，会话开始时间: \(sessionStartTime!)")
        } catch {
            lastError = error.localizedDescription
            isAuthorized = false
            print("❌ 权限授权失败: \(error.localizedDescription)")
            throw error
        }
    }
    
    /// 创建并测试权限授权
    private func createAuthorizationRef() async throws {
        return try await withCheckedThrowingContinuation { continuation in
            DispatchQueue.main.async {
                // 创建一个测试脚本来获取权限
                let testScript = """
                do shell script "echo 'Authorization test successful'" with administrator privileges
                """

                guard let appleScript = NSAppleScript(source: testScript) else {
                    continuation.resume(throwing: SimpleAuthorizationError.executionFailed("无法创建AppleScript"))
                    return
                }

                var errorDict: NSDictionary?
                _ = appleScript.executeAndReturnError(&errorDict)

                if let error = errorDict {
                    let errorMessage = error["NSAppleScriptErrorMessage"] as? String ?? "未知错误"
                    if errorMessage.contains("User canceled") {
                        continuation.resume(throwing: SimpleAuthorizationError.userCancelled)
                    } else {
                        continuation.resume(throwing: SimpleAuthorizationError.executionFailed(errorMessage))
                    }
                    return
                }

                // 权限获取成功，保存这个已授权的脚本实例
                self.authorizedScript = appleScript
                print("✅ 权限授权成功，已保存授权脚本")
                continuation.resume()
            }
        }
    }



    /// 使用现有权限执行shell命令
    func executeCommand(_ command: String, password: String) async throws {
        print("🔧 准备执行命令: \(command)")

        // 确保有有效的权限会话
        try await requestAuthorization()

        print("🔧 权限验证通过，开始执行命令")

        return try await withCheckedThrowingContinuation { continuation in
            DispatchQueue.global().async {
                let sudoCommand = "echo \"\(password)\" | sudo -S \(command)"
                let process = Process()
                process.launchPath = "/bin/bash"
                process.arguments = ["-c", sudoCommand]

                let pipe = Pipe()
                process.standardOutput = pipe
                process.standardError = pipe

                process.launch()
                process.waitUntilExit()

                let data = pipe.fileHandleForReading.readDataToEndOfFile()
                let output = String(data: data, encoding: .utf8) ?? ""

                if process.terminationStatus == 0 {
                    print("✅ 命令执行成功")
                    continuation.resume()
                } else {
                    continuation.resume(throwing: SimpleAuthorizationError.executionFailed("命令执行失败: \(output)"))
                }
            }
        }
    }
    
                                                                                                                                        /// 删除文件（使用权限会话）
    func deleteFile(at path: String, password: String) async throws {
        let command = "rm -rf '\(path)'"
        try await executeCommand(command, password: password)
        
        // 验证文件是否已删除
        if FileManager.default.fileExists(atPath: path) {
            throw SimpleAuthorizationError.operationFailed("文件删除失败，文件仍然存在")
        }
        
        print("✅ 成功删除文件: \(path)")
    }
    
    /// 重命名文件（使用权限会话）
    func renameFile(from oldPath: String, to newPath: String, password: String) async throws {
        let command = "mv '\(oldPath)' '\(newPath)'"
        try await executeCommand(command, password: password)
        
        // 验证重命名是否成功
        if !FileManager.default.fileExists(atPath: newPath) {
            throw SimpleAuthorizationError.operationFailed("文件重命名失败，目标文件不存在")
        }
        if FileManager.default.fileExists(atPath: oldPath) {
            throw SimpleAuthorizationError.operationFailed("文件重命名失败，原文件仍然存在")
        }
        
        print("✅ 成功重命名文件: \(oldPath) -> \(newPath)")
    }
    
    /// 批量删除文件（使用权限会话）
    func deleteFiles(_ paths: [String], password: String) async throws {
        guard !paths.isEmpty else { return }
        
        let escapedPaths = paths.map { "'\($0)'" }.joined(separator: " ")
        let command = "rm -rf \(escapedPaths)"
        try await executeCommand(command, password: password)
        
        print("✅ 成功批量删除 \(paths.count) 个文件")
    }
    
    /// 使权限会话失效
    func invalidateSession() {
        if Thread.isMainThread {
            _invalidateSession()
        } else {
            DispatchQueue.main.sync {
                _invalidateSession()
            }
        }
    }

    private func _invalidateSession() {
        sessionStartTime = nil
        isAuthorized = false
        authorizedScript = nil
        print("🔒 权限会话已失效")
    }
    
    /// 清除错误状态
    func clearError() {
        lastError = nil
    }
}

// MARK: - 错误类型
enum SimpleAuthorizationError: LocalizedError {
    case userCancelled
    case executionFailed(String)
    case operationFailed(String)
    
    var errorDescription: String? {
        switch self {
        case .userCancelled:
            return "用户取消了权限请求"
        case .executionFailed(let message):
            return "命令执行失败: \(message)"
        case .operationFailed(let message):
            return "操作失败: \(message)"
        }
    }
    
    var recoverySuggestion: String? {
        switch self {
        case .userCancelled:
            return "请重新尝试并在权限对话框中输入管理员密码"
        case .executionFailed, .operationFailed:
            return "请检查文件是否被其他程序占用或路径是否正确"
        }
    }
}
