//
//  SizeCacheManager.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/5.
//

import Foundation

// MARK: - 体积缓存管理器
class SizeCacheManager: ObservableObject {
    static let shared = SizeCacheManager()

    private var cache: [String: Int64] = [:]
    private var loadingPaths: Set<String> = []
    private let queue = DispatchQueue(label: "com.dayu.sizecache", qos: .utility, attributes: .concurrent)
    private let lock = NSLock() // 额外的锁保护

    private init() {}

    func getSize(for path: String) -> Int64? {
        return queue.sync { [weak self] in
            guard let self = self else { return nil }
            return self.cache[path]
        }
    }

    func setSize(_ size: Int64, for path: String) {
        queue.async(flags: .barrier) { [weak self] in
            guard let self = self else { return }
            self.lock.lock()
            defer { self.lock.unlock() }
            self.cache[path] = size
        }
    }

    func isLoading(_ path: String) -> Bool {
        return queue.sync { [weak self] in
            guard let self = self else { return false }
            return self.loadingPaths.contains(path)
        }
    }

    func setLoading(_ path: String, loading: Bool) {
        queue.async(flags: .barrier) { [weak self] in
            guard let self = self else { return }
            self.lock.lock()
            defer { self.lock.unlock() }
            if loading {
                self.loadingPaths.insert(path)
            } else {
                self.loadingPaths.remove(path)
            }
        }
    }
    
    func clearCache() {
        queue.async(flags: .barrier) { [weak self] in
            guard let self = self else { return }
            self.lock.lock()
            defer { self.lock.unlock() }
            self.cache.removeAll()
            self.loadingPaths.removeAll()
        }
    }

    func removeCache(for path: String) {
        queue.async(flags: .barrier) { [weak self] in
            guard let self = self else { return }
            self.lock.lock()
            defer { self.lock.unlock() }
            self.cache.removeValue(forKey: path)
            self.loadingPaths.remove(path)
        }
    }
}
