//
//  SudoPermissionManager.swift
//  TemmplatesArchive
//
//  Created by AI Assistant on 2025/7/8.
//

import Foundation
import AppKit

// MARK: - Sudo权限管理器
class SudoPermissionManager: ObservableObject {
    static let shared = SudoPermissionManager()

    @Published var isRequestingPermission = false
    @Published var lastError: String?

    private init() {}

    // MARK: - 请求管理员权限并执行文件删除
    func deleteFileWithSudoPermission(at path: String) async throws {
        await MainActor.run {
            isRequestingPermission = true
            lastError = nil
        }

        defer {
            Task { @MainActor in
                isRequestingPermission = false
            }
        }

        do {
            // 直接使用AppleScript删除文件
            try await executeAppleScriptCommand("rm -rf '\(path)'")
            print("✅ 成功删除系统插件: \(path)")
        } catch {
            let errorMessage = "删除系统插件失败: \(error.localizedDescription)"
            await MainActor.run {
                lastError = errorMessage
            }
            print("❌ \(errorMessage)")
            throw error
        }
    }

    // MARK: - 请求管理员权限并执行文件重命名
    func renameFileWithSudoPermission(from oldPath: String, to newPath: String) async throws {
        await MainActor.run {
            isRequestingPermission = true
            lastError = nil
        }

        defer {
            Task { @MainActor in
                isRequestingPermission = false
            }
        }

        do {
            // 直接使用AppleScript重命名文件
            try await executeAppleScriptCommand("mv '\(oldPath)' '\(newPath)'")
            print("✅ 成功重命名系统插件: \(oldPath) -> \(newPath)")
        } catch {
            let errorMessage = "重命名系统插件失败: \(error.localizedDescription)"
            await MainActor.run {
                lastError = errorMessage
            }
            print("❌ \(errorMessage)")
            throw error
        }
    }

    // MARK: - 批量删除文件（使用权限会话）
    func deleteFilesWithSudoPermission(_ paths: [String]) async throws {
        guard !paths.isEmpty else { return }

        await MainActor.run {
            isRequestingPermission = true
            lastError = nil
        }

        defer {
            Task { @MainActor in
                isRequestingPermission = false
            }
        }

        do {
            // 直接使用AppleScript批量删除文件
            let escapedPaths = paths.map { "'\($0)'" }.joined(separator: " ")
            try await executeAppleScriptCommand("rm -rf \(escapedPaths)")
            print("✅ 成功批量删除 \(paths.count) 个文件")
        } catch {
            let errorMessage = "批量删除文件失败: \(error.localizedDescription)"
            await MainActor.run {
                lastError = errorMessage
            }
            print("❌ \(errorMessage)")
            throw error
        }
    }

    // MARK: - 私有方法

    /// 执行需要管理员权限的AppleScript命令
    func executeAppleScriptCommand(_ command: String) async throws {
        return try await withCheckedThrowingContinuation { continuation in
            DispatchQueue.main.async {
                let script = """
                do shell script "\(command)" with administrator privileges
                """

                guard let appleScript = NSAppleScript(source: script) else {
                    continuation.resume(throwing: SudoPermissionError.scriptCreationFailed)
                    return
                }

                var errorDict: NSDictionary?
                _ = appleScript.executeAndReturnError(&errorDict)

                if let error = errorDict {
                    let errorMessage = error["NSAppleScriptErrorMessage"] as? String ?? "未知错误"
                    if errorMessage.contains("User canceled") {
                        continuation.resume(throwing: SudoPermissionError.userCancelled)
                    } else {
                        continuation.resume(throwing: SudoPermissionError.executionFailed(errorMessage))
                    }
                    return
                }

                continuation.resume()
            }
        }
    }

    // MARK: - 检查是否需要sudo权限
    func needsSudoPermission(for path: String) -> Bool {
        // FxPlug插件位于系统目录，需要管理员权限
        // 系统插件位于系统目录，也需要管理员权限
        return path.hasPrefix("/Library/Plug-Ins/FxPlug") ||
               path.hasPrefix("/System/") ||
               path.hasPrefix("/Library/Application Support/Final Cut Pro/Templates.localized") ||
               (path.hasPrefix("/Library/") && !path.hasPrefix("/Library/Application Support/"))
    }
    
    // MARK: - 清除错误状态
    func clearError() {
        lastError = nil
    }
}

// MARK: - 错误类型
enum SudoPermissionError: LocalizedError {
    case scriptCreationFailed
    case userCancelled
    case executionFailed(String)

    var errorDescription: String? {
        switch self {
        case .scriptCreationFailed:
            return "无法创建AppleScript"
        case .userCancelled:
            return "用户取消了权限请求"
        case .executionFailed(let message):
            return "命令执行失败: \(message)"
        }
    }
}

// MARK: - 错误类型
enum SudoError: LocalizedError {
    case userCancelled
    case executionFailed(String)

    var errorDescription: String? {
        switch self {
        case .userCancelled:
            return "用户取消了权限请求"
        case .executionFailed(let message):
            return "执行失败: \(message)"
        }
    }

    var recoverySuggestion: String? {
        switch self {
        case .userCancelled:
            return "请重新尝试并在权限对话框中点击允许"
        case .executionFailed:
            return "请检查文件是否被其他程序占用"
        }
    }
}
