//
//  SystemCompatibilityManager.swift
//  TemmplatesArchive
//
//  Created by AI Assistant on 2025/7/8.
//

import Foundation
import SwiftUI

// MARK: - 系统兼容性管理器
class SystemCompatibilityManager: ObservableObject {
    static let shared = SystemCompatibilityManager()
    
    @Published var compatibilityIssues: [CompatibilityIssue] = []
    @Published var systemInfo: SystemInfo?
    
    private init() {
        // 延迟执行兼容性检查，避免阻塞初始化
        Task.detached(priority: .background) {
            await self.performCompatibilityCheck()
        }
    }
    
    // MARK: - 兼容性检查
    func checkSystemCompatibility() {
        Task.detached(priority: .background) {
            await self.performCompatibilityCheck()
        }
    }

    // MARK: - 执行兼容性检查（异步版本）
    private func performCompatibilityCheck() async {
        var issues: [CompatibilityIssue] = []
        
        // 收集系统信息
        let info = collectSystemInfo()
        systemInfo = info
        
        // 检查macOS版本
        if info.osVersion.majorVersion < 12 {
            issues.append(CompatibilityIssue(
                type: .osVersion,
                severity: .critical,
                message: "系统版本过低 (\(info.osVersionString))，需要macOS 12.0或更高版本",
                suggestion: "请升级到macOS 12.0或更高版本"
            ))
        } else if info.osVersion.majorVersion == 12 && info.osVersion.minorVersion < 4 {
            issues.append(CompatibilityIssue(
                type: .osVersion,
                severity: .warning,
                message: "系统版本较低 (\(info.osVersionString))，建议升级到macOS 12.4或更高版本",
                suggestion: "建议升级系统以获得更好的兼容性"
            ))
        }
        
        // 检查内存
        if info.memoryGB < 4 {
            issues.append(CompatibilityIssue(
                type: .memory,
                severity: .critical,
                message: "系统内存不足 (\(info.memoryGB)GB)，可能导致应用崩溃",
                suggestion: "建议至少4GB内存，推荐8GB或更多"
            ))
        } else if info.memoryGB < 8 {
            issues.append(CompatibilityIssue(
                type: .memory,
                severity: .warning,
                message: "系统内存较低 (\(info.memoryGB)GB)，可能影响性能",
                suggestion: "建议8GB或更多内存以获得最佳性能"
            ))
        }
        
        // 检查关键目录权限
        checkDirectoryPermissions(&issues)
        
        // 检查架构兼容性
        checkArchitectureCompatibility(info: info, issues: &issues)
        
        // await MainActor.run { self.compatibilityIssues = issues }
        let issuesCopy = issues
        await MainActor.run { self.compatibilityIssues = issuesCopy }
        
        // 打印详细信息
        logSystemInfo(info: info, issues: issuesCopy)
    }
    
    // MARK: - 收集系统信息
    private func collectSystemInfo() -> SystemInfo {
        let processInfo = ProcessInfo.processInfo
        let osVersion = processInfo.operatingSystemVersion
        
        return SystemInfo(
            osVersion: osVersion,
            osVersionString: processInfo.operatingSystemVersionString,
            architecture: getMachineArchitecture(),
            memoryGB: Int(processInfo.physicalMemory / 1024 / 1024 / 1024),
            processorCount: processInfo.processorCount,
            userName: NSUserName(),
            homeDirectory: NSHomeDirectory(),
            isInSandbox: isRunningInSandbox(),
            appVersion: Bundle.main.infoDictionary?["CFBundleShortVersionString"] as? String ?? "未知"
        )
    }
    
    // MARK: - 检查目录权限
    private func checkDirectoryPermissions(_ issues: inout [CompatibilityIssue]) {
        let criticalPaths = [
            (path: NSHomeDirectory() + "/Movies/Motion Templates.localized", name: "用户插件目录"),
            (path: "/Library/Application Support/Final Cut Pro/Templates.localized", name: "系统插件目录"),
            (path: "/Library/Plug-Ins/FxPlug", name: "FxPlug插件目录")
        ]
        
        for (path, name) in criticalPaths {
            let fileManager = FileManager.default
            let exists = fileManager.fileExists(atPath: path)
            let isReadable = fileManager.isReadableFile(atPath: path)
            
            if !exists {
                issues.append(CompatibilityIssue(
                    type: .directoryAccess,
                    severity: .warning,
                    message: "\(name)不存在: \(path)",
                    suggestion: "这可能是正常的，如果未安装相关软件"
                ))
            } else if !isReadable {
                issues.append(CompatibilityIssue(
                    type: .directoryAccess,
                    severity: .critical,
                    message: "\(name)无法访问: \(path)",
                    suggestion: "请检查文件权限或运行权限"
                ))
            }
        }
    }
    
    // MARK: - 检查架构兼容性
    private func checkArchitectureCompatibility(info: SystemInfo, issues: inout [CompatibilityIssue]) {
        // 检查是否在Rosetta下运行
        if info.architecture.contains("x86_64") && isAppleSilicon() {
            issues.append(CompatibilityIssue(
                type: .architecture,
                severity: .warning,
                message: "应用在Rosetta模式下运行",
                suggestion: "建议使用原生Apple Silicon版本以获得更好性能"
            ))
        }
    }
    
    // MARK: - 工具方法
    private func getMachineArchitecture() -> String {
        var systemInfo = utsname()
        uname(&systemInfo)
        let machine = withUnsafePointer(to: &systemInfo.machine) {
            $0.withMemoryRebound(to: CChar.self, capacity: 1) {
                String(validatingUTF8: $0)
            }
        }
        return machine ?? "未知"
    }
    
    private func isRunningInSandbox() -> Bool {
        let environment = ProcessInfo.processInfo.environment
        return environment["APP_SANDBOX_CONTAINER_ID"] != nil
    }
    
    private func isAppleSilicon() -> Bool {
        var systemInfo = utsname()
        uname(&systemInfo)
        let machine = withUnsafePointer(to: &systemInfo.machine) {
            $0.withMemoryRebound(to: CChar.self, capacity: 1) {
                String(validatingUTF8: $0)
            }
        }
        return machine?.hasPrefix("arm64") == true
    }
    
    // MARK: - 日志输出
    private func logSystemInfo(info: SystemInfo, issues: [CompatibilityIssue]) {
        print("🖥️ ========== 系统兼容性报告 ==========")
        print("📱 应用版本: \(info.appVersion)")
        print("🍎 系统版本: \(info.osVersionString)")
        print("💻 架构: \(info.architecture)")
        print("💾 物理内存: \(info.memoryGB)GB")
        print("🔧 处理器数量: \(info.processorCount)")
        print("👤 用户名: \(info.userName)")
        print("📁 主目录: \(info.homeDirectory)")
        print("🛡️ 沙盒状态: \(info.isInSandbox ? "启用" : "禁用")")
        
        if !issues.isEmpty {
            print("⚠️ ========== 兼容性问题 ==========")
            for issue in issues {
                let icon = issue.severity == .critical ? "🚨" : "⚠️"
                print("\(icon) \(issue.message)")
                print("   建议: \(issue.suggestion)")
            }
        } else {
            print("✅ 未发现兼容性问题")
        }
        print("=====================================")
    }
}

// MARK: - 数据模型
struct SystemInfo {
    let osVersion: OperatingSystemVersion
    let osVersionString: String
    let architecture: String
    let memoryGB: Int
    let processorCount: Int
    let userName: String
    let homeDirectory: String
    let isInSandbox: Bool
    let appVersion: String
}

struct CompatibilityIssue: Identifiable {
    let id = UUID()
    let type: IssueType
    let severity: Severity
    let message: String
    let suggestion: String
    
    enum IssueType {
        case osVersion
        case memory
        case directoryAccess
        case architecture
        case other
    }
    
    enum Severity {
        case critical
        case warning
        case info
    }
}
