//
//  Models.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import Foundation
import SwiftUI
import UniformTypeIdentifiers

// MARK: - 插件类型枚举
enum PluginType: String, CaseIterable, Identifiable, Codable {
    case system = "system"        // 系统插件
    case user = "user"            // 用户插件
    case fxplug = "fxplug"        // FxPLUG插件
    case builtin = "builtin"      // 内置插件
    case plugkit = "plugkit"      // PlugKit插件
    case trash = "trash"          // 回收站
    
    var id: String { rawValue }
    
    var displayName: String {
        switch self {
        case .system: return "系统插件"
        case .user: return "用户插件"
        case .fxplug: return "FxPLUG插件"
        case .builtin: return "内置插件"
        case .plugkit: return "PlugKit插件"
        case .trash: return "回收站"
        }
    }
    
    var icon: String {
        switch self {
        case .system: return "gear"
        case .user: return "person"
        case .fxplug: return "fx"
        case .builtin: return "cube"
        case .plugkit: return "puzzlepiece"
        case .trash: return "trash"
        }
    }
    
    var basePath: String {
        switch self {
        case .system:
            return "/Library/Application Support/Final Cut Pro/Templates.localized"
        case .user:
            return NSString(string: "~/Movies/Motion Templates.localized").expandingTildeInPath
        case .fxplug:
            return "/Library/Plug-Ins/FxPlug"
        case .builtin:
            return "/Applications/Final Cut Pro.app/Contents/PlugIns/MediaProviders/MotionEffect.fxp/Contents/Resources/Templates.localized"
        case .plugkit:
            return "" // PlugKit插件通过命令行获取
        case .trash:
            return NSString(string: "~/.Trash").expandingTildeInPath
        }
    }
}

// MARK: - 插件子类型枚举
enum PluginSubType: String, CaseIterable, Identifiable, Codable {
    case titles = "Titles.localized"
    case generators = "Generators.localized"
    case effects = "Effects.localized"
    case transitions = "Transitions.localized"
    case compositions = "Compositions.localized"
    
    var id: String { rawValue }
    
    var displayName: String {
        switch self {
        case .effects: return "效果"
        case .generators: return "发生器"
        case .titles: return "字幕"
        case .transitions: return "转场"
        case .compositions: return "复合项目"
        }
    }
    
    var icon: String {
        switch self {
        case .effects: return "wand.and.rays"
        case .generators: return "plus.circle"
        case .titles: return "textformat"
        case .transitions: return "arrow.left.arrow.right"
        case .compositions: return "square.stack"
        }
    }
}

// MARK: - 插件分类模型
struct PluginCategory: Identifiable, Hashable {
    let id = UUID()
    let name: String
    let icon: String
    let path: String
    let type: PluginType
    var isExpanded: Bool = false
    var subcategories: [PluginSubcategory] = []
    
    init(name: String, icon: String, path: String, type: PluginType, subcategories: [PluginSubcategory] = []) {
        self.name = name
        self.icon = icon
        self.path = path
        self.type = type
        self.subcategories = subcategories
    }
}

// MARK: - 插件子分类模型
struct PluginSubcategory: Identifiable, Hashable {
    let id = UUID()
    let name: String
    let path: String
    let subType: PluginSubType
    var pluginCount: Int = 0
    
    init(name: String, path: String, subType: PluginSubType) {
        self.name = name
        self.path = path
        self.subType = subType
    }
}

// MARK: - FCPX插件模型
struct FCPXPlugin: Identifiable, Hashable, Codable {
    let id: UUID
    let name: String
    let path: String
    let type: PluginType
    let subType: PluginSubType?
    let categoryPath: String
    var fileSize: Int64 = 0
    var createdDate: Date = Date()
    var modifiedDate: Date = Date()
    var isFxFactoryPlugin: Bool = false
    var realName: String? // FxFactory插件的真实名称
    var motionFilePath: String? // Motion文件的具体路径
    var bundleIdentifier: String? // FxPlug插件的Bundle ID
    var version: String? // 插件版本号
    
    init(name: String, path: String, type: PluginType, subType: PluginSubType? = nil, categoryPath: String) {
        // 使用路径的哈希值作为唯一标识符，确保同一路径的插件有相同的ID
        self.id = UUID(uuidString: Self.generateUUIDFromPath(path)) ?? UUID()
        self.name = name
        self.path = path
        self.type = type
        self.subType = subType
        self.categoryPath = categoryPath
        self.isFxFactoryPlugin = Self.checkIfFxFactoryPlugin(path: path)

        // 验证插件类型和路径的一致性
        if !Self.validatePluginTypeAndPath(type: type, path: path) {
            //print("⚠️ 插件类型和路径不匹配: \(name) - 类型: \(type.displayName), 路径: \(path)")
        }
    }

    // 根据路径生成确定性的UUID
    private static func generateUUIDFromPath(_ path: String) -> String {
        let hash = path.hash
        let hashString = String(format: "%016llx", abs(hash))
        let paddedHash = String(hashString.prefix(32)).padding(toLength: 32, withPad: "0", startingAt: 0)

        // 格式化为UUID字符串
        let uuid = "\(paddedHash.prefix(8))-\(paddedHash.dropFirst(8).prefix(4))-\(paddedHash.dropFirst(12).prefix(4))-\(paddedHash.dropFirst(16).prefix(4))-\(paddedHash.dropFirst(20).prefix(12))"
        return uuid
    }

    // 验证插件类型和路径的一致性
    private static func validatePluginTypeAndPath(type: PluginType, path: String) -> Bool {
        switch type {
        case .user:
            // 用户插件应该在用户目录下
            return path.contains("/Users/") && path.contains("Movies/Motion Templates.localized")
        case .system:
            // 系统插件应该在系统目录下
            return path.contains("/Library/Application Support/Final Cut Pro/Templates.localized")
        case .fxplug:
            // FxPlug插件应该在FxPlug目录下
            return path.contains("/Library/Plug-Ins/FxPlug")
        default:
            return true
        }
    }
    
    // 显示名称（FxFactory插件显示真实名称）
    var displayName: String {
        if isFxFactoryPlugin, let realName = realName {
            return realName
        }
        return name
    }

    // 验证插件的类型和路径是否匹配
    var isValidPluginSource: Bool {
        return Self.validatePluginTypeAndPath(type: type, path: path)
    }
    
    // 缩略图URL
    var thumbnailURL: URL? {
        let pluginURL = URL(fileURLWithPath: path)

        // 如果是FxPlug插件（.app文件），查找应用程序图标
        if path.hasSuffix(".app") {
            // 查找应用程序图标
            let iconPaths = [
                "Contents/Resources/AppIcon.icns",
                "Contents/Resources/icon.icns",
                "Contents/Resources/AppIcon.png",
                "Contents/Resources/icon.png"
            ]

            for iconPath in iconPaths {
                let iconURL = pluginURL.appendingPathComponent(iconPath)
                if FileManager.default.fileExists(atPath: iconURL.path) {
                    return iconURL
                }
            }
        } else {
            // Motion Templates插件的缩略图查找
            // 优先查找large.png
            let largeThumbURL = pluginURL.appendingPathComponent("large.png")
            if FileManager.default.fileExists(atPath: largeThumbURL.path) {
                return largeThumbURL
            }

            // 备选缩略图路径
            let alternativePaths = [
                "thumbnail.png",
                "preview.png",
                "icon.png",
                "small.png"
            ]

            for path in alternativePaths {
                let altURL = pluginURL.appendingPathComponent(path)
                if FileManager.default.fileExists(atPath: altURL.path) {
                    return altURL
                }
            }
        }

        return nil
    }
    
    // 插件主文件URL
    var mainFileURL: URL? {
        let pluginURL = URL(fileURLWithPath: path)
        let extensions = [".motn", ".moef", ".moti", ".motr"]
        
        for ext in extensions {
            let fileURL = pluginURL.appendingPathComponent(name + ext)
            if FileManager.default.fileExists(atPath: fileURL.path) {
                return fileURL
            }
        }
        
        return nil
    }
    


    // 直接读取 .localized/en.strings 文件内容
    private func readLocalizedNameDirectly(from directoryPath: String) -> String? {
        let stringsPath = URL(fileURLWithPath: directoryPath)
            .appendingPathComponent(".localized")
            .appendingPathComponent("en.strings")
            .path

        // 检查文件是否存在
        guard FileManager.default.fileExists(atPath: stringsPath) else {
            return nil
        }

        do {
            // 读取文件内容
            let content = try String(contentsOfFile: stringsPath, encoding: .utf8)

            // 简单解析：查找第一个 = 后面引号中的内容
            let lines = content.components(separatedBy: .newlines)

            for line in lines {
                let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)

                // 跳过空行和注释
                if trimmedLine.isEmpty || trimmedLine.hasPrefix("//") || trimmedLine.hasPrefix("/*") {
                    continue
                }

                // 查找格式: "key" = "value";
                if let equalIndex = trimmedLine.firstIndex(of: "=") {
                    let afterEqual = String(trimmedLine[trimmedLine.index(after: equalIndex)...])
                        .trimmingCharacters(in: .whitespacesAndNewlines)

                    // 查找第一个引号
                    if let firstQuoteIndex = afterEqual.firstIndex(of: "\"") {
                        let afterFirstQuote = String(afterEqual[afterEqual.index(after: firstQuoteIndex)...])

                        // 查找结束引号
                        if let lastQuoteIndex = afterFirstQuote.firstIndex(of: "\"") {
                            let value = String(afterFirstQuote[..<lastQuoteIndex])
                            if !value.isEmpty {
                                return value
                            }
                        }
                    }
                }
            }

            return nil

        } catch {
            return nil
        }
    }

    // 检查是否为FxFactory插件（仅检查.fxfactory.plist文件）
    static func checkIfFxFactoryPlugin(path: String) -> Bool {
        let url = URL(fileURLWithPath: path)

        // 检查插件目录本身是否有 .fxfactory.plist 文件
        let pluginPlistPath = url.appendingPathComponent(".fxfactory.plist").path
        if FileManager.default.fileExists(atPath: pluginPlistPath) {
            return true
        }

        // 检查父目录是否有 .fxfactory.plist 文件
        let parentURL = url.deletingLastPathComponent()
        let parentPlistPath = parentURL.appendingPathComponent(".fxfactory.plist").path
        if FileManager.default.fileExists(atPath: parentPlistPath) {
            return true
        }

        return false
    }
    
    // 解析FxFactory插件真实名称（简化版本 - 只读取en.strings）
    mutating func resolveFxFactoryName() {
        guard isFxFactoryPlugin else { return }

        let pluginURL = URL(fileURLWithPath: path)

        // 先尝试从插件目录读取
        if let realName = readLocalizedNameDirectly(from: path) {
            self.realName = realName
            return
        }

        // 再尝试从父目录读取
        let parentURL = pluginURL.deletingLastPathComponent()
        if let parentRealName = readLocalizedNameDirectly(from: parentURL.path) {
            self.realName = parentRealName
            //print("✅ 从父目录读取FxFactory真实名称: \(parentRealName)")
            return
        }

        // 读取失败时使用原始名称
    }

}

// MARK: - 插件操作类型
enum PluginOperation: Equatable {
    case rename(newName: String)
    case uninstall
    case merge
    case duplicate
    case export(destination: URL)

    // 实现Equatable协议
    static func == (lhs: PluginOperation, rhs: PluginOperation) -> Bool {
        switch (lhs, rhs) {
        case (.rename(let lhsName), .rename(let rhsName)):
            return lhsName == rhsName
        case (.uninstall, .uninstall):
            return true
        case (.merge, .merge):
            return true
        case (.duplicate, .duplicate):
            return true
        case (.export(let lhsDestination), .export(let rhsDestination)):
            return lhsDestination == rhsDestination
        default:
            return false
        }
    }
}

// MARK: - FxFactory状态
enum FxFactoryStatus {
    case notInstalled    // 未安装
    case ready          // 已安装且未运行，可以操作
    case running        // 正在运行，需要关闭
    case disabled       // 已临时禁用
}

// MARK: - 类别目录信息模型（用于拖拽）
// 项目进度记录：
// 2024-12-19: 修复拖拽功能 - 支持 public.url 类型标识符和 NSSecureCoding 类型转换
//   - 添加对多种URL类型标识符的支持（UTType.fileURL.identifier, "public.url"）
//   - 修复 NSItemProvider 返回 Optional<NSSecureCoding> 类型的处理问题
//   - 增强URL类型转换逻辑，支持 URL、NSURL 和字符串路径的转换
//   - 修复public.folder类型处理问题，移除临时文件机制，直接使用路径信息
//   - 解决临时文件路径不存在导致的拖拽失败问题，增加错误恢复机制
// - 2024年修复：解决了MergeOperationView.swift中PluginSubType可选类型解包错误
// - 修复了FCPXPlugin初始化器参数不匹配问题
// - 修复了BatchMergeManager.swift中的编译错误
// - 修复了ConflictResolutionRow.swift中的编译错误
// - 项目现在可以成功编译和运行
struct CategoryInfo: Identifiable, Hashable, Codable {
    let id: UUID
    let name: String
    let path: String
    let type: PluginType
    let subType: PluginSubType?
    var pluginCount: Int = 0
    var totalSize: Int64 = 0 // 类别目录总体积
    var isFxFactoryCategory: Bool = false
    var realName: String? // FxFactory类别的真实名称
    
    init(name: String, path: String, type: PluginType, subType: PluginSubType? = nil) {
        self.id = UUID()
        self.name = name
        self.path = path
        self.type = type
        self.subType = subType
        self.isFxFactoryCategory = Self.checkIfFxFactoryCategory(path: path)
    }
    
    // 显示名称（FxFactory类别显示真实名称）
    var displayName: String {
        if isFxFactoryCategory, let realName = realName {
            return realName
        }
        return name
    }
    
    // 检查是否为FxFactory类别（仅检查.fxfactory.plist文件）
    static func checkIfFxFactoryCategory(path: String) -> Bool {
        let plistPath = URL(fileURLWithPath: path)
            .appendingPathComponent(".fxfactory.plist")
            .path

        return FileManager.default.fileExists(atPath: plistPath)
    }
    
    // 解析FxFactory类别真实名称（简化版本 - 直接读取）
    mutating func resolveFxFactoryName() {
        guard isFxFactoryCategory else { return }

        // 直接读取 .localized/en.strings 文件
        if let realName = readLocalizedNameDirectly(from: path) {
            self.realName = realName
        }
    }

    // 直接读取 .localized/en.strings 文件内容
    private func readLocalizedNameDirectly(from directoryPath: String) -> String? {
        let stringsPath = URL(fileURLWithPath: directoryPath)
            .appendingPathComponent(".localized")
            .appendingPathComponent("en.strings")
            .path

        // 检查文件是否存在
        guard FileManager.default.fileExists(atPath: stringsPath) else {
            return nil
        }

        do {
            // 读取文件内容
            let content = try String(contentsOfFile: stringsPath, encoding: .utf8)

            // 简单解析：查找第一个 = 后面引号中的内容
            let lines = content.components(separatedBy: .newlines)

            for line in lines {
                let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)

                // 跳过空行和注释
                if trimmedLine.isEmpty || trimmedLine.hasPrefix("//") || trimmedLine.hasPrefix("/*") {
                    continue
                }

                // 查找格式: "key" = "value";
                if let equalIndex = trimmedLine.firstIndex(of: "=") {
                    let afterEqual = String(trimmedLine[trimmedLine.index(after: equalIndex)...])
                        .trimmingCharacters(in: .whitespacesAndNewlines)

                    // 查找第一个引号
                    if let firstQuoteIndex = afterEqual.firstIndex(of: "\"") {
                        let afterFirstQuote = String(afterEqual[afterEqual.index(after: firstQuoteIndex)...])

                        // 查找结束引号
                        if let lastQuoteIndex = afterFirstQuote.firstIndex(of: "\"") {
                            let value = String(afterFirstQuote[..<lastQuoteIndex])
                            if !value.isEmpty {
                                //print("   📄 成功解析 .strings 文件: \(value)")
                                return value
                            }
                        }
                    }
                }
            }

            return nil

        } catch {
            // 读取失败时不显示警告
            return nil
        }
    }
}

// MARK: - Transferable 支持
// 项目进度记录：
// - 2024年修复：将拖拽机制从JSON编码改为URL传递，提高兼容性和可靠性
// - 2024年修复：修复拖拽功能支持public.url类型标识符和NSSecureCoding类型转换
//   - 增强URL类型转换逻辑，支持URL、NSURL、NSSecureCoding、Data和String类型的转换
//   - 添加对public.url类型标识符的支持（除了原有的public.file-url）
//   - 修复NSItemProvider返回NSSecureCoding类型的处理问题
// - 2024年修复：解决MergeOperationView拖拽类型不匹配问题，统一使用URL类型接收拖拽数据
// - 2024年重构：使用macOS标准文件拖拽API，简化实现并提高稳定性
// - 2024年修复：修复MergeOperationView.swift编译错误，包括FCPXPlugin和CategoryInfo构造函数参数匹配、PluginType和PluginSubType枚举值修正、变量引用错误修复
// - 2024年修复：使用正确的ProxyRepresentation语法，传递URL对象用于拖拽
// macOS 12.0兼容的拖拽实现 - 移除了@available标记以确保兼容性

// macOS 12.0兼容的拖拽实现
extension FCPXPlugin {
    func itemProvider() -> NSItemProvider {
        let provider = NSItemProvider()
        provider.registerFileRepresentation(forTypeIdentifier: "public.file-url", visibility: .all) { completion in
            let url = URL(fileURLWithPath: self.path)
            completion(url, true, nil)
            return nil
        }
        return provider
    }
}

// 移除了PluginArray以确保macOS 12.0兼容性

// macOS 12.0兼容的插件数组拖拽实现
struct PluginArrayCompat: Codable {
    let plugins: [FCPXPlugin]

    init(_ plugins: [FCPXPlugin]) {
        self.plugins = plugins
    }

    func itemProvider() -> NSItemProvider {
        let provider = NSItemProvider()
        provider.registerDataRepresentation(forTypeIdentifier: "com.dayu.plugin-array", visibility: .all) { completion in
            do {
                let data = try JSONEncoder().encode(self)
                completion(data, nil)
            } catch {
                completion(nil, error)
            }
            return nil
        }
        return provider
    }
}

// MARK: - 新方法中的数据结构

/// 插件源类型（新方法）
enum PluginSourceNew: String, CaseIterable, Identifiable {
    case system = "system"     // 系统插件
    case user = "user"         // 用户插件
    case fxplug = "fxplug"     // FxPlug插件

    var id: String { rawValue }

    var displayName: String {
        switch self {
        case .system: return "系统插件"
        case .user: return "用户插件"
        case .fxplug: return "FxPlug插件"
        }
    }

    var path: String {
        switch self {
        case .system: return "/Library/Application Support/Final Cut Pro/Templates.localized"
        case .user: return NSHomeDirectory() + "/Movies/Motion Templates.localized"
        case .fxplug: return "/Library/Plug-Ins/FxPlug"
        }
    }

    var displayOrder: Int {
        switch self {
        case .fxplug: return 0
        case .system: return 1
        case .user: return 2
        }
    }
}

/// 插件类别信息（新方法）
struct PluginCategoryNew: Identifiable, Hashable {
    let id = UUID()
    let name: String                    // 显示名称
    let originalName: String            // 原始目录名
    let path: String                    // 完整路径
    let source: PluginSourceNew         // 插件源
    let subType: PluginSubType          // 子类型
    let isFxFactory: Bool               // 是否为FxFactory类别
    var plugins: [PluginInfoNew] = []   // 包含的插件

    /// 类别中插件总数
    var pluginCount: Int {
        plugins.count
    }

    /// 类别总大小（基于插件累计）
    var totalSize: Int64 {
        plugins.reduce(0) { $0 + $1.fileSize }
    }

    /// 类别目录实际大小（递归计算目录下所有文件）
    var actualDirectorySize: Int64 {
        calculateDirectorySize(at: path)
    }

    /// 递归计算目录大小
    private func calculateDirectorySize(at path: String) -> Int64 {
        let fileManager = FileManager.default
        var totalSize: Int64 = 0

        guard fileManager.fileExists(atPath: path) else {
            return 0
        }

        do {
            let resourceKeys: [URLResourceKey] = [.isRegularFileKey, .fileAllocatedSizeKey, .isDirectoryKey]
            let directoryURL = URL(fileURLWithPath: path)

            if let enumerator = fileManager.enumerator(
                at: directoryURL,
                includingPropertiesForKeys: resourceKeys,
                options: [.skipsHiddenFiles],
                errorHandler: { (url, error) -> Bool in
                    //print("目录遍历错误: \(url.path) - \(error)")
                    return true
                }
            ) {
                for case let fileURL as URL in enumerator {
                    let resourceValues = try fileURL.resourceValues(forKeys: Set(resourceKeys))

                    if resourceValues.isRegularFile == true {
                        totalSize += Int64(resourceValues.fileAllocatedSize ?? 0)
                    }
                }
            }
        } catch {
            //print("计算目录大小失败: \(error)")
        }

        return totalSize
    }
}

/// 插件信息（新方法）
struct PluginInfoNew: Identifiable, Hashable {
    let id = UUID()
    let name: String                    // 插件名称
    let displayName: String             // 显示名称（FxFactory插件的真实名称）
    let path: String                    // 插件路径
    let categoryPath: String            // 所属类别路径
    let isFxFactory: Bool               // 是否为FxFactory插件
    let fileSize: Int64                 // 文件大小
    let modificationDate: Date          // 修改日期
    let thumbnailPath: String?          // 缩略图路径

    /// 格式化文件大小
    var formattedSize: String {
        ByteCountFormatter.string(fromByteCount: fileSize, countStyle: .file)
    }

    /// 缩略图URL
    var thumbnailURL: URL? {
        guard let thumbnailPath = thumbnailPath else { return nil }
        return URL(fileURLWithPath: thumbnailPath)
    }
}

// 移除了CategoryInfo的Transferable扩展以确保macOS 12.0兼容性

// macOS 12.0兼容的类别拖拽实现
extension CategoryInfo {
    func itemProvider() -> NSItemProvider {
        let provider = NSItemProvider()
        provider.registerFileRepresentation(forTypeIdentifier: "public.file-url", visibility: .all) { completion in
            let url = URL(fileURLWithPath: self.path)
            completion(url, true, nil)
            return nil
        }
        return provider
    }
}
