//
//  PluginCategoryView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

struct PluginCategoryView: View {
    @Binding var selectedCategory: PluginType
    @StateObject private var pluginManager = PluginManager()
    @State private var expandedCategories: Set<UUID> = []
    
    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            // 标题
            HStack {
                Text("插件分类")
                    .font(.headline)
                    .foregroundColor(.primary)
                Spacer()
            }
            .padding(.horizontal, 16)
            .padding(.vertical, 12)
            .background(Color(NSColor.controlBackgroundColor))
            
            Divider()
            
            // 分类列表
            ScrollView {
                LazyVStack(alignment: .leading, spacing: 2) {
                    ForEach(pluginManager.categories) { category in
                        PluginCategoryRowView(
                            category: category,
                            selectedCategory: $selectedCategory,
                            expandedCategories: $expandedCategories,
                            pluginManager: pluginManager
                        )
                    }
                }
                .padding(.vertical, 8)
            }
            
            Spacer()
            
            // 底部统计信息
            VStack(alignment: .leading, spacing: 4) {
                Divider()
                
                HStack {
                    Image(systemName: "info.circle")
                        .foregroundColor(.secondary)
                    Text("总计: \(totalPluginCount) 个插件")
                        .font(.caption)
                        .foregroundColor(.secondary)
                    Spacer()
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 8)
            }
        }
        .background(Color(NSColor.controlBackgroundColor))
    }
    
    private var totalPluginCount: Int {
        pluginManager.plugins.values.reduce(0) { $0 + $1.count }
    }
}

struct PluginCategoryRowView: View {
    let category: PluginCategory
    @Binding var selectedCategory: PluginType
    @Binding var expandedCategories: Set<UUID>
    let pluginManager: PluginManager
    
    @State private var isHovered = false
    
    var isExpanded: Bool {
        expandedCategories.contains(category.id)
    }
    
    var isSelected: Bool {
        selectedCategory == category.type
    }
    
    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            // 主分类行
            Button(action: {
                selectedCategory = category.type
                
                // 切换展开状态
                if isExpanded {
                    expandedCategories.remove(category.id)
                } else {
                    expandedCategories.insert(category.id)
                }
                
                // 加载插件数据
                Task {
                    await pluginManager.loadPlugins(for: category.type)
                }
            }) {
                HStack(spacing: 12) {
                    // 展开/收起图标
                    if !category.subcategories.isEmpty {
                        Image(systemName: isExpanded ? "chevron.down" : "chevron.right")
                            .font(.caption)
                            .foregroundColor(.secondary)
                            .frame(width: 12)
                    } else {
                        Spacer()
                            .frame(width: 12)
                    }
                    
                    // 分类图标
                    Image(systemName: category.icon)
                        .font(.system(size: 16))
                        .foregroundColor(isSelected ? .white : .primary)
                        .frame(width: 20)
                    
                    // 分类名称
                    Text(category.name)
                        .font(.body)
                        .foregroundColor(isSelected ? .white : .primary)
                    
                    Spacer()
                    
                    // 插件数量
                    if let plugins = pluginManager.plugins[category.type] {
                        Text("\(plugins.count)")
                            .font(.caption)
                            .foregroundColor(isSelected ? .white.opacity(0.8) : .secondary)
                            .padding(.horizontal, 6)
                            .padding(.vertical, 2)
                            .background(
                                Capsule()
                                    .fill(isSelected ? Color.white.opacity(0.2) : Color.secondary.opacity(0.1))
                            )
                    }
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 8)
                .background(
                    RoundedRectangle(cornerRadius: 6)
                        .fill(backgroundColorForRow)
                )
                .contentShape(Rectangle())
            }
            .buttonStyle(PlainButtonStyle())
            .onHover { hovering in
                isHovered = hovering
            }
            
            // 子分类列表
            if isExpanded && !category.subcategories.isEmpty {
                VStack(alignment: .leading, spacing: 1) {
                    ForEach(category.subcategories) { subcategory in
                        SubcategoryRowView(
                            subcategory: subcategory,
                            categoryType: category.type,
                            selectedCategory: $selectedCategory,
                            pluginManager: pluginManager
                        )
                    }
                }
                .padding(.leading, 28)
                .padding(.trailing, 16)
                .padding(.bottom, 4)
            }
        }
        .padding(.horizontal, 8)
    }
    
    private var backgroundColorForRow: Color {
        if isSelected {
            return Color.accentColor
        } else if isHovered {
            return Color.primary.opacity(0.05)
        } else {
            return Color.clear
        }
    }
}

struct SubcategoryRowView: View {
    let subcategory: PluginSubcategory
    let categoryType: PluginType
    @Binding var selectedCategory: PluginType
    let pluginManager: PluginManager
    
    @State private var isHovered = false
    
    var body: some View {
        Button(action: {
            selectedCategory = categoryType
            // TODO: 过滤显示特定子类型的插件
        }) {
            HStack(spacing: 8) {
                // 子分类图标
                Image(systemName: subcategory.subType.icon)
                    .font(.system(size: 14))
                    .foregroundColor(.secondary)
                    .frame(width: 16)
                
                // 子分类名称
                Text(subcategory.name)
                    .font(.callout)
                    .foregroundColor(.primary)
                
                Spacer()
                
                // 插件数量
                Text("\(subcategory.pluginCount)")
                    .font(.caption2)
                    .foregroundColor(.secondary)
                    .padding(.horizontal, 4)
                    .padding(.vertical, 1)
                    .background(
                        Capsule()
                            .fill(Color.secondary.opacity(0.1))
                    )
            }
            .padding(.horizontal, 12)
            .padding(.vertical, 6)
            .background(
                RoundedRectangle(cornerRadius: 4)
                    .fill(isHovered ? Color.primary.opacity(0.05) : Color.clear)
            )
            .contentShape(Rectangle())
        }
        .buttonStyle(PlainButtonStyle())
        .onHover { hovering in
            isHovered = hovering
        }
    }
}

#Preview {
    PluginCategoryView(selectedCategory: .constant(.user))
        .frame(width: 200, height: 600)
}
