//
//  PluginContentView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

struct PluginContentView: View {
    let selectedSourceType: PluginType
    let selectedSubType: PluginSubType?
    let selectedCategoryPath: String?
    @ObservedObject var pluginManager: PluginManager
    @ObservedObject var batchOperationManager: BatchOperationManager

    @State private var viewMode: ViewMode = .grid
    @State private var searchText = ""
    @State private var sortOption: SortOption = .name
    
    enum ViewMode: String, CaseIterable {
        case grid = "grid"
        case list = "list"
        
        var icon: String {
            switch self {
            case .grid: return "square.grid.2x2"
            case .list: return "list.bullet"
            }
        }
        
        var displayName: String {
            switch self {
            case .grid: return "网格视图"
            case .list: return "列表视图"
            }
        }
    }
    
    enum SortOption: String, CaseIterable {
        case name = "name"
        case date = "date"
        case size = "size"
        case type = "type"
        
        var displayName: String {
            switch self {
            case .name: return "名称"
            case .date: return "修改日期"
            case .size: return "文件大小"
            case .type: return "类型"
            }
        }
    }
    
    var filteredAndSortedPlugins: [FCPXPlugin] {
        //print("🔍 PluginContentView 请求插件数据 - selectedSourceType: \(selectedSourceType)")
        var plugins = pluginManager.filteredPlugins(for: selectedSourceType)
        //print("🔍 获得 \(plugins.count) 个插件，前3个插件的类型: \(plugins.prefix(3).map { "\($0.displayName):\($0.type)" })")

        // 按子类型过滤
        if let subType = selectedSubType {
            _ = plugins.count
            plugins = plugins.filter { $0.subType == subType }
            //print("🔍 子类型过滤: \(subType) - 过滤前: \(beforeCount), 过滤后: \(plugins.count)")
            if plugins.count < 10 {
                //print("🔍 过滤后的插件: \(plugins.map { "\($0.displayName)(\($0.subType?.rawValue ?? "nil"))" })")
            }
        }

        // 按类别路径过滤（确保插件源类型匹配）
        if let categoryPath = selectedCategoryPath {
            let beforeFilterCount = plugins.count
            plugins = plugins.filter { plugin in
                // 确保插件类型匹配当前选择的插件源
                guard plugin.type == selectedSourceType else { return false }

                // 🔧 修复：使用更准确的路径匹配逻辑
                // 获取插件类别路径的最后一个组件进行比较
                let pluginCategoryName = URL(fileURLWithPath: plugin.categoryPath).lastPathComponent
                let matches = pluginCategoryName == categoryPath

                return matches
            }
            print("🔍 类别路径过滤: \(categoryPath) - 过滤前: \(beforeFilterCount), 过滤后: \(plugins.count) 个插件")
        }

        // 按搜索文本过滤
        if !searchText.isEmpty {
            plugins = plugins.filter { plugin in
                plugin.displayName.localizedCaseInsensitiveContains(searchText)
            }
        }

        // 排序
        switch sortOption {
        case .name:
            plugins.sort { $0.displayName.localizedStandardCompare($1.displayName) == .orderedAscending }
        case .date:
            plugins.sort { $0.modifiedDate > $1.modifiedDate }
        case .size:
            // 按大小排序时，尝试从缓存中获取文件大小
            plugins = plugins.map { plugin in
                let updatedPlugin = plugin
                if updatedPlugin.fileSize == 0 {
                    // 暂时跳过大小缓存功能
                    // TODO: 实现大小缓存功能
                }
                return updatedPlugin
            }
            plugins.sort { $0.fileSize > $1.fileSize }
        case .type:
            plugins.sort { ($0.subType?.displayName ?? "") < ($1.subType?.displayName ?? "") }
        }

        return plugins
    }
    
    var body: some View {
        VStack(spacing: 0) {
            // 工具栏
            PluginContentToolbar(
                viewMode: $viewMode,
                searchText: $searchText,
                sortOption: $sortOption,
                selectedSourceType: selectedSourceType,
                selectedSubType: selectedSubType,
                selectedCategoryPath: selectedCategoryPath,
                pluginManager: pluginManager
            )
            
            Divider()
            
            // 内容区域
            if pluginManager.isLoading || !pluginManager.isGlobalScanComplete {
                // 正在加载或全局扫描未完成时，显示加载界面
                LoadingView(progressText: pluginManager.loadingProgress.isEmpty ? "正在初始化插件数据..." : pluginManager.loadingProgress)
            } else if filteredAndSortedPlugins.isEmpty {
                // 扫描完成但没有数据时，显示空状态
                EmptyStateView(
                    selectedSourceType: selectedSourceType,
                    selectedSubType: selectedSubType,
                    selectedCategoryPath: selectedCategoryPath
                )
            } else {
                // 只有在扫描完成且有数据时才显示插件内容
                switch viewMode {
                case .grid:
                    PluginGridView(
                        plugins: filteredAndSortedPlugins,
                        onPluginChanged: {
                            // 数据源已通过@Published自动更新，无需手动刷新
                            //print("🔴 PluginContentView 收到插件变化回调")
                        },
                        batchOperationManager: batchOperationManager
                    )
                    .id("\(selectedSourceType.rawValue)-\(selectedSubType?.rawValue ?? "all")-\(selectedCategoryPath ?? "all")")
                case .list:
                    PluginListView(
                        plugins: filteredAndSortedPlugins,
                        onPluginChanged: {
                            // 数据源已通过@Published自动更新，无需手动刷新
                            //print("🔴 PluginContentView 收到插件变化回调")
                        },
                        batchOperationManager: batchOperationManager
                    )
                    .id("\(selectedSourceType.rawValue)-\(selectedSubType?.rawValue ?? "all")-\(selectedCategoryPath ?? "all")")
                }
            }
        }
        .background(Color(NSColor.controlBackgroundColor))
        .onChange(of: selectedSourceType) { newValue in
            searchText = ""
            // 只在插件数据实际变更时刷新，移除强制objectWillChange.send()
            // 数据变更由@Published自动驱动，无需手动刷新
        }
        .onChange(of: selectedSubType) { newValue in
            //print("🔴 PluginContentView selectedSubType 变化: \(String(describing: newValue))")
            searchText = ""
        }
        .onChange(of: selectedCategoryPath) { newValue in
            //print("🔴 PluginContentView selectedCategoryPath 变化: \(String(describing: newValue))")
            searchText = ""
        }
    }
}

struct PluginContentToolbar: View {
    @Binding var viewMode: PluginContentView.ViewMode
    @Binding var searchText: String
    @Binding var sortOption: PluginContentView.SortOption
    let selectedSourceType: PluginType
    let selectedSubType: PluginSubType?
    let selectedCategoryPath: String?
    @ObservedObject var pluginManager: PluginManager
    
    var body: some View {
        HStack(spacing: 12) {
            // 搜索框
            HStack {
                Image(systemName: "magnifyingglass")
                    .foregroundColor(.secondary)
                
                TextField("搜索插件...", text: $searchText)
                    .textFieldStyle(PlainTextFieldStyle())
                
                if !searchText.isEmpty {
                    Button(action: { searchText = "" }) {
                        Image(systemName: "xmark.circle.fill")
                            .foregroundColor(.secondary)
                    }
                    .buttonStyle(PlainButtonStyle())
                }
            }
            .padding(.horizontal, 8)
            .padding(.vertical, 6)
            .background(Color(NSColor.textBackgroundColor))
            .cornerRadius(6)
            .frame(maxWidth: 300)
            
            Spacer()

            // 当前选择信息
            VStack(alignment: .trailing, spacing: 2) {
                if let subType = selectedSubType {
                    Text(subType.displayName)
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
                if let categoryPath = selectedCategoryPath {
                    Text(categoryPath)
                        .font(.caption2)
                        .foregroundColor(.secondary)
                }
            }
            
            // 排序选项
            Menu {
                ForEach(PluginContentView.SortOption.allCases, id: \.self) { option in
                    Button(option.displayName) {
                        sortOption = option
                    }
                }
            } label: {
                HStack {
                    Image(systemName: "arrow.up.arrow.down")
                    Text(sortOption.displayName)
                }
                .font(.callout)
                .padding(.horizontal, 8)
                .padding(.vertical, 4)
            }
            .menuStyle(BorderlessButtonMenuStyle())
            
            // 视图模式切换
            Picker("视图模式", selection: $viewMode) {
                ForEach(PluginContentView.ViewMode.allCases, id: \.self) { mode in
                    Image(systemName: mode.icon)
                        .tag(mode)
                }
            }
            .pickerStyle(SegmentedPickerStyle())
            .frame(width: 80)
            
            // 插件数量
            Text("\(filteredAndSortedPlugins.count) 个插件")
                .font(.caption)
                .foregroundColor(.secondary)
                .padding(.horizontal, 8)
        }
        .padding(.horizontal, 16)
        .padding(.vertical, 12)
        .background(Color(NSColor.controlBackgroundColor))
    }
    
    private var filteredAndSortedPlugins: [FCPXPlugin] {
        var plugins = pluginManager.filteredPlugins(for: selectedSourceType)

        if let subType = selectedSubType {
            plugins = plugins.filter { $0.subType == subType }
        }

        if let categoryPath = selectedCategoryPath {
            plugins = plugins.filter { plugin in
                plugin.categoryPath.hasSuffix(categoryPath)
            }
        }

        if !searchText.isEmpty {
            plugins = plugins.filter { plugin in
                plugin.displayName.localizedCaseInsensitiveContains(searchText)
            }
        }

        return plugins
    }
}

struct LoadingView: View {
    let progressText: String

    init(progressText: String = "正在加载插件...") {
        self.progressText = progressText
    }

    var body: some View {
        VStack(spacing: 20) {
            ProgressView()
                .scaleEffect(1.5)

            VStack(spacing: 8) {
                Text(progressText.isEmpty ? "正在加载插件..." : progressText)
                    .font(.headline)
                    .foregroundColor(.primary)
                    .multilineTextAlignment(.center)

                Text("请稍候，正在扫描所有插件源...")
                    .font(.caption)
                    .foregroundColor(.secondary)
                    .multilineTextAlignment(.center)
            }
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
        .background(Color(NSColor.controlBackgroundColor))
    }
}

struct EmptyStateView: View {
    let selectedSourceType: PluginType
    let selectedSubType: PluginSubType?
    let selectedCategoryPath: String?

    var body: some View {
        VStack(spacing: 20) {
            Image(systemName: iconForCurrentSelection)
                .font(.system(size: 64))
                .foregroundColor(.secondary)

            VStack(spacing: 8) {
                Text("没有找到插件")
                    .font(.title2)
                    .fontWeight(.medium)

                Text(emptyStateMessage)
                    .font(.body)
                    .foregroundColor(.secondary)
                    .multilineTextAlignment(.center)
            }

            if selectedSourceType == .user {
                VStack(spacing: 12) {
                    Text("插件通常安装在以下位置：")
                        .font(.callout)
                        .foregroundColor(.secondary)

                    Text("~/Movies/Motion Templates.localized/")
                        .font(.system(.callout, design: .monospaced))
                        .padding(.horizontal, 12)
                        .padding(.vertical, 6)
                        .background(Color.secondary.opacity(0.1))
                        .cornerRadius(6)
                }
            }
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
        .background(Color(NSColor.controlBackgroundColor))
    }

    private var iconForCurrentSelection: String {
        if let subType = selectedSubType {
            return subType.icon
        }
        return selectedSourceType.icon
    }

    private var emptyStateMessage: String {
        var message = "在 \(selectedSourceType.displayName)"

        if let subType = selectedSubType {
            message += " 的 \(subType.displayName)"
        }

        if let categoryPath = selectedCategoryPath {
            message += " 的 \(categoryPath) 分类"
        }

        message += " 中没有发现任何插件"
        return message
    }
}

#Preview {
    PluginContentView(
        selectedSourceType: PluginType.user,
        selectedSubType: PluginSubType.titles,
        selectedCategoryPath: "示例分类",
        pluginManager: PluginManager(),
        batchOperationManager: BatchOperationManager()
    )
    .frame(width: 600, height: 400)
}
