//
//  PluginManager.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import Foundation
import SwiftUI



@MainActor
class PluginManager: ObservableObject {
    @Published var plugins: [PluginType: [FCPXPlugin]] = [:]
    @Published var categories: [PluginCategory] = []
    @Published var isLoading = false
    @Published var isGlobalScanComplete = false   // 标记全局扫描是否完成
    @Published var searchText = ""
    @Published var selectedPlugins: Set<UUID> = []
    @Published var errorMessage: String?
    @Published var loadingProgress: String = "" // 加载进度信息
    @Published var scannedCount: Int = 0 // 已扫描的插件数量

    // 新方法中的数据结构
    @Published var pluginCategories: [PluginCategoryNew] = []
    @Published var isScanning = false
    @Published var scanProgress: Double = 0.0

    private let fileManager = FileManager.default
    private let thumbnailCache = ThumbnailCache()

    init() {
        setupCategories()
    }

    // MARK: - 设置插件分类
    private func setupCategories() {
        categories = [
            PluginCategory(
                name: "用户插件",
                icon: "person",
                path: PluginType.user.basePath,
                type: .user,
                subcategories: PluginSubType.allCases.map { subType in
                    PluginSubcategory(
                        name: subType.displayName,
                        path: subType.rawValue,
                        subType: subType
                    )
                }
            ),
            PluginCategory(
                name: "系统插件",
                icon: "gear",
                path: PluginType.system.basePath,
                type: .system,
                subcategories: PluginSubType.allCases.map { subType in
                    PluginSubcategory(
                        name: subType.displayName,
                        path: subType.rawValue, // 系统插件也使用.localized后缀
                        subType: subType
                    )
                }
            ),
            PluginCategory(
                name: "FxPLUG插件",
                icon: "fx",
                path: PluginType.fxplug.basePath,
                type: .fxplug
            )
        ]
    }

    // MARK: - 新方法扫描逻辑

    /// 开始扫描所有插件（新方法）
    func scanAllPluginsNew() async {
        await MainActor.run {
            isScanning = true
            scanProgress = 0.0
            errorMessage = nil
            pluginCategories.removeAll()
        }

        do {
            var allCategories: [PluginCategoryNew] = []

            // 扫描所有插件源
            for source in PluginSourceNew.allCases {
                let sourceCategories = try await scanPluginSourceNew(source)
                allCategories.append(contentsOf: sourceCategories)
            }

            let finalCategories = allCategories
            await MainActor.run {
                self.pluginCategories = finalCategories
                self.isScanning = false
                self.scanProgress = 1.0
            }
        } catch {
            await MainActor.run {
                self.errorMessage = "扫描失败: \(error.localizedDescription)"
                self.isScanning = false
            }
        }
    }

    /// 扫描指定插件源（新方法）
    private func scanPluginSourceNew(_ source: PluginSourceNew) async throws -> [PluginCategoryNew] {
        let sourcePath = source.path

        // 检查路径是否存在
        guard fileManager.fileExists(atPath: sourcePath) else {
            return []
        }

        var categories: [PluginCategoryNew] = []

        // 🔧 修复FxPlug插件扫描问题
        if source == .fxplug {
            // FxPlug插件直接扫描.app文件，不按子类型分目录
            let fxPlugCategory = try await scanFxPlugDirectoryNew(source: source, path: sourcePath)
            if !fxPlugCategory.plugins.isEmpty {
                categories.append(fxPlugCategory)
            }
        } else {
            // Motion Templates结构：按子类型扫描
            for subType in PluginSubType.allCases {
                let subTypePath = sourcePath + "/" + subType.rawValue

                guard fileManager.fileExists(atPath: subTypePath) else {
                    continue
                }

                let subTypeCategories = try await scanSubTypeNew(source: source, subType: subType, path: subTypePath)
                categories.append(contentsOf: subTypeCategories)
            }
        }

        return categories
    }

    /// 扫描子类型目录（新方法）
    private func scanSubTypeNew(source: PluginSourceNew, subType: PluginSubType, path: String) async throws -> [PluginCategoryNew] {
        let contents = try fileManager.contentsOfDirectory(atPath: path)
        var categories: [PluginCategoryNew] = []

        for item in contents {
            let itemPath = path + "/" + item
            var isDirectory: ObjCBool = false

            guard fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                  isDirectory.boolValue else {
                continue
            }

            // 检查是否为FxFactory插件类别（检查.fxfactory.plist文件）
            let isFxFactory = fileManager.fileExists(atPath: itemPath + "/.fxfactory.plist")

            let categoryName = isFxFactory ?
                await getFxFactoryDisplayNameNew(path: itemPath, uuid: String(item.dropLast(10))) : item

            var category = PluginCategoryNew(
                name: categoryName,
                originalName: item,
                path: itemPath,
                source: source,
                subType: subType,
                isFxFactory: isFxFactory,
                plugins: []
            )

            // 扫描类别中的插件
            category.plugins = try await scanPluginsInCategoryNew(category: category)

            if !category.plugins.isEmpty {
                categories.append(category)
            }
        }

        return categories
    }

    /// 扫描类别中的插件（新方法）
    private func scanPluginsInCategoryNew(category: PluginCategoryNew) async throws -> [PluginInfoNew] {
        return try await scanPluginsRecursivelyNew(
            currentPath: category.path,
            categoryPath: category.path,
            source: category.source,
            subType: category.subType,
            isFxFactory: category.isFxFactory
        )
    }

    /// 递归扫描插件（新方法）
    private func scanPluginsRecursivelyNew(
        currentPath: String,
        categoryPath: String,
        source: PluginSourceNew,
        subType: PluginSubType,
        isFxFactory: Bool
    ) async throws -> [PluginInfoNew] {
        let contents = try fileManager.contentsOfDirectory(atPath: currentPath)
        var plugins: [PluginInfoNew] = []

        for item in contents {
            // 跳过隐藏文件
            if item.hasPrefix(".") { continue }

            let itemPath = currentPath + "/" + item
            var isDirectory: ObjCBool = false

            guard fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                  isDirectory.boolValue else {
                continue
            }

            if containsPluginFiles(in: itemPath) {
                // 这是一个插件目录
                let isFxFactory = detectFxFactoryPlugin(name: item, path: itemPath)

                let displayName = isFxFactory ?
                    await getFxFactoryDisplayNameNew(path: itemPath, uuid: String(item.dropLast(10))) : item

                // 获取插件信息
                let attributes = try fileManager.attributesOfItem(atPath: itemPath)
                let fileSize = calculateDirectorySize(at: itemPath)
                let modificationDate = attributes[.modificationDate] as? Date ?? Date()

                // 查找缩略图
                let thumbnailPath = findThumbnail(in: itemPath)

                let plugin = PluginInfoNew(
                    name: item,
                    displayName: displayName,
                    path: itemPath,
                    categoryPath: categoryPath,
                    isFxFactory: isFxFactory,
                    fileSize: fileSize,
                    modificationDate: modificationDate,
                    thumbnailPath: thumbnailPath
                )

                plugins.append(plugin)
            } else {
                // 这可能是主题目录，递归扫描
                let subPlugins = try await scanPluginsRecursivelyNew(
                    currentPath: itemPath,
                    categoryPath: categoryPath,
                    source: source,
                    subType: subType,
                    isFxFactory: isFxFactory
                )
                plugins.append(contentsOf: subPlugins)
            }
        }

        return plugins
    }

    /// 获取FxFactory插件显示名称（新方法）
    private func getFxFactoryDisplayNameNew(path: String, uuid: String) async -> String {
        let stringsPath = path + "/.localized/en.strings"

        guard fileManager.fileExists(atPath: stringsPath) else {
            return uuid
        }

        do {
            let content = try String(contentsOfFile: stringsPath, encoding: .utf8)
            // 解析strings文件内容
            if let range = content.range(of: "\"([^\"]+)\"\\s*=\\s*\"([^\"]+)\"", options: .regularExpression) {
                let match = String(content[range])
                if let equalRange = match.range(of: "=") {
                    let value = String(match[equalRange.upperBound...])
                        .trimmingCharacters(in: .whitespacesAndNewlines)
                        .trimmingCharacters(in: CharacterSet(charactersIn: "\""))
                    return value.isEmpty ? uuid : value
                }
            }
        } catch {
            //print("读取FxFactory显示名称失败: \(error)")
        }

        return uuid
    }

    /// 检查是否包含插件文件（新方法）
    private func containsPluginFiles(in path: String) -> Bool {
        guard let contents = try? fileManager.contentsOfDirectory(atPath: path) else {
            return false
        }

        // 检查是否包含Motion模板文件
        let pluginExtensions = [".moti", ".motn", ".moef", ".motr"]
        return contents.contains { file in
            pluginExtensions.contains { ext in
                file.lowercased().hasSuffix(ext)
            }
        }
    }

    /// 检测是否为FxFactory插件（仅检查.fxfactory.plist文件）
    private func detectFxFactoryPlugin(name: String, path: String) -> Bool {
        // 唯一判定条件：检查是否存在.fxfactory.plist文件
        return fileManager.fileExists(atPath: path + "/.fxfactory.plist")
    }

    /// 查找缩略图（新方法）
    private func findThumbnail(in path: String) -> String? {
        let thumbnailNames = ["large.png", "medium.png", "small.png", "thumbnail.png"]

        for thumbnailName in thumbnailNames {
            let thumbnailPath = path + "/" + thumbnailName
            if fileManager.fileExists(atPath: thumbnailPath) {
                return thumbnailPath
            }
        }

        return nil
    }

    /// 计算目录大小（新方法）
    private func calculateDirectorySize(at path: String) -> Int64 {
        var totalSize: Int64 = 0

        guard fileManager.fileExists(atPath: path) else {
            return 0
        }

        do {
            let resourceKeys: [URLResourceKey] = [.isRegularFileKey, .fileAllocatedSizeKey, .isDirectoryKey]
            let directoryURL = URL(fileURLWithPath: path)

            if let enumerator = fileManager.enumerator(
                at: directoryURL,
                includingPropertiesForKeys: resourceKeys,
                options: [.skipsHiddenFiles],
                errorHandler: { (url, error) -> Bool in
                    return true
                }
            ) {
                for case let fileURL as URL in enumerator {
                    let resourceValues = try fileURL.resourceValues(forKeys: Set(resourceKeys))

                    if resourceValues.isRegularFile == true {
                        totalSize += Int64(resourceValues.fileAllocatedSize ?? 0)
                    }
                }
            }
        } catch {
            //print("计算目录大小失败: \(error)")
        }

        return totalSize
    }

    /// 检查字符串是否为UUID格式（新方法）
    private func isUUID(_ string: String) -> Bool {
        let uuidPattern = "^[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$"
        let regex = try? NSRegularExpression(pattern: uuidPattern, options: .caseInsensitive)
        let range = NSRange(location: 0, length: string.count)
        return regex?.firstMatch(in: string, options: [], range: range) != nil
    }

    /// 扫描FxPlug目录（新方法）
    private func scanFxPlugDirectoryNew(source: PluginSourceNew, path: String) async throws -> PluginCategoryNew {
        var category = PluginCategoryNew(
            name: "FxPlug插件",
            originalName: "FxPlug插件",
            path: path,
            source: source,
            subType: .effects, // FxPlug插件默认归类为效果
            isFxFactory: false,
            plugins: []
        )

        let contents = try fileManager.contentsOfDirectory(atPath: path)

        for item in contents {
            // 只处理.app文件
            guard item.hasSuffix(".app") else { continue }

            let itemPath = path + "/" + item
            let pluginName = String(item.dropLast(4)) // 移除.app后缀

            // 获取插件信息
            let attributes = try fileManager.attributesOfItem(atPath: itemPath)
            let fileSize = calculateDirectorySize(at: itemPath)
            let modificationDate = attributes[.modificationDate] as? Date ?? Date()

            let pluginInfo = PluginInfoNew(
                name: pluginName,
                displayName: pluginName,
                path: itemPath,
                categoryPath: path,
                isFxFactory: false,
                fileSize: fileSize,
                modificationDate: modificationDate,
                thumbnailPath: nil
            )

            category.plugins.append(pluginInfo)
        }

        return category
    }

    // MARK: - 获取可用类别列表
    func getAvailableCategories(for pluginType: PluginType, subType: PluginSubType) async -> [(displayName: String, originalPath: String)] {
        let basePath = pluginType.basePath
        
        // 构建子类型路径
        let subTypePath: String
        switch pluginType {
        case .user, .system:
            subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(subType.rawValue).path
        case .fxplug:
            // FxPlug插件不支持类别合并，因为它们是独立的.app文件
            return []
        case .builtin:
            subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(subType.rawValue).path
        case .plugkit, .trash:
            // PlugKit和回收站不支持类别合并
            return []
        }
        
        guard fileManager.fileExists(atPath: subTypePath) else {
            return []
        }
        
        do {
            let contents = try fileManager.contentsOfDirectory(atPath: subTypePath)
            var categories: [(displayName: String, originalPath: String)] = []
            
            for categoryName in contents {
                // 跳过隐藏文件、系统文件和特殊目录
                if categoryName.hasPrefix(".") ||
                   categoryName == "templateThemes" ||
                   categoryName == "Motion Templates.localized" ||
                   categoryName == "Templates.localized" {
                    continue
                }
                
                let categoryPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(categoryName).path
                var isDirectory: ObjCBool = false
                
                // 验证是否为目录且存在
                if fileManager.fileExists(atPath: categoryPath, isDirectory: &isDirectory) && isDirectory.boolValue {
                    // 解析FxFactory类别名称
                    let resolvedName = await resolveFxFactoryCategoryName(categoryPath: categoryPath, categoryName: categoryName)
                    categories.append((displayName: resolvedName, originalPath: categoryName))
                }
            }
            
            return categories.sorted { $0.displayName.localizedStandardCompare($1.displayName) == .orderedAscending }
        } catch {
            //print("获取类别列表失败: \(error)")
            return []
        }
    }
    

    

    
    // MARK: - 合并插件到其他类别
    func mergePluginToCategory(_ plugin: FCPXPlugin, targetCategoryPath: String, newName: String? = nil) async throws {
        guard let subType = plugin.subType else {
            throw NSError(domain: "PluginManager", code: 1, userInfo: [NSLocalizedDescriptionKey: "插件子类型未知"])
        }
        
        // 构建目标路径
        let basePath = plugin.type.basePath
        let subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(subType.rawValue).path
        let targetPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(targetCategoryPath).path
        
        // 确保目标目录存在
        if !fileManager.fileExists(atPath: targetPath) {
            try fileManager.createDirectory(atPath: targetPath, withIntermediateDirectories: true, attributes: nil)
        }
        
        // 构建新的插件路径
        let originalPluginName: String
        if let customName = newName, !customName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty {
            originalPluginName = customName.trimmingCharacters(in: .whitespacesAndNewlines)
        } else {
            originalPluginName = URL(fileURLWithPath: plugin.path).lastPathComponent
        }
        
        // 处理同名插件冲突，自动添加副本后缀
        var pluginName = originalPluginName
        var newPluginPath = URL(fileURLWithPath: targetPath).appendingPathComponent(pluginName).path
        var copyIndex = 1
        
        while fileManager.fileExists(atPath: newPluginPath) {
            // 如果存在同名插件，添加副本后缀
            let nameWithoutExtension = URL(fileURLWithPath: originalPluginName).deletingPathExtension().lastPathComponent
            let pathExtension = URL(fileURLWithPath: originalPluginName).pathExtension
            
            if pathExtension.isEmpty {
                pluginName = "\(nameWithoutExtension) 副本 \(copyIndex)"
            } else {
                pluginName = "\(nameWithoutExtension) 副本 \(copyIndex).\(pathExtension)"
            }
            
            newPluginPath = URL(fileURLWithPath: targetPath).appendingPathComponent(pluginName).path
            copyIndex += 1
            
            // 防止无限循环，最多尝试100次
            if copyIndex > 100 {
                throw NSError(domain: "PluginManager", code: 3, userInfo: [NSLocalizedDescriptionKey: "无法生成唯一的插件名称"])
            }
        }
        
        // 如果生成了新名称，打印日志
        if pluginName != originalPluginName {
            //print("🔄 检测到同名插件冲突，自动重命名: \(originalPluginName) -> \(pluginName)")
        }
        
        // 移动插件
        try fileManager.moveItem(atPath: plugin.path, toPath: newPluginPath)
        
        // 更新内存中的插件信息
        await MainActor.run { [weak self] in
            guard let self = self else { return }

            if var pluginList = self.plugins[plugin.type] {
                if let index = pluginList.firstIndex(where: { $0.id == plugin.id }) {
                    // 创建新的插件对象，因为path是let常量
                    let updatedPlugin = pluginList[index]
                    let categoryName = URL(fileURLWithPath: newPluginPath).deletingLastPathComponent().lastPathComponent

                    // 创建新的插件实例
                    let finalPluginName: String
                    if let customName = newName, !customName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty {
                        finalPluginName = customName.trimmingCharacters(in: .whitespacesAndNewlines)
                    } else {
                        finalPluginName = updatedPlugin.name
                    }

                    let newPlugin = FCPXPlugin(
                        name: finalPluginName,
                        path: newPluginPath,
                        type: updatedPlugin.type,
                        subType: updatedPlugin.subType,
                        categoryPath: categoryName
                    )

                    // 复制其他属性
                    var finalPlugin = newPlugin
                    finalPlugin.fileSize = updatedPlugin.fileSize
                    finalPlugin.createdDate = updatedPlugin.createdDate
                    finalPlugin.modifiedDate = updatedPlugin.modifiedDate
                    finalPlugin.isFxFactoryPlugin = updatedPlugin.isFxFactoryPlugin
                    finalPlugin.realName = updatedPlugin.realName
                    finalPlugin.motionFilePath = updatedPlugin.motionFilePath
                    finalPlugin.bundleIdentifier = updatedPlugin.bundleIdentifier
                    finalPlugin.version = updatedPlugin.version

                    pluginList[index] = finalPlugin
                    self.plugins[plugin.type] = pluginList
                }
            }
        }
        
        //print("✅ 插件合并成功: \(plugin.displayName) -> \(targetCategoryPath)")
    }

    /// 批量合并插件到指定类别（只需要输入一次密码）
    func batchMergePluginsToCategory(_ plugins: [FCPXPlugin], targetCategoryPath: String) async throws {
        guard !plugins.isEmpty else { return }

        print("🔄 开始批量合并 \(plugins.count) 个插件到类别: \(targetCategoryPath)")

        // 验证所有插件都有相同的子类型
        guard let firstSubType = plugins.first?.subType else {
            throw NSError(domain: "PluginManager", code: 1, userInfo: [NSLocalizedDescriptionKey: "插件子类型未知"])
        }

        let allSameType = plugins.allSatisfy { $0.subType == firstSubType }
        guard allSameType else {
            throw NSError(domain: "PluginManager", code: 2, userInfo: [NSLocalizedDescriptionKey: "批量合并的插件必须是相同类型"])
        }

        // 构建目标路径
        let basePath = plugins.first!.type.basePath
        let subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(firstSubType.rawValue).path
        let targetPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(targetCategoryPath).path

        // 确保目标目录存在
        if !fileManager.fileExists(atPath: targetPath) {
            try fileManager.createDirectory(atPath: targetPath, withIntermediateDirectories: true, attributes: nil)
        }

        // 分组处理：需要权限的操作和普通操作
        var systemMoves: [(from: String, to: String)] = []
        var normalMoves: [(from: String, to: String)] = []
        var updatedPlugins: [FCPXPlugin] = []

        for plugin in plugins {
            // 处理同名冲突
            let originalPluginName = URL(fileURLWithPath: plugin.path).lastPathComponent
            var pluginName = originalPluginName
            var newPluginPath = URL(fileURLWithPath: targetPath).appendingPathComponent(pluginName).path
            var copyIndex = 1

            while fileManager.fileExists(atPath: newPluginPath) {
                let nameWithoutExtension = URL(fileURLWithPath: originalPluginName).deletingPathExtension().lastPathComponent
                let pathExtension = URL(fileURLWithPath: originalPluginName).pathExtension

                if pathExtension.isEmpty {
                    pluginName = "\(nameWithoutExtension) 副本 \(copyIndex)"
                } else {
                    pluginName = "\(nameWithoutExtension) 副本 \(copyIndex).\(pathExtension)"
                }

                newPluginPath = URL(fileURLWithPath: targetPath).appendingPathComponent(pluginName).path
                copyIndex += 1

                if copyIndex > 100 {
                    throw NSError(domain: "PluginManager", code: 3, userInfo: [NSLocalizedDescriptionKey: "无法生成唯一的插件名称"])
                }
            }

            // 根据是否需要权限分组
            if SudoPermissionManager.shared.needsSudoPermission(for: plugin.path) {
                systemMoves.append((from: plugin.path, to: newPluginPath))
            } else {
                normalMoves.append((from: plugin.path, to: newPluginPath))
            }

            // 准备更新的插件信息
            let categoryName = URL(fileURLWithPath: newPluginPath).deletingLastPathComponent().lastPathComponent
            let newPlugin = FCPXPlugin(
                name: plugin.name,
                path: newPluginPath,
                type: plugin.type,
                subType: plugin.subType,
                categoryPath: categoryName
            )

            var finalPlugin = newPlugin
            finalPlugin.fileSize = plugin.fileSize
            finalPlugin.createdDate = plugin.createdDate
            finalPlugin.modifiedDate = plugin.modifiedDate
            finalPlugin.isFxFactoryPlugin = plugin.isFxFactoryPlugin
            finalPlugin.realName = plugin.realName
            finalPlugin.motionFilePath = plugin.motionFilePath
            finalPlugin.bundleIdentifier = plugin.bundleIdentifier
            finalPlugin.version = plugin.version

            updatedPlugins.append(finalPlugin)
        }

        // 批量执行需要权限的移动操作（一次性请求权限）
        if !systemMoves.isEmpty {
            let moveCommands = systemMoves.map { "mv '\($0.from)' '\($0.to)'" }.joined(separator: " && ")
            try await SudoPermissionManager.shared.executeAppleScriptCommand(moveCommands)
            print("✅ 成功批量移动 \(systemMoves.count) 个系统插件")
        }

        // 执行普通移动操作
        for move in normalMoves {
            try fileManager.moveItem(atPath: move.from, toPath: move.to)
        }

        // 更新内存中的插件信息
        await MainActor.run { [weak self] in
            guard let self = self else { return }

            for (index, plugin) in plugins.enumerated() {
                if var pluginList = self.plugins[plugin.type] {
                    if let pluginIndex = pluginList.firstIndex(where: { $0.id == plugin.id }) {
                        pluginList[pluginIndex] = updatedPlugins[index]
                        self.plugins[plugin.type] = pluginList
                    }
                }
            }
        }

        print("🎉 批量合并完成: 成功合并 \(plugins.count) 个插件到 \(targetCategoryPath)")
    }

    // MARK: - 加载插件（流式更新版本）
    func loadPlugins(for type: PluginType, forceRefreshCache: Bool = false) async {
        // 检查系统兼容性
        let compatibilityManager = SystemCompatibilityManager.shared
        let criticalIssues = compatibilityManager.compatibilityIssues.filter { $0.severity == .critical }

        if !criticalIssues.isEmpty {
            await MainActor.run {
                errorMessage = "检测到严重兼容性问题，可能影响应用稳定性。请查看兼容性警告。"
                isLoading = false
            }
            return
        }

        // 如果已经加载过且不强制刷新，直接返回缓存结果
        if !forceRefreshCache && plugins[type] != nil && !plugins[type]!.isEmpty {
            await MainActor.run {
                loadingProgress = "已缓存 \(plugins[type]?.count ?? 0) 个插件"
                isLoading = false
                // 注意：不设置isGlobalScanComplete，因为这只是单个插件源的缓存
            }

            // 1秒后清空进度信息
            Task { @MainActor [weak self] in
                try? await Task.sleep(nanoseconds: 1_000_000_000)
                self?.loadingProgress = ""
            }
            return
        }

        await MainActor.run {
            isLoading = true
            errorMessage = nil
            // 清空当前插件列表，准备流式更新
            plugins[type] = []
            scannedCount = 0
            loadingProgress = "首次扫描 \(type.displayName)..."
        }

        // 移除 FxFactory 缓存依赖，改为直接读取

        defer {
            Task { @MainActor [weak self] in
                guard let self = self else { return }

                self.isLoading = false
                self.loadingProgress = "扫描完成！共找到 \(self.plugins[type]?.count ?? 0) 个插件"

                // 注意：不设置isGlobalScanComplete，这由scanAllPluginSources统一管理

                // 3秒后清空进度信息
                Task { @MainActor [weak self] in
                    try? await Task.sleep(nanoseconds: 3_000_000_000) // 3秒
                    self?.loadingProgress = ""
                }
            }
        }

        await readPluginDirectorySimple(for: type)
    }

    // MARK: - 批量扫描所有插件源
    func scanAllPluginSources() async {
        // 使用新方法进行扫描
        await scanAllPluginsNew()

        // 转换新方法的数据到旧格式，保持兼容性
        await convertNewDataToOldFormat()

        await MainActor.run {
            isLoading = false
            isGlobalScanComplete = true

            let totalPlugins = plugins.values.reduce(0) { $0 + $1.count }
            loadingProgress = "扫描完成！共找到 \(totalPlugins) 个插件"

            // 3秒后清空进度信息
            Task { @MainActor [weak self] in
                try? await Task.sleep(nanoseconds: 3_000_000_000)
                self?.loadingProgress = ""
            }
        }
    }

    /// 将新方法的数据转换为旧格式（保持兼容性）
    private func convertNewDataToOldFormat() async {
        await MainActor.run {
            // 清空旧数据
            plugins.removeAll()

            // 按插件源分组转换
            for category in pluginCategories {
                let pluginType: PluginType
                switch category.source {
                case .user: pluginType = .user
                case .system: pluginType = .system
                case .fxplug: pluginType = .fxplug
                }

                // 转换插件数据
                let convertedPlugins = category.plugins.map { pluginInfo in
                    var plugin = FCPXPlugin(
                        name: pluginInfo.name,
                        path: pluginInfo.path,
                        type: pluginType,
                        subType: category.subType,
                        categoryPath: category.path
                    )
                    plugin.fileSize = pluginInfo.fileSize
                    plugin.modifiedDate = pluginInfo.modificationDate
                    plugin.isFxFactoryPlugin = pluginInfo.isFxFactory
                    if pluginInfo.isFxFactory {
                        plugin.realName = pluginInfo.displayName
                    }
                    return plugin
                }

                // 添加到对应的插件源
                if plugins[pluginType] == nil {
                    plugins[pluginType] = []
                }
                plugins[pluginType]?.append(contentsOf: convertedPlugins)
            }

            //print("✅ 数据转换完成，插件源数据:")
            for (_, _) in plugins {
                //print("   \(type.displayName): \(pluginList.count) 个插件")
            }
        }
    }

    // MARK: - 静默扫描插件（不更新UI状态）
    private func loadPluginsSilently(for type: PluginType) async {
        //print("🚀 开始静默扫描插件源: \(type.displayName)")

        // 检查系统兼容性
        let compatibilityManager = SystemCompatibilityManager.shared
        let criticalIssues = compatibilityManager.compatibilityIssues.filter { $0.severity == .critical }

        if !criticalIssues.isEmpty {
            await MainActor.run {
                errorMessage = "检测到严重兼容性问题，可能影响应用稳定性。请查看兼容性警告。"
            }
            return
        }

        // 清空当前插件源的数据，避免重复累积
        await MainActor.run {
            plugins[type] = []
            scannedCount = 0
        }

        // 验证插件源路径
        let basePath = type.basePath
        guard fileManager.fileExists(atPath: basePath) else {
            //print("⚠️ 插件源路径不存在: \(basePath)")
            return
        }

        //print("📍 插件源路径: \(basePath)")

        // 静默扫描，直接更新数据但不触发UI状态变化
        await readPluginDirectorySimple(for: type)

        // 验证扫描结果
        await MainActor.run {
            _ = plugins[type]?.count ?? 0
            //print("✅ 插件源 \(type.displayName) 扫描完成，找到 \(pluginCount) 个插件")

            // 验证插件路径的一致性
            if let sourcePlugins = plugins[type] {
                let invalidPlugins = sourcePlugins.filter { plugin in
                    !validatePluginSourcePath(categoryPath: plugin.path, expectedSource: type)
                }

                if !invalidPlugins.isEmpty {
                    //print("🚨 发现 \(invalidPlugins.count) 个路径不匹配的插件:")
                    for _ in invalidPlugins {
                        //print("   - \(plugin.name): \(plugin.path)")
                    }

                    // 过滤掉路径不匹配的插件
                    let validPlugins = sourcePlugins.filter { plugin in
                        validatePluginSourcePath(categoryPath: plugin.path, expectedSource: type)
                    }
                    plugins[type] = validPlugins
                    //print("🔧 已过滤无效插件，剩余 \(validPlugins.count) 个有效插件")
                }
            }
        }
    }

    // MARK: - 刷新插件缓存
    func refreshPlugins(for type: PluginType) async {
        await loadPlugins(for: type, forceRefreshCache: true)
    }

    // MARK: - 清空所有缓存
    func clearAllCache() {
        // 清空插件数据
        plugins.removeAll()
        pluginCategories.removeAll()
        categories.removeAll()

        // 清空状态
        isGlobalScanComplete = false
        isLoading = false
        isScanning = false
        scanProgress = 0.0
        scannedCount = 0
        loadingProgress = ""
        errorMessage = nil

        // 清空搜索和选择状态
        searchText = ""
        selectedPlugins.removeAll()

        // 清空体积缓存
        SizeCacheManager.shared.clearCache()

        // 清空缩略图缓存
        thumbnailCache.clearCache()

        print("🧹 已清空所有缓存和状态")
    }

    // MARK: - 新的扫描逻辑（基于新方法）
    private func readPluginDirectorySimple(for type: PluginType) async {
        let basePath = type.basePath

        // 添加系统目录访问的安全检查
        if type == .system {
            guard await checkSystemDirectoryAccess(basePath) else {
                //print("❌ 无法访问系统插件目录: \(basePath)")
                await MainActor.run {
                    errorMessage = "无法访问系统插件目录，可能是权限问题。请确保应用有足够的权限访问系统目录。"
                    isLoading = false
                }
                return
            }
        }

        guard fileManager.fileExists(atPath: basePath) else {
            return
        }

        // 根据插件类型选择不同的读取策略
        switch type {
        case .user, .system:
            await scanMotionTemplatesWithNewLogic(basePath: basePath, type: type)
        case .fxplug:
            await readFxPlugDirectory(basePath: basePath, type: type)
        default:
            break
        }
    }

    // MARK: - 使用新扫描逻辑扫描Motion Templates目录
    private func scanMotionTemplatesWithNewLogic(basePath: String, type: PluginType) async {
        // 确定模板目录路径
        let motionTemplatesPath: String
        if basePath.hasSuffix("Templates.localized") {
            motionTemplatesPath = basePath
        } else if basePath.hasSuffix("Motion Templates.localized") {
            motionTemplatesPath = basePath
        } else {
            motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
        }

        guard fileManager.fileExists(atPath: motionTemplatesPath) else {
            //print("⚠️ Motion Templates目录不存在: \(motionTemplatesPath)")
            return
        }

        //print("🔍 开始扫描插件源: \(type.displayName) 路径: \(motionTemplatesPath)")

        // 扫描每个子类型
        for subType in PluginSubType.allCases.filter({ $0 != .compositions }) {
            let subTypePath = motionTemplatesPath + "/" + subType.rawValue

            guard fileManager.fileExists(atPath: subTypePath) else {
                continue
            }

            //print("📁 扫描子类型: \(subType.displayName) 路径: \(subTypePath)")
            await scanSubTypeWithNewLogic(source: type, subType: subType, path: subTypePath)
        }

        //print("✅ 完成扫描插件源: \(type.displayName)")
    }

    // MARK: - 使用新逻辑扫描子类型目录（快速扫描，不计算大小）
    private func scanSubTypeWithNewLogic(source: PluginType, subType: PluginSubType, path: String) async {
        do {
            let contents = try fileManager.contentsOfDirectory(atPath: path)
            var batchPlugins: [FCPXPlugin] = []

            for categoryItem in contents {
                let categoryPath = path + "/" + categoryItem
                var isDirectory: ObjCBool = false

                guard fileManager.fileExists(atPath: categoryPath, isDirectory: &isDirectory),
                      isDirectory.boolValue else {
                    continue
                }

                // 验证路径与插件源的一致性
                if !validatePluginSourcePath(categoryPath: categoryPath, expectedSource: source) {
                    //print("🚨 路径与插件源不匹配，跳过: \(categoryPath)")
                    continue
                }

                // 检查是否为FxFactory插件类别（检查.fxfactory.plist文件）
                let isFxFactory = fileManager.fileExists(atPath: categoryPath + "/.fxfactory.plist")

                //print("📂 扫描类别目录: \(categoryItem) (FxFactory: \(isFxFactory))")

                // 快速扫描类别目录中的插件
                let plugins = await scanPluginsFast(
                    categoryPath: categoryPath,
                    source: source,
                    subType: subType,
                    isFxFactory: isFxFactory
                )

                // 再次验证扫描结果中的插件路径
                let validatedPlugins = plugins.filter { plugin in
                    let isValid = validatePluginSourcePath(categoryPath: plugin.path, expectedSource: source)
                    if !isValid {
                        //print("🚨 发现路径不匹配的插件，已过滤: \(plugin.name) - \(plugin.path)")
                    }
                    return isValid
                }

                batchPlugins.append(contentsOf: validatedPlugins)
                //print("✅ 类别 \(categoryItem) 扫描完成，找到 \(validatedPlugins.count) 个有效插件")
            }

            // 批量更新UI，减少频繁更新
            await MainActor.run {
                if var existingPlugins = self.plugins[source] {
                    existingPlugins.append(contentsOf: batchPlugins)
                    self.plugins[source] = existingPlugins
                } else {
                    self.plugins[source] = batchPlugins
                }
                self.scannedCount = self.plugins[source]?.count ?? 0
                self.loadingProgress = "已扫描 \(subType.displayName)，找到 \(batchPlugins.count) 个插件"
            }
        } catch {
            //print("扫描子类型目录失败 \(path): \(error)")
        }
    }

    // MARK: - 验证插件路径与插件源的一致性
    private func validatePluginSourcePath(categoryPath: String, expectedSource: PluginType) -> Bool {
        switch expectedSource {
        case .user:
            // 用户插件应该在用户目录下
            return categoryPath.contains("/Users/") && categoryPath.contains("Movies/Motion Templates.localized")
        case .system:
            // 系统插件应该在系统目录下
            return categoryPath.contains("/Library/Application Support/Final Cut Pro/Templates.localized")
        case .fxplug:
            // FxPlug插件应该在FxPlug目录下
            return categoryPath.contains("/Library/Plug-Ins/FxPlug")
        default:
            return true
        }
    }

    // MARK: - 快速扫描插件（不计算大小和缩略图）
    private func scanPluginsFast(
        categoryPath: String,
        source: PluginType,
        subType: PluginSubType,
        isFxFactory: Bool
    ) async -> [FCPXPlugin] {
        return await scanPluginsRecursively(
            currentPath: categoryPath,
            originalCategoryPath: categoryPath,
            source: source,
            subType: subType,
            isFxFactory: isFxFactory
        )
    }

    // MARK: - 递归扫描插件目录
    private func scanPluginsRecursively(
        currentPath: String,
        originalCategoryPath: String,
        source: PluginType,
        subType: PluginSubType,
        isFxFactory: Bool
    ) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        do {
            let contents = try fileManager.contentsOfDirectory(atPath: currentPath)

            for item in contents {
                // 跳过隐藏文件
                if item.hasPrefix(".") { continue }

                let itemPath = currentPath + "/" + item
                var isDirectory: ObjCBool = false

                guard fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                      isDirectory.boolValue else {
                    continue
                }

                // 快速检查是否包含插件文件
                if containsPluginFilesQuick(in: itemPath) {
                    // 这是一个插件目录
                    //print("🔍 发现插件目录: \(itemPath)")

                    // 检测是否为FxFactory插件（改进版本）
                    let pluginIsFxFactory = detectFxFactoryPlugin(name: item, path: itemPath)

                    // 获取基本信息（不计算大小）
                    let attributes = try fileManager.attributesOfItem(atPath: itemPath)
                    let modificationDate = attributes[.modificationDate] as? Date ?? Date()

                    // 获取显示名称（FxFactory插件解析真实名称）
                    let displayName = pluginIsFxFactory ?
                        await getFxFactoryDisplayName(path: itemPath, uuid: extractUUIDFromName(item)) : item

                    // 验证插件路径与插件源的一致性
                    if !validatePluginSourcePath(categoryPath: itemPath, expectedSource: source) {
                        //print("🚨 插件路径与插件源不匹配，跳过: \(displayName) - \(itemPath)")
                        continue
                    }

                    // 创建插件对象（不计算大小）
                    var plugin = FCPXPlugin(
                        name: item,
                        path: itemPath,
                        type: source,
                        subType: subType,
                        categoryPath: originalCategoryPath  // 使用原始类别路径
                    )

                    plugin.fileSize = 0 // 不计算大小以提高速度
                    plugin.modifiedDate = modificationDate
                    plugin.isFxFactoryPlugin = pluginIsFxFactory

                    // 设置FxFactory插件的真实名称
                    if pluginIsFxFactory {
                        plugin.realName = displayName
                    }

                    plugins.append(plugin)
                    //print("✅ 添加插件: \(displayName) 在路径 \(itemPath)")
                } else {
                    // 这可能是主题目录，递归扫描子目录
                    //print("🔄 递归扫描主题目录: \(itemPath)")
                    let subPlugins = await scanPluginsRecursively(
                        currentPath: itemPath,
                        originalCategoryPath: originalCategoryPath,  // 保持原始类别路径
                        source: source,
                        subType: subType,
                        isFxFactory: isFxFactory
                    )
                    plugins.append(contentsOf: subPlugins)
                }
            }
        } catch {
            //print("快速扫描插件失败 \(currentPath): \(error)")
        }

        return plugins
    }

    // MARK: - 快速检查是否包含插件文件
    private func containsPluginFilesQuick(in path: String) -> Bool {
        guard let contents = try? fileManager.contentsOfDirectory(atPath: path) else {
            return false
        }

        // 检查是否包含Motion模板文件
        let pluginExtensions = [".moti", ".motn", ".moef", ".motr"]
        for item in contents {
            for ext in pluginExtensions {
                if item.hasSuffix(ext) {
                    return true
                }
            }
        }

        // 检查是否包含Media目录（也是插件的标识）
        if contents.contains("Media") {
            let mediaPath = URL(fileURLWithPath: path).appendingPathComponent("Media").path
            var isDirectory: ObjCBool = false
            if fileManager.fileExists(atPath: mediaPath, isDirectory: &isDirectory) && isDirectory.boolValue {
                return true
            }
        }

        return false
    }



    // MARK: - 新逻辑辅助方法

    /// 获取FxFactory插件的显示名称（复用新方法的实现）
    private func getFxFactoryDisplayName(path: String, uuid: String) async -> String {
        let stringsPath = path + "/.localized/en.strings"

        guard fileManager.fileExists(atPath: stringsPath),
              let data = fileManager.contents(atPath: stringsPath),
              let content = String(data: data, encoding: .utf8) else {
            return uuid
        }

        // 解析strings文件格式: "UUID" = "Display Name";
        let pattern = "\"\(uuid)\"\\s*=\\s*\"([^\"]+)\""
        if let regex = try? NSRegularExpression(pattern: pattern),
           let match = regex.firstMatch(in: content, range: NSRange(content.startIndex..., in: content)),
           let range = Range(match.range(at: 1), in: content) {
            return String(content[range])
        }

        return uuid
    }



    /// 从文件名中提取UUID
    private func extractUUIDFromName(_ name: String) -> String {
        // 如果有.localized后缀，去掉后缀
        if name.hasSuffix(".localized") {
            return String(name.dropLast(10))
        }

        // 如果直接是UUID格式，直接返回
        if isUUID(name) {
            return name
        }

        return name
    }





    // MARK: - 读取Motion Templates目录（简单版本）
    private func readMotionTemplatesDirectory(basePath: String, type: PluginType) async {
        // 确定模板目录路径
        let motionTemplatesPath: String
        if basePath.hasSuffix("Templates.localized") {
            motionTemplatesPath = basePath
        } else if basePath.hasSuffix("Motion Templates.localized") {
            motionTemplatesPath = basePath
        } else {
            motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
        }

        guard fileManager.fileExists(atPath: motionTemplatesPath) else {
            return
        }

        // 简单顺序读取所有子类型目录
        let subTypes = PluginSubType.allCases.filter { $0 != .compositions }

        for subType in subTypes {
            await readSubTypeDirectory(motionTemplatesPath: motionTemplatesPath, subType: subType, type: type)
        }
    }

    // MARK: - 读取子类型目录（简单版本）
    private func readSubTypeDirectory(motionTemplatesPath: String, subType: PluginSubType, type: PluginType) async {
        let subTypePath = URL(fileURLWithPath: motionTemplatesPath).appendingPathComponent(subType.rawValue).path

        guard fileManager.fileExists(atPath: subTypePath) else {
            return
        }

        do {
            let categoryNames = try fileManager.contentsOfDirectory(atPath: subTypePath)
                .filter { !$0.hasPrefix(".") }

            // 简单顺序读取每个类别目录
            for categoryName in categoryNames {
                await readCategoryDirectory(
                    subTypePath: subTypePath,
                    categoryName: categoryName,
                    subType: subType,
                    type: type
                )
            }
        } catch {
            // 静默处理错误，避免日志影响性能
        }
    }

    // MARK: - 读取类别目录（批量优化版本）
    private func readCategoryDirectory(subTypePath: String, categoryName: String, subType: PluginSubType, type: PluginType) async {
        let categoryPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(categoryName).path

        var isDirectory: ObjCBool = false
        guard fileManager.fileExists(atPath: categoryPath, isDirectory: &isDirectory), isDirectory.boolValue else {
            return
        }

        do {
            let pluginContents = try fileManager.contentsOfDirectory(atPath: categoryPath)
                .filter { !$0.hasPrefix(".") }

            var batchPlugins: [FCPXPlugin] = []

            // 批量处理插件，减少UI更新频率
            for pluginName in pluginContents {
                let pluginPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(pluginName).path

                // 检查是否为插件目录
                var pluginIsDirectory: ObjCBool = false
                guard fileManager.fileExists(atPath: pluginPath, isDirectory: &pluginIsDirectory), pluginIsDirectory.boolValue else {
                    continue
                }

                // 创建插件对象
                if let plugin = await createPluginFromPath(
                    pluginPath: pluginPath,
                    pluginName: pluginName,
                    categoryPath: categoryPath,
                    subType: subType,
                    type: type
                ) {
                    batchPlugins.append(plugin)
                }
            }

            // 批量更新UI，减少主线程切换
            if !batchPlugins.isEmpty {
                await MainActor.run {
                    if plugins[type] == nil {
                        plugins[type] = []
                    }
                    plugins[type]?.append(contentsOf: batchPlugins)
                    scannedCount += batchPlugins.count

                    // 减少进度更新频率，提高性能
                    if scannedCount % 10 == 0 || batchPlugins.count < 10 {
                        loadingProgress = "已读取 \(scannedCount) 个插件..."
                    }
                }
            }
        } catch {
            // 静默处理错误，避免日志影响性能
        }
    }

    // MARK: - 从路径创建插件对象（极简版本 - 像访达一样快）
    private func createPluginFromPath(pluginPath: String, pluginName: String, categoryPath: String, subType: PluginSubType, type: PluginType) async -> FCPXPlugin? {
        // 只做最基本的检查 - 确保是插件目录
        var isDirectory: ObjCBool = false
        guard fileManager.fileExists(atPath: pluginPath, isDirectory: &isDirectory), isDirectory.boolValue else {
            return nil
        }

        // 快速检查是否包含Motion文件（不深度扫描）
        let hasMotionFile = hasMotionFileQuick(in: pluginPath)
        guard hasMotionFile else {
            return nil
        }

        // 快速检查是否为FxFactory插件
        let isFxFactory = checkIsFxFactoryPluginQuick(at: pluginPath)

        // 创建插件对象（只设置基本信息）
        var plugin = FCPXPlugin(
            name: pluginName,
            path: pluginPath,
            type: type,
            subType: subType,
            categoryPath: categoryPath
        )

        // 只设置必要属性，其他延迟加载
        plugin.isFxFactoryPlugin = isFxFactory
        plugin.fileSize = 0  // 延迟计算
        plugin.modifiedDate = Date()  // 延迟获取

        // FxFactory插件名称立即解析
        if isFxFactory {
            plugin.resolveFxFactoryName()
        }

        return plugin
    }

    // MARK: - 快速检查是否包含Motion文件
    private func hasMotionFileQuick(in pluginPath: String) -> Bool {
        do {
            let contents = try fileManager.contentsOfDirectory(atPath: pluginPath)
            return contents.contains { file in
                file.hasSuffix(".motn") || file.hasSuffix(".moef") ||
                file.hasSuffix(".moti") || file.hasSuffix(".motr")
            }
        } catch {
            return false
        }
    }

    // MARK: - 快速检查FxFactory插件
    private func checkIsFxFactoryPluginQuick(at path: String) -> Bool {
        let fxfactoryPlistPath = URL(fileURLWithPath: path).appendingPathComponent(".fxfactory.plist").path
        return fileManager.fileExists(atPath: fxfactoryPlistPath)
    }



    // MARK: - 读取FxPlug目录（简单版本）
    private func readFxPlugDirectory(basePath: String, type: PluginType) async {
        guard fileManager.fileExists(atPath: basePath) else {
            return
        }

        do {
            let pluginFiles = try fileManager.contentsOfDirectory(atPath: basePath)
                .filter { $0.hasSuffix(".app") && !$0.hasPrefix(".") }

            var batchPlugins: [FCPXPlugin] = []

            // 极简处理FxPlug插件
            for pluginFile in pluginFiles {
                let pluginPath = URL(fileURLWithPath: basePath).appendingPathComponent(pluginFile).path
                let pluginName = String(pluginFile.dropLast(4)) // 移除.app后缀

                // 创建FxPlug插件对象（最小信息）
                let plugin = FCPXPlugin(
                    name: pluginName,
                    path: pluginPath,
                    type: type,
                    subType: nil,
                    categoryPath: basePath
                )

                // 不做任何额外计算，保持最快速度
                batchPlugins.append(plugin)
            }

            // 批量更新UI
            if !batchPlugins.isEmpty {
                await MainActor.run {
                    if plugins[type] == nil {
                        plugins[type] = []
                    }
                    plugins[type]?.append(contentsOf: batchPlugins)
                    scannedCount += batchPlugins.count
                    loadingProgress = "已读取 \(scannedCount) 个插件..."
                }
            }
        } catch {
            // 静默处理错误，避免日志影响性能
        }
    }

    // MARK: - 辅助方法：检查FxFactory插件
    private func checkIsFxFactoryPlugin(at path: String) -> Bool {
        let fxfactoryPlistPath = URL(fileURLWithPath: path).appendingPathComponent(".fxfactory.plist").path
        return fileManager.fileExists(atPath: fxfactoryPlistPath)
    }

    // MARK: - 辅助方法：解析FxFactory插件名称
    private func resolveFxFactoryName(pluginPath: String, originalName: String) -> String {
        let localizedPath = URL(fileURLWithPath: pluginPath).appendingPathComponent(".localized")
        let stringsPath = localizedPath.appendingPathComponent("en.strings")

        guard fileManager.fileExists(atPath: stringsPath.path) else {
            return originalName
        }

        do {
            let content = try String(contentsOfFile: stringsPath.path, encoding: .utf8)

            // 解析strings文件格式: "key" = "value";
            let lines = content.components(separatedBy: .newlines)
            for line in lines {
                let trimmed = line.trimmingCharacters(in: .whitespacesAndNewlines)
                if trimmed.contains("=") && trimmed.contains("\"") {
                    if let equalIndex = trimmed.firstIndex(of: "=") {
                        let valueString = String(trimmed[trimmed.index(after: equalIndex)...])
                            .trimmingCharacters(in: .whitespacesAndNewlines)

                        if valueString.hasPrefix("\"") && valueString.hasSuffix("\";") {
                            let startIndex = valueString.index(after: valueString.startIndex)
                            let endIndex = valueString.index(valueString.endIndex, offsetBy: -2)
                            return String(valueString[startIndex..<endIndex])
                        }
                    }
                }
            }
        } catch {
            // 静默处理错误，避免日志影响性能
        }

        return originalName
    }

    // MARK: - 按需计算插件文件大小
    func calculatePluginSize(for plugin: FCPXPlugin) async -> Int64 {
        return calculateDirectorySize(at: plugin.path)
    }

    // MARK: - 加载目录插件
    private func loadDirectoryPlugins(for type: PluginType) async -> [FCPXPlugin] {
        let basePath = type.basePath

        // 添加系统目录访问的安全检查
        if type == .system {
            guard await checkSystemDirectoryAccess(basePath) else {
                //print("❌ 无法访问系统插件目录: \(basePath)")
                await MainActor.run {
                    errorMessage = "无法访问系统插件目录，可能是权限问题。请确保应用有足够的权限访问系统目录。"
                }
                return []
            }
        }

        guard fileManager.fileExists(atPath: basePath) else {
            //print("插件目录不存在: \(basePath)")
            return []
        }

        var allPlugins: [FCPXPlugin] = []

        // 根据插件类型选择不同的扫描策略
        switch type {
        case .user, .system:
            // 使用简单的顺序扫描，避免并发导致的闪退问题
            allPlugins = []  // 新的简单读取方法不返回数组，直接更新UI
        case .fxplug:
            // 扫描FxPlug目录
            allPlugins = await scanFxPlugDirectory(basePath: basePath, type: type)
        default:
            break
        }

        return allPlugins
    }

    // MARK: - 检查系统目录访问权限
    private func checkSystemDirectoryAccess(_ path: String) async -> Bool {
        do {
            // 尝试读取目录内容来验证访问权限
            let _ = try fileManager.contentsOfDirectory(atPath: path)
            return true
        } catch {
            //print("❌ 系统目录访问失败: \(error.localizedDescription)")

            // 检查具体的错误类型
            if let nsError = error as NSError? {
                switch nsError.code {
                case NSFileReadNoPermissionError:
                    break //print("   错误类型: 权限不足")
                case NSFileReadNoSuchFileError:
                    break //print("   错误类型: 目录不存在")
                default:
                    break //print("   错误代码: \(nsError.code)")
                }
            }

            return false
        }
    }

    // MARK: - 优化加载目录插件
    private func loadDirectoryPluginsOptimized(for type: PluginType) async {
        let basePath = type.basePath

        // 添加系统目录访问的安全检查
        if type == .system {
            guard await checkSystemDirectoryAccess(basePath) else {
                //print("❌ 无法访问系统插件目录: \(basePath)")
                await MainActor.run {
                    errorMessage = "无法访问系统插件目录，可能是权限问题。请确保应用有足够的权限访问系统目录。"
                    isLoading = false
                }
                return
            }
        }

        guard fileManager.fileExists(atPath: basePath) else {
            //print("插件目录不存在: \(basePath)")
            return
        }

        // 根据插件类型选择不同的扫描策略
        switch type {
        case .user, .system:
            // 使用优化的并发扫描，但保持简单的更新策略
            let allPlugins = await scanMotionTemplatesDirectoryConcurrent(basePath: basePath, type: type)
            await MainActor.run {
                // 去重：使用Set来移除重复的插件（基于路径）
                let uniquePlugins = Array(Set(allPlugins))
                plugins[type] = uniquePlugins
                scannedCount = uniquePlugins.count
                loadingProgress = "扫描完成！共找到 \(uniquePlugins.count) 个插件"
                // 静默处理重复插件，不输出日志
                updatePluginCounts(for: type)
            }
        case .fxplug:
            // FxPlug插件使用原有方式（数量较少）
            let fxPlugins = await scanFxPlugDirectory(basePath: basePath, type: type)
            await MainActor.run {
                // 去重：使用Set来移除重复的插件（基于路径）
                let uniquePlugins = Array(Set(fxPlugins))
                plugins[type] = uniquePlugins
                scannedCount = uniquePlugins.count
                loadingProgress = "扫描完成！共找到 \(uniquePlugins.count) 个插件"
                // 静默处理重复插件，不输出日志
                updatePluginCounts(for: type)
            }
        default:
            break
        }
    }

    // MARK: - 流式扫描Motion Templates目录
    private func scanMotionTemplatesDirectoryStreaming(basePath: String, type: PluginType) async {
        // 确定模板目录路径
        let motionTemplatesPath: String
        if basePath.hasSuffix("Templates.localized") {
            motionTemplatesPath = basePath
        } else if basePath.hasSuffix("Motion Templates.localized") {
            motionTemplatesPath = basePath
        } else {
            motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
        }

        guard fileManager.fileExists(atPath: motionTemplatesPath) else {
            //print("Motion Templates目录不存在: \(motionTemplatesPath)")
            return
        }

        // 流式扫描所有子类型目录
        let subTypes = PluginSubType.allCases.filter { $0 != .compositions }

        await withTaskGroup(of: Void.self) { group in
            for subType in subTypes {
                group.addTask {
                    await self.scanSubTypeDirectoryStreaming(
                        motionTemplatesPath: motionTemplatesPath,
                        subType: subType,
                        type: type
                    )
                }
            }
        }
    }

    // MARK: - 流式扫描子类型目录
    private func scanSubTypeDirectoryStreaming(motionTemplatesPath: String, subType: PluginSubType, type: PluginType) async {
        let subTypePath = URL(fileURLWithPath: motionTemplatesPath).appendingPathComponent(subType.rawValue).path

        guard fileManager.fileExists(atPath: subTypePath) else {
            return
        }

        do {
            let categoryNames = try fileManager.contentsOfDirectory(atPath: subTypePath)
                .filter { !$0.hasPrefix(".") }

            // 流式扫描所有类别目录
            await withTaskGroup(of: Void.self) { group in
                for categoryName in categoryNames {
                    group.addTask {
                        let categoryPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(categoryName).path
                        let displayCategoryName = await self.resolveFxFactoryCategoryName(categoryPath: categoryPath, categoryName: categoryName)

                        await self.scanCategoryDirectoryStreaming(
                            categoryPath: categoryPath,
                            categoryName: displayCategoryName,
                            type: type,
                            subType: subType
                        )
                    }
                }
            }

        } catch {
            //print("流式扫描子类型目录失败 \(subTypePath): \(error)")
        }
    }

    // MARK: - 扫描Motion Templates目录
    private func scanMotionTemplatesDirectory(basePath: String, type: PluginType) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        // 确定模板目录路径
        let motionTemplatesPath: String
        if basePath.hasSuffix("Templates.localized") {
            // 系统插件目录：/Library/Application Support/Final Cut Pro/Templates.localized
            motionTemplatesPath = basePath
        } else if basePath.hasSuffix("Motion Templates.localized") {
            // 用户插件目录：~/Movies/Motion Templates.localized
            motionTemplatesPath = basePath
        } else {
            // 其他情况，尝试添加Motion Templates.localized子目录
            motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
        }

        guard fileManager.fileExists(atPath: motionTemplatesPath) else {
            //print("模板目录不存在: \(motionTemplatesPath)")
            return plugins
        }

        for subType in PluginSubType.allCases {
            let subTypePath = URL(fileURLWithPath: motionTemplatesPath).appendingPathComponent(subType.rawValue).path

            guard fileManager.fileExists(atPath: subTypePath) else { continue }

            do {
                let categoryContents = try fileManager.contentsOfDirectory(atPath: subTypePath)

                for categoryName in categoryContents {
                    // 跳过隐藏文件和系统文件
                    if categoryName.hasPrefix(".") || categoryName == "templateThemes" { continue }

                    let categoryPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(categoryName).path
                    var isDirectory: ObjCBool = false

                    guard fileManager.fileExists(atPath: categoryPath, isDirectory: &isDirectory),
                          isDirectory.boolValue else { continue }

                    // 解析FxFactory类别目录的真实名称
                    let displayCategoryName = await resolveFxFactoryCategoryName(
                        categoryPath: categoryPath,
                        categoryName: categoryName
                    )

                    // 扫描类别目录中的插件
                    let categoryPlugins = await scanCategoryDirectory(
                        categoryPath: categoryPath,
                        categoryName: displayCategoryName,
                        type: type,
                        subType: subType
                    )

                    plugins.append(contentsOf: categoryPlugins)
                }
            } catch {
                //print("扫描子类型目录失败 \(subTypePath): \(error)")
            }
        }

        return plugins
    }

    // MARK: - 并发扫描Motion Templates目录（优化版本）
    private func scanMotionTemplatesDirectoryConcurrent(basePath: String, type: PluginType) async -> [FCPXPlugin] {
        // 确定模板目录路径
        let motionTemplatesPath: String
        if basePath.hasSuffix("Templates.localized") {
            motionTemplatesPath = basePath
        } else if basePath.hasSuffix("Motion Templates.localized") {
            motionTemplatesPath = basePath
        } else {
            motionTemplatesPath = URL(fileURLWithPath: basePath).appendingPathComponent("Motion Templates.localized").path
        }

        guard fileManager.fileExists(atPath: motionTemplatesPath) else {
            //print("Motion Templates目录不存在: \(motionTemplatesPath)")
            return []
        }

        // 添加系统目录的额外安全检查
        if type == .system {
            do {
                let _ = try fileManager.contentsOfDirectory(atPath: motionTemplatesPath)
            } catch {
                //print("❌ 无法读取系统Motion Templates目录: \(error.localizedDescription)")
                return []
            }
        }

        // 并发扫描所有子类型目录
        let subTypes = PluginSubType.allCases.filter { $0 != .compositions }

        let allPlugins = await withTaskGroup(of: [FCPXPlugin].self) { group in
            var plugins: [FCPXPlugin] = []

            for subType in subTypes {
                group.addTask {
                    await self.scanSubTypeDirectoryConcurrent(
                        motionTemplatesPath: motionTemplatesPath,
                        subType: subType,
                        type: type
                    )
                }
            }

            for await subTypePlugins in group {
                plugins.append(contentsOf: subTypePlugins)
            }

            return plugins
        }

        return allPlugins
    }

    // MARK: - 并发扫描子类型目录（简化版本）
    private func scanSubTypeDirectoryConcurrent(motionTemplatesPath: String, subType: PluginSubType, type: PluginType) async -> [FCPXPlugin] {
        let subTypePath = URL(fileURLWithPath: motionTemplatesPath).appendingPathComponent(subType.rawValue).path

        // 扫描子类型目录

        guard fileManager.fileExists(atPath: subTypePath) else {
            //print("⚠️ 子类型目录不存在: \(subTypePath)")
            return []
        }

        do {
            let categoryNames = try fileManager.contentsOfDirectory(atPath: subTypePath)
                .filter { !$0.hasPrefix(".") }

            // 处理类别目录

            // 限制并发数量，避免过度并发
            let maxConcurrency = min(categoryNames.count, 4) // 最多4个并发任务
            var allPlugins: [FCPXPlugin] = []

            // 分批处理类别目录
            for i in stride(from: 0, to: categoryNames.count, by: maxConcurrency) {
                let endIndex = min(i + maxConcurrency, categoryNames.count)
                let batch = Array(categoryNames[i..<endIndex])

                let batchPlugins = await withTaskGroup(of: [FCPXPlugin].self) { group in
                    var plugins: [FCPXPlugin] = []

                    for categoryName in batch {
                        group.addTask {
                            let categoryPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(categoryName).path
                            let displayCategoryName = await self.resolveFxFactoryCategoryName(categoryPath: categoryPath, categoryName: categoryName)

                            return await self.scanCategoryDirectoryFast(
                                categoryPath: categoryPath,
                                categoryName: displayCategoryName,
                                type: type,
                                subType: subType
                            )
                        }
                    }

                    for await categoryPlugins in group {
                        plugins.append(contentsOf: categoryPlugins)
                    }

                    return plugins
                }

                allPlugins.append(contentsOf: batchPlugins)
            }

            // 扫描完成
            return allPlugins

        } catch {
            //print("❌ 扫描子类型目录失败 \(subTypePath): \(error)")
            return []
        }
    }

    // 直接读取 .localized/en.strings 文件内容
    private func readLocalizedNameDirectly(from directoryPath: String) -> String? {
        let stringsPath = URL(fileURLWithPath: directoryPath)
            .appendingPathComponent(".localized")
            .appendingPathComponent("en.strings")
            .path

        // 检查文件是否存在
        guard FileManager.default.fileExists(atPath: stringsPath) else {
            return nil
        }

        do {
            // 读取文件内容
            let content = try String(contentsOfFile: stringsPath, encoding: .utf8)

            // 简单解析：查找第一个 = 后面引号中的内容
            let lines = content.components(separatedBy: .newlines)

            for line in lines {
                let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)

                // 跳过空行和注释
                if trimmedLine.isEmpty || trimmedLine.hasPrefix("//") || trimmedLine.hasPrefix("/*") {
                    continue
                }

                // 查找格式: "key" = "value";
                if let equalIndex = trimmedLine.firstIndex(of: "=") {
                    let afterEqual = String(trimmedLine[trimmedLine.index(after: equalIndex)...])
                        .trimmingCharacters(in: .whitespacesAndNewlines)

                    // 查找第一个引号
                    if let firstQuoteIndex = afterEqual.firstIndex(of: "\"") {
                        let afterFirstQuote = String(afterEqual[afterEqual.index(after: firstQuoteIndex)...])

                        // 查找结束引号
                        if let lastQuoteIndex = afterFirstQuote.firstIndex(of: "\"") {
                            let value = String(afterFirstQuote[..<lastQuoteIndex])
                            if !value.isEmpty {
                                return value
                            }
                        }
                    }
                }
            }

            return nil

        } catch {
            // 读取失败时不显示警告，直接返回nil
            return nil
        }
    }

    // MARK: - 解析FxFactory类别目录名称（简化版本 - 直接读取）
    private func resolveFxFactoryCategoryName(categoryPath: String, categoryName: String) async -> String {
        // 直接检查是否存在 .localized/en.strings 文件
        if let realName = readLocalizedNameDirectly(from: categoryPath) {
            return realName
        }

        // 如果读取失败，返回原名称
        return categoryName
    }

    // MARK: - 扫描类别目录
    private func scanCategoryDirectory(
        categoryPath: String,
        categoryName: String,
        type: PluginType,
        subType: PluginSubType
    ) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        do {
            let pluginContents = try fileManager.contentsOfDirectory(atPath: categoryPath)

            for pluginName in pluginContents {
                // 跳过隐藏文件
                if pluginName.hasPrefix(".") { continue }

                let pluginPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(pluginName).path
                var isDirectory: ObjCBool = false

                guard fileManager.fileExists(atPath: pluginPath, isDirectory: &isDirectory),
                      isDirectory.boolValue else { continue }

                // 验证是否为插件目录
                if await isValidPlugin(at: pluginPath) {
                    // 检测是否为FxFactory插件
                    let pluginIsFxFactory = detectFxFactoryPlugin(name: pluginName, path: pluginPath)

                    // 获取显示名称（FxFactory插件解析真实名称）
                    let displayName = pluginIsFxFactory ?
                        await getFxFactoryDisplayName(path: pluginPath, uuid: extractUUIDFromName(pluginName)) : pluginName

                    // 这是一个插件目录，直接扫描
                    let pluginFiles = await scanPluginFiles(at: pluginPath)

                    for pluginFile in pluginFiles {
                        var plugin = FCPXPlugin(
                            name: pluginName, // 保持原始名称
                            path: pluginPath,
                            type: type,
                            subType: subType,
                            categoryPath: categoryPath
                        )

                        // 设置插件文件信息
                        plugin.motionFilePath = pluginFile.path
                        plugin.isFxFactoryPlugin = pluginIsFxFactory

                        // 设置FxFactory插件的真实名称
                        if pluginIsFxFactory {
                            plugin.realName = displayName
                        }

                        // 获取文件信息
                        await updatePluginFileInfo(&plugin)

                        plugins.append(plugin)
                    }
                } else {
                    // 这可能是一个主题目录，递归扫描其子目录
                    let themePlugins = await scanThemeDirectory(
                        themePath: pluginPath,
                        categoryName: categoryName,
                        type: type,
                        subType: subType,
                        originalCategoryPath: categoryPath
                    )
                    plugins.append(contentsOf: themePlugins)
                }
            }
        } catch {
            //print("扫描类别目录失败 \(categoryPath): \(error)")
        }

        return plugins
    }

    // MARK: - 快速扫描类别目录（优化版本）
    private func scanCategoryDirectoryFast(
        categoryPath: String,
        categoryName: String,
        type: PluginType,
        subType: PluginSubType
    ) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        guard await MainActor.run(body: { fileManager.fileExists(atPath: categoryPath) }) else {
            return plugins
        }

        do {
            let pluginContents = try fileManager.contentsOfDirectory(atPath: categoryPath)
                .filter { !$0.hasPrefix(".") }

            // 并发扫描插件目录
            let allPlugins = await withTaskGroup(of: [FCPXPlugin].self) { group in
                var results: [FCPXPlugin] = []

                for pluginName in pluginContents {
                    group.addTask {
                        let pluginPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(pluginName).path
                        var isDirectory: ObjCBool = false

                        // 使用本地 FileManager 实例避免 actor 边界问题
                        let localFileManager = FileManager.default
                        guard localFileManager.fileExists(atPath: pluginPath, isDirectory: &isDirectory),
                              isDirectory.boolValue else { return [] }

                        // 快速验证和扫描
                        if await self.isValidPlugin(at: pluginPath) {
                            return await self.scanPluginDirectoryFast(
                                pluginPath: pluginPath,
                                categoryPath: categoryPath,
                                type: type,
                                subType: subType
                            )
                        } else {
                            // 主题目录的快速扫描
                            return await self.scanThemeDirectoryFast(
                                themePath: pluginPath,
                                categoryName: categoryName,
                                type: type,
                                subType: subType,
                                originalCategoryPath: categoryPath
                            )
                        }
                    }
                }

                for await pluginGroup in group {
                    results.append(contentsOf: pluginGroup)
                }

                return results
            }

            plugins.append(contentsOf: allPlugins)

        } catch {
            //print("快速扫描类别目录失败 \(categoryPath): \(error)")
        }

        return plugins
    }

    // MARK: - 快速扫描插件目录
    private func scanPluginDirectoryFast(
        pluginPath: String,
        categoryPath: String,
        type: PluginType,
        subType: PluginSubType
    ) async -> [FCPXPlugin] {
        let pluginFiles = await scanPluginFiles(at: pluginPath)
        var plugins: [FCPXPlugin] = []

        // 从路径中提取插件目录名
        let pluginName = URL(fileURLWithPath: pluginPath).lastPathComponent

        // 检测是否为FxFactory插件
        let pluginIsFxFactory = detectFxFactoryPlugin(name: pluginName, path: pluginPath)

        // 获取显示名称（FxFactory插件解析真实名称）
        let displayName = pluginIsFxFactory ?
            await getFxFactoryDisplayName(path: pluginPath, uuid: extractUUIDFromName(pluginName)) : pluginName

        for pluginFile in pluginFiles {
            var plugin = FCPXPlugin(
                name: pluginName, // 保持原始名称
                path: pluginPath,
                type: type,
                subType: subType,
                categoryPath: categoryPath
            )

            // 设置插件文件信息
            plugin.motionFilePath = pluginFile.path
            plugin.isFxFactoryPlugin = pluginIsFxFactory

            // 设置FxFactory插件的真实名称
            if pluginIsFxFactory {
                plugin.realName = displayName
            }

            // 快速获取基本文件信息（不计算体积）
            await updatePluginFileInfo(&plugin)

            plugins.append(plugin)
        }

        return plugins
    }

    // MARK: - 快速扫描主题目录
    private func scanThemeDirectoryFast(
        themePath: String,
        categoryName: String,
        type: PluginType,
        subType: PluginSubType,
        originalCategoryPath: String
    ) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        do {
            let themeContents = try await MainActor.run { try fileManager.contentsOfDirectory(atPath: themePath) }
                .filter { !$0.hasPrefix(".") }

            // 并发扫描主题中的插件
            let allPlugins = await withTaskGroup(of: [FCPXPlugin].self) { group in
                var results: [FCPXPlugin] = []

                for itemName in themeContents {
                    group.addTask {
                        let itemPath = URL(fileURLWithPath: themePath).appendingPathComponent(itemName).path
                        var isDirectory: ObjCBool = false

                        // 使用本地 FileManager 实例避免 actor 边界问题
                        let localFileManager = FileManager.default
                        guard localFileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                              isDirectory.boolValue else { return [] }

                        if await self.isValidPlugin(at: itemPath) {
                            return await self.scanPluginDirectoryFast(
                                pluginPath: itemPath,
                                categoryPath: originalCategoryPath,
                                type: type,
                                subType: subType
                            )
                        } else {
                            // 这可能是一个嵌套的主题目录，递归扫描
                            return await self.scanThemeDirectoryFast(
                                themePath: itemPath,
                                categoryName: categoryName,
                                type: type,
                                subType: subType,
                                originalCategoryPath: originalCategoryPath
                            )
                        }
                    }
                }

                for await pluginGroup in group {
                    results.append(contentsOf: pluginGroup)
                }

                return results
            }

            plugins.append(contentsOf: allPlugins)

        } catch {
            //print("快速扫描主题目录失败 \(themePath): \(error)")
        }

        return plugins
    }

    // MARK: - 批量扫描类别目录（优化版本）
    private func scanCategoryDirectoryStreaming(
        categoryPath: String,
        categoryName: String,
        type: PluginType,
        subType: PluginSubType
    ) async {
        guard await MainActor.run(body: { fileManager.fileExists(atPath: categoryPath) }) else {
            return
        }

        do {
            let pluginContents = try await MainActor.run { try fileManager.contentsOfDirectory(atPath: categoryPath) }
                .filter { !$0.hasPrefix(".") }

            // 批量处理插件目录，减少并发任务数量
            var allNewPlugins: [FCPXPlugin] = []

            // 分批处理，每批最多10个目录
            let batchSize = 10
            for i in stride(from: 0, to: pluginContents.count, by: batchSize) {
                let endIndex = min(i + batchSize, pluginContents.count)
                let batch = Array(pluginContents[i..<endIndex])

                let batchPlugins = await withTaskGroup(of: [FCPXPlugin].self) { group in
                    var results: [FCPXPlugin] = []

                    for pluginName in batch {
                        group.addTask {
                            let pluginPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(pluginName).path

                            // 使用本地 FileManager 和变量避免并发问题
                            let localFileManager = FileManager.default
                            var isDirectory: ObjCBool = false
                            guard localFileManager.fileExists(atPath: pluginPath, isDirectory: &isDirectory),
                                  isDirectory.boolValue else { return [] }

                            if await self.isValidPlugin(at: pluginPath) {
                                return await self.scanPluginDirectoryFast(
                                    pluginPath: pluginPath,
                                    categoryPath: categoryPath,
                                    type: type,
                                    subType: subType
                                )
                            } else {
                                return await self.scanThemeDirectoryFast(
                                    themePath: pluginPath,
                                    categoryName: categoryName,
                                    type: type,
                                    subType: subType,
                                    originalCategoryPath: categoryPath
                                )
                            }
                        }
                    }

                    for await pluginGroup in group {
                        results.append(contentsOf: pluginGroup)
                    }

                    return results
                }

                allNewPlugins.append(contentsOf: batchPlugins)

                // 每批处理完后更新UI
                if !batchPlugins.isEmpty {
                    await addPluginsToUI(batchPlugins, for: type)
                }
            }

        } catch {
            //print("批量扫描类别目录失败 \(categoryPath): \(error)")
        }
    }

    // MARK: - 流式扫描主题目录
    private func scanThemeDirectoryStreaming(
        themePath: String,
        categoryName: String,
        type: PluginType,
        subType: PluginSubType,
        originalCategoryPath: String
    ) async {
        do {
            let themeContents = try fileManager.contentsOfDirectory(atPath: themePath)
                .filter { !$0.hasPrefix(".") }

            // 流式扫描主题中的插件
            await withTaskGroup(of: Void.self) { group in
                for itemName in themeContents {
                    group.addTask {
                        let itemPath = URL(fileURLWithPath: themePath).appendingPathComponent(itemName).path
                        var isDirectory: ObjCBool = false

                        // 使用本地 FileManager 实例避免 actor 边界问题
                        let localFileManager = FileManager.default
                        guard localFileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                              isDirectory.boolValue else { return }

                        if await self.isValidPlugin(at: itemPath) {
                            let newPlugins = await self.scanPluginDirectoryFast(
                                pluginPath: itemPath,
                                categoryPath: originalCategoryPath,
                                type: type,
                                subType: subType
                            )

                            // 立即更新UI
                            await self.addPluginsToUI(newPlugins, for: type)
                        } else {
                            // 这可能是一个嵌套的主题目录，递归扫描
                            await self.scanThemeDirectoryStreaming(
                                themePath: itemPath,
                                categoryName: categoryName,
                                type: type,
                                subType: subType,
                                originalCategoryPath: originalCategoryPath
                            )
                        }
                    }
                }
            }

        } catch {
            //print("流式扫描主题目录失败 \(themePath): \(error)")
        }
    }

    // MARK: - 批量添加插件到UI（优化版本）
    private func addPluginsToUI(_ newPlugins: [FCPXPlugin], for type: PluginType) async {
        guard !newPlugins.isEmpty else { return }

        // 使用批量更新，减少UI刷新频率
        await MainActor.run { [weak self] in
            guard let self = self else { return }

            if self.plugins[type] == nil {
                self.plugins[type] = []
            }
            self.plugins[type]?.append(contentsOf: newPlugins)

            // 更新扫描计数和进度
            self.scannedCount += newPlugins.count

            // 每50个插件更新一次进度，减少UI刷新
            if self.scannedCount % 50 == 0 || newPlugins.count >= 10 {
                self.loadingProgress = "已扫描 \(self.scannedCount) 个插件..."
                self.updatePluginCounts(for: type)
            }

            //print("📱 批量更新: 新增 \(newPlugins.count) 个插件，当前总数: \(self.plugins[type]?.count ?? 0)")
        }
    }

    // MARK: - 扫描主题目录
    private func scanThemeDirectory(
        themePath: String,
        categoryName: String,
        type: PluginType,
        subType: PluginSubType,
        originalCategoryPath: String
    ) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        do {
            let themeContents = try fileManager.contentsOfDirectory(atPath: themePath)

            for itemName in themeContents {
                // 跳过隐藏文件
                if itemName.hasPrefix(".") { continue }

                let itemPath = URL(fileURLWithPath: themePath).appendingPathComponent(itemName).path
                var isDirectory: ObjCBool = false

                guard fileManager.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                      isDirectory.boolValue else { continue }

                // 验证是否为插件目录
                if await isValidPlugin(at: itemPath) {
                    // 这是一个插件目录，扫描其中的Motion文件
                    let pluginFiles = await scanPluginFiles(at: itemPath)

                    for pluginFile in pluginFiles {
                        var plugin = FCPXPlugin(
                            name: pluginFile.name,
                            path: itemPath,
                            type: type,
                            subType: subType,
                            categoryPath: originalCategoryPath
                        )

                        // 设置插件文件信息
                        plugin.motionFilePath = pluginFile.path

                        // 获取文件信息
                        await updatePluginFileInfo(&plugin)

                        // FxFactory插件名称已在创建时解析

                        plugins.append(plugin)
                    }
                } else {
                    // 这可能是一个嵌套的主题目录，递归扫描
                    // 但要限制递归深度，避免无限嵌套
                    let nestedPlugins = await scanThemeDirectory(
                        themePath: itemPath,
                        categoryName: categoryName,
                        type: type,
                        subType: subType,
                        originalCategoryPath: originalCategoryPath
                    )
                    plugins.append(contentsOf: nestedPlugins)
                }
            }
        } catch {
            //print("扫描主题目录失败 \(themePath): \(error)")
        }

        return plugins
    }

    // MARK: - 扫描插件文件
    private func scanPluginFiles(at pluginPath: String) async -> [(name: String, path: String)] {
        var pluginFiles: [(name: String, path: String)] = []

        do {
            let contents = try fileManager.contentsOfDirectory(atPath: pluginPath)
            let extensions = [".motn", ".moef", ".moti", ".motr"]

            for filename in contents {
                if extensions.contains(where: { filename.hasSuffix($0) }) {
                    let filePath = URL(fileURLWithPath: pluginPath).appendingPathComponent(filename).path
                    let name = filename.replacingOccurrences(of: "\\.mo[tnefir]+$", with: "", options: .regularExpression)
                    pluginFiles.append((name: name, path: filePath))
                }
            }

            // 如果没有找到Motion文件，但目录是有效的插件目录，则使用目录名
            if pluginFiles.isEmpty {
                let pluginName = URL(fileURLWithPath: pluginPath).lastPathComponent
                pluginFiles.append((name: pluginName, path: pluginPath))
            }

        } catch {
            //print("扫描插件文件失败 \(pluginPath): \(error)")
            // 如果扫描失败，至少返回目录名
            let pluginName = URL(fileURLWithPath: pluginPath).lastPathComponent
            pluginFiles.append((name: pluginName, path: pluginPath))
        }

        return pluginFiles
    }

    // MARK: - 验证插件完整性
    private func isValidPlugin(at path: String) async -> Bool {
        let pluginURL = URL(fileURLWithPath: path)
        _ = pluginURL.lastPathComponent

        do {
            let contents = try fileManager.contentsOfDirectory(atPath: path)

            // 检查是否存在任何Motion模板文件
            let extensions = [".motn", ".moef", ".moti", ".motr"]
            let hasMotionFile = contents.contains { filename in
                extensions.contains { ext in
                    filename.hasSuffix(ext)
                }
            }

            // 检查是否存在Media目录
            let hasMediaDir = contents.contains { filename in
                filename == "Media"
            }

            // 检查是否存在缩略图文件
            _ = contents.contains { filename in
                filename.lowercased().contains("large.png") ||
                filename.lowercased().contains("small.png") ||
                filename.lowercased().hasSuffix(".jpg") ||
                filename.lowercased().hasSuffix(".jpeg") ||
                filename.lowercased().hasSuffix(".png")
            }

            // 插件必须至少有Motion文件或Media目录
            return hasMotionFile || hasMediaDir

        } catch {
            //print("验证插件失败 \(path): \(error)")
            return false
        }
    }
    
    // MARK: - 更新插件文件信息（快速版本，不计算体积）
    private func updatePluginFileInfo(_ plugin: inout FCPXPlugin) async {
        do {
            let attributes = try fileManager.attributesOfItem(atPath: plugin.path)
            plugin.createdDate = attributes[.creationDate] as? Date ?? Date()
            plugin.modifiedDate = attributes[.modificationDate] as? Date ?? Date()
            // 体积计算延迟到需要时再进行
            plugin.fileSize = 0
        } catch {
            //print("获取文件信息失败: \(error)")
        }
    }

    // MARK: - 按需更新插件体积信息
    func updatePluginSize(_ plugin: inout FCPXPlugin) async {
        guard plugin.fileSize == 0 else { return } // 已经计算过了
        plugin.fileSize = calculateDirectorySize(at: plugin.path)
    }



    // MARK: - 计算类别目录体积
    func calculateCategorySize(at path: String) async -> Int64 {
        return calculateDirectorySize(at: path)
    }

    
    // MARK: - 扫描FxPlug目录
    private func scanFxPlugDirectory(basePath: String, type: PluginType) async -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        guard fileManager.fileExists(atPath: basePath) else {
            //print("FxPlug目录不存在: \(basePath)")
            return plugins
        }

        do {
            let contents = try fileManager.contentsOfDirectory(atPath: basePath)

            for itemName in contents {
                // 跳过隐藏文件和非.app文件
                if itemName.hasPrefix(".") || !itemName.hasSuffix(".app") { continue }

                let appPath = URL(fileURLWithPath: basePath).appendingPathComponent(itemName).path
                var isDirectory: ObjCBool = false

                guard fileManager.fileExists(atPath: appPath, isDirectory: &isDirectory),
                      isDirectory.boolValue else { continue }

                // 验证是否为有效的FxPlug插件
                if await isValidFxPlugApp(at: appPath) {
                    // 从应用程序包中提取插件信息
                    if let pluginInfo = await extractFxPlugInfo(from: appPath) {
                        var plugin = FCPXPlugin(
                            name: pluginInfo.name,
                            path: appPath,
                            type: type,
                            subType: pluginInfo.subType,
                            categoryPath: basePath
                        )

                        // 设置FxPlug特有的属性
                        plugin.bundleIdentifier = pluginInfo.bundleIdentifier
                        plugin.version = pluginInfo.version

                        // 获取文件信息
                        await updatePluginFileInfo(&plugin)

                        plugins.append(plugin)
                    }
                }
            }
        } catch {
            //print("扫描FxPlug目录失败 \(basePath): \(error)")
        }

        return plugins
    }









    // MARK: - FxPlug插件辅助方法

    // 验证是否为有效的FxPlug应用程序
    private func isValidFxPlugApp(at appPath: String) async -> Bool {
        let infoPlistPath = URL(fileURLWithPath: appPath).appendingPathComponent("Contents/Info.plist").path
        return fileManager.fileExists(atPath: infoPlistPath)
    }

    // 从FxPlug应用程序中提取插件信息
    private func extractFxPlugInfo(from appPath: String) async -> (name: String, bundleIdentifier: String?, version: String?, subType: PluginSubType)? {
        let infoPlistPath = URL(fileURLWithPath: appPath).appendingPathComponent("Contents/Info.plist").path

        guard let plistData = fileManager.contents(atPath: infoPlistPath),
              let plist = try? PropertyListSerialization.propertyList(from: plistData, options: [], format: nil) as? [String: Any] else {
            return nil
        }

        // 提取基本信息
        let bundleName = plist["CFBundleName"] as? String ??
                        plist["CFBundleDisplayName"] as? String ??
                        URL(fileURLWithPath: appPath).deletingPathExtension().lastPathComponent

        let bundleIdentifier = plist["CFBundleIdentifier"] as? String
        let version = plist["CFBundleShortVersionString"] as? String

        // FxPlug插件通常没有明确的类型分类，默认归类为Effects
        let subType = PluginSubType.effects

        return (name: bundleName, bundleIdentifier: bundleIdentifier, version: version, subType: subType)
    }


    
    // MARK: - 更新插件数量
    private func updatePluginCounts(for type: PluginType) {
        guard let typePlugins = plugins[type] else { return }
        
        if let categoryIndex = categories.firstIndex(where: { $0.type == type }) {
            for subCategoryIndex in categories[categoryIndex].subcategories.indices {
                let subType = categories[categoryIndex].subcategories[subCategoryIndex].subType
                let count = typePlugins.filter { $0.subType == subType }.count
                categories[categoryIndex].subcategories[subCategoryIndex].pluginCount = count
            }
        }
    }
    
    // MARK: - 搜索过滤
    func filteredPlugins(for type: PluginType) -> [FCPXPlugin] {
        //print("🔍 filteredPlugins 被调用 - type: \(type)")
        //print("🔍 当前 plugins 字典内容: \(plugins.keys.map { "\($0): \(plugins[$0]?.count ?? 0)个插件" })")

        guard let typePlugins = plugins[type], !typePlugins.isEmpty else {
            //print("🔍 没有找到 \(type) 类型的插件数据")
            return []
        }

        //print("🔍 找到 \(typePlugins.count) 个 \(type) 类型的插件")

        // 🔧 修复数据混淆问题：验证插件路径与插件源的一致性
        let validPlugins = typePlugins.filter { plugin in
            let isValid = validatePluginSourcePath(categoryPath: plugin.path, expectedSource: type)
            if !isValid {
                //print("🚨 过滤掉路径不匹配的插件: \(plugin.displayName) - 期望源: \(type.displayName), 实际路径: \(plugin.path)")
            }
            return isValid
        }

        //print("🔧 路径验证后剩余 \(validPlugins.count) 个有效插件")

        if searchText.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty {
            return validPlugins
        }

        let trimmedSearchText = searchText.trimmingCharacters(in: .whitespacesAndNewlines)
        return validPlugins.filter { plugin in
            plugin.displayName.localizedCaseInsensitiveContains(trimmedSearchText)
        }
    }

    // MARK: - 获取类别中的插件
    func getPluginsInCategory(categoryPath: String, subType: PluginSubType, sourceType: PluginType) async -> [FCPXPlugin] {
        // 获取指定源类型的所有插件
        let allPlugins = plugins[sourceType] ?? []

        // 过滤出指定类别路径和子类型的插件
        return allPlugins.filter { plugin in
            plugin.categoryPath == categoryPath && plugin.subType == subType
        }
    }

    // MARK: - 刷新类别列表
    func refreshCategories() {
        // 类别数据已通过@Published自动更新，无需手动触发刷新
        //print("🔴 类别数据将自动更新")
    }

    // MARK: - 内存管理

    /// 从内存中移除插件（不重新加载列表）
    func removePluginFromMemory(_ plugin: FCPXPlugin) {
        guard var typePlugins = plugins[plugin.type], !typePlugins.isEmpty else {
            //print("⚠️ 插件列表为空或不存在，无法移除插件: \(plugin.displayName)")
            return
        }

        // 从插件列表中移除
        let originalCount = typePlugins.count
        typePlugins.removeAll { $0.id == plugin.id }

        // 验证移除操作是否成功
        if typePlugins.count == originalCount {
            //print("⚠️ 未找到要移除的插件: \(plugin.displayName)")
            return
        }

        plugins[plugin.type] = typePlugins

        // 更新分类中的插件数量
        updatePluginCounts(for: plugin.type)

        //print("已从内存中移除插件: \(plugin.displayName)")
    }

    /// 在内存中更新插件信息（用于重命名）
    func updatePluginInMemory(_ oldPlugin: FCPXPlugin, newName: String) {
        guard var typePlugins = plugins[oldPlugin.type] else { return }

        // 找到并更新插件
        if let index = typePlugins.firstIndex(where: { $0.id == oldPlugin.id }) {
            let oldPluginData = typePlugins[index]

            // 计算新的路径（特别是FxFactory插件重命名后路径会改变）
            let newPath: String
            if oldPluginData.isFxFactoryPlugin {
                // FxFactory插件重命名后，路径从UUID.localized变为真实名称
                let parentURL = URL(fileURLWithPath: oldPluginData.path).deletingLastPathComponent()
                newPath = parentURL.appendingPathComponent(newName).path
                print("🔄 FxFactory插件路径更新: \(oldPluginData.path) -> \(newPath)")
            } else {
                // 普通插件重命名后的路径
                let parentURL = URL(fileURLWithPath: oldPluginData.path).deletingLastPathComponent()
                newPath = parentURL.appendingPathComponent(newName).path
            }

            // 创建新的插件对象，更新名称和路径
            var updatedPlugin = FCPXPlugin(
                name: newName,
                path: newPath,
                type: oldPluginData.type,
                subType: oldPluginData.subType,
                categoryPath: oldPluginData.categoryPath
            )

            // 保持其他属性不变
            updatedPlugin.fileSize = oldPluginData.fileSize
            updatedPlugin.createdDate = oldPluginData.createdDate
            updatedPlugin.modifiedDate = oldPluginData.modifiedDate
            updatedPlugin.isFxFactoryPlugin = false  // FxFactory插件重命名后变为普通插件

            // 更新真实名称
            updatedPlugin.realName = newName

            typePlugins[index] = updatedPlugin
            plugins[oldPlugin.type] = typePlugins

            //print("已在内存中更新插件: \(oldPlugin.displayName) -> \(newName)")
        }
    }

    /// 从内存中移除整个类别的插件（用于类别删除）
    func removeCategoryFromMemory(_ categoryName: String, sourceType: PluginType) {
        guard var typePlugins = plugins[sourceType] else { return }

        let categoryPath = getCategoryPath(for: categoryName, sourceType: sourceType)

        // 清理类别目录的体积缓存
        SizeCacheManager.shared.removeCache(for: categoryPath)

        // 移除该类别路径下的所有插件
        let removedCount = typePlugins.count
        typePlugins.removeAll { plugin in
            plugin.categoryPath.contains(categoryPath) ||
            plugin.path.contains(categoryPath)
        }

        plugins[sourceType] = typePlugins

        // 更新分类中的插件数量
        updatePluginCounts(for: sourceType)

        _ = removedCount - typePlugins.count
        //print("已从内存中移除类别 \(categoryName) 的 \(actualRemovedCount) 个插件")
    }

    /// 获取类别路径
    private func getCategoryPath(for categoryName: String, sourceType: PluginType) -> String {
        let basePath = sourceType.basePath

        // 根据插件类型构建完整的类别路径
        switch sourceType {
        case .user, .system:
            // Motion Templates 结构需要确定具体的子类型
            // 这里我们返回类别名称，让移除逻辑通过包含关系来匹配
            return categoryName
        case .fxplug:
            return basePath
        default:
            return categoryName
        }
    }

    /// 在内存中重命名类别（更新该类别下所有插件的路径信息）
    func renameCategoryInMemory(oldName: String, newName: String, sourceType: PluginType) {
        guard var typePlugins = plugins[sourceType] else { return }

        var updatedCount = 0

        print("🔄 开始重命名类别: \(oldName) -> \(newName)")

        // 更新该类别下所有插件的路径信息
        for i in 0..<typePlugins.count {
            let plugin = typePlugins[i]

            // 🔧 修复：使用categoryPath的最后一个组件进行匹配
            let categoryName = URL(fileURLWithPath: plugin.categoryPath).lastPathComponent
            let isInTargetCategory = categoryName == oldName

            if isInTargetCategory {
                print("🔄 找到需要更新的插件: \(plugin.name)")
                print("  - 插件路径: \(plugin.path)")
                print("  - 类别路径: \(plugin.categoryPath)")
                print("  - 类别名: \(categoryName)")

                // 创建新的插件对象，更新路径信息
                var updatedPlugin = FCPXPlugin(
                    name: plugin.name,
                    path: plugin.path.replacingOccurrences(of: oldName, with: newName),
                    type: plugin.type,
                    subType: plugin.subType,
                    categoryPath: plugin.categoryPath.replacingOccurrences(of: oldName, with: newName)
                )

                // 保持其他属性不变
                updatedPlugin.fileSize = plugin.fileSize
                updatedPlugin.createdDate = plugin.createdDate
                updatedPlugin.modifiedDate = plugin.modifiedDate
                updatedPlugin.isFxFactoryPlugin = plugin.isFxFactoryPlugin
                updatedPlugin.realName = plugin.realName

                typePlugins[i] = updatedPlugin
                updatedCount += 1
            }
        }

        // 🔧 修复：确保触发@Published变化通知
        plugins[sourceType] = typePlugins

        // 强制触发objectWillChange以确保视图更新
        objectWillChange.send()

        print("✅ 已在内存中重命名类别 \(oldName) -> \(newName)，更新了 \(updatedCount) 个插件")
    }

    /// 在内存中处理类别合并（移除源类别插件，更新目标类别插件路径）
    func mergeCategoryInMemory(sourceCategory: String, targetCategory: String, finalCategoryName: String, sourceType: PluginType) {
        guard var typePlugins = plugins[sourceType] else { return }

        var movedCount = 0
        var _ = 0 // removedCount 暂时不使用

        // 1. 找到源类别的所有插件并更新其路径到目标类别
        for i in 0..<typePlugins.count {
            let plugin = typePlugins[i]

            // 检查插件是否属于源类别
            if plugin.categoryPath.contains(sourceCategory) || plugin.path.contains(sourceCategory) {
                // 创建新的插件对象，更新路径信息到目标类别
                var updatedPlugin = FCPXPlugin(
                    name: plugin.name,
                    path: plugin.path.replacingOccurrences(of: sourceCategory, with: finalCategoryName),
                    type: plugin.type,
                    subType: plugin.subType,
                    categoryPath: plugin.categoryPath.replacingOccurrences(of: sourceCategory, with: finalCategoryName)
                )

                // 保持其他属性不变
                updatedPlugin.fileSize = plugin.fileSize
                updatedPlugin.createdDate = plugin.createdDate
                updatedPlugin.modifiedDate = plugin.modifiedDate
                updatedPlugin.isFxFactoryPlugin = plugin.isFxFactoryPlugin
                updatedPlugin.realName = plugin.realName

                typePlugins[i] = updatedPlugin
                movedCount += 1
            }
        }

        // 2. 如果目标类别名称发生了变化，也需要更新目标类别的插件路径
        if targetCategory != finalCategoryName {
            for i in 0..<typePlugins.count {
                let plugin = typePlugins[i]

                // 检查插件是否属于目标类别（但不是刚刚从源类别移过来的）
                if (plugin.categoryPath.contains(targetCategory) || plugin.path.contains(targetCategory)) &&
                   !(plugin.categoryPath.contains(sourceCategory) || plugin.path.contains(sourceCategory)) {

                    // 创建新的插件对象，更新路径信息
                    var updatedPlugin = FCPXPlugin(
                        name: plugin.name,
                        path: plugin.path.replacingOccurrences(of: targetCategory, with: finalCategoryName),
                        type: plugin.type,
                        subType: plugin.subType,
                        categoryPath: plugin.categoryPath.replacingOccurrences(of: targetCategory, with: finalCategoryName)
                    )

                    // 保持其他属性不变
                    updatedPlugin.fileSize = plugin.fileSize
                    updatedPlugin.createdDate = plugin.createdDate
                    updatedPlugin.modifiedDate = plugin.modifiedDate
                    updatedPlugin.isFxFactoryPlugin = plugin.isFxFactoryPlugin
                    updatedPlugin.realName = plugin.realName

                    typePlugins[i] = updatedPlugin
                }
            }
        }

        plugins[sourceType] = typePlugins

        // 更新分类中的插件数量
        updatePluginCounts(for: sourceType)

        //print("已在内存中合并类别 \(sourceCategory) -> \(finalCategoryName)，移动了 \(movedCount) 个插件")
    }

    // MARK: - 插件管理操作

    /// 卸载插件
    func uninstallPlugin(_ plugin: FCPXPlugin) async throws {
        //print("开始卸载插件: \(plugin.displayName)")

        // 清理体积缓存
        SizeCacheManager.shared.removeCache(for: plugin.path)

        if plugin.type == .plugkit {
            // PlugKit插件通过命令行卸载
            try await uninstallPlugKitPlugin(plugin)
        } else if plugin.isFxFactoryPlugin {
            // FxFactory插件使用防护机制卸载
            let categoryRealName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: plugin.path)
            let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                categoryRealName: categoryRealName,
                operation: .remove
            )
            // 执行实际的文件删除操作
            try await movePluginToTrash(plugin)
        } else if plugin.type == .fxplug {
            // FxPlug插件需要sudo权限删除
            try await uninstallFxPlugPluginWithSudo(plugin)
        } else if SudoPermissionManager.shared.needsSudoPermission(for: plugin.path) {
            // 系统插件需要sudo权限删除
            try await uninstallSystemPluginWithSudo(plugin)
        } else {
            // 其他插件移动到回收站
            try await movePluginToTrash(plugin)
        }

        // 直接从内存中移除插件，不重新加载整个列表
        await MainActor.run {
            removePluginFromMemory(plugin)
        }

        //print("插件卸载完成: \(plugin.displayName)")
    }

    /// 批量卸载插件（只需要输入一次密码）
    func batchUninstallPlugins(_ plugins: [FCPXPlugin]) async throws {
        guard !plugins.isEmpty else { return }

        print("🔄 开始批量卸载 \(plugins.count) 个插件")

        // 按照权限需求分组插件
        var systemPlugins: [FCPXPlugin] = []
        var fxPlugPlugins: [FCPXPlugin] = []
        var fxFactoryPlugins: [FCPXPlugin] = []
        var normalPlugins: [FCPXPlugin] = []
        var plugKitPlugins: [FCPXPlugin] = []

        for plugin in plugins {
            // 清理体积缓存
            SizeCacheManager.shared.removeCache(for: plugin.path)

            if plugin.type == .plugkit {
                plugKitPlugins.append(plugin)
            } else if plugin.isFxFactoryPlugin {
                fxFactoryPlugins.append(plugin)
            } else if plugin.type == .fxplug {
                fxPlugPlugins.append(plugin)
            } else if SudoPermissionManager.shared.needsSudoPermission(for: plugin.path) {
                systemPlugins.append(plugin)
            } else {
                normalPlugins.append(plugin)
            }
        }

        // 批量处理需要权限的插件（一次性请求权限）
        if !systemPlugins.isEmpty || !fxPlugPlugins.isEmpty {
            let pathsToDelete = (systemPlugins + fxPlugPlugins).map { $0.path }
            try await SudoPermissionManager.shared.deleteFilesWithSudoPermission(pathsToDelete)
            print("✅ 成功批量删除 \(pathsToDelete.count) 个系统/FxPlug插件")
        }

        // 处理FxFactory插件
        for plugin in fxFactoryPlugins {
            let categoryRealName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: plugin.path)
            let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                categoryRealName: categoryRealName,
                operation: .remove
            )
            try await movePluginToTrash(plugin)
        }

        // 处理普通插件（移动到回收站）
        for plugin in normalPlugins {
            try await movePluginToTrash(plugin)
        }

        // 处理PlugKit插件
        for plugin in plugKitPlugins {
            try await uninstallPlugKitPlugin(plugin)
        }

        // 从内存中移除所有插件
        await MainActor.run {
            for plugin in plugins {
                removePluginFromMemory(plugin)
            }
        }

        print("🎉 批量卸载完成: 成功卸载 \(plugins.count) 个插件")
    }

    /// 使用sudo权限卸载FxPlug插件
    private func uninstallFxPlugPluginWithSudo(_ plugin: FCPXPlugin) async throws {
        //print("🔐 FxPlug插件需要管理员权限进行卸载: \(plugin.displayName)")

        // 使用SudoPermissionManager请求权限并删除
        try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: plugin.path)

        //print("✅ FxPlug插件卸载成功: \(plugin.displayName)")
    }

    /// 使用sudo权限卸载系统插件
    private func uninstallSystemPluginWithSudo(_ plugin: FCPXPlugin) async throws {
        //print("🔐 系统插件需要管理员权限进行卸载: \(plugin.displayName)")

        // 使用SudoPermissionManager请求权限并删除
        try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: plugin.path)

        //print("✅ 系统插件卸载成功: \(plugin.displayName)")
    }

    /// 移动插件到回收站
    private func movePluginToTrash(_ plugin: FCPXPlugin) async throws {
        let pluginURL = URL(fileURLWithPath: plugin.path)

        // 检查插件目录是否存在
        guard fileManager.fileExists(atPath: plugin.path) else {
            throw PluginManagerError.pluginNotFound
        }

        do {
            // 移动到回收站
            var resultingURL: NSURL?
            try fileManager.trashItem(at: pluginURL, resultingItemURL: &resultingURL)
            //print("插件已移动到回收站: \(plugin.path)")

            if resultingURL != nil {
                //print("回收站位置: \(trashedURL.path ?? "未知")")
            }
        } catch {
            //print("移动插件到回收站失败: \(error)")
            throw PluginManagerError.uninstallFailed(error.localizedDescription)
        }
    }

    /// 卸载PlugKit插件
    private func uninstallPlugKitPlugin(_ plugin: FCPXPlugin) async throws {
        // TODO: 实现PlugKit插件的命令行卸载
        // 这需要根据具体的PlugKit插件管理命令来实现
        //print("PlugKit插件卸载功能待实现: \(plugin.displayName)")
        throw PluginManagerError.unsupportedOperation("PlugKit插件卸载功能暂未实现")
    }

    /// 重命名插件
    func renamePlugin(_ plugin: FCPXPlugin, newName: String) async throws {
        //print("开始重命名插件: \(plugin.displayName) -> \(newName)")

        let trimmedName = newName.trimmingCharacters(in: .whitespacesAndNewlines)
        guard !trimmedName.isEmpty else {
            throw PluginManagerError.invalidName("插件名称不能为空")
        }

        if plugin.type == .plugkit {
            throw PluginManagerError.unsupportedOperation("PlugKit插件不支持重命名")
        }

        if plugin.isFxFactoryPlugin {
            // FxFactory插件需要按正确顺序处理：还原真实文件名 -> 去掉特征文件 -> 删除管理文件 -> 重命名
            print("🔄 处理FxFactory插件重命名: \(plugin.displayName)")

            // 1. 获取真实文件名
            let categoryRealName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: plugin.path)
            print("✅ 获取到真实文件名: \(categoryRealName)")

            // 2. 先处理子插件重命名（在删除.fxfactory.plist之前）
            try await renameMotionFiles(in: plugin.path, newName: categoryRealName)
            print("✅ 已处理子插件重命名")

            // 3. 还原主插件文件名为真实名称
            if let restoredName = try await FxFactoryProtectionManager.shared.restoreRealFileName(at: plugin.path) {
                print("✅ 已还原文件名: \(plugin.name) -> \(restoredName)")

                // 4. 计算还原后的路径
                let parentURL = URL(fileURLWithPath: plugin.path).deletingLastPathComponent()
                let restoredPath = parentURL.appendingPathComponent(restoredName).path

                // 5. 删除特征文件和隐藏文件（.localized、.fxfactory.plist等）
                try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: restoredPath)
                print("✅ 已删除特征文件和隐藏文件")

                // 6. 删除FxFactory管理文件（.fxpack和.fxtemplates）
                let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                    categoryRealName: categoryRealName,
                    operation: .rename
                )
                print("✅ 已删除FxFactory管理文件")

                // 7. 如果用户指定的新名称与真实名称不同，则进行最终重命名
                if trimmedName != restoredName {
                    try await renamePluginDirectory(from: restoredPath, to: trimmedName)
                    print("✅ 已重命名为用户指定名称: \(restoredName) -> \(trimmedName)")
                }
            } else {
                throw PluginManagerError.renameFailed("无法还原FxFactory插件的真实文件名")
            }
        } else {
            // 普通插件重命名
            try await renameRegularPlugin(plugin, newName: trimmedName)
        }

        // 直接在内存中更新插件信息，不重新加载整个列表
        await MainActor.run {
            updatePluginInMemory(plugin, newName: trimmedName)
        }

        //print("插件重命名完成: \(plugin.displayName) -> \(trimmedName)")
    }

    /// 重命名插件目录（用于FxFactory插件的最终重命名步骤）
    private func renamePluginDirectory(from currentPath: String, to newName: String) async throws {
        let currentURL = URL(fileURLWithPath: currentPath)
        let parentURL = currentURL.deletingLastPathComponent()
        let newPluginURL = parentURL.appendingPathComponent(newName)

        // 检查目标路径是否已存在
        if fileManager.fileExists(atPath: newPluginURL.path) {
            throw PluginManagerError.nameConflict("名称 '\(newName)' 已存在")
        }

        // 检查是否需要管理员权限（系统插件）
        if SudoPermissionManager.shared.needsSudoPermission(for: currentPath) {
            // 系统插件需要管理员权限进行重命名
            try await SudoPermissionManager.shared.renameFileWithSudoPermission(
                from: currentPath,
                to: newPluginURL.path
            )
            print("系统插件目录重命名成功: \(currentURL.path) -> \(newPluginURL.path)")
        } else {
            // 用户插件可以直接重命名
            do {
                // 1. 重命名插件目录
                try fileManager.moveItem(at: currentURL, to: newPluginURL)
                print("插件目录重命名成功: \(currentURL.path) -> \(newPluginURL.path)")
            } catch {
                print("重命名插件目录失败: \(error)")
                throw PluginManagerError.renameFailed(error.localizedDescription)
            }
        }

        // 2. 重命名插件内部的Motion文件
        try await renameMotionFiles(in: newPluginURL.path, newName: newName)
    }

    /// 重命名普通插件
    private func renameRegularPlugin(_ plugin: FCPXPlugin, newName: String) async throws {
        let pluginURL = URL(fileURLWithPath: plugin.path)
        let parentURL = pluginURL.deletingLastPathComponent()
        let newPluginURL = parentURL.appendingPathComponent(newName)

        // 检查目标路径是否已存在
        if fileManager.fileExists(atPath: newPluginURL.path) {
            throw PluginManagerError.nameConflict("名称 '\(newName)' 已存在")
        }

        // 检查是否需要管理员权限（系统插件）
        if SudoPermissionManager.shared.needsSudoPermission(for: plugin.path) {
            // 系统插件需要管理员权限进行重命名
            try await renameSystemPlugin(plugin, newName: newName)
        } else {
            // 用户插件可以直接重命名
            do {
                // 1. 重命名插件目录
                try fileManager.moveItem(at: pluginURL, to: newPluginURL)
                //print("插件目录重命名成功: \(pluginURL.path) -> \(newPluginURL.path)")

                // 2. 重命名插件内部的Motion文件
                try await renameMotionFiles(in: newPluginURL.path, newName: newName)

            } catch {
                //print("重命名普通插件失败: \(error)")
                throw PluginManagerError.renameFailed(error.localizedDescription)
            }
        }
    }

    /// 重命名系统插件（需要管理员权限）
    private func renameSystemPlugin(_ plugin: FCPXPlugin, newName: String) async throws {
        //print("🔐 系统插件需要管理员权限进行重命名: \(plugin.displayName)")

        let pluginURL = URL(fileURLWithPath: plugin.path)
        let parentURL = pluginURL.deletingLastPathComponent()
        let newPluginURL = parentURL.appendingPathComponent(newName)

        // 使用SudoPermissionManager请求权限并重命名
        try await SudoPermissionManager.shared.renameFileWithSudoPermission(
            from: plugin.path,
            to: newPluginURL.path
        )

        // 重命名插件内部的Motion文件
        try await renameMotionFiles(in: newPluginURL.path, newName: newName)

        //print("✅ 系统插件重命名成功: \(plugin.displayName)")
    }

    /// 重命名FxFactory插件
    private func renameFxFactoryPlugin(_ plugin: FCPXPlugin, newName: String) async throws {
        let pluginURL = URL(fileURLWithPath: plugin.path)
        let parentURL = pluginURL.deletingLastPathComponent()
        let newPluginURL = parentURL.appendingPathComponent(newName)

        // 检查目标路径是否已存在
        if fileManager.fileExists(atPath: newPluginURL.path) {
            throw PluginManagerError.nameConflict("名称 '\(newName)' 已存在")
        }

        do {
            // 1. 重命名插件目录（移除.localized后缀）
            try fileManager.moveItem(at: pluginURL, to: newPluginURL)
            //print("FxFactory插件目录重命名成功: \(pluginURL.path) -> \(newPluginURL.path)")

            // 2. 删除.localized目录（如果存在）
            let localizedURL = newPluginURL.appendingPathComponent(".localized")
            if fileManager.fileExists(atPath: localizedURL.path) {
                try fileManager.removeItem(at: localizedURL)
                //print("已删除.localized目录: \(localizedURL.path)")
            }

            // 3. 删除.fxfactory.plist文件（如果存在）
            let plistURL = newPluginURL.appendingPathComponent(".fxfactory.plist")
            if fileManager.fileExists(atPath: plistURL.path) {
                try fileManager.removeItem(at: plistURL)
                //print("已删除.fxfactory.plist文件: \(plistURL.path)")
            }

            // 4. 重命名插件内部的Motion文件
            try await renameMotionFiles(in: newPluginURL.path, newName: newName)

        } catch {
            //print("重命名FxFactory插件失败: \(error)")
            throw PluginManagerError.renameFailed(error.localizedDescription)
        }
    }

    /// 重命名插件内部的Motion文件和子插件目录
    private func renameMotionFiles(in pluginPath: String, newName: String) async throws {
        do {
            let contents = try fileManager.contentsOfDirectory(atPath: pluginPath)
            let motionExtensions = [".motn", ".moef", ".moti", ".motr"]

            for filename in contents {
                let itemURL = URL(fileURLWithPath: pluginPath).appendingPathComponent(filename)

                // 检查是否为Motion文件
                if motionExtensions.contains(where: { filename.hasSuffix($0) }) {
                    let fileExtension = itemURL.pathExtension
                    let newFileURL = URL(fileURLWithPath: pluginPath).appendingPathComponent("\(newName).\(fileExtension)")

                    // 重命名Motion文件
                    try fileManager.moveItem(at: itemURL, to: newFileURL)
                    //print("Motion文件重命名成功: \(filename) -> \(newName).\(fileExtension)")
                }
                // 检查是否为子插件目录（FxFactory格式：UUID.localized）
                else if filename.hasSuffix(".localized") && fileManager.fileExists(atPath: itemURL.path) {
                    var isDirectory: ObjCBool = false
                    if fileManager.fileExists(atPath: itemURL.path, isDirectory: &isDirectory) && isDirectory.boolValue {
                        // 检查是否为FxFactory子插件（检查.fxfactory.plist文件）
                        let fxfactoryPlistURL = itemURL.appendingPathComponent(".fxfactory.plist")
                        if fileManager.fileExists(atPath: fxfactoryPlistURL.path) {
                            print("🔄 处理FxFactory子插件重命名: \(filename)")

                            // 获取子插件的真实文件名
                            let realPluginName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: itemURL.path)
                            print("✅ 获取到子插件真实文件名: \(filename) -> \(realPluginName)")

                            // 如果真实名称与当前名称不同，进行重命名
                            if realPluginName != filename {
                                let realNameURL = URL(fileURLWithPath: pluginPath).appendingPathComponent(realPluginName)

                                // 检查目标路径是否已存在
                                if !fileManager.fileExists(atPath: realNameURL.path) {
                                    // 先还原为普通插件（删除FxFactory相关文件）
                                    try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: itemURL.path)

                                    // 重命名子插件目录
                                    try fileManager.moveItem(at: itemURL, to: realNameURL)
                                    print("✅ 子插件重命名成功: \(filename) -> \(realPluginName)")

                                    // 处理子插件目录内部与原目录同名的插件本体文件
                                    let originalUUID = filename.replacingOccurrences(of: ".localized", with: "")

                                    // 查找子插件目录内部所有以原UUID开头的文件
                                    do {
                                        let subPluginContents = try fileManager.contentsOfDirectory(at: realNameURL, includingPropertiesForKeys: nil)

                                        for subItemURL in subPluginContents {
                                            let subItemName = subItemURL.lastPathComponent

                                            // 如果文件名以原UUID开头，重命名为真实名称
                                            if subItemName.hasPrefix(originalUUID) {
                                                let fileExtension = subItemURL.pathExtension
                                                let newFileName = fileExtension.isEmpty ? realPluginName : "\(realPluginName).\(fileExtension)"
                                                let newSubItemURL = realNameURL.appendingPathComponent(newFileName)

                                                // 检查目标路径是否已存在
                                                if !fileManager.fileExists(atPath: newSubItemURL.path) {
                                                    try fileManager.moveItem(at: subItemURL, to: newSubItemURL)
                                                    print("✅ 子插件本体重命名成功: \(subItemName) -> \(newFileName)")
                                                } else {
                                                    print("⚠️ 子插件本体目标路径已存在，跳过重命名: \(newSubItemURL.path)")
                                                }
                                            }
                                        }
                                    } catch {
                                        print("❌ 处理子插件本体文件失败: \(error)")
                                    }

                                    // 递归处理子插件内部的Motion文件（使用子插件的真实名称）
                                    try await renameMotionFiles(in: realNameURL.path, newName: realPluginName)
                                } else {
                                    print("⚠️ 子插件目标路径已存在，跳过重命名: \(realNameURL.path)")
                                }
                            }
                        }
                    }
                }
            }
        } catch {
            //print("重命名Motion文件失败: \(error)")
            throw error
        }
    }
}

// MARK: - 错误类型
enum PluginManagerError: LocalizedError {
    case pluginNotFound
    case uninstallFailed(String)
    case unsupportedOperation(String)
    case invalidName(String)
    case nameConflict(String)
    case renameFailed(String)

    var errorDescription: String? {
        switch self {
        case .pluginNotFound:
            return "插件文件未找到"
        case .uninstallFailed(let message):
            return "卸载失败: \(message)"
        case .unsupportedOperation(let message):
            return "不支持的操作: \(message)"
        case .invalidName(let message):
            return "无效名称: \(message)"
        case .nameConflict(let message):
            return "名称冲突: \(message)"
        case .renameFailed(let message):
            return "重命名失败: \(message)"
        }
    }
}

// MARK: - 缩略图缓存
class ThumbnailCache {
    private let cache = NSCache<NSString, NSImage>()

    func getThumbnail(for plugin: FCPXPlugin) async -> NSImage? {
        let cacheKey = plugin.path as NSString

        // 检查内存缓存
        if let cachedImage = cache.object(forKey: cacheKey) {
            return cachedImage
        }

        // 加载缩略图
        guard let thumbnailURL = plugin.thumbnailURL,
              let image = NSImage(contentsOf: thumbnailURL) else {
            return nil
        }

        // 缓存图片
        cache.setObject(image, forKey: cacheKey)
        return image
    }

    func clearCache() {
        cache.removeAllObjects()
    }
}


