//
//  PluginSourceTypeView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

struct PluginSourceTypeView: View {
    @Binding var selectedSourceType: PluginType
    @ObservedObject var pluginManager: PluginManager
    
    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            // 标题
            HStack {
                Text("插件源")
                    .font(.headline)
                    .foregroundColor(.primary)
                Spacer()
            }
            .padding(.horizontal, 16)
            .padding(.vertical, 12)
            .background(Color(NSColor.controlBackgroundColor))
            
            Divider()
            
            // 插件源列表
            ScrollView {
                LazyVStack(alignment: .leading, spacing: 2) {
                    ForEach(availableSourceTypes, id: \.self) { sourceType in
                        SourceTypeRowView(
                            sourceType: sourceType,
                            isSelected: selectedSourceType == sourceType,
                            pluginCount: pluginManager.plugins[sourceType]?.count ?? 0
                        ) {
                            // 切换插件源（使用已扫描的数据，不重新扫描）
                            //print("🔴 切换插件源: \(selectedSourceType) -> \(sourceType)")
                            //print("🔴 当前数据状态: \(pluginManager.plugins.keys.map { "\($0): \(pluginManager.plugins[$0]?.count ?? 0)" })")
                            selectedSourceType = sourceType
                        }
                        .contextMenu {
                            Button("刷新所有插件") {
                                pluginManager.isGlobalScanComplete = false
                                Task {
                                    pluginManager.clearAllCache()
                                    await pluginManager.scanAllPluginSources()
                                }
                            }

                            Button("清空所有缓存") {
                                pluginManager.clearAllCache()
                            }
                        }
                    }
                }
                .padding(.vertical, 8)
            }
            
            Spacer()

            // 底部版权信息和使用提示
            VStack(alignment: .leading, spacing: 8) {
                Divider()

                // 版权信息
                VStack(alignment: .leading, spacing: 4) {
                    HStack {
                        Image(systemName: "info.circle")
                            .foregroundColor(.secondary)
                            .font(.caption)
                        Text("版权信息")
                            .font(.caption)
                            .foregroundColor(.secondary)
                        Spacer()
                    }

                    VStack(alignment: .leading, spacing: 2) {
                        Text("本软件仅在")
                            .font(.caption2)
                            .foregroundColor(.secondary)
                        + Text("dayu.media")
                            .font(.caption2)
                            .foregroundColor(.blue)
                            .underline()
                        + Text("更新和发布")
                            .font(.caption2)
                            .foregroundColor(.secondary)
                    }
                    .onTapGesture {
                        if let url = URL(string: "https://dayu.media") {
                            NSWorkspace.shared.open(url)
                        }
                    }
                    .cursor(.pointingHand)
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 6)

                Divider()

                // 使用提示
                VStack(alignment: .leading, spacing: 4) {
                    HStack {
                        Image(systemName: "exclamationmark.triangle")
                            .foregroundColor(.orange)
                            .font(.caption)
                        Text("重要提示")
                            .font(.caption)
                            .foregroundColor(.secondary)
                        Spacer()
                    }

                    VStack(alignment: .leading, spacing: 2) {
                        Text("给类别重命名时添加[1]、[2]等前缀可以给插件在FCPX中的显示进行排序。")
                            .font(.caption2)
                            .foregroundColor(.secondary)
                            .fixedSize(horizontal: false, vertical: true)

                        HStack {
                            Text("详细教程：")
                                .font(.caption2)
                                .foregroundColor(.secondary)
                            Text("dayu.media/7961")
                                .font(.caption2)
                                .foregroundColor(.blue)
                                .underline()
                        }
                        .onTapGesture {
                            if let url = URL(string: "https://dayu.media/7961/") {
                                NSWorkspace.shared.open(url)
                            }
                        }
                        .cursor(.pointingHand)
                    }
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 6)

                Divider()

                // 软件功能介绍
                VStack(alignment: .leading, spacing: 4) {
                    HStack {
                        Image(systemName: "star.circle")
                            .foregroundColor(.blue)
                            .font(.caption)
                        Text("主要功能")
                            .font(.caption)
                            .foregroundColor(.secondary)
                        Spacer()
                    }

                    VStack(alignment: .leading, spacing: 2) {
                        FeatureRow(icon: "eye", text: "查看插件详情和缩略图")
                        FeatureRow(icon: "pencil", text: "重命名插件和类别目录")
                        FeatureRow(icon: "trash", text: "安全卸载插件到回收站")
                        FeatureRow(icon: "arrow.triangle.merge", text: "合并多个插件类别")
                        FeatureRow(icon: "chart.bar", text: "显示插件文件体积")
                        FeatureRow(icon: "gear", text: "FxFactory防止自动恢复")
                    }
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 6)

                Divider()

                // 基本用法
                VStack(alignment: .leading, spacing: 4) {
                    HStack {
                        Image(systemName: "questionmark.circle")
                            .foregroundColor(.green)
                            .font(.caption)
                        Text("基本用法")
                            .font(.caption)
                            .foregroundColor(.secondary)
                        Spacer()
                    }

                    VStack(alignment: .leading, spacing: 2) {
                        UsageRow(step: "1", text: "选择插件源（用户/系统/FxPlug）")
                        UsageRow(step: "2", text: "浏览插件类型和类别目录")
                        UsageRow(step: "3", text: "右键插件进行操作")
                        UsageRow(step: "4", text: "多选模式可批量操作")
                        UsageRow(step: "5", text: "Fx插件移除需要密码")
                    }
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 6)
            }
        }
        .background(Color(NSColor.controlBackgroundColor))
    }
    
    private var availableSourceTypes: [PluginType] {
        [.user, .system, .fxplug]
    }
}

struct SourceTypeRowView: View {
    let sourceType: PluginType
    let isSelected: Bool
    let pluginCount: Int
    let onTap: () -> Void
    
    @State private var isHovered = false
    
    var body: some View {
        Button(action: onTap) {
            HStack(spacing: 12) {
                // 插件源图标
                Image(systemName: sourceType.icon)
                    .font(.system(size: 16))
                    .foregroundColor(isSelected ? .white : .primary)
                    .frame(width: 20)
                
                // 插件源名称
                Text(sourceType.displayName)
                    .font(.body)
                    .foregroundColor(isSelected ? .white : .primary)
                
                Spacer()
                
                // 插件数量
                if pluginCount > 0 {
                    Text("\(pluginCount)")
                        .font(.caption)
                        .foregroundColor(isSelected ? .white.opacity(0.8) : .secondary)
                        .padding(.horizontal, 6)
                        .padding(.vertical, 2)
                        .background(
                            Capsule()
                                .fill(isSelected ? Color.white.opacity(0.2) : Color.secondary.opacity(0.1))
                        )
                }
            }
            .padding(.horizontal, 16)
            .padding(.vertical, 10)
            .background(
                RoundedRectangle(cornerRadius: 6)
                    .fill(backgroundColorForRow)
            )
            .contentShape(Rectangle())
        }
        .buttonStyle(PlainButtonStyle())
        .onHover { hovering in
            isHovered = hovering
        }
        .padding(.horizontal, 8)
    }
    
    private var backgroundColorForRow: Color {
        if isSelected {
            return Color.accentColor
        } else if isHovered {
            return Color.primary.opacity(0.05)
        } else {
            return Color.clear
        }
    }
}

// MARK: - 辅助视图组件
struct FeatureRow: View {
    let icon: String
    let text: String

    var body: some View {
        HStack(spacing: 6) {
            Image(systemName: icon)
                .font(.caption2)
                .foregroundColor(.blue)
                .frame(width: 12)
            Text(text)
                .font(.caption2)
                .foregroundColor(.secondary)
            Spacer()
        }
    }
}

struct UsageRow: View {
    let step: String
    let text: String

    var body: some View {
        HStack(spacing: 6) {
            Text(step)
                .font(.caption2)
                .foregroundColor(.white)
                .frame(width: 12, height: 12)
                .background(
                    Circle()
                        .fill(Color.green)
                )
            Text(text)
                .font(.caption2)
                .foregroundColor(.secondary)
            Spacer()
        }
    }
}

// MARK: - 鼠标指针样式扩展
extension View {
    func cursor(_ cursor: NSCursor) -> some View {
        self.onHover { inside in
            if inside {
                cursor.push()
            } else {
                NSCursor.pop()
            }
        }
    }
}

#Preview {
    PluginSourceTypeView(
        selectedSourceType: .constant(.user),
        pluginManager: PluginManager()
    )
    .frame(width: 180, height: 600)
}
