//
//  PluginTypeAndCategoryView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

// MARK: - 类别更新操作枚举
enum CategoryUpdateAction {
    case rename(oldName: String, newName: String)
    case remove(categoryName: String)
}

struct PluginTypeAndCategoryView: View {
    let selectedSourceType: PluginType
    @Binding var selectedSubType: PluginSubType?
    @Binding var selectedCategoryPath: String?
    @ObservedObject var pluginManager: PluginManager

    @State private var expandedSubTypes: Set<PluginSubType> = []
    @State private var categoryPluginCounts: [String: Int] = [:]
    @StateObject private var categorySelectionManager = CategorySelectionManager()
    @State private var showingBatchMergeDialog = false
    @State private var showingBatchUninstallAlert = false
    @State private var isProcessingBatch = false
    
    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            // 标题栏
            VStack(spacing: 0) {
                // 主标题行
                HStack {
                    Text("类型与分类")
                        .font(.headline)
                        .foregroundColor(.primary)

                    Spacer()

                    // 多选模式切换按钮
                    HStack(spacing: 6) {
                        Text("多选")
                            .font(.caption)
                            .foregroundColor(.secondary)

                        Button(action: {
                            categorySelectionManager.toggleMultiSelectMode()
                        }) {
                            Image(systemName: categorySelectionManager.isMultiSelectMode ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(categorySelectionManager.isMultiSelectMode ? .accentColor : .secondary)
                        }
                        .buttonStyle(.plain)
                        .help(categorySelectionManager.isMultiSelectMode ? "退出多选模式" : "进入多选模式")
                    }
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 12)

                // 批量操作按钮栏（仅在多选模式且有选中项时显示）
                if categorySelectionManager.isMultiSelectMode && !categorySelectionManager.selectedCategories.isEmpty {
                    HStack(spacing: 8) {
                        // 选中数量显示
                        Text("\(categorySelectionManager.selectedCategories.count) 个类别")
                            .font(.caption)
                            .foregroundColor(.secondary)

                        Spacer()

                        // 批量合并按钮
                        Button("批量合并") {
                            showingBatchMergeDialog = true
                        }
                        .buttonStyle(.bordered)
                        .controlSize(.small)
                        .disabled(!categorySelectionManager.canPerformBatchMerge() || isProcessingBatch)

                        // 批量卸载按钮
                        Button("批量卸载") {
                            showingBatchUninstallAlert = true
                        }
                        .buttonStyle(.bordered)
                        .controlSize(.small)
                        .tint(.red)
                        .disabled(!categorySelectionManager.canPerformBatchUninstall() || isProcessingBatch)
                    }
                    .padding(.horizontal, 16)
                    .padding(.bottom, 8)
                    .background(Color.secondary.opacity(0.05))
                }
            }
            .background(Color(NSColor.controlBackgroundColor))
            
            Divider()
            
            // 插件类型和分类列表
            ScrollView {
                LazyVStack(alignment: .leading, spacing: 2) {
                    if selectedSourceType == .user || selectedSourceType == .system {
                        // Motion Templates 结构
                        ForEach(PluginSubType.allCases.filter { $0 != .compositions }, id: \.self) { subType in
                            PluginSubTypeSection(
                                subType: subType,
                                selectedSourceType: selectedSourceType,
                                selectedSubType: $selectedSubType,
                                selectedCategoryPath: $selectedCategoryPath,
                                isExpanded: expandedSubTypes.contains(subType),
                                categoryPluginCounts: categoryPluginCounts,
                                pluginManager: pluginManager,
                                categorySelectionManager: categorySelectionManager
                            ) {
                                toggleExpansion(for: subType)
                            }
                            .id("\(selectedSourceType.rawValue)-\(subType.rawValue)") // 🔧 修复状态混乱：为每个组合添加唯一标识符
                        }
                    } else if selectedSourceType == .fxplug {
                        // FxPlug插件的简化视图
                        Text("FxPlug插件不支持分类浏览")
                            .font(.callout)
                            .foregroundColor(.secondary)
                            .padding(.horizontal, 16)
                            .padding(.vertical, 20)
                    }
                }
                .padding(.vertical, 8)
            }
            
            Spacer()
        }
        .background(Color(NSColor.controlBackgroundColor))
        .onChange(of: selectedSourceType) { newValue in
            // 重置选择状态
            selectedSubType = nil
            selectedCategoryPath = nil
            expandedSubTypes.removeAll()
            updateCategoryPluginCounts()

            // 触发所有子类型的类别重新加载
            Task {
                // 等待一个短暂的延迟，确保UI状态已经更新
                try? await Task.sleep(nanoseconds: 100_000_000) // 0.1秒

                // 数据源已通过@Published自动更新，无需手动刷新
                //print("🔴 类别数据将自动更新")
            }
        }
        .onAppear {
            updateCategoryPluginCounts()
        }
        .sheet(isPresented: $showingBatchMergeDialog) {
            BatchCategoryMergeDialog(
                categories: categorySelectionManager.selectedCategories,
                onMerge: { targetCategory in
                    Task {
                        await performBatchCategoryMerge(targetCategory: targetCategory)
                    }
                },
                pluginManager: pluginManager
            )
        }
        .alert("批量卸载确认", isPresented: $showingBatchUninstallAlert) {
            Button("取消", role: .cancel) { }
            Button("确认卸载", role: .destructive) {
                Task {
                    await performBatchCategoryUninstall()
                }
            }
        } message: {
            Text("确定要卸载选中的 \(categorySelectionManager.selectedCategories.count) 个类别中的所有插件吗？总共约 \(categorySelectionManager.getTotalPluginCount()) 个插件将被卸载。此操作不可撤销。")
        }
    }
    
    private func toggleExpansion(for subType: PluginSubType) {
        if expandedSubTypes.contains(subType) {
            expandedSubTypes.remove(subType)
        } else {
            expandedSubTypes.insert(subType)
        }
    }
    
    private func updateCategoryPluginCounts() {
        guard let plugins = pluginManager.plugins[selectedSourceType] else { return }
        
        var counts: [String: Int] = [:]
        for plugin in plugins {
            if let categoryPath = plugin.categoryPath.components(separatedBy: "/").last {
                counts[categoryPath, default: 0] += 1
            }
        }
        categoryPluginCounts = counts
    }

    // MARK: - 批量操作方法

    /// 执行批量类别合并
    private func performBatchCategoryMerge(targetCategory: String) async {
        isProcessingBatch = true
        defer { isProcessingBatch = false }

        let categoriesToMerge = categorySelectionManager.selectedCategories
        print("🔄 开始批量合并 \(categoriesToMerge.count) 个类别到: \(targetCategory)")

        var successCount = 0
        var failedCategories: [String] = []
        var totalItemsMoved = 0

        // 确定目标类别路径
        guard let firstCategory = categoriesToMerge.first else {
            print("❌ 没有选中的类别")
            return
        }

        let targetCategoryPath: String
        var categoriesToProcess = Array(categoriesToMerge)

        // 检查目标类别是否是选中类别中的一个
        if let targetCategoryInfo = categoriesToMerge.first(where: { $0.displayName == targetCategory }) {
            // 如果目标是选中的类别之一，使用其路径，并从处理列表中移除
            targetCategoryPath = targetCategoryInfo.categoryPath
            categoriesToProcess.removeAll { $0.id == targetCategoryInfo.id }
            print("🎯 使用现有类别作为目标: \(targetCategory) (路径: \(targetCategoryPath))")
        } else {
            // 否则创建新的目标路径
            targetCategoryPath = buildTargetCategoryPath(
                targetName: targetCategory,
                sourceType: firstCategory.sourceType,
                subType: firstCategory.subType
            )
            print("🎯 创建新目标类别: \(targetCategory) (路径: \(targetCategoryPath))")
        }

        for category in categoriesToProcess {
            print("🔄 正在合并类别: \(category.displayName) (路径: \(category.categoryPath))")

            do {
                // 直接移动类别目录下的所有内容
                let movedCount = try await mergeCategoryDirectly(
                    sourcePath: category.categoryPath,
                    targetPath: targetCategoryPath,
                    categoryName: category.displayName
                )

                totalItemsMoved += movedCount
                successCount += 1
                print("✅ 类别合并成功: \(category.displayName) (移动了 \(movedCount) 个项目)")

                // 在内存中处理类别合并
                await MainActor.run {
                    pluginManager.mergeCategoryInMemory(
                        sourceCategory: category.displayName,
                        targetCategory: targetCategory,
                        finalCategoryName: targetCategory,
                        sourceType: category.sourceType
                    )
                }

            } catch {
                failedCategories.append(category.displayName)
                print("❌ 类别合并失败: \(category.displayName) - \(error)")
            }
        }

        // 清空选择并退出多选模式，并刷新插件列表
        await MainActor.run {
            categorySelectionManager.clearSelection()
            categorySelectionManager.isMultiSelectMode = false
        }

        // 使用增量更新而不是完全重新扫描
        await MainActor.run {
            updateCategoryPluginCounts()

            // 强制触发插件数据更新通知，确保所有PluginSubTypeSection重新加载类别列表
            pluginManager.objectWillChange.send()
        }

        print("🎉 批量类别合并完成: 成功 \(successCount) 个，失败 \(failedCategories.count) 个，总共移动 \(totalItemsMoved) 个项目")
        print("📊 处理了 \(categoriesToProcess.count) 个源类别，合并到目标: \(targetCategory)")
        if !failedCategories.isEmpty {
            print("❌ 失败的类别: \(failedCategories.joined(separator: ", "))")
        }
    }

    /// 构建目标类别路径
    private func buildTargetCategoryPath(targetName: String, sourceType: PluginType, subType: PluginSubType) -> String {
        let basePath = sourceType.basePath
        return "\(basePath)/\(subType.rawValue)/\(targetName)"
    }

    /// 直接合并类别目录
    private func mergeCategoryDirectly(sourcePath: String, targetPath: String, categoryName: String) async throws -> Int {
        let fileManager = FileManager.default
        var movedCount = 0

        // 确保目标目录存在
        if !fileManager.fileExists(atPath: targetPath) {
            // 检查是否需要管理员权限创建目标目录
            if SudoPermissionManager.shared.needsSudoPermission(for: targetPath) {
                try await SudoPermissionManager.shared.executeAppleScriptCommand("mkdir -p '\(targetPath)'")
            } else {
                try fileManager.createDirectory(atPath: targetPath, withIntermediateDirectories: true, attributes: nil)
            }
            print("📁 创建目标目录: \(targetPath)")
        }

        // 获取源目录下的所有内容
        let sourceContents = try fileManager.contentsOfDirectory(atPath: sourcePath)

        // 分组处理：需要权限的操作和普通操作
        var systemMoves: [(from: String, to: String)] = []
        var normalMoves: [(from: String, to: String)] = []

        for item in sourceContents {
            // 跳过隐藏文件
            if item.hasPrefix(".") { continue }

            let sourceItemPath = "\(sourcePath)/\(item)"
            var targetItemPath = "\(targetPath)/\(item)"

            // 检查目标位置是否已存在同名项目
            if fileManager.fileExists(atPath: targetItemPath) {
                // 生成唯一名称
                let uniqueName = generateUniqueItemName(baseName: item, targetDirectory: targetPath)
                targetItemPath = "\(targetPath)/\(uniqueName)"
                print("📦 准备移动项目: \(item) -> \(uniqueName)")
            } else {
                print("📦 准备移动项目: \(item)")
            }

            // 根据是否需要权限分组
            if SudoPermissionManager.shared.needsSudoPermission(for: sourceItemPath) {
                systemMoves.append((from: sourceItemPath, to: targetItemPath))
            } else {
                normalMoves.append((from: sourceItemPath, to: targetItemPath))
            }
        }

        // 批量执行需要权限的移动操作（一次性请求权限）
        if !systemMoves.isEmpty {
            let moveCommands = systemMoves.map { "mv '\($0.from)' '\($0.to)'" }.joined(separator: " && ")
            try await SudoPermissionManager.shared.executeAppleScriptCommand(moveCommands)
            print("✅ 成功批量移动 \(systemMoves.count) 个系统项目")
            movedCount += systemMoves.count
        }

        // 执行普通移动操作
        for move in normalMoves {
            do {
                try fileManager.moveItem(atPath: move.from, toPath: move.to)
                movedCount += 1
            } catch {
                print("❌ 移动项目失败: \(URL(fileURLWithPath: move.from).lastPathComponent) - \(error)")
                throw error
            }
        }

        // 删除空的源目录
        let remainingContents = try fileManager.contentsOfDirectory(atPath: sourcePath)
        if remainingContents.filter({ !$0.hasPrefix(".") }).isEmpty {
            // 检查是否需要管理员权限删除源目录
            if SudoPermissionManager.shared.needsSudoPermission(for: sourcePath) {
                try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: sourcePath)
            } else {
                try fileManager.removeItem(atPath: sourcePath)
            }
            print("🗑️ 删除空的源类别目录: \(categoryName)")
        }

        return movedCount
    }

    /// 生成唯一的项目名称
    private func generateUniqueItemName(baseName: String, targetDirectory: String) -> String {
        let fileManager = FileManager.default
        var counter = 1
        var uniqueName = baseName

        while fileManager.fileExists(atPath: "\(targetDirectory)/\(uniqueName)") {
            counter += 1
            uniqueName = "\(baseName) \(counter)"
        }

        return uniqueName
    }

    /// 执行批量类别卸载
    private func performBatchCategoryUninstall() async {
        isProcessingBatch = true
        defer { isProcessingBatch = false }

        let categoriesToUninstall = categorySelectionManager.selectedCategories
        print("🔄 开始批量卸载 \(categoriesToUninstall.count) 个类别")

        var successCount = 0
        var failedCategories: [String] = []
        var totalPluginsUninstalled = 0

        for category in categoriesToUninstall {
            print("🔄 正在卸载类别: \(category.displayName) (路径: \(category.categoryPath))")

            // 获取该类别下的所有插件
            let plugins = await pluginManager.getPluginsInCategory(
                categoryPath: category.categoryPath,
                subType: category.subType,
                sourceType: category.sourceType
            )

            print("📦 找到 \(plugins.count) 个插件需要卸载")

            if plugins.isEmpty {
                print("⚠️ 类别 \(category.displayName) 中没有找到插件")
                continue
            }

            // 逐个卸载插件
            var pluginSuccessCount = 0
            for plugin in plugins {
                do {
                    print("🔄 正在卸载插件: \(plugin.displayName)")
                    try await pluginManager.uninstallPlugin(plugin)
                    pluginSuccessCount += 1
                    totalPluginsUninstalled += 1
                    print("✅ 插件卸载成功: \(plugin.displayName)")
                } catch {
                    print("❌ 插件卸载失败: \(plugin.displayName) - \(error)")
                    // 继续处理其他插件，不因为单个插件失败而停止整个类别的卸载
                }
            }

            if pluginSuccessCount > 0 {
                successCount += 1
                print("✅ 类别卸载成功: \(category.displayName) (成功卸载 \(pluginSuccessCount)/\(plugins.count) 个插件)")
            } else {
                failedCategories.append(category.displayName)
                print("❌ 类别卸载失败: \(category.displayName) - 没有插件成功卸载")
            }
        }

        // 清空选择并退出多选模式，并刷新插件列表
        await MainActor.run {
            categorySelectionManager.clearSelection()
            categorySelectionManager.isMultiSelectMode = false
        }

        // 使用增量更新而不是完全重新扫描（每个插件卸载时已经自动从内存中移除）
        await MainActor.run {
            updateCategoryPluginCounts()
        }

        print("🎉 批量类别卸载完成: 成功 \(successCount) 个，失败 \(failedCategories.count) 个，总共卸载 \(totalPluginsUninstalled) 个插件")
        if !failedCategories.isEmpty {
            print("❌ 失败的类别: \(failedCategories.joined(separator: ", "))")
        }
    }
}

struct PluginSubTypeSection: View {
    let subType: PluginSubType
    let selectedSourceType: PluginType
    @Binding var selectedSubType: PluginSubType?
    @Binding var selectedCategoryPath: String?
    let isExpanded: Bool
    let categoryPluginCounts: [String: Int]
    @ObservedObject var pluginManager: PluginManager
    @ObservedObject var categorySelectionManager: CategorySelectionManager
    let onToggleExpansion: () -> Void
    
    @State private var categories: [String] = []
    @State private var categoryMapping: [String: String] = [:] // 显示名称 -> 原始目录名称的映射
    @State private var isHovered = false
    
    var subTypePluginCount: Int {
        pluginManager.plugins[selectedSourceType]?.filter { $0.subType == subType }.count ?? 0
    }
    
    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            // 插件类型行
            Button(action: {
                selectedSubType = subType
                selectedCategoryPath = nil
                onToggleExpansion()
            }) {
                HStack(spacing: 12) {
                    // 展开/收起图标
                    Image(systemName: isExpanded ? "chevron.down" : "chevron.right")
                        .font(.caption)
                        .foregroundColor(.secondary)
                        .frame(width: 12)
                    
                    // 插件类型图标
                    Image(systemName: subType.icon)
                        .font(.system(size: 16))
                        .foregroundColor(selectedSubType == subType && selectedCategoryPath == nil ? .white : .primary)
                        .frame(width: 20)
                    
                    // 插件类型名称
                    Text(subType.displayName)
                        .font(.body)
                        .fontWeight(.medium)
                        .foregroundColor(selectedSubType == subType && selectedCategoryPath == nil ? .white : .primary)
                    
                    Spacer()
                    
                    // 插件数量
                    if subTypePluginCount > 0 {
                        Text("\(subTypePluginCount)")
                            .font(.caption)
                            .foregroundColor(selectedSubType == subType && selectedCategoryPath == nil ? .white.opacity(0.8) : .secondary)
                            .padding(.horizontal, 6)
                            .padding(.vertical, 2)
                            .background(
                                Capsule()
                                    .fill(selectedSubType == subType && selectedCategoryPath == nil ? Color.white.opacity(0.2) : Color.secondary.opacity(0.1))
                            )
                    }
                }
                .padding(.horizontal, 16)
                .padding(.vertical, 8)
                .background(
                    RoundedRectangle(cornerRadius: 6)
                        .fill(backgroundColorForSubType)
                )
                .contentShape(Rectangle())
            }
            .buttonStyle(PlainButtonStyle())
            .onHover { hovering in
                isHovered = hovering
            }
            
            // 类别列表
            if isExpanded {
                VStack(alignment: .leading, spacing: 1) {
                    ForEach(categories.indices, id: \.self) { index in
                        let category = categories[index]
                        CategoryRowView(
                            category: category,
                            subType: subType,
                            selectedSourceType: selectedSourceType,
                            categoryMapping: categoryMapping,
                            categories: categories,
                            isSelected: selectedSubType == subType && selectedCategoryPath == (categoryMapping[category] ?? category),
                            onCategoryChanged: {
                                await loadCategories()
                            },
                            onIncrementalUpdate: handleIncrementalUpdate,
                            pluginCount: categoryPluginCounts[categoryMapping[category] ?? category] ?? 0,
                            onTap: {
                                selectedSubType = subType
                                selectedCategoryPath = categoryMapping[category] ?? category // 传递原始目录名称
                            },
                            pluginManager: pluginManager,
                            selectedCategoryPath: $selectedCategoryPath,
                            selectedSubType: $selectedSubType,
                            categorySelectionManager: categorySelectionManager
                        )
                    }
                }
                .padding(.leading, 28)
                .padding(.trailing, 16)
                .padding(.bottom, 4)
            }
        }
        .padding(.horizontal, 8)
        .onAppear {
            // 🔧 修复初始加载问题：只在数据准备好后才加载类别
            if pluginManager.plugins[selectedSourceType] != nil && !pluginManager.plugins[selectedSourceType]!.isEmpty {
                Task {
                    await loadCategories()
                }
            }
        }
        .onChange(of: selectedSourceType) { newValue in
            // 🔧 修复竞态条件：延迟加载，确保主视图的状态重置完成
            Task {
                // 等待主视图状态重置完成
                try? await Task.sleep(nanoseconds: 200_000_000) // 0.2秒
                await loadCategories()
            }
        }
        .onChange(of: pluginManager.plugins) { _ in
            // 🔧 当插件数据更新时，只在必要时重新加载类别
            // 避免在类别重命名等操作时触发全量刷新
            Task {
                // 检查是否有新的类别出现或类别完全消失，只有这种情况才需要全量刷新
                let currentCategoryPaths = Set(categories.compactMap { categoryMapping[$0] })
                let newCategoryPaths = Set(await getCategoryPathsFromPlugins())

                // 如果类别路径集合发生了变化（新增或删除类别），才进行全量刷新
                if currentCategoryPaths != newCategoryPaths {
                    await loadCategories()
                }
                // 否则只更新插件计数，不重新加载类别列表
                // 插件计数会通过@Published自动更新，无需手动调用
            }
        }

    }
    
    private var backgroundColorForSubType: Color {
        if selectedSubType == subType && selectedCategoryPath == nil {
            return Color.accentColor
        } else if isHovered {
            return Color.primary.opacity(0.05)
        } else {
            return Color.clear
        }
    }
    
    private func loadCategories() async {
        //print("🔧 loadCategories 被调用 - selectedSourceType: \(selectedSourceType), subType: \(subType)")

        // 🔧 修复数据混淆问题：从已扫描的插件数据中获取类别，而不是重新扫描文件系统
        guard let sourcePlugins = pluginManager.plugins[selectedSourceType] else {
            //print("🔧 没有找到 \(selectedSourceType) 的插件数据")
            await MainActor.run {
                categories = []
                categoryMapping = [:]
            }
            return
        }

        // 过滤出指定子类型的插件
        let subTypePlugins = sourcePlugins.filter { $0.subType == subType }
        //print("🔧 找到 \(subTypePlugins.count) 个 \(subType.displayName) 类型的插件")

        // 验证插件路径与插件源的一致性
        let validPlugins = subTypePlugins.filter { plugin in
            let isValid = validatePluginSourcePath(categoryPath: plugin.path, expectedSource: selectedSourceType)
            if !isValid {
                //print("🚨 过滤掉路径不匹配的插件: \(plugin.displayName) - 期望源: \(selectedSourceType.displayName), 实际路径: \(plugin.path)")
            }
            return isValid
        }

        //print("🔧 路径验证后剩余 \(validPlugins.count) 个有效插件")

        // 从有效插件中提取类别信息
        var categorySet: Set<String> = []
        var mapping: [String: String] = [:]

        for plugin in validPlugins {
            let categoryPath = plugin.categoryPath
            let categoryName = URL(fileURLWithPath: categoryPath).lastPathComponent

            // 解析FxFactory类别名称
            let resolvedName = await resolveFxFactoryCategoryName(categoryPath: categoryPath, categoryName: categoryName)

            categorySet.insert(resolvedName)
            mapping[resolvedName] = categoryName // 显示名称 -> 原始目录名称
        }

        let sortedCategories = Array(categorySet).sorted { $0.localizedStandardCompare($1) == .orderedAscending }
        //print("🔧 最终类别列表: \(sortedCategories)")

        // 确保在主线程更新UI状态
        await MainActor.run {
            categories = sortedCategories
            categoryMapping = mapping
        }
    }

    // 解析FxFactory类别目录名称（简化版本）
    private func resolveFxFactoryCategoryName(categoryPath: String, categoryName: String) async -> String {
        // 直接检查是否存在 .localized/en.strings 文件
        let stringsPath = URL(fileURLWithPath: categoryPath)
            .appendingPathComponent(".localized")
            .appendingPathComponent("en.strings")
            .path

        guard FileManager.default.fileExists(atPath: stringsPath) else {
            return categoryName // 不是FxFactory目录，返回原名称
        }

        // 直接读取 .localized/en.strings 文件
        do {
            let content = try String(contentsOfFile: stringsPath, encoding: .utf8)

            // 简单解析 strings 文件内容
            for line in content.components(separatedBy: .newlines) {
                let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)
                if trimmedLine.contains("=") && trimmedLine.contains("\"") {
                    if let _ = trimmedLine.firstIndex(of: "\""),
                       let equalIndex = trimmedLine.firstIndex(of: "=") {
                        let afterEqual = trimmedLine[trimmedLine.index(after: equalIndex)...]
                        if let secondQuoteIndex = afterEqual.firstIndex(of: "\"") {
                            let afterSecondQuote = afterEqual[afterEqual.index(after: secondQuoteIndex)...]
                            if let thirdQuoteIndex = afterSecondQuote.firstIndex(of: "\"") {
                                let realName = String(afterSecondQuote[..<thirdQuoteIndex])
                                if !realName.isEmpty {
                                    return realName
                                }
                            }
                        }
                    }
                }
            }
        } catch {
            // 读取失败时不显示警告，直接使用原始名称
        }

        // 如果读取失败，直接返回原始名称
        return categoryName
    }

    // 验证插件路径与插件源的一致性
    private func validatePluginSourcePath(categoryPath: String, expectedSource: PluginType) -> Bool {
        switch expectedSource {
        case .user:
            // 用户插件应该在用户目录下
            return categoryPath.contains("/Users/") && categoryPath.contains("Movies/Motion Templates.localized")
        case .system:
            // 系统插件应该在系统目录下
            return categoryPath.contains("/Library/Application Support/Final Cut Pro/Templates.localized")
        case .fxplug:
            // FxPlug插件应该在FxPlug目录下
            return categoryPath.contains("/Library/Plug-Ins/FxPlug")
        default:
            return true
        }
    }

    /// 从插件数据中获取类别路径集合
    private func getCategoryPathsFromPlugins() async -> [String] {
        guard let typePlugins = pluginManager.plugins[selectedSourceType] else { return [] }

        let categoryPaths = Set(typePlugins.map { plugin in
            URL(fileURLWithPath: plugin.categoryPath).lastPathComponent
        })

        return Array(categoryPaths)
    }

    // MARK: - 增量更新处理
    private func handleIncrementalUpdate(_ action: CategoryUpdateAction) {
        switch action {
        case .rename(let oldName, let newName):
            // 处理重命名
            if let index = categories.firstIndex(of: oldName) {
                // 检查当前选中的是否是被重命名的类别（在更新映射之前）
                let originalCategoryName = categoryMapping[oldName] ?? oldName
                let shouldUpdateSelection = selectedCategoryPath == originalCategoryName

                var updatedCategories = categories
                updatedCategories[index] = newName
                categories = updatedCategories

                // 更新映射关系
                var updatedMapping = categoryMapping
                updatedMapping.removeValue(forKey: oldName)
                updatedMapping[newName] = newName
                categoryMapping = updatedMapping

                // 如果当前选中的是被重命名的类别，更新选中状态
                if shouldUpdateSelection {
                    selectedCategoryPath = newName
                }
            }

        case .remove(let categoryName):
            // 处理移除
            if let index = categories.firstIndex(of: categoryName) {
                var updatedCategories = categories
                updatedCategories.remove(at: index)
                categories = updatedCategories

                // 更新映射关系
                var updatedMapping = categoryMapping
                updatedMapping.removeValue(forKey: categoryName)
                categoryMapping = updatedMapping
            }
        }
    }

}

struct CategoryRowView: View {
    let category: String
    let subType: PluginSubType
    let selectedSourceType: PluginType
    let categoryMapping: [String: String] // 显示名称 -> 原始目录名称的映射
    let categories: [String] // 所有类别列表
    let isSelected: Bool
    let onCategoryChanged: () async -> Void // 类别变化回调
    let onIncrementalUpdate: (CategoryUpdateAction) -> Void // 增量更新回调
    let pluginCount: Int
    let onTap: () -> Void
    @ObservedObject var pluginManager: PluginManager
    @Binding var selectedCategoryPath: String?
    @Binding var selectedSubType: PluginSubType?
    @ObservedObject var categorySelectionManager: CategorySelectionManager

    @State private var isHovered = false
    @State private var showingRenameAlert = false
    @State private var newCategoryName = ""
    @State private var showingMergeView = false
    @State private var draggedCategory: String?
    @State private var showingNewCategoryAlert = false
    @State private var newCategoryForMerge = ""
    @State private var categorySize: Int64 = 0
    @State private var isLoadingSize = false

    /// 判断是否为FxFactory类别
    private var isFxFactoryCategory: Bool {
        let originalCategoryName = categoryMapping[category] ?? category
        return isFxFactoryCategory(originalCategoryName)
    }

    /// 创建类别信息对象
    private var categoryInfo: CategorySelectionManager.CategoryInfo {
        // 构建完整的类别路径
        let originalCategoryName = categoryMapping[category] ?? category
        let basePath = selectedSourceType.basePath
        let fullCategoryPath = "\(basePath)/\(subType.rawValue)/\(originalCategoryName)"

        return CategorySelectionManager.CategoryInfo(
            categoryPath: fullCategoryPath,
            displayName: displayCategoryName,
            subType: subType,
            sourceType: selectedSourceType,
            pluginCount: pluginCount
        )
    }

    /// 是否在多选模式下被选中
    private var isMultiSelected: Bool {
        categorySelectionManager.isSelected(categoryInfo)
    }

    /// 是否应该使用白色文本（当背景为蓝色时）
    private var shouldUseWhiteText: Bool {
        if categorySelectionManager.isMultiSelectMode {
            return isMultiSelected
        } else {
            return isSelected
        }
    }

    /// 获取显示的类别名称
    private var displayCategoryName: String {
        if isFxFactoryCategory {
            // 对于FxFactory插件，直接读取真实名称
            let _ = categoryMapping[category] ?? category
            let categoryPath = getCategoryPath()

            // 直接读取 .localized/en.strings 文件
            let stringsPath = URL(fileURLWithPath: categoryPath)
                .appendingPathComponent(".localized")
                .appendingPathComponent("en.strings")
                .path

            if FileManager.default.fileExists(atPath: stringsPath) {
                do {
                    let content = try String(contentsOfFile: stringsPath, encoding: .utf8)

                    // 简单解析 strings 文件内容
                    for line in content.components(separatedBy: .newlines) {
                        let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)
                        if trimmedLine.contains("=") && trimmedLine.contains("\"") {
                            if let equalIndex = trimmedLine.firstIndex(of: "=") {
                                let afterEqual = trimmedLine[trimmedLine.index(after: equalIndex)...]
                                if let secondQuoteIndex = afterEqual.firstIndex(of: "\"") {
                                    let afterSecondQuote = afterEqual[afterEqual.index(after: secondQuoteIndex)...]
                                    if let thirdQuoteIndex = afterSecondQuote.firstIndex(of: "\"") {
                                        let realName = String(afterSecondQuote[..<thirdQuoteIndex])
                                        if !realName.isEmpty {
                                            return realName
                                        }
                                    }
                                }
                            }
                        }
                    }
                } catch {
                    // 读取失败，继续使用原始名称
                }
            }
        }
        return category
    }
    
    var body: some View {
        HStack(spacing: 8) {
            // 多选模式下的选择框
            if categorySelectionManager.isMultiSelectMode {
                Button(action: {
                    categorySelectionManager.toggleSelection(for: categoryInfo)
                }) {
                    ZStack {
                        if isMultiSelected {
                            // 选中状态：绿色背景 + 白色勾选
                            Circle()
                                .fill(Color.green)
                                .frame(width: 16, height: 16)

                            Image(systemName: "checkmark")
                                .foregroundColor(.white)
                                .font(.system(size: 10, weight: .bold))
                        } else {
                            // 未选中状态：灰色圆圈
                            Circle()
                                .stroke(Color.secondary, lineWidth: 1.5)
                                .frame(width: 16, height: 16)
                        }
                    }
                }
                .buttonStyle(.plain)
            }

            // 文件夹图标 - 根据是否为FxFactory插件显示不同图标
            ZStack(alignment: .topTrailing) {
                Image(systemName: isFxFactoryCategory ? "folder.fill" : "folder")
                    .font(.system(size: 14))
                    .foregroundColor(shouldUseWhiteText ? .white : (isFxFactoryCategory ? .orange : .secondary))
                    .frame(width: 16)

                // FxFactory插件特殊标识
                if isFxFactoryCategory {
                    Image(systemName: "f.circle.fill")
                        .font(.system(size: 8))
                        .foregroundColor(.white)
                        .background(
                            Circle()
                                .fill(Color.orange)
                                .frame(width: 10, height: 10)
                        )
                        .offset(x: 4, y: -4)
                }
            }
            .frame(width: 20)

            // 类别名称
            Text(displayCategoryName)
                .font(.callout)
                .foregroundColor(shouldUseWhiteText ? .white : .primary)

            Spacer()

            // 体积显示
            VStack(alignment: .trailing, spacing: 2) {
                // 插件数量
                if pluginCount > 0 {
                    Text("\(pluginCount)")
                        .font(.caption2)
                        .foregroundColor(shouldUseWhiteText ? .white.opacity(0.8) : .secondary)
                        .padding(.horizontal, 4)
                        .padding(.vertical, 1)
                        .background(
                            Capsule()
                                .fill(shouldUseWhiteText ? Color.white.opacity(0.2) : Color.secondary.opacity(0.1))
                        )
                }

                // 目录体积
                if isLoadingSize {
                    Text("计算中...")
                        .font(.caption2)
                        .foregroundColor(.orange)
                } else if categorySize > 0 {
                    Text(formatFileSize(categorySize))
                        .font(.caption2)
                        .fontWeight(.medium)
                        .foregroundColor(shouldUseWhiteText ? .white : .orange)
                }
            }
        }
        .padding(.horizontal, 12)
        .padding(.vertical, 6)
        .background(
            RoundedRectangle(cornerRadius: 4)
                .fill(backgroundColorForCategory)
        )
        .contentShape(Rectangle())
        .onTapGesture {
            if categorySelectionManager.isMultiSelectMode {
                categorySelectionManager.toggleSelection(for: categoryInfo)
            } else {
                onTap()
            }
        }
        .onHover { hovering in
            isHovered = hovering
        }
        .onAppear {
            loadCategorySize()
        }
        .modifier(CategoryDragModifier(
            categoryInfoProvider: { createCategoryInfo() },
            previewContent: {
                // 拖拽预览
                HStack {
                    Image(systemName: "folder.fill")
                        .foregroundColor(.blue)
                    Text(category)
                        .font(.callout)
                }
                .padding(8)
                .background(Color.blue.opacity(0.1))
                .cornerRadius(6)
            }
        ))
        .contextMenu {
            categoryContextMenu
        }
        .alert("重命名类别", isPresented: $showingRenameAlert) {
            TextField("新名称", text: $newCategoryName)
            Button("取消", role: .cancel) { }
            Button("确定") {
                renameCategoryAction()
            }
        } message: {
            Text("请输入新的类别名称")
        }
        .alert("新建类别", isPresented: $showingNewCategoryAlert) {
            TextField("类别名称", text: $newCategoryForMerge)
            Button("取消", role: .cancel) {
                newCategoryForMerge = ""
            }
            Button("创建并合并") {
                createCategoryAndMerge()
            }
            .disabled(newCategoryForMerge.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty)
        } message: {
            Text("请输入新类别的名称，当前类别的所有插件将合并到新类别中")
        }
        .modifier(CategoryDropModifier(
            onDrop: { providers in
                // 处理拖拽放置 - 接收类别目录URL
                for provider in providers {
                    if provider.hasItemConformingToTypeIdentifier("public.file-url") {
                        provider.loadItem(forTypeIdentifier: "public.file-url", options: nil) { (item, error) in
                            if let url = item as? URL {
                                let droppedCategoryName = url.lastPathComponent
                                guard droppedCategoryName != category else { return }

                                DispatchQueue.main.async {
                                    draggedCategory = droppedCategoryName
                                    showingMergeView = true
                                }
                            }
                        }
                        return true
                    }
                }
                return false
            }
        ))
        .sheet(isPresented: $showingMergeView) {
            if let draggedCategory = draggedCategory {
                CategoryMergeView(
                    isPresented: $showingMergeView,
                    mergeOperation: CategoryMergeOperation(
                        sourceCategory: draggedCategory,
                        targetCategory: category,
                        sourceType: selectedSourceType,
                        subType: subType
                    ),
                    categoryMapping: categoryMapping,
                    pluginManager: pluginManager,
                    onCategoryChanged: onCategoryChanged
                )
            }
        }
    }
    
    private var backgroundColorForCategory: Color {
        // 在多选模式下，优先显示多选状态
        if categorySelectionManager.isMultiSelectMode {
            if isMultiSelected {
                return Color.accentColor
            } else if isHovered {
                return Color.primary.opacity(0.05)
            } else {
                return Color.clear
            }
        } else {
            // 非多选模式下的原有逻辑
            if isSelected {
                return Color.accentColor
            } else if isHovered {
                return Color.primary.opacity(0.05)
            } else {
                return Color.clear
            }
        }
    }

    // MARK: - 右键菜单
    @ViewBuilder
    private var categoryContextMenu: some View {
        Button(action: showInFinderAction) {
            Label("在访达中显示", systemImage: "folder")
        }

        Divider()

        Button(action: showRenameAlert) {
            Label("重命名", systemImage: "pencil")
        }

        Menu("合并到其他类别") {
            Text("选择目标类别:")
                .font(.caption)
                .foregroundColor(.secondary)

            // 列出当前插件类型下的所有其他类别
            ForEach(getOtherCategories(), id: \.self) { otherCategory in
                Button(action: {
                    mergeToCategory(otherCategory)
                }) {
                    Label(getCategoryDisplayName(otherCategory), systemImage: "folder")
                }
            }

            if !getOtherCategories().isEmpty {
                Divider()
            }

            // 新建类别选项
            Button(action: {
                showingNewCategoryAlert = true
            }) {
                Label("新建类别...", systemImage: "folder.badge.plus")
            }
        }

        Divider()

        Button(action: removeCategoryAction) {
            Label("移除", systemImage: "trash")
        }
        .foregroundColor(.red)
    }

    // MARK: - 操作方法
    private func showInFinderAction() {
        // 构建类别目录的完整路径
        let categoryPath = getCategoryPath()
        let url = URL(fileURLWithPath: categoryPath)

        // 在访达中显示
        NSWorkspace.shared.selectFile(categoryPath, inFileViewerRootedAtPath: url.deletingLastPathComponent().path)
    }

    private func showRenameAlert() {
        newCategoryName = category
        showingRenameAlert = true
    }

    private func renameCategoryAction() {
        guard !newCategoryName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty else { return }

        let categoryPath = getCategoryPath()
        let originalCategoryName = categoryMapping[category] ?? category

        Task {
            // 直接检查类别目录本身是否为FxFactory插件
            let isFxFactoryCategory = isCategoryFxFactoryPlugin(categoryPath: categoryPath)

            print("🔍 重命名检查: \(originalCategoryName)")
            print("  - 路径: \(categoryPath)")

            // 用于跟踪当前类别路径的变量
            var currentCategoryPath = categoryPath

            if isFxFactoryCategory {
                print("  ✅ 这是FxFactory类别，开始完整还原流程")

                // 1. 获取类别的真实名称（必须在删除.localized文件之前）
                let realCategoryName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: categoryPath)
                print("  - 类别真实名称: \(realCategoryName)")

                // 2. 先还原该类别下的所有FxFactory子插件（必须在删除类别.localized文件之前，因为子插件真实名称需要从类别的.localized/en.strings读取）
                await restoreFxFactoryPluginsInCategory(categoryPath: categoryPath)

                // 3. 执行FxFactory防护操作（删除.fxpack和.fxtemplates文件）
                do {
                    let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                        categoryRealName: realCategoryName,
                        operation: .rename
                    )
                    print("  ✅ FxFactory防护操作完成")
                } catch {
                    print("  ❌ FxFactory防护操作失败: \(error)")
                }

                // 4. 最后还原类别目录本身的FxFactory结构（删除.localized、.fxfactory.plist等）
                do {
                    try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: categoryPath)
                    print("  ✅ 类别目录FxFactory结构还原完成")
                } catch {
                    print("  ❌ 类别目录FxFactory结构还原失败: \(error)")
                }

                // 5. 如果类别目录名称是UUID格式，先还原为真实名称
                if originalCategoryName.hasSuffix(".localized") {
                    let parentPath = URL(fileURLWithPath: categoryPath).deletingLastPathComponent().path
                    let realNamePath = URL(fileURLWithPath: parentPath).appendingPathComponent(realCategoryName).path

                    do {
                        // 检查是否需要管理员权限（系统插件类别）
                        if SudoPermissionManager.shared.needsSudoPermission(for: categoryPath) {
                            try await SudoPermissionManager.shared.renameFileWithSudoPermission(
                                from: categoryPath,
                                to: realNamePath
                            )
                        } else {
                            try FileManager.default.moveItem(atPath: categoryPath, toPath: realNamePath)
                        }
                        print("  ✅ 类别目录还原为真实名称: \(originalCategoryName) -> \(realCategoryName)")

                        // 更新当前路径为还原后的路径
                        currentCategoryPath = realNamePath
                    } catch {
                        print("  ❌ 类别目录还原真实名称失败: \(error)")
                        return
                    }
                }
            } else {
                print("  ✅ 执行普通类别重命名")
            }

            // 6. 最终重命名为用户指定的名称（如果与当前名称不同）
            let currentName = URL(fileURLWithPath: currentCategoryPath).lastPathComponent
            if currentName != newCategoryName {
                let parentPath = URL(fileURLWithPath: currentCategoryPath).deletingLastPathComponent().path
                let finalPath = URL(fileURLWithPath: parentPath).appendingPathComponent(newCategoryName).path

                do {
                    // 检查是否需要管理员权限（系统插件类别）
                    if SudoPermissionManager.shared.needsSudoPermission(for: currentCategoryPath) {
                        try await SudoPermissionManager.shared.renameFileWithSudoPermission(
                            from: currentCategoryPath,
                            to: finalPath
                        )
                    } else {
                        try FileManager.default.moveItem(atPath: currentCategoryPath, toPath: finalPath)
                    }
                    print("  ✅ 类别目录重命名成功: \(currentName) -> \(newCategoryName)")
                } catch {
                    print("  ❌ 类别目录重命名失败: \(error)")
                    return
                }
            } else {
                print("  ✅ 类别名称无需更改")
            }

            // 重命名完成后使用增量更新
            await MainActor.run {
                // 在内存中重命名类别
                pluginManager.renameCategoryInMemory(
                    oldName: category,
                    newName: newCategoryName,
                    sourceType: selectedSourceType
                )

                // 通过回调通知父视图进行增量更新
                onIncrementalUpdate(.rename(oldName: category, newName: newCategoryName))
            }
        }
    }

    private func isFxFactoryCategory(_ categoryName: String) -> Bool {
        // 唯一判定条件：检查是否存在.fxfactory.plist文件
        let categoryPath = getCategoryPath()
        let plistPath = URL(fileURLWithPath: categoryPath)
            .appendingPathComponent(".fxfactory.plist")
            .path
        return FileManager.default.fileExists(atPath: plistPath)
    }

    /// 还原类别目录下的所有FxFactory插件
    private func restoreFxFactoryPluginsInCategory(categoryPath: String) async {
        print("🔧 开始还原类别目录下的FxFactory插件: \(categoryPath)")
        do {
            let categoryURL = URL(fileURLWithPath: categoryPath)
            let contents = try FileManager.default.contentsOfDirectory(at: categoryURL, includingPropertiesForKeys: nil)

            for itemURL in contents {
                var isDirectory: ObjCBool = false
                guard FileManager.default.fileExists(atPath: itemURL.path, isDirectory: &isDirectory),
                      isDirectory.boolValue else { continue }

                let itemName = itemURL.lastPathComponent
                print("  - 检查插件: \(itemName)")

                // 检查是否为FxFactory插件（检查.fxfactory.plist文件）
                let fxfactoryPlistURL = itemURL.appendingPathComponent(".fxfactory.plist")
                let isFxFactoryPlugin = FileManager.default.fileExists(atPath: fxfactoryPlistURL.path)

                if isFxFactoryPlugin {
                    print("    ✅ 发现FxFactory插件，开始还原: \(itemName)")

                    do {
                        // 1. 获取子插件的真实文件名（从子插件自己的.localized/en.strings读取）
                        let realPluginName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: itemURL.path)
                        print("    - 子插件真实名称: \(realPluginName)")

                        // 2. 还原为普通插件（删除FxFactory相关文件）
                        try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: itemURL.path)

                        // 3. 如果是UUID.localized格式，重命名为真实文件名
                        if itemName.hasSuffix(".localized") && itemName != realPluginName {
                            let parentURL = itemURL.deletingLastPathComponent()
                            let realNameURL = parentURL.appendingPathComponent(realPluginName)

                            do {
                                try FileManager.default.moveItem(at: itemURL, to: realNameURL)
                                print("    ✅ 子插件重命名成功: \(itemName) -> \(realPluginName)")

                                // 4. 处理子插件目录内部与原目录同名的插件本体文件
                                let originalUUID = itemName.replacingOccurrences(of: ".localized", with: "")

                                // 查找子插件目录内部所有以原UUID开头的文件
                                do {
                                    let subPluginContents = try FileManager.default.contentsOfDirectory(at: realNameURL, includingPropertiesForKeys: nil)

                                    for subItemURL in subPluginContents {
                                        let subItemName = subItemURL.lastPathComponent

                                        // 如果文件名以原UUID开头，重命名为真实名称
                                        if subItemName.hasPrefix(originalUUID) {
                                            let fileExtension = subItemURL.pathExtension
                                            let newFileName = fileExtension.isEmpty ? realPluginName : "\(realPluginName).\(fileExtension)"
                                            let newSubItemURL = realNameURL.appendingPathComponent(newFileName)

                                            // 检查目标路径是否已存在
                                            if !FileManager.default.fileExists(atPath: newSubItemURL.path) {
                                                try FileManager.default.moveItem(at: subItemURL, to: newSubItemURL)
                                                print("    ✅ 子插件本体重命名成功: \(subItemName) -> \(newFileName)")
                                            } else {
                                                print("    ⚠️ 子插件本体目标路径已存在，跳过重命名: \(newSubItemURL.path)")
                                            }
                                        }
                                    }
                                } catch {
                                    print("    ❌ 处理子插件本体文件失败: \(error)")
                                }
                            } catch {
                                print("    ❌ 子插件重命名失败: \(itemName) -> \(realPluginName), 错误: \(error)")
                            }
                        }

                        // 4. 删除FxFactory保护文件
                        _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(categoryRealName: realPluginName, operation: .remove)

                        print("    ✅ 插件还原完成: \(itemName)")
                    } catch {
                        print("    ❌ 插件还原失败: \(itemName), 错误: \(error)")
                    }
                } else {
                    print("    ❌ 非FxFactory插件，跳过: \(itemName)")
                }
            }
        } catch {
            print("❌ 还原FxFactory插件失败: \(error)")
        }
        print("🔧 类别目录FxFactory插件还原完成")
    }

    /// 检查类别目录本身是否为FxFactory插件
    private func isCategoryFxFactoryPlugin(categoryPath: String) -> Bool {
        let fxfactoryPlistPath = categoryPath + "/.fxfactory.plist"
        let exists = FileManager.default.fileExists(atPath: fxfactoryPlistPath)
        print("🔍 检查类别目录本身是否为FxFactory插件: \(categoryPath)")
        print("  - .fxfactory.plist文件存在: \(exists)")
        return exists
    }



    /// 重命名FxFactory类别（还原该目录下的所有插件）
    private func renameFxFactoryCategory(categoryPath: String, newName: String) async {

        do {
            // 1. 获取类别目录下的所有插件
            let categoryURL = URL(fileURLWithPath: categoryPath)
            let contents = try FileManager.default.contentsOfDirectory(at: categoryURL, includingPropertiesForKeys: nil)

            // 2. 还原每个FxFactory插件
            for itemURL in contents {
                var isDirectory: ObjCBool = false
                guard FileManager.default.fileExists(atPath: itemURL.path, isDirectory: &isDirectory),
                      isDirectory.boolValue else { continue }

                let itemName = itemURL.lastPathComponent

                // 检查是否为FxFactory插件（检查.fxfactory.plist文件）
                let fxfactoryPlistPath = itemURL.appendingPathComponent(".fxfactory.plist").path
                if FileManager.default.fileExists(atPath: fxfactoryPlistPath) {
                    print("🔄 处理FxFactory插件重命名: \(itemName)")

                    // 1. 获取真实文件名
                    let realName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: itemURL.path)
                    print("✅ 获取到真实文件名: \(itemName) -> \(realName)")

                    // 2. 还原真实文件名
                    if let restoredName = try await FxFactoryProtectionManager.shared.restoreRealFileName(at: itemURL.path) {
                        // 更新路径为新的真实名称路径
                        let newItemURL = categoryURL.appendingPathComponent(restoredName)

                        // 3. 删除特征文件和隐藏文件
                        try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: newItemURL.path)
                        print("✅ 已删除特征文件和隐藏文件")

                        // 4. 删除FxFactory管理文件（.fxpack和.fxtemplates）
                        let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                            categoryRealName: realName,
                            operation: .rename
                        )
                        print("✅ 已删除FxFactory管理文件")
                    }
                }
            }

            // 3. 重命名类别目录
            let parentPath = categoryURL.deletingLastPathComponent().path
            let newCategoryPath = URL(fileURLWithPath: parentPath).appendingPathComponent(newName).path

            try FileManager.default.moveItem(atPath: categoryPath, toPath: newCategoryPath)

            // FxFactory缓存已移除，无需清理

        } catch {
        }
    }

    private func updateFxFactoryCategoryName(categoryPath: String, newName: String) {
        let stringsURL = URL(fileURLWithPath: categoryPath).appendingPathComponent(".localized/en.strings")

        guard FileManager.default.fileExists(atPath: stringsURL.path) else {
            return
        }

        do {
            let content = try String(contentsOf: stringsURL, encoding: .utf8)
            let lines = content.components(separatedBy: .newlines)
            var updatedLines: [String] = []

            for line in lines {
                let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)
                if trimmedLine.contains("=") {
                    let components = trimmedLine.components(separatedBy: "=")
                    if components.count >= 2 {
                        let key = components[0].trimmingCharacters(in: .whitespacesAndNewlines)
                        updatedLines.append("\(key) = \"\(newName)\";")
                    } else {
                        updatedLines.append(line)
                    }
                } else {
                    updatedLines.append(line)
                }
            }

            let updatedContent = updatedLines.joined(separator: "\n")
            try updatedContent.write(to: stringsURL, atomically: true, encoding: .utf8)
        } catch {
        }
    }

    private func removeCategoryAction() {
        let categoryPath = getCategoryPath()
        let originalCategoryName = categoryMapping[category] ?? category

        // 检查是否为FxFactory类别
        if isFxFactoryCategory(originalCategoryName) {
            // FxFactory类别需要使用防护机制
            removeFxFactoryCategory(categoryPath: categoryPath)
        } else {
            // 普通类别直接移除
            removeRegularCategory(categoryPath: categoryPath)
        }
    }

    /// 移除FxFactory类别（带防护）
    private func removeFxFactoryCategory(categoryPath: String) {
        // 直接使用FxFactory防护管理器执行类别移除
        Task {
            do {
                // 获取类别的真实名称
                let categoryRealName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: categoryPath)
                let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                    categoryRealName: categoryRealName,
                    operation: .remove
                )

                // 执行实际的类别移除操作
                try await performCategoryRemoval(categoryPath: categoryPath)

                // 操作成功后，执行清理工作
                await MainActor.run {
                    // FxFactory缓存已移除，无需清理

                    // 从内存中移除该类别的所有插件
                    pluginManager.removeCategoryFromMemory(category, sourceType: selectedSourceType)

                    // 检查当前选中的类别是否就是被删除的类别
                    let originalCategoryName = categoryMapping[category] ?? category
                    if selectedCategoryPath == originalCategoryName {
                        // 如果当前选中的就是被删除的类别，清空选中状态
                        selectedCategoryPath = nil
                        selectedSubType = nil
                    }

                    // 通过回调通知父视图进行增量更新
                    onIncrementalUpdate(.remove(categoryName: category))
                }

            } catch {
                await MainActor.run {
                    // 这里可以显示错误提示
                }
            }
        }
    }

    /// 移除普通类别
    private func removeRegularCategory(categoryPath: String) {
        Task {
            do {
                // 检查是否需要管理员权限（系统插件类别）
                if SudoPermissionManager.shared.needsSudoPermission(for: categoryPath) {
                    // 系统插件类别需要管理员权限删除
                    try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: categoryPath)
                } else {
                    // 用户插件类别可以直接移动到回收站
                    try FileManager.default.trashItem(at: URL(fileURLWithPath: categoryPath), resultingItemURL: nil)
                }

                // FxFactory缓存已移除，无需清理

                // 移除完成后从内存中移除该类别的所有插件
                await MainActor.run {
                    pluginManager.removeCategoryFromMemory(category, sourceType: selectedSourceType)

                    // 检查当前选中的类别是否就是被删除的类别
                    let originalCategoryName = categoryMapping[category] ?? category
                    if selectedCategoryPath == originalCategoryName {
                        // 如果当前选中的就是被删除的类别，清空选中状态
                        selectedCategoryPath = nil
                        selectedSubType = nil
                    }

                    // 通过回调通知父视图进行增量更新
                    onIncrementalUpdate(.remove(categoryName: category))
                }
            } catch {
                // 这里可以显示错误提示
                print("移除类别失败: \(error.localizedDescription)")
            }
        }
    }

    /// 执行类别移除操作
    private func performCategoryRemoval(categoryPath: String) async throws {
        let categoryURL = URL(fileURLWithPath: categoryPath)

        // 检查类别目录是否存在
        guard FileManager.default.fileExists(atPath: categoryPath) else {
            throw NSError(domain: "CategoryRemovalError", code: 1, userInfo: [NSLocalizedDescriptionKey: "类别目录不存在"])
        }

        // 检查是否需要管理员权限（系统插件类别）
        if SudoPermissionManager.shared.needsSudoPermission(for: categoryPath) {
            // 系统插件类别需要管理员权限删除
            try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: categoryPath)
        } else {
            // 用户插件类别可以直接移动到回收站
            var resultingURL: NSURL?
            try FileManager.default.trashItem(at: categoryURL, resultingItemURL: &resultingURL)

            //print("类别已移动到回收站: \(categoryPath)")
            if resultingURL != nil {
                //print("回收站位置: \(trashedURL.path ?? "未知")")
            }
        }
    }

    // MARK: - 合并相关方法

    /// 获取当前插件类型下的其他类别（排除当前类别）
    private func getOtherCategories() -> [String] {
        // 从 PluginSubTypeSection 中获取类别列表
        return categories.filter { $0 != category }
    }

    /// 获取类别的显示名称
    private func getCategoryDisplayName(_ categoryName: String) -> String {
        // 如果是FxFactory插件，直接读取真实名称
        let basePath = selectedSourceType == .user ?
            NSString(string: "~/Movies/Motion Templates.localized").expandingTildeInPath :
            "/Library/Application Support/Final Cut Pro/Templates.localized"

        let subTypeName = selectedSubType?.rawValue ?? ""
        let categoryPath = URL(fileURLWithPath: basePath)
            .appendingPathComponent(subTypeName)
            .appendingPathComponent(categoryName)
            .path

        let fxfactoryPlistPath = categoryPath + "/.fxfactory.plist"
        if FileManager.default.fileExists(atPath: fxfactoryPlistPath) {
            // 直接读取 .localized/en.strings 文件
            let stringsPath = URL(fileURLWithPath: categoryPath)
                .appendingPathComponent(".localized")
                .appendingPathComponent("en.strings")
                .path

            if FileManager.default.fileExists(atPath: stringsPath) {
                do {
                    let content = try String(contentsOfFile: stringsPath, encoding: .utf8)

                    // 简单解析 strings 文件内容
                    for line in content.components(separatedBy: .newlines) {
                        let trimmedLine = line.trimmingCharacters(in: .whitespacesAndNewlines)
                        if trimmedLine.contains("=") && trimmedLine.contains("\"") {
                            if let equalIndex = trimmedLine.firstIndex(of: "=") {
                                let afterEqual = trimmedLine[trimmedLine.index(after: equalIndex)...]
                                if let secondQuoteIndex = afterEqual.firstIndex(of: "\"") {
                                    let afterSecondQuote = afterEqual[afterEqual.index(after: secondQuoteIndex)...]
                                    if let thirdQuoteIndex = afterSecondQuote.firstIndex(of: "\"") {
                                        let realName = String(afterSecondQuote[..<thirdQuoteIndex])
                                        if !realName.isEmpty {
                                            return realName
                                        }
                                    }
                                }
                            }
                        }
                    }
                } catch {
                    // 读取失败，继续使用原始名称
                }
            }
        }
        return categoryName
    }

    /// 合并到指定类别
    private func mergeToCategory(_ targetCategory: String) {
        let sourcePath = getCategoryPath()
        let targetPath = getTargetCategoryPath(targetCategory)

        // 执行合并操作
        performMergeOperation(sourcePath: sourcePath, targetPath: targetPath, targetCategoryName: targetCategory)
    }

    /// 创建新类别并合并
    private func createCategoryAndMerge() {
        let newCategoryName = newCategoryForMerge.trimmingCharacters(in: .whitespacesAndNewlines)
        guard !newCategoryName.isEmpty else { return }

        let sourcePath = getCategoryPath()
        let targetPath = createNewCategoryPath(newCategoryName)

        // 执行合并操作
        performMergeOperation(sourcePath: sourcePath, targetPath: targetPath, targetCategoryName: newCategoryName)

        // 清理状态
        newCategoryForMerge = ""
    }

    /// 获取目标类别的路径
    private func getTargetCategoryPath(_ targetCategory: String) -> String {
        let originalTargetName = categoryMapping[targetCategory] ?? targetCategory
        let basePath = selectedSourceType.basePath

        switch selectedSourceType {
        case .user, .system:
            return "\(basePath)/\(subType.rawValue)/\(originalTargetName)"
        case .fxplug:
            return basePath
        default:
            return "\(basePath)/\(originalTargetName)"
        }
    }

    /// 创建新类别的路径
    private func createNewCategoryPath(_ newCategoryName: String) -> String {
        let basePath = selectedSourceType.basePath

        switch selectedSourceType {
        case .user, .system:
            return "\(basePath)/\(subType.rawValue)/\(newCategoryName)"
        case .fxplug:
            return basePath
        default:
            return "\(basePath)/\(newCategoryName)"
        }
    }

    /// 执行合并操作
    private func performMergeOperation(sourcePath: String, targetPath: String, targetCategoryName: String) {
        Task {
            do {
                let sourceURL = URL(fileURLWithPath: sourcePath)
                let targetURL = URL(fileURLWithPath: targetPath)

                // 如果目标目录不存在，创建它
                if !FileManager.default.fileExists(atPath: targetPath) {
                    try FileManager.default.createDirectory(at: targetURL, withIntermediateDirectories: true, attributes: nil)
                }

                // 获取源目录中的所有插件
                let sourceContents = try FileManager.default.contentsOfDirectory(at: sourceURL, includingPropertiesForKeys: nil)

                // 移动每个插件到目标目录
                for pluginURL in sourceContents {
                    var isDirectory: ObjCBool = false
                    guard FileManager.default.fileExists(atPath: pluginURL.path, isDirectory: &isDirectory),
                          isDirectory.boolValue else { continue }

                    let pluginName = pluginURL.lastPathComponent

                    // 检查是否为FxFactory插件
                    let fxfactoryPlistPath = pluginURL.appendingPathComponent(".fxfactory.plist").path
                    let isFxFactoryPlugin = FileManager.default.fileExists(atPath: fxfactoryPlistPath)
                    var finalPluginName = pluginName
                    var processedPluginURL = pluginURL

                    if isFxFactoryPlugin {
                        print("🔄 处理FxFactory插件合并: \(pluginName)")

                        // 1. 获取真实文件名
                        let realName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: pluginURL.path)
                        print("✅ 获取到真实文件名: \(pluginName) -> \(realName)")

                        // 2. 先处理子插件重命名（在删除.fxfactory.plist之前）
                        try await processSubPluginsForMerge(in: pluginURL.path, realName: realName)
                        print("✅ 已处理子插件重命名")

                        // 3. 还原真实文件名
                        if let restoredName = try await FxFactoryProtectionManager.shared.restoreRealFileName(at: pluginURL.path) {
                            finalPluginName = restoredName
                            // 更新URL为还原后的路径
                            processedPluginURL = sourceURL.appendingPathComponent(restoredName)
                            print("✅ 已还原文件名: \(pluginName) -> \(restoredName)")
                        }

                        // 4. 删除特征文件和隐藏文件
                        try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: processedPluginURL.path)
                        print("✅ 已删除特征文件和隐藏文件")

                        // 4. 删除FxFactory管理文件（.fxpack和.fxtemplates）
                        let _ = try await FxFactoryProtectionManager.shared.protectFxFactoryPlugin(
                            categoryRealName: realName,
                            operation: .merge
                        )
                        print("✅ 已删除FxFactory管理文件")
                    }

                    let targetPluginURL = targetURL.appendingPathComponent(finalPluginName)

                    // 如果目标位置已存在同名插件，添加后缀
                    var finalTargetURL = targetPluginURL
                    var counter = 1
                    while FileManager.default.fileExists(atPath: finalTargetURL.path) {
                        let nameWithoutExtension = (finalPluginName as NSString).deletingPathExtension
                        let pathExtension = (finalPluginName as NSString).pathExtension
                        let newName = pathExtension.isEmpty ? "\(nameWithoutExtension)_\(counter)" : "\(nameWithoutExtension)_\(counter).\(pathExtension)"
                        finalTargetURL = targetURL.appendingPathComponent(newName)
                        counter += 1
                    }

                    try FileManager.default.moveItem(at: processedPluginURL, to: finalTargetURL)
                }

                // 删除空的源目录
                try FileManager.default.removeItem(at: sourceURL)

                // 清理体积缓存
                let sourceCategoryPath = getCategoryPath()
                SizeCacheManager.shared.removeCache(for: sourceCategoryPath)

                // FxFactory缓存已移除，无需清理

                // 检查当前选中的类别是否就是被合并的源类别
                let originalCategoryName = categoryMapping[category] ?? category
                let shouldClearSelection = selectedCategoryPath == originalCategoryName

                // 使用和移除操作一样的视图更新逻辑
                await MainActor.run {
                    // 在内存中处理类别合并
                    pluginManager.mergeCategoryInMemory(
                        sourceCategory: category,
                        targetCategory: targetCategoryName,
                        finalCategoryName: targetCategoryName,
                        sourceType: selectedSourceType
                    )

                    // 如果当前选中的是被合并的源类别，清空选中状态
                    if shouldClearSelection {
                        selectedCategoryPath = nil
                        selectedSubType = nil
                    }

                    // 通过回调通知父视图进行增量更新
                    onIncrementalUpdate(.remove(categoryName: category))
                }

            } catch {
            }
        }
    }

    private func getCategoryPath() -> String {
        // 获取原始目录名称（用于文件系统操作）
        let originalCategoryName = categoryMapping[category] ?? category

        // 构建完整路径
        let basePath = selectedSourceType.basePath
        let subTypePath = URL(fileURLWithPath: basePath).appendingPathComponent(subType.rawValue).path
        let categoryPath = URL(fileURLWithPath: subTypePath).appendingPathComponent(originalCategoryName).path

        return categoryPath
    }

    private func createCategoryInfo() -> CategoryInfo {
        let categoryPath = getCategoryPath()

        // 扫描类别目录获取实际的插件列表
        let plugins = scanCategoryForPlugins(at: categoryPath)

        var categoryInfo = CategoryInfo(
            name: category,
            path: categoryPath,
            type: selectedSourceType,
            subType: subType
        )

        categoryInfo.pluginCount = plugins.count

        // 如果是FxFactory类别，解析真实名称
        if categoryInfo.isFxFactoryCategory {
            categoryInfo.resolveFxFactoryName()
        }

        return categoryInfo
    }

    private func scanCategoryForPlugins(at categoryPath: String) -> [FCPXPlugin] {
        var plugins: [FCPXPlugin] = []

        guard FileManager.default.fileExists(atPath: categoryPath) else {
            return plugins
        }

        let totalMotionFiles = countMotionFilesInCategory(at: categoryPath)

        // 创建虚拟插件对象来表示Motion文件数量
        if totalMotionFiles > 0 {
            let categoryName = URL(fileURLWithPath: categoryPath).lastPathComponent
            // 为每个Motion文件创建一个插件对象
            for i in 0..<totalMotionFiles {
                let plugin = FCPXPlugin(
                    name: "\(categoryName)_Motion_\(i+1)",
                    path: categoryPath,
                    type: selectedSourceType,
                    subType: subType,
                    categoryPath: categoryPath
                )
                plugins.append(plugin)
            }
        }

        return plugins
    }

    private func countMotionFilesInCategory(at categoryPath: String) -> Int {
        var totalCount = 0

        do {
            let contents = try FileManager.default.contentsOfDirectory(atPath: categoryPath)

            for itemName in contents {
                if itemName.hasPrefix(".") { continue }

                let itemPath = URL(fileURLWithPath: categoryPath).appendingPathComponent(itemName).path
                var isDirectory: ObjCBool = false

                guard FileManager.default.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                      isDirectory.boolValue else { continue }

                let motionCount = countMotionFilesInDirectory(at: itemPath)
                totalCount += motionCount
            }
        } catch {
        }

        return totalCount
    }

    private func countMotionFilesInDirectory(at directoryPath: String) -> Int {
        var count = 0

        do {
            let contents = try FileManager.default.contentsOfDirectory(atPath: directoryPath)

            // 计算Motion文件数量
            let motionExtensions = [".motn", ".moef", ".moti", ".motr"]
            let motionFiles = contents.filter { filename in
                motionExtensions.contains { ext in
                    filename.hasSuffix(ext)
                }
            }

            count = motionFiles.count

            // 如果当前目录没有Motion文件，可能是主题目录，递归扫描
            if count == 0 {
                for itemName in contents {
                    if itemName.hasPrefix(".") { continue }

                    let itemPath = URL(fileURLWithPath: directoryPath).appendingPathComponent(itemName).path
                    var isDirectory: ObjCBool = false

                    if FileManager.default.fileExists(atPath: itemPath, isDirectory: &isDirectory),
                       isDirectory.boolValue {
                        count += countMotionFilesInDirectory(at: itemPath)
                    }
                }
            }

        } catch {
        }

        return count
    }

    // MARK: - 体积计算方法
    private func loadCategorySize() {
        let categoryPath = getCategoryPath()

        // 检查缓存中是否已有体积信息
        if let cachedSize = SizeCacheManager.shared.getSize(for: categoryPath) {
            categorySize = cachedSize
            return
        }

        // 如果正在加载中，跳过
        guard !SizeCacheManager.shared.isLoading(categoryPath) else {
            isLoadingSize = true
            return
        }

        Task {
            await MainActor.run {
                isLoadingSize = true
                SizeCacheManager.shared.setLoading(categoryPath, loading: true)
            }

            let size = await pluginManager.calculateCategorySize(at: categoryPath)

            await MainActor.run {
                categorySize = size
                isLoadingSize = false
                SizeCacheManager.shared.setSize(size, for: categoryPath)
                SizeCacheManager.shared.setLoading(categoryPath, loading: false)
            }
        }
    }

    private func formatFileSize(_ bytes: Int64) -> String {
        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: bytes)
    }

    /// 处理FxFactory插件合并时的子插件重命名
    private func processSubPluginsForMerge(in pluginPath: String, realName: String) async throws {
        let pluginURL = URL(fileURLWithPath: pluginPath)
        let contents = try FileManager.default.contentsOfDirectory(at: pluginURL, includingPropertiesForKeys: nil)

        for itemURL in contents {
            let itemName = itemURL.lastPathComponent
            var isDirectory: ObjCBool = false

            // 检查是否为子插件目录（FxFactory格式：UUID.localized）
            if itemName.hasSuffix(".localized") &&
               FileManager.default.fileExists(atPath: itemURL.path, isDirectory: &isDirectory) &&
               isDirectory.boolValue {

                // 检查是否为FxFactory子插件（检查.fxfactory.plist文件）
                let fxfactoryPlistURL = itemURL.appendingPathComponent(".fxfactory.plist")
                if FileManager.default.fileExists(atPath: fxfactoryPlistURL.path) {
                    print("🔄 处理FxFactory子插件合并: \(itemName)")

                    // 获取子插件的真实文件名
                    let realPluginName = await FxFactoryProtectionManager.shared.getCategoryRealName(from: itemURL.path)
                    print("✅ 获取到子插件真实文件名: \(itemName) -> \(realPluginName)")

                    // 如果真实名称与当前名称不同，进行重命名
                    if realPluginName != itemName {
                        let realNameURL = pluginURL.appendingPathComponent(realPluginName)

                        // 检查目标路径是否已存在
                        if !FileManager.default.fileExists(atPath: realNameURL.path) {
                            // 先还原为普通插件（删除FxFactory相关文件）
                            try await FxFactoryProtectionManager.shared.restoreToNormalPlugin(at: itemURL.path)

                            // 重命名子插件目录
                            try FileManager.default.moveItem(at: itemURL, to: realNameURL)
                            print("✅ 子插件重命名成功: \(itemName) -> \(realPluginName)")

                            // 处理子插件目录内部与原目录同名的插件本体文件
                            let originalUUID = itemName.replacingOccurrences(of: ".localized", with: "")

                            // 查找子插件目录内部所有以原UUID开头的文件
                            do {
                                let subPluginContents = try FileManager.default.contentsOfDirectory(at: realNameURL, includingPropertiesForKeys: nil)

                                for subItemURL in subPluginContents {
                                    let subItemName = subItemURL.lastPathComponent

                                    // 如果文件名以原UUID开头，重命名为真实名称
                                    if subItemName.hasPrefix(originalUUID) {
                                        let fileExtension = subItemURL.pathExtension
                                        let newFileName = fileExtension.isEmpty ? realPluginName : "\(realPluginName).\(fileExtension)"
                                        let newSubItemURL = realNameURL.appendingPathComponent(newFileName)

                                        // 检查目标路径是否已存在
                                        if !FileManager.default.fileExists(atPath: newSubItemURL.path) {
                                            try FileManager.default.moveItem(at: subItemURL, to: newSubItemURL)
                                            print("✅ 子插件本体重命名成功: \(subItemName) -> \(newFileName)")
                                        } else {
                                            print("⚠️ 子插件本体目标路径已存在，跳过重命名: \(newSubItemURL.path)")
                                        }
                                    }
                                }
                            } catch {
                                print("❌ 处理子插件本体文件失败: \(error)")
                            }
                        } else {
                            print("⚠️ 子插件目标路径已存在，跳过重命名: \(realNameURL.path)")
                        }
                    }
                }
            }
        }
    }
}

// MARK: - macOS 12.0兼容的拖拽修饰符
struct CategoryDragModifier<PreviewContent: View>: ViewModifier {
    let categoryInfoProvider: () -> CategoryInfo
    let previewContent: () -> PreviewContent

    func body(content: Content) -> some View {
        content
            .onDrag {
                // 只在真正开始拖拽时才创建CategoryInfo，避免每次视图更新都扫描
                let categoryInfo = categoryInfoProvider()

                // 使用文件URL方式传递类别目录路径，同时传递路径信息
                let url = URL(fileURLWithPath: categoryInfo.path)
                let provider = NSItemProvider()

                // 传递文件URL
                provider.registerFileRepresentation(forTypeIdentifier: "public.folder", fileOptions: [], visibility: .all) { completion in
                    completion(url, true, nil)
                    return nil
                }

                // 同时传递路径信息作为字符串
                provider.registerDataRepresentation(forTypeIdentifier: "public.utf8-plain-text", visibility: .all) { completion in
                    let pathData = categoryInfo.path.data(using: .utf8) ?? Data()
                    completion(pathData, nil)
                    return nil
                }

                return provider
            }
    }
}

struct CategoryDropModifier: ViewModifier {
    let onDrop: ([NSItemProvider]) -> Bool

    func body(content: Content) -> some View {
        content
            .onDrop(of: ["public.file-url", "public.url"], delegate: CategoryDropDelegate(onDrop: onDrop))
    }
}

struct CategoryDropDelegate: DropDelegate {
    let onDrop: ([NSItemProvider]) -> Bool

    func performDrop(info: DropInfo) -> Bool {
        return onDrop(info.itemProviders(for: ["public.file-url", "public.url"]))
    }
}

#Preview {
    PluginTypeAndCategoryView(
        selectedSourceType: .user,
        selectedSubType: .constant(nil),
        selectedCategoryPath: .constant(nil),
        pluginManager: PluginManager()
    )
    .frame(width: 250, height: 600)
}
