//
//  PluginViews.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

// MARK: - 插件网格视图
struct PluginGridView: View {
    let plugins: [FCPXPlugin]
    let onPluginChanged: () async -> Void
    @ObservedObject var batchOperationManager: BatchOperationManager
    @State private var selectedPlugins: Set<UUID> = []
    @State private var showingBatchUninstallAlert = false
    @State private var showingBatchMergeCategoryDialog = false
    @State private var availableCategoriesForBatch: [(displayName: String, originalPath: String)] = []
    @State private var lastSelectedPlugin: UUID? = nil
    @EnvironmentObject private var pluginManager: PluginManager

    // 使用统一的批量合并管理器
    @StateObject private var batchMergeManager = BatchMergeManager()

    private let columns = [
        GridItem(.adaptive(minimum: 160, maximum: 200), spacing: 16)
    ]

    var body: some View {
        ScrollView {
            LazyVGrid(columns: columns, spacing: 16) {
                ForEach(plugins) { (plugin: FCPXPlugin) in
                    PluginCardView(
                        plugin: plugin,
                        isSelected: selectedPlugins.contains(plugin.id),
                        onTap: {
                            handlePluginTap(plugin.id)
                        },
                        onPluginChanged: onPluginChanged,
                        batchOperationManager: batchOperationManager
                    )
                    .id(plugin.id)
                }
            }
            .padding(16)
        }
        .background(Color(NSColor.controlBackgroundColor))
        .contextMenu {
            if !selectedPlugins.isEmpty {
                batchContextMenu
            }
        }
        .alert("批量卸载确认", isPresented: $showingBatchUninstallAlert) {
            Button("取消", role: .cancel) { }
            Button("确认卸载", role: .destructive) {
                performBatchUninstall()
            }
        } message: {
            Text("确定要卸载选中的 \(selectedPlugins.count) 个插件吗？此操作不可撤销。")
        }
        .alert("批量合并", isPresented: $showingBatchMergeCategoryDialog) {
            Button("确定") {
                // 暂时简化处理
                Task {
                    await onPluginChanged()
                     selectedPlugins.removeAll()
                     lastSelectedPlugin = nil
                 }
             }
             Button("取消", role: .cancel) { }
         } message: {
             Text("批量合并功能正在开发中")
         }
        .onAppear {
            print("🔍 PluginGridView 加载，当前选中插件数量: \(selectedPlugins.count)")
        }
    }

    // MARK: - 选择处理方法
    private func handlePluginTap(_ pluginId: UUID) {
        let modifierFlags = NSEvent.modifierFlags

        if modifierFlags.contains(.command) {
            // Command+点击：切换选择状态
            toggleSelection(for: pluginId)
        } else if modifierFlags.contains(.shift) && lastSelectedPlugin != nil {
            // Shift+点击：范围选择
            selectRange(to: pluginId)
        } else {
            // 普通点击：单选
            selectedPlugins = [pluginId]
            lastSelectedPlugin = pluginId
        }
        print("🎯 插件选择更新，当前选中数量: \(selectedPlugins.count)")
    }

    private func toggleSelection(for pluginId: UUID) {
        if selectedPlugins.contains(pluginId) {
            selectedPlugins.remove(pluginId)
        } else {
            selectedPlugins.insert(pluginId)
            lastSelectedPlugin = pluginId
        }
    }

    private func selectRange(to targetId: UUID) {
        guard let lastSelected = lastSelectedPlugin,
              let lastSelectedIndex = plugins.firstIndex(where: { $0.id == lastSelected }),
              let targetIndex = plugins.firstIndex(where: { $0.id == targetId }) else {
            selectedPlugins.insert(targetId)
            lastSelectedPlugin = targetId
            return
        }

        let startIndex = min(lastSelectedIndex, targetIndex)
        let endIndex = max(lastSelectedIndex, targetIndex)

        for index in startIndex...endIndex {
            selectedPlugins.insert(plugins[index].id)
        }
        lastSelectedPlugin = targetId
    }

    // MARK: - 批量操作方法
    private func getSelectedPlugins() -> [FCPXPlugin] {
        return plugins.filter { selectedPlugins.contains($0.id) }
    }

    @ViewBuilder
    private var batchContextMenu: some View {
        // 批量添加到操作缓冲区
        Button(action: {
            let selectedPluginObjects = getSelectedPlugins()
            for plugin in selectedPluginObjects {
                batchOperationManager.addPlugin(plugin)
            }
            selectedPlugins.removeAll()
        }) {
            Label("添加到批量操作缓冲区 (\(selectedPlugins.count))", systemImage: "tray.and.arrow.down")
        }

        Divider()

        // 批量合并到其他类别
        Button(action: {
            Task {
                await batchMergeManager.loadAvailableCategories(pluginManager: pluginManager)
                availableCategoriesForBatch = batchMergeManager.availableCategories
                showingBatchMergeCategoryDialog = true
            }
        }) {
            Label("批量合并到其他类别 (\(selectedPlugins.count))", systemImage: "arrow.right.circle")
        }

        Divider()

        Button(action: {
            showingBatchUninstallAlert = true
        }) {
            Label("批量卸载 (\(selectedPlugins.count))", systemImage: "trash")
        }
        .foregroundColor(.red)

        Button(action: {
            selectedPlugins.removeAll()
        }) {
            Label("取消选择", systemImage: "xmark.circle")
        }
    }

    private func performBatchUninstall() {
        let pluginsToUninstall = getSelectedPlugins()

        Task {
            for plugin in pluginsToUninstall {
                do {
                    // 使用PluginManager的统一卸载方法，它会自动处理FxFactory插件
                    try await pluginManager.uninstallPlugin(plugin)
                    print("✅ 插件卸载成功: \(plugin.displayName)")

                    // 立即从选择中移除成功卸载的插件，提供即时反馈
                    _ = await MainActor.run {
                        selectedPlugins.remove(plugin.id)
                    }

                } catch {
                    print("❌ 卸载插件失败: \(plugin.displayName) - \(error)")
                    // 即使失败也从选择中移除，避免界面混乱
                    _ = await MainActor.run {
                        selectedPlugins.remove(plugin.id)
                    }
                }
            }

            // 最终清空所有选择并强制刷新视图
            await MainActor.run {
                selectedPlugins.removeAll()
                lastSelectedPlugin = nil
            }

            // 强制调用父视图的刷新回调
            await onPluginChanged()

            print("🎉 批量卸载完成，共处理 \(pluginsToUninstall.count) 个插件")
        }
    }
    
    // 批量合并相关方法已统一到BatchMergeManager中


}

// MARK: - 插件列表视图
struct PluginListView: View {
    let plugins: [FCPXPlugin]
    let onPluginChanged: () async -> Void
    @ObservedObject var batchOperationManager: BatchOperationManager
    @State private var selectedPlugins: Set<UUID> = []
    @State private var showingBatchUninstallAlert = false
    @State private var showingBatchMergeCategoryDialog = false
    @State private var availableCategoriesForBatch: [(displayName: String, originalPath: String)] = []
    @State private var lastSelectedPlugin: UUID? = nil
    @EnvironmentObject private var pluginManager: PluginManager

    // 使用卡片视图的批量合并管理器
    @StateObject private var batchMergeManager = BatchMergeManager()

    // 自适应列数的网格布局
    private let columns = [
        GridItem(.adaptive(minimum: 400, maximum: .infinity), spacing: 1)
    ]
    
    var body: some View {
        ScrollView {
            LazyVGrid(columns: columns, spacing: 1) {
                ForEach(plugins) { plugin in
                    PluginRowView(
                        plugin: plugin,
                        isSelected: selectedPlugins.contains(plugin.id),
                        onTap: {
                            handlePluginTap(plugin.id)
                        },
                        onPluginChanged: onPluginChanged,
                        batchOperationManager: batchOperationManager
                    )
                }
            }
            .padding(.vertical, 8)
        }
        .background(Color(NSColor.controlBackgroundColor))
        .contextMenu {
            if !selectedPlugins.isEmpty {
                batchContextMenu
            }
        }
        .alert("批量卸载确认", isPresented: $showingBatchUninstallAlert) {
            Button("取消", role: .cancel) { }
            Button("确认卸载", role: .destructive) {
                performBatchUninstall()
            }
        } message: {
            Text("确定要卸载选中的 \(selectedPlugins.count) 个插件吗？此操作不可撤销。")
        }
        .alert("批量合并", isPresented: $showingBatchMergeCategoryDialog) {
            Button("确定") {
                // 暂时简化处理
                Task {
                    await onPluginChanged()
                    selectedPlugins.removeAll()
                    lastSelectedPlugin = nil
                }
            }
            Button("取消", role: .cancel) { }
        } message: {
            Text("批量合并功能正在开发中")
        }
    }

    // MARK: - 选择处理方法
    private func handlePluginTap(_ pluginId: UUID) {
        let modifierFlags = NSEvent.modifierFlags

        if modifierFlags.contains(.command) {
            // Command+点击：切换选择状态
            toggleSelection(for: pluginId)
        } else if modifierFlags.contains(.shift) && lastSelectedPlugin != nil {
            // Shift+点击：范围选择
            selectRange(to: pluginId)
        } else {
            // 普通点击：单选
            selectedPlugins = [pluginId]
            lastSelectedPlugin = pluginId
        }
    }

    private func toggleSelection(for pluginId: UUID) {
        if selectedPlugins.contains(pluginId) {
            selectedPlugins.remove(pluginId)
        } else {
            selectedPlugins.insert(pluginId)
            lastSelectedPlugin = pluginId
        }
    }

    private func selectRange(to targetId: UUID) {
        guard let lastSelected = lastSelectedPlugin,
              let lastSelectedIndex = plugins.firstIndex(where: { $0.id == lastSelected }),
              let targetIndex = plugins.firstIndex(where: { $0.id == targetId }) else {
            selectedPlugins.insert(targetId)
            lastSelectedPlugin = targetId
            return
        }

        let startIndex = min(lastSelectedIndex, targetIndex)
        let endIndex = max(lastSelectedIndex, targetIndex)

        for index in startIndex...endIndex {
            selectedPlugins.insert(plugins[index].id)
        }
        lastSelectedPlugin = targetId
    }

    // MARK: - 批量操作方法
    private func getSelectedPlugins() -> [FCPXPlugin] {
        return plugins.filter { selectedPlugins.contains($0.id) }
    }

    @ViewBuilder
    private var batchContextMenu: some View {
        // 批量添加到操作缓冲区
        Button(action: {
            let selectedPluginObjects = getSelectedPlugins()
            for plugin in selectedPluginObjects {
                batchOperationManager.addPlugin(plugin)
            }
            selectedPlugins.removeAll()
        }) {
            Label("添加到批量操作缓冲区 (\(selectedPlugins.count))", systemImage: "tray.and.arrow.down")
        }

        Divider()

        // 批量合并到其他类别
        Button(action: {
            Task {
                await batchMergeManager.loadAvailableCategories(pluginManager: pluginManager)
                availableCategoriesForBatch = batchMergeManager.availableCategories
                showingBatchMergeCategoryDialog = true
            }
        }) {
            Label("批量合并到其他类别 (\(selectedPlugins.count))", systemImage: "arrow.right.circle")
        }

        Divider()

        Button(action: {
            showingBatchUninstallAlert = true
        }) {
            Label("批量卸载 (\(selectedPlugins.count))", systemImage: "trash")
        }
        .foregroundColor(.red)

        Button(action: {
            selectedPlugins.removeAll()
        }) {
            Label("取消选择", systemImage: "xmark.circle")
        }
    }

    private func performBatchUninstall() {
        let pluginsToUninstall = getSelectedPlugins()

        Task {
            for plugin in pluginsToUninstall {
                do {
                    // 使用PluginManager的统一卸载方法，它会自动处理FxFactory插件
                    try await pluginManager.uninstallPlugin(plugin)
                    print("✅ 插件卸载成功: \(plugin.displayName)")

                    // 立即从选择中移除成功卸载的插件，提供即时反馈
                    _ = await MainActor.run {
                        selectedPlugins.remove(plugin.id)
                    }

                } catch {
                    print("❌ 卸载插件失败: \(plugin.displayName) - \(error)")
                    // 即使失败也从选择中移除，避免界面混乱
                    _ = await MainActor.run {
                        selectedPlugins.remove(plugin.id)
                    }
                }
            }

            // 最终清空所有选择并强制刷新视图
            await MainActor.run {
                selectedPlugins.removeAll()
                lastSelectedPlugin = nil
            }

            // 强制调用父视图的刷新回调
            await onPluginChanged()

            print("🎉 批量卸载完成，共处理 \(pluginsToUninstall.count) 个插件")
        }
    }
    
    // 批量合并相关方法已统一到BatchMergeManager中

}

// MARK: - 插件卡片视图
struct PluginCardView: View {
    let plugin: FCPXPlugin
    let isSelected: Bool
    let onTap: () -> Void
    let onPluginChanged: () async -> Void
    @ObservedObject var batchOperationManager: BatchOperationManager

    @State private var thumbnail: NSImage?
    @State private var isHovered = false
    @State private var showingRenameDialog = false
    @State private var showingUninstallConfirmation = false
    @State private var isUninstalling = false
    @State private var showingFxFactoryOperation = false
    @State private var showingFxFactoryUninstall = false
    @State private var fxFactoryOperation: PluginOperation?
    @State private var showingMergeCategoryDialog = false
    @State private var availableCategories: [(displayName: String, originalPath: String)] = []
    @EnvironmentObject private var pluginManager: PluginManager
    
    var body: some View {
        VStack(spacing: 12) {
            // 缩略图区域
            ZStack {
                // 缩略图背景
                RoundedRectangle(cornerRadius: 8)
                    .fill(Color.secondary.opacity(0.1))
                    .frame(height: 120)
                
                // 缩略图内容
                Group {
                    if let thumbnail = thumbnail {
                        Image(nsImage: thumbnail)
                            .resizable()
                            .aspectRatio(contentMode: .fit)
                    } else {
                        VStack(spacing: 8) {
                            Image(systemName: plugin.subType?.icon ?? "photo")
                                .font(.system(size: 32))
                                .foregroundColor(.secondary)
                            
                            if plugin.isFxFactoryPlugin {
                                Text("FxFactory")
                                    .font(.caption2)
                                    .foregroundColor(.secondary)
                                    .padding(.horizontal, 6)
                                    .padding(.vertical, 2)
                                    .background(Color.orange.opacity(0.2))
                                    .cornerRadius(4)
                            }
                        }
                    }
                }
                .frame(height: 120)
                .clipped()
                
                // 选中状态覆盖层
                if isSelected {
                    RoundedRectangle(cornerRadius: 8)
                        .stroke(Color.accentColor, lineWidth: 3)
                        .background(
                            RoundedRectangle(cornerRadius: 8)
                                .fill(Color.accentColor.opacity(0.1))
                        )
                }
            }
            
            // 插件信息
            VStack(spacing: 6) {
                // 插件名称
                Text(plugin.displayName)
                    .font(.callout)
                    .fontWeight(.medium)
                    .lineLimit(2)
                    .multilineTextAlignment(.center)
                    .frame(height: 32)
                
                // 插件类型和大小
                HStack(spacing: 4) {
                    if let subType = plugin.subType {
                        Text(subType.displayName)
                            .font(.caption2)
                            .foregroundColor(.secondary)
                            .padding(.horizontal, 4)
                            .padding(.vertical, 1)
                            .background(Color.secondary.opacity(0.1))
                            .cornerRadius(3)
                    }
                    
                    Spacer()

                    PluginSizeView(plugin: plugin, pluginManager: pluginManager)
                }
            }
            
            // 操作按钮
            if isHovered || isSelected {
                HStack(spacing: 8) {
                    // PlugKit插件不支持重命名
                    if plugin.type != .plugkit {
                        Button("重命名") {
                            if plugin.isFxFactoryPlugin {
                                fxFactoryOperation = .rename(newName: "")
                                showingFxFactoryOperation = true
                            } else {
                                showingRenameDialog = true
                            }
                        }
                        .buttonStyle(.bordered)
                        .controlSize(.mini)
                    }

                    // 在访达中打开按钮
                    Button(action: {
                        openInFinder()
                    }) {
                        Image(systemName: "folder")
                    }
                    .buttonStyle(.bordered)
                    .controlSize(.mini)
                    .help("在访达中打开")

                    Button("卸载") {
                        if plugin.isFxFactoryPlugin {
                            showingFxFactoryUninstall = true
                        } else {
                            showingUninstallConfirmation = true
                        }
                    }
                    .buttonStyle(.bordered)
                    .controlSize(.mini)
                    .foregroundColor(.red)
                }
                .transition(.opacity.combined(with: .scale(scale: 0.9)))
            }
        }
        .padding(12)
        .background {
            let fillColor = isSelected ? Color.blue.opacity(0.1) : Color(NSColor.controlBackgroundColor)
            let strokeColor = isSelected ? Color.blue : Color.clear
            let shadowRadius = isHovered ? 8.0 : 2.0
            let shadowY = isHovered ? 4.0 : 1.0
            
            RoundedRectangle(cornerRadius: 12)
                .fill(fillColor)
                .overlay(
                    RoundedRectangle(cornerRadius: 12)
                        .stroke(strokeColor, lineWidth: 2)
                )
                .shadow(color: .black.opacity(0.1), radius: shadowRadius, x: 0, y: shadowY)
        }
        .scaleEffect(isHovered ? 1.02 : 1.0)
        .animation(.easeInOut(duration: 0.2), value: isHovered)
        .onTapGesture {
            onTap()
        }
        .onHover { hovering in
            withAnimation(.easeInOut(duration: 0.2)) {
                isHovered = hovering
            }
        }
        .contextMenu {
            pluginContextMenu
        }
        .task {
            await loadThumbnail()
        }
        .sheet(isPresented: $showingRenameDialog) {
            RenamePluginDialog(plugin: plugin)
                .environmentObject(pluginManager)
        }
        .alert("FxFactory操作", isPresented: $showingFxFactoryOperation) {
            Button("确定") {
                // 暂时简化处理
                Task {
                    await onPluginChanged()
                }
            }
            Button("取消", role: .cancel) { }
        } message: {
            Text("FxFactory插件操作功能正在开发中")
        }
        .alert("FxFactory卸载", isPresented: $showingFxFactoryUninstall) {
            Button("确定") {
                // 暂时简化处理
                Task {
                    await onPluginChanged()
                }
            }
            Button("取消", role: .cancel) { }
        } message: {
            Text("FxFactory插件卸载功能正在开发中")
        }
        .alert("确认卸载", isPresented: $showingUninstallConfirmation) {
            Button("取消", role: .cancel) { }
            Button("卸载", role: .destructive) {
                Task {
                    await uninstallPlugin()
                }
            }
            .disabled(isUninstalling)
        } message: {
            if plugin.type == .plugkit {
                Text("确定要卸载PlugKit插件 \"\(plugin.displayName)\" 吗？此操作将通过命令行移除插件。")
            } else {
                Text("确定要卸载插件 \"\(plugin.displayName)\" 吗？此操作将把插件移至回收站。")
            }
        }
        .sheet(isPresented: $showingMergeCategoryDialog) {
            MergeCategoryDialog(
                plugin: plugin,
                availableCategories: availableCategories,
                onMerge: { targetCategory, newPluginName in
                    Task {
                        do {
                            try await pluginManager.mergePluginToCategory(plugin, targetCategoryPath: targetCategory, newName: newPluginName)
                            await onPluginChanged()
                        } catch {
                            print("合并插件失败: \(error.localizedDescription)")
                        }
                    }
                }
            )
        }
    }
    
    @ViewBuilder
    private var pluginContextMenu: some View {
        // 重命名选项
        if plugin.type != .plugkit {
            Button(action: {
                if plugin.isFxFactoryPlugin {
                    fxFactoryOperation = .rename(newName: "")
                    showingFxFactoryOperation = true
                } else {
                    showingRenameDialog = true
                }
            }) {
                Label("重命名", systemImage: "pencil")
            }
        }
        
        // 在访达中打开
        Button(action: {
            openInFinder()
        }) {
            Label("在访达中打开", systemImage: "folder")
        }
        
        Divider()

        // 添加到批量操作缓冲区
        if batchOperationManager.contains(plugin) {
            Button(action: {
                batchOperationManager.removePlugin(plugin)
            }) {
                Label("从批量操作缓冲区移除", systemImage: "tray.and.arrow.up")
            }
        } else {
            Button(action: {
                batchOperationManager.addPlugin(plugin)
            }) {
                Label("添加到批量操作缓冲区", systemImage: "tray.and.arrow.down")
            }
        }

        Divider()

        // 合并到其他类别
        if plugin.type == .user || plugin.type == .system {
            Button(action: {
                Task {
                    await loadAvailableCategories()
                    showingMergeCategoryDialog = true
                }
            }) {
                Label("合并到其他类别", systemImage: "arrow.right.circle")
            }
        }

        Divider()

        // 卸载选项
        Button(action: {
            if plugin.isFxFactoryPlugin {
                showingFxFactoryUninstall = true
            } else {
                showingUninstallConfirmation = true
            }
        }) {
            Label("卸载", systemImage: "trash")
        }
        .foregroundColor(.red)
    }
    
    private func loadAvailableCategories() async {
        guard let subType = plugin.subType else { return }
        
        let categories = await pluginManager.getAvailableCategories(for: plugin.type, subType: subType)
        
        // 过滤掉当前插件所在的类别
        let currentCategory = plugin.categoryPath
        let filteredCategories = categories.filter { $0.originalPath != currentCategory }
        
        await MainActor.run {
            availableCategories = filteredCategories
        }
    }
    
    private func loadThumbnail() async {
        guard let thumbnailURL = plugin.thumbnailURL else { return }

        await MainActor.run {
            thumbnail = NSImage(contentsOf: thumbnailURL)
        }
    }

    private func openInFinder() {
        let pluginURL = URL(fileURLWithPath: plugin.path)
        NSWorkspace.shared.selectFile(plugin.path, inFileViewerRootedAtPath: pluginURL.deletingLastPathComponent().path)
    }

    private func uninstallPlugin() async {
        isUninstalling = true
        defer { isUninstalling = false }

        do {
            try await pluginManager.uninstallPlugin(plugin)
            print("插件卸载成功: \(plugin.displayName)")
        } catch {
            print("插件卸载失败: \(error.localizedDescription)")
            // TODO: 显示错误提示
        }
    }
    
    private func formatFileSize(_ bytes: Int64) -> String {
        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: bytes)
    }
}

// MARK: - 插件行视图
struct PluginRowView: View {
    let plugin: FCPXPlugin
    let isSelected: Bool
    let onTap: () -> Void
    let onPluginChanged: () async -> Void
    @ObservedObject var batchOperationManager: BatchOperationManager

    @State private var thumbnail: NSImage?
    @State private var isHovered = false
    @State private var showingRenameDialog = false
    @State private var showingUninstallConfirmation = false
    @State private var isUninstalling = false
    @State private var showingFxFactoryOperation = false
    @State private var showingFxFactoryUninstall = false
    @State private var fxFactoryOperation: PluginOperation?
    @State private var showingMergeCategoryDialog = false
    @State private var availableCategories: [(displayName: String, originalPath: String)] = []
    @EnvironmentObject private var pluginManager: PluginManager
    
    var body: some View {
        HStack(spacing: 12) {
            // 选择指示器
            Circle()
                .foregroundColor(isSelected ? Color.accentColor : Color.clear)
                .overlay(
                    Circle()
                        .stroke(Color.secondary.opacity(0.3), lineWidth: 1)
                )
                .frame(width: 16, height: 16)
                .overlay(
                    Image(systemName: "checkmark")
                        .font(.system(size: 10, weight: .bold))
                        .foregroundColor(.white)
                        .opacity(isSelected ? 1 : 0)
                )
            
            // 缩略图
            ZStack {
                RoundedRectangle(cornerRadius: 4)
                    .fill(Color.secondary.opacity(0.1))
                    .frame(width: 40, height: 30)
                
                if let thumbnail = thumbnail {
                    Image(nsImage: thumbnail)
                        .resizable()
                        .aspectRatio(contentMode: .fit)
                        .frame(width: 40, height: 30)
                        .clipped()
                } else {
                    Image(systemName: plugin.subType?.icon ?? "photo")
                        .font(.system(size: 16))
                        .foregroundColor(.secondary)
                }
            }
            
            // 插件信息
            VStack(alignment: .leading, spacing: 2) {
                HStack {
                    Text(plugin.displayName)
                        .font(.body)
                        .fontWeight(.medium)
                        .lineLimit(1)
                    
                    if plugin.isFxFactoryPlugin {
                        Text("FxFactory")
                            .font(.caption2)
                            .foregroundColor(.orange)
                            .padding(.horizontal, 4)
                            .padding(.vertical, 1)
                            .background(Color.orange.opacity(0.1))
                            .cornerRadius(3)
                    }
                    
                    Spacer()
                }
                
                HStack(spacing: 8) {
                    if let subType = plugin.subType {
                        Text(subType.displayName)
                            .font(.caption)
                            .foregroundColor(.secondary)
                    }
                    
                    Text("•")
                        .font(.caption)
                        .foregroundColor(.secondary)

                    PluginSizeView(plugin: plugin, pluginManager: pluginManager)

                    Text("•")
                        .font(.caption)
                        .foregroundColor(.secondary)
                    
                    Text(formatDate(plugin.modifiedDate))
                        .font(.caption)
                        .foregroundColor(.secondary)
                    
                    Spacer()
                }
            }
            
            // 操作按钮
            if isHovered || isSelected {
                HStack(spacing: 6) {
                    // PlugKit插件不支持重命名
                    if plugin.type != .plugkit {
                        Button("重命名") {
                            if plugin.isFxFactoryPlugin {
                                fxFactoryOperation = .rename(newName: "")
                                showingFxFactoryOperation = true
                            } else {
                                showingRenameDialog = true
                            }
                        }
                        .buttonStyle(.bordered)
                        .controlSize(.small)
                    }

                    // 在访达中打开按钮
                    Button(action: {
                        let pluginURL = URL(fileURLWithPath: plugin.path)
                        NSWorkspace.shared.selectFile(plugin.path, inFileViewerRootedAtPath: pluginURL.deletingLastPathComponent().path)
                    }) {
                        Image(systemName: "folder")
                    }
                    .buttonStyle(.bordered)
                    .controlSize(.small)
                    .help("在访达中打开")

                    Button("卸载") {
                        if plugin.isFxFactoryPlugin {
                            showingFxFactoryUninstall = true
                        } else {
                            showingUninstallConfirmation = true
                        }
                    }
                    .buttonStyle(.bordered)
                    .controlSize(.small)
                    .foregroundColor(.red)
                }
                .transition(.opacity.combined(with: .move(edge: .trailing)))
            }
        }
        .padding(.horizontal, 16)
        .padding(.vertical, 8)
        .background(
            Rectangle()
                .fill(isSelected ? Color.accentColor.opacity(0.1) : (isHovered ? Color.primary.opacity(0.05) : Color.clear))
        )
        .contentShape(Rectangle())
        .onTapGesture {
            onTap()
        }
        .onHover { hovering in
            withAnimation(.easeInOut(duration: 0.15)) {
                isHovered = hovering
            }
        }
        .contextMenu {
            pluginRowContextMenu
        }
        .task {
            await loadThumbnail()
        }
        .sheet(isPresented: $showingRenameDialog) {
            RenamePluginDialog(plugin: plugin)
                .environmentObject(pluginManager)
        }
        .alert("FxFactory操作", isPresented: $showingFxFactoryOperation) {
            Button("确定") {
                // 暂时简化处理
                Task {
                    await pluginManager.loadPlugins(for: plugin.type)
                }
            }
            Button("取消", role: .cancel) { }
        } message: {
            Text("FxFactory插件操作功能正在开发中")
        }
        .alert("FxFactory卸载", isPresented: $showingFxFactoryUninstall) {
            Button("确定") {
                // 暂时简化处理
                Task {
                    await onPluginChanged()
                }
            }
            Button("取消", role: .cancel) { }
        } message: {
            Text("FxFactory插件卸载功能正在开发中")
        }
        .alert("确认卸载", isPresented: $showingUninstallConfirmation) {
            Button("取消", role: .cancel) { }
            Button("卸载", role: .destructive) {
                Task {
                    await uninstallPlugin()
                }
            }
            .disabled(isUninstalling)
        } message: {
            if plugin.type == .plugkit {
                Text("确定要卸载PlugKit插件 \"\(plugin.displayName)\" 吗？此操作将通过命令行移除插件。")
            } else {
                Text("确定要卸载插件 \"\(plugin.displayName)\" 吗？此操作将把插件移至回收站。")
            }
        }
        .sheet(isPresented: $showingMergeCategoryDialog) {
            MergeCategoryDialog(
                plugin: plugin,
                availableCategories: availableCategories,
                onMerge: { targetCategory, newPluginName in
                    Task {
                        do {
                            try await pluginManager.mergePluginToCategory(plugin, targetCategoryPath: targetCategory, newName: newPluginName)
                            await onPluginChanged()
                        } catch {
                            print("合并插件失败: \(error.localizedDescription)")
                        }
                    }
                }
            )
        }
    }
    
    @ViewBuilder
    private var pluginRowContextMenu: some View {
        // 重命名选项
        if plugin.type != .plugkit {
            Button(action: {
                if plugin.isFxFactoryPlugin {
                    fxFactoryOperation = .rename(newName: "")
                    showingFxFactoryOperation = true
                } else {
                    showingRenameDialog = true
                }
            }) {
                Label("重命名", systemImage: "pencil")
            }
        }
        
        // 在访达中打开
        Button(action: {
            openInFinder()
        }) {
            Label("在访达中打开", systemImage: "folder")
        }
        
        Divider()

        // 添加到批量操作缓冲区
        if batchOperationManager.contains(plugin) {
            Button(action: {
                batchOperationManager.removePlugin(plugin)
            }) {
                Label("从批量操作缓冲区移除", systemImage: "tray.and.arrow.up")
            }
        } else {
            Button(action: {
                batchOperationManager.addPlugin(plugin)
            }) {
                Label("添加到批量操作缓冲区", systemImage: "tray.and.arrow.down")
            }
        }

        Divider()

        // 合并到其他类别
        if plugin.type == .user || plugin.type == .system {
            Button(action: {
                Task {
                    await loadAvailableCategoriesForRow()
                    showingMergeCategoryDialog = true
                }
            }) {
                Label("合并到其他类别", systemImage: "arrow.right.circle")
            }
        }

        Divider()

        // 卸载选项
        Button(action: {
            if plugin.isFxFactoryPlugin {
                showingFxFactoryUninstall = true
            } else {
                showingUninstallConfirmation = true
            }
        }) {
            Label("卸载", systemImage: "trash")
        }
        .foregroundColor(.red)
    }
    
    private func loadAvailableCategoriesForRow() async {
        guard let subType = plugin.subType else { return }
        
        let categories = await pluginManager.getAvailableCategories(for: plugin.type, subType: subType)
        
        // 过滤掉当前插件所在的类别
        let currentCategory = plugin.categoryPath
        let filteredCategories = categories.filter { $0.originalPath != currentCategory }
        
        await MainActor.run {
            availableCategories = filteredCategories
        }
    }
    
    private func loadThumbnail() async {
        guard let thumbnailURL = plugin.thumbnailURL else { return }

        await MainActor.run {
            thumbnail = NSImage(contentsOf: thumbnailURL)
        }
    }

    private func openInFinder() {
        let pluginURL = URL(fileURLWithPath: plugin.path)
        NSWorkspace.shared.selectFile(plugin.path, inFileViewerRootedAtPath: pluginURL.deletingLastPathComponent().path)
    }

    private func uninstallPlugin() async {
        isUninstalling = true
        defer { isUninstalling = false }

        do {
            try await pluginManager.uninstallPlugin(plugin)
            print("插件卸载成功: \(plugin.displayName)")
        } catch {
            print("插件卸载失败: \(error.localizedDescription)")
            // TODO: 显示错误提示
        }
    }
    
    private func formatFileSize(_ bytes: Int64) -> String {
        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: bytes)
    }
    
    private func formatDate(_ date: Date) -> String {
        let formatter = DateFormatter()
        formatter.dateStyle = .short
        formatter.timeStyle = .none
        return formatter.string(from: date)
    }
}

// MARK: - 合并类别对话框
struct MergeCategoryDialog: View {
    let plugin: FCPXPlugin
    let availableCategories: [(displayName: String, originalPath: String)]
    let onMerge: (String, String) -> Void  // (targetCategory, newPluginName)
    
    @State private var selectedCategory: String = ""
    @State private var isProcessing = false
    @State private var errorMessage: String?
    @Environment(\.dismiss) private var dismiss
    
    var body: some View {
        VStack(spacing: 20) {
            // 标题 - 单个插件合并标识
            HStack {
                Image(systemName: "arrow.triangle.merge")
                    .foregroundColor(.green)
                    .font(.title2)
                
                VStack(alignment: .leading) {
                    Text("合并插件")
                        .font(.headline)
                        .foregroundColor(.primary)
                    
                    Text("将单个插件移动到其他类别")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
                
                Spacer()
                
                // 单个操作标识
                Text("单个操作")
                    .font(.caption)
                    .foregroundColor(.white)
                    .padding(.horizontal, 8)
                    .padding(.vertical, 4)
                    .background(Color.green)
                    .cornerRadius(4)
            }
            
            // 插件信息
            VStack(alignment: .leading, spacing: 8) {
                Text("插件名称:")
                    .font(.callout)
                    .foregroundColor(.secondary)
                
                Text(plugin.displayName)
                    .font(.body)
                    .padding(.horizontal, 12)
                    .padding(.vertical, 8)
                    .background(Color.secondary.opacity(0.1))
                    .cornerRadius(6)
                
                if plugin.isFxFactoryPlugin {
                    HStack {
                        Image(systemName: "info.circle")
                            .foregroundColor(.blue)
                        Text("真实文件名: \(plugin.name)")
                            .font(.caption)
                            .foregroundColor(.secondary)
                    }
                }
                
                if let subType = plugin.subType {
                    Text("插件类型: \(subType.displayName)")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
            }
            
            // 目标类别选择
            VStack(alignment: .leading, spacing: 8) {
                Text("选择目标类别:")
                    .font(.callout)
                    .foregroundColor(.secondary)
                
                if availableCategories.isEmpty {
                    VStack(spacing: 8) {
                        Text("没有可用的目标类别")
                            .font(.body)
                            .foregroundColor(.secondary)
                    }
                    .padding(.horizontal, 12)
                    .padding(.vertical, 8)
                    .background(Color.orange.opacity(0.1))
                    .cornerRadius(6)
                } else {
                    ScrollView {
                        LazyVStack(spacing: 4) {
                            ForEach(availableCategories, id: \.originalPath) { category in
                                Button(action: {
                                    selectedCategory = category.originalPath
                                }) {
                                    HStack {
                                        Image(systemName: selectedCategory == category.originalPath ? "checkmark.circle.fill" : "circle")
                                            .foregroundColor(selectedCategory == category.originalPath ? .accentColor : .secondary)
                                        
                                        Text(category.displayName)
                                            .font(.body)
                                            .foregroundColor(.primary)
                                        
                                        Spacer()
                                    }
                                    .padding(.horizontal, 12)
                                    .padding(.vertical, 8)
                                    .background(
                                        RoundedRectangle(cornerRadius: 6)
                                            .fill(selectedCategory == category.originalPath ? Color.accentColor.opacity(0.1) : Color.clear)
                                    )
                                }
                                .buttonStyle(PlainButtonStyle())
                            }
                        }
                    }
                    .frame(maxHeight: 200)
                    .background(
                        RoundedRectangle(cornerRadius: 8)
                            .stroke(Color.secondary.opacity(0.3), lineWidth: 1)
                    )
                }
            }
            
            // 错误信息显示
            if let errorMessage = errorMessage {
                HStack {
                    Image(systemName: "exclamationmark.circle")
                        .foregroundColor(.red)
                    
                    Text(errorMessage)
                        .font(.caption)
                        .foregroundColor(.red)
                }
                .padding(.horizontal, 12)
                .padding(.vertical, 8)
                .background(Color.red.opacity(0.1))
                .cornerRadius(6)
            }
            
            // 操作按钮
            HStack(spacing: 12) {
                Button("取消") {
                    dismiss()
                }
                .buttonStyle(.bordered)
                
                Button("合并") {
                    performMerge()
                }
                .buttonStyle(.borderedProminent)
                .disabled(selectedCategory.isEmpty || isProcessing || availableCategories.isEmpty)
            }
        }
        .padding(24)
        .frame(width: 450)
        .background(Color(NSColor.windowBackgroundColor))

    }
    
    private func performMerge() {
        guard !selectedCategory.isEmpty else { return }
        
        isProcessing = true
        errorMessage = nil
        
        // 使用插件原始名称，不进行重命名
        onMerge(selectedCategory, plugin.name)
        
        // 延迟关闭对话框，给用户一些反馈时间
        DispatchQueue.main.asyncAfter(deadline: .now() + 0.5) {
            dismiss()
        }
    }
    

}

// MARK: - 重命名对话框
struct RenamePluginDialog: View {
    let plugin: FCPXPlugin
    @State private var newName: String = ""
    @State private var isRenaming = false
    @State private var errorMessage: String?
    @Environment(\.dismiss) private var dismiss
    @EnvironmentObject private var pluginManager: PluginManager
    
    var body: some View {
        VStack(spacing: 20) {
            Text("重命名插件")
                .font(.headline)
            
            VStack(alignment: .leading, spacing: 8) {
                Text("当前名称:")
                    .font(.callout)
                    .foregroundColor(.secondary)
                
                Text(plugin.displayName)
                    .font(.body)
                    .padding(.horizontal, 12)
                    .padding(.vertical, 8)
                    .background(Color.secondary.opacity(0.1))
                    .cornerRadius(6)
                
                Text("新名称:")
                    .font(.callout)
                    .foregroundColor(.secondary)
                
                TextField("输入新名称", text: $newName)
                    .textFieldStyle(.roundedBorder)
            }
            
            if plugin.isFxFactoryPlugin {
                HStack {
                    Image(systemName: "exclamationmark.triangle")
                        .foregroundColor(.orange)

                    Text("这是一个FxFactory插件，重命名后将断开与FxFactory的关联。")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
                .padding(.horizontal, 12)
                .padding(.vertical, 8)
                .background(Color.orange.opacity(0.1))
                .cornerRadius(6)
            }

            // 错误信息显示
            if let errorMessage = errorMessage {
                HStack {
                    Image(systemName: "exclamationmark.circle")
                        .foregroundColor(.red)

                    Text(errorMessage)
                        .font(.caption)
                        .foregroundColor(.red)
                }
                .padding(.horizontal, 12)
                .padding(.vertical, 8)
                .background(Color.red.opacity(0.1))
                .cornerRadius(6)
            }
            
            HStack {
                Button("取消") {
                    dismiss()
                }
                .keyboardShortcut(.escape)
                
                Spacer()
                
                Button("重命名") {
                    Task {
                        await renamePlugin()
                    }
                }
                .buttonStyle(.borderedProminent)
                .disabled(newName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty || isRenaming)
                .keyboardShortcut(.return)
            }
        }
        .padding(20)
        .frame(width: 400)
        .onAppear {
            newName = plugin.displayName
        }
    }

    private func renamePlugin() async {
        isRenaming = true
        errorMessage = nil
        defer { isRenaming = false }

        do {
            try await pluginManager.renamePlugin(plugin, newName: newName)
            print("插件重命名成功: \(plugin.displayName) -> \(newName)")
            dismiss()
        } catch {
            print("插件重命名失败: \(error.localizedDescription)")
            errorMessage = error.localizedDescription
        }
    }
}

// MARK: - 插件体积显示组件（按需加载）
struct PluginSizeView: View {
    let plugin: FCPXPlugin
    @ObservedObject var pluginManager: PluginManager
    @State private var displaySize: Int64 = 0
    @State private var isLoading = false

    var body: some View {
        Group {
            if isLoading {
                Text("...")
                    .font(.caption2)
                    .foregroundColor(.orange)
            } else {
                Text(formatFileSize(displaySize))
                    .font(.caption2)
                    .foregroundColor(.secondary)
            }
        }
        .onAppear {
            loadSizeIfNeeded()
        }
    }

    private func loadSizeIfNeeded() {
        // 如果已经有体积信息，直接显示
        if plugin.fileSize > 0 {
            displaySize = plugin.fileSize
            return
        }

        // 如果正在加载中，跳过
        guard !isLoading else {
            return
        }

        // 异步加载体积信息
        Task {
            await MainActor.run {
                isLoading = true
            }

            let size = await pluginManager.calculateCategorySize(at: plugin.path)

            await MainActor.run {
                displaySize = size
                isLoading = false
            }
        }
    }

    private func formatFileSize(_ bytes: Int64) -> String {
        guard bytes > 0 else { return "0 KB" }

        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: bytes)
    }
}