//
//  AuthorizationTestView.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-15.
//

import SwiftUI

// MARK: - 权限管理测试视图（仅用于开发测试）
struct AuthorizationTestView: View {
    @ObservedObject private var sudoManager = SudoPermissionManager.shared
    @State private var testResults: [String] = []
    @State private var isRunningTest = false
    
    var body: some View {
        VStack(alignment: .leading, spacing: 16) {
            Text("权限管理系统测试")
                .font(.title2)
                .fontWeight(.bold)
            
            // 当前状态
            GroupBox("当前状态") {
                VStack(alignment: .leading, spacing: 8) {
                    HStack {
                        Text("请求中:")
                        Spacer()
                        Text(sudoManager.isRequestingPermission ? "是" : "否")
                            .foregroundColor(sudoManager.isRequestingPermission ? .orange : .primary)
                    }

                    if let error = sudoManager.lastError {
                        HStack {
                            Text("错误:")
                            Spacer()
                            Text(error)
                                .foregroundColor(.red)
                                .lineLimit(2)
                        }
                    }
                }
            }
            
            // 测试按钮
            GroupBox("测试操作") {
                VStack(spacing: 12) {
                    HStack {
                        Button("测试权限检查") {
                            let testPath = "/Library/Application Support/Final Cut Pro/Templates.localized/Effects.localized"
                            let needsPermission = SudoPermissionManager.shared.needsSudoPermission(for: testPath)
                            addTestResult("🔍 路径权限检查: \(needsPermission ? "需要权限" : "无需权限")")
                        }
                        .disabled(sudoManager.isRequestingPermission)

                        Spacer()

                        Button("清除错误") {
                            sudoManager.clearError()
                            addTestResult("🧹 错误状态已清除")
                        }
                        .disabled(sudoManager.lastError == nil)
                    }
                    
                    HStack {
                        Button("测试文件操作") {
                            runFileOperationTest()
                        }
                        .disabled(isRunningTest)
                        
                        Spacer()
                        
                        Button("清除结果") {
                            testResults.removeAll()
                        }
                    }
                }
            }
            
            // 测试结果
            GroupBox("测试结果") {
                ScrollView {
                    VStack(alignment: .leading, spacing: 4) {
                        if testResults.isEmpty {
                            Text("暂无测试结果")
                                .foregroundColor(.secondary)
                                .italic()
                        } else {
                            ForEach(Array(testResults.enumerated()), id: \.offset) { index, result in
                                HStack {
                                    Text("\(index + 1).")
                                        .foregroundColor(.secondary)
                                        .font(.caption)
                                    Text(result)
                                        .font(.caption)
                                    Spacer()
                                }
                            }
                        }
                    }
                    .frame(maxWidth: .infinity, alignment: .leading)
                }
                .frame(height: 150)
            }
            
            Spacer()
            
            // 说明
            Text("注意：此测试视图仅用于开发调试，不会包含在正式版本中。")
                .font(.caption)
                .foregroundColor(.secondary)
                .italic()
        }
        .padding()
        .frame(width: 500, height: 600)
    }
    
    // MARK: - 私有方法
    
    private func addTestResult(_ result: String) {
        let timestamp = DateFormatter.localizedString(from: Date(), dateStyle: .none, timeStyle: .medium)
        testResults.append("[\(timestamp)] \(result)")
    }
    
    private func runFileOperationTest() {
        isRunningTest = true
        
        Task {
            defer { isRunningTest = false }
            
            addTestResult("🧪 开始文件操作测试...")
            
            // 创建临时测试文件
            let tempDir = NSTemporaryDirectory()
            let testFile1 = tempDir + "auth_test_1.txt"
            let testFile2 = tempDir + "auth_test_2.txt"
            let renamedFile = tempDir + "auth_test_renamed.txt"
            
            do {
                // 1. 创建测试文件
                try "Test content 1".write(toFile: testFile1, atomically: true, encoding: .utf8)
                try "Test content 2".write(toFile: testFile2, atomically: true, encoding: .utf8)
                addTestResult("📝 创建测试文件成功")
                
                // 2. 测试单个文件删除
                try await sudoManager.deleteFileWithSudoPermission(at: testFile1)
                addTestResult("🗑️ 单个文件删除成功")

                // 3. 重新创建文件用于重命名测试
                try "Test content for rename".write(toFile: testFile1, atomically: true, encoding: .utf8)

                // 4. 测试文件重命名
                try await sudoManager.renameFileWithSudoPermission(from: testFile1, to: renamedFile)
                addTestResult("📝 文件重命名成功")

                // 5. 测试批量删除
                try "Test content 3".write(toFile: testFile1, atomically: true, encoding: .utf8)
                try await sudoManager.deleteFilesWithSudoPermission([testFile1, testFile2, renamedFile])
                addTestResult("🗑️ 批量文件删除成功")
                
                addTestResult("✅ 所有文件操作测试通过")
                
            } catch {
                addTestResult("❌ 文件操作测试失败: \(error.localizedDescription)")
                
                // 清理可能残留的测试文件
                try? FileManager.default.removeItem(atPath: testFile1)
                try? FileManager.default.removeItem(atPath: testFile2)
                try? FileManager.default.removeItem(atPath: renamedFile)
            }
        }
    }
}

// MARK: - 预览
#Preview {
    AuthorizationTestView()
}
