//
//  BatchCategoryMergeDialog.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-14.
//

import SwiftUI

struct BatchCategoryMergeDialog: View {
    let categories: Set<CategorySelectionManager.CategoryInfo>
    let onMerge: (String) -> Void
    @ObservedObject var pluginManager: PluginManager
    @Environment(\.dismiss) private var dismiss

    @State private var mergeOption: MergeOption = .useExisting
    @State private var selectedCategoryName = ""
    @State private var selectedOtherCategoryName = ""
    @State private var newCategoryName = ""
    @State private var availableCategories: [CategoryInfo] = []
    @State private var isLoadingCategories = false
    @State private var isProcessing = false
    @State private var errorMessage: String?

    enum MergeOption {
        case useExisting    // 使用现有类别名称
        case mergeToOther   // 合并到其他类别
        case createNew      // 创建新类别
    }

    struct CategoryInfo {
        let originalPath: String
        let displayName: String
    }
    
    var availableCategoryNames: [String] {
        // 从选中的类别中获取可用的类别名称
        Array(categories).map { $0.displayName }
    }

    var availableOtherCategories: [CategoryInfo] {
        // 过滤掉选中的类别，只显示其他同类型的类别
        let selectedCategoryPaths = Set(categories.map { $0.categoryPath })
        return availableCategories.filter { !selectedCategoryPaths.contains($0.originalPath) }
    }

    var isTargetNameEmpty: Bool {
        switch mergeOption {
        case .useExisting:
            return selectedCategoryName.isEmpty
        case .mergeToOther:
            return selectedOtherCategoryName.isEmpty || availableOtherCategories.isEmpty
        case .createNew:
            return newCategoryName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty
        }
    }

    var body: some View {
        VStack(alignment: .leading, spacing: 20) {
            // 标题
            HStack {
                Image(systemName: "folder.badge.plus")
                    .foregroundColor(.blue)
                    .font(.title2)

                VStack(alignment: .leading) {
                    Text("批量合并类别")
                        .font(.title2)
                        .fontWeight(.semibold)

                    Text("将 \(categories.count) 个类别合并到指定目标")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }

                Spacer()
            }

            Divider()

            // 源类别列表
            VStack(alignment: .leading, spacing: 8) {
                Text("要合并的类别:")
                    .font(.callout)
                    .foregroundColor(.secondary)

                ScrollView {
                    LazyVStack(spacing: 4) {
                        ForEach(Array(categories), id: \.id) { category in
                            HStack {
                                Image(systemName: "folder")
                                    .foregroundColor(.blue)
                                Text(category.displayName)
                                    .font(.callout)
                                Spacer()
                                Text("\(category.pluginCount) 个插件")
                                    .font(.caption)
                                    .foregroundColor(.secondary)
                            }
                            .padding(.horizontal, 12)
                            .padding(.vertical, 6)
                            .background(Color.secondary.opacity(0.1))
                            .cornerRadius(6)
                        }
                    }
                }
                .frame(maxHeight: 120)
            }

            Divider()

            // 目标类别选择
            VStack(alignment: .leading, spacing: 12) {
                Text("选择目标类别:")
                    .font(.callout)
                    .foregroundColor(.secondary)

                // 使用现有类别名称
                HStack {
                    Button(action: {
                        mergeOption = .useExisting
                    }) {
                        HStack {
                            Image(systemName: mergeOption == .useExisting ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(mergeOption == .useExisting ? .accentColor : .secondary)
                            Text("使用现有类别名称")
                                .font(.body)
                        }
                    }
                    .buttonStyle(.plain)

                    Spacer()
                }

                if mergeOption == .useExisting {
                    Picker("选择类别", selection: $selectedCategoryName) {
                        ForEach(availableCategoryNames, id: \.self) { name in
                            Text(name).tag(name)
                        }
                    }
                    .pickerStyle(.menu)
                    .disabled(availableCategoryNames.isEmpty)
                }

                // 合并到其他类别
                HStack {
                    Button(action: {
                        mergeOption = .mergeToOther
                    }) {
                        HStack {
                            Image(systemName: mergeOption == .mergeToOther ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(mergeOption == .mergeToOther ? .accentColor : .secondary)
                            Text("合并到其他类别")
                                .font(.body)
                        }
                    }
                    .buttonStyle(.plain)

                    Spacer()
                }

                if mergeOption == .mergeToOther {
                    if isLoadingCategories {
                        HStack {
                            ProgressView()
                                .controlSize(.small)
                            Text("加载类别中...")
                                .font(.callout)
                                .foregroundColor(.secondary)
                        }
                    } else {
                        Picker("选择目标类别", selection: $selectedOtherCategoryName) {
                            ForEach(availableOtherCategories, id: \.displayName) { category in
                                Text(category.displayName).tag(category.displayName)
                            }
                        }
                        .pickerStyle(.menu)
                        .disabled(availableOtherCategories.isEmpty)
                    }
                }

                // 创建新类别
                HStack {
                    Button(action: {
                        mergeOption = .createNew
                    }) {
                        HStack {
                            Image(systemName: mergeOption == .createNew ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(mergeOption == .createNew ? .accentColor : .secondary)
                            Text("创建新类别")
                                .font(.body)
                        }
                    }
                    .buttonStyle(.plain)

                    Spacer()
                }

                if mergeOption == .createNew {
                    TextField("输入新类别名称", text: $newCategoryName)
                        .textFieldStyle(.roundedBorder)
                }
            }

            // 错误信息显示
            if let errorMessage = errorMessage {
                HStack {
                    Image(systemName: "exclamationmark.circle")
                        .foregroundColor(.red)

                    Text(errorMessage)
                        .font(.caption)
                        .foregroundColor(.red)
                }
                .padding(.horizontal, 12)
                .padding(.vertical, 8)
                .background(Color.red.opacity(0.1))
                .cornerRadius(6)
            }

            // 操作按钮
            HStack(spacing: 12) {
                Button("取消") {
                    dismiss()
                }
                .buttonStyle(.bordered)

                Button("批量合并 (\(categories.count)个)") {
                    performMerge()
                }
                .buttonStyle(.borderedProminent)
                .disabled(isTargetNameEmpty || isProcessing)
            }
        }
        .padding(24)
        .frame(width: 500)
        .background(Color(NSColor.windowBackgroundColor))
        .onAppear {
            // 初始化默认选择
            if !availableCategoryNames.isEmpty {
                selectedCategoryName = availableCategoryNames.first ?? ""
            }

            Task {
                await loadAvailableCategories()

                // 加载完成后初始化其他类别的默认选择
                await MainActor.run {
                    if !availableOtherCategories.isEmpty {
                        selectedOtherCategoryName = availableOtherCategories.first?.displayName ?? ""
                    }
                }
            }
        }
    }

    private func performMerge() {
        isProcessing = true
        errorMessage = nil

        let targetName: String
        switch mergeOption {
        case .useExisting:
            targetName = selectedCategoryName
        case .mergeToOther:
            targetName = selectedOtherCategoryName
        case .createNew:
            targetName = newCategoryName.trimmingCharacters(in: .whitespacesAndNewlines)
        }

        // 验证目标名称不为空
        guard !targetName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty else {
            errorMessage = "目标类别名称不能为空"
            isProcessing = false
            return
        }

        onMerge(targetName)
        dismiss()
    }

    private func loadAvailableCategories() async {
        guard let firstCategory = categories.first else { return }

        isLoadingCategories = true

        // 获取相同类型的所有类别
        let allCategories = await pluginManager.getAvailableCategories(
            for: firstCategory.sourceType,
            subType: firstCategory.subType
        )

        await MainActor.run {
            availableCategories = allCategories.map { category in
                CategoryInfo(
                    originalPath: category.originalPath,
                    displayName: category.displayName
                )
            }
            isLoadingCategories = false
        }
    }
}

#Preview {
    let sampleCategories: Set<CategorySelectionManager.CategoryInfo> = [
        CategorySelectionManager.CategoryInfo(
            categoryPath: "/path/to/category1",
            displayName: "测试类别1",
            subType: .titles,
            sourceType: .user,
            pluginCount: 5
        ),
        CategorySelectionManager.CategoryInfo(
            categoryPath: "/path/to/category2",
            displayName: "测试类别2",
            subType: .titles,
            sourceType: .user,
            pluginCount: 3
        )
    ]
    
    BatchCategoryMergeDialog(
        categories: sampleCategories,
        onMerge: { _ in },
        pluginManager: PluginManager()
    )
}
