//
//  BatchMergeCategoryDialog.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

struct BatchMergeCategoryDialog: View {
    let plugins: [FCPXPlugin]
    let availableCategories: [(displayName: String, originalPath: String)]
    let onMerge: (String, String) -> Void  // (targetCategory, newPluginName)

    @State private var mergeOption: MergeOption = .useExisting
    @State private var selectedCategoryName = ""
    @State private var selectedOtherCategoryName = ""
    @State private var newCategoryName = ""
    @State private var allAvailableCategories: [(displayName: String, originalPath: String)] = []
    @State private var isLoadingCategories = false
    @State private var isProcessing = false
    @State private var errorMessage: String?
    @Environment(\.dismiss) private var dismiss
    @EnvironmentObject private var pluginManager: PluginManager

    enum MergeOption {
        case useExisting    // 从选择的插件类别目录选择
        case mergeToOther   // 从现有当前类型所有类别目录中选择
        case createNew      // 新建类别目录
    }

    // 从选择的插件中获取的类别名称
    var selectedPluginCategories: [String] {
        let uniqueCategories = Set(plugins.compactMap { plugin in
            URL(fileURLWithPath: plugin.categoryPath).lastPathComponent
        })
        return Array(uniqueCategories).sorted()
    }

    // 过滤掉已选择插件类别的其他类别
    var otherAvailableCategories: [(displayName: String, originalPath: String)] {
        let selectedCategoryPaths = Set(plugins.map { $0.categoryPath })
        return allAvailableCategories.filter { !selectedCategoryPaths.contains($0.originalPath) }
    }

    // 最终的目标名称
    var finalTargetName: String {
        switch mergeOption {
        case .useExisting:
            return selectedCategoryName
        case .mergeToOther:
            return selectedOtherCategoryName
        case .createNew:
            return newCategoryName.trimmingCharacters(in: .whitespacesAndNewlines)
        }
    }

    // 检查目标名称是否为空
    var isTargetNameEmpty: Bool {
        switch mergeOption {
        case .useExisting:
            return selectedCategoryName.isEmpty
        case .mergeToOther:
            return selectedOtherCategoryName.isEmpty || otherAvailableCategories.isEmpty
        case .createNew:
            return newCategoryName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty
        }
    }

    var body: some View {
        VStack(spacing: 20) {
            // 标题
            HStack {
                Image(systemName: "square.stack.3d.up")
                    .foregroundColor(.blue)
                    .font(.title2)

                VStack(alignment: .leading) {
                    Text("批量合并插件")
                        .font(.headline)
                        .foregroundColor(.primary)

                    Text("将多个插件合并到同一类别")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }

                Spacer()

                // 批量操作标识
                Text("批量操作")
                    .font(.caption)
                    .foregroundColor(.white)
                    .padding(.horizontal, 8)
                    .padding(.vertical, 4)
                    .background(Color.blue)
                    .cornerRadius(4)
            }

            // 插件信息
            VStack(alignment: .leading, spacing: 8) {
                HStack {
                    Text("选中的插件 (\(plugins.count) 个)")
                        .font(.callout)
                        .foregroundColor(.secondary)

                    Spacer()

                    // 显示主要插件类型
                    if let primaryType = getPrimaryPluginType() {
                        Text(primaryType.displayName)
                            .font(.caption)
                            .foregroundColor(.blue)
                            .padding(.horizontal, 6)
                            .padding(.vertical, 2)
                            .background(Color.blue.opacity(0.1))
                            .cornerRadius(3)
                    }
                }

                // 显示插件名称列表（简化）
                Text(plugins.prefix(3).map { $0.displayName }.joined(separator: ", ") + (plugins.count > 3 ? "..." : ""))
                    .font(.caption)
                    .foregroundColor(.secondary)
                    .lineLimit(2)
            }
            .padding(.horizontal, 12)
            .padding(.vertical, 8)
            .background(Color.secondary.opacity(0.1))
            .cornerRadius(8)

            // 目标类别选择
            VStack(alignment: .leading, spacing: 16) {
                Text("选择目标类别:")
                    .font(.callout)
                    .foregroundColor(.secondary)

                // 选项1：从选择的插件类别目录选择
                VStack(alignment: .leading, spacing: 8) {
                    Button(action: {
                        mergeOption = .useExisting
                    }) {
                        HStack {
                            Image(systemName: mergeOption == .useExisting ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(mergeOption == .useExisting ? .accentColor : .secondary)
                            Text("从选择的插件类别目录选择")
                                .font(.body)
                        }
                    }
                    .buttonStyle(.plain)

                    if mergeOption == .useExisting {
                        if selectedPluginCategories.isEmpty {
                            Text("没有可用的目标类别")
                                .font(.caption)
                                .foregroundColor(.orange)
                                .padding(.horizontal, 12)
                                .padding(.vertical, 6)
                                .background(Color.orange.opacity(0.1))
                                .cornerRadius(6)
                        } else {
                            Picker("选择类别", selection: $selectedCategoryName) {
                                ForEach(selectedPluginCategories, id: \.self) { name in
                                    Text(name).tag(name)
                                }
                            }
                            .pickerStyle(.menu)
                            .disabled(selectedPluginCategories.isEmpty)
                        }
                    }
                }

                // 选项2：从现有当前类型所有类别目录中选择
                VStack(alignment: .leading, spacing: 8) {
                    Button(action: {
                        mergeOption = .mergeToOther
                    }) {
                        HStack {
                            Image(systemName: mergeOption == .mergeToOther ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(mergeOption == .mergeToOther ? .accentColor : .secondary)
                            Text("从现有当前类型所有类别目录中选择")
                                .font(.body)
                        }
                    }
                    .buttonStyle(.plain)

                    if mergeOption == .mergeToOther {
                        if isLoadingCategories {
                            HStack {
                                ProgressView()
                                    .controlSize(.small)
                                Text("加载类别中...")
                                    .font(.callout)
                                    .foregroundColor(.secondary)
                            }
                        } else if otherAvailableCategories.isEmpty {
                            Text("没有可用的目标类别")
                                .font(.caption)
                                .foregroundColor(.orange)
                                .padding(.horizontal, 12)
                                .padding(.vertical, 6)
                                .background(Color.orange.opacity(0.1))
                                .cornerRadius(6)
                        } else {
                            Picker("选择目标类别", selection: $selectedOtherCategoryName) {
                                ForEach(otherAvailableCategories, id: \.displayName) { category in
                                    Text(category.displayName).tag(category.displayName)
                                }
                            }
                            .pickerStyle(.menu)
                            .disabled(otherAvailableCategories.isEmpty)
                        }
                    }
                }

                // 选项3：新建类别目录
                VStack(alignment: .leading, spacing: 8) {
                    Button(action: {
                        mergeOption = .createNew
                    }) {
                        HStack {
                            Image(systemName: mergeOption == .createNew ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(mergeOption == .createNew ? .accentColor : .secondary)
                            Text("新建类别目录")
                                .font(.body)
                        }
                    }
                    .buttonStyle(.plain)

                    if mergeOption == .createNew {
                        TextField("输入新类别名称", text: $newCategoryName)
                            .textFieldStyle(.roundedBorder)
                    }
                }
            }

            // 错误信息显示
            if let errorMessage = errorMessage {
                HStack {
                    Image(systemName: "exclamationmark.circle")
                        .foregroundColor(.red)

                    Text(errorMessage)
                        .font(.caption)
                        .foregroundColor(.red)
                }
                .padding(.horizontal, 12)
                .padding(.vertical, 8)
                .background(Color.red.opacity(0.1))
                .cornerRadius(6)
            }

            // 操作按钮
            HStack(spacing: 12) {
                Button("取消") {
                    dismiss()
                }
                .buttonStyle(.bordered)

                Button("批量合并 (\(plugins.count)个)") {
                    performMerge()
                }
                .buttonStyle(.borderedProminent)
                .disabled(isTargetNameEmpty || isProcessing)
            }
        }
        .padding(24)
        .frame(width: 600)
        .background(Color(NSColor.windowBackgroundColor))
        .onAppear {
            // 初始化默认选择
            if !selectedPluginCategories.isEmpty {
                selectedCategoryName = selectedPluginCategories.first ?? ""
            }

            Task {
                await loadAvailableCategories()

                // 加载完成后初始化其他类别的默认选择
                await MainActor.run {
                    if !otherAvailableCategories.isEmpty {
                        selectedOtherCategoryName = otherAvailableCategories.first?.displayName ?? ""
                    }
                }
            }
        }
    }

    private func performMerge() {
        guard !isTargetNameEmpty else { return }

        isProcessing = true
        errorMessage = nil

        // 验证目标名称不为空
        let targetName = finalTargetName
        guard !targetName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty else {
            errorMessage = "目标类别名称不能为空"
            isProcessing = false
            return
        }

        onMerge(targetName, "")

        // 延迟关闭对话框，给用户一些反馈时间
        DispatchQueue.main.asyncAfter(deadline: .now() + 0.5) {
            dismiss()
        }
    }
    
    // MARK: - 辅助方法
    
    /// 获取选中插件的主要类型
    private func getPrimaryPluginType() -> PluginSubType? {
        // 统计各种插件类型的数量
        var typeCounts: [PluginSubType: Int] = [:]

        for plugin in plugins {
            if let subType = plugin.subType {
                typeCounts[subType, default: 0] += 1
            }
        }

        // 返回数量最多的类型
        return typeCounts.max(by: { $0.value < $1.value })?.key
    }

    /// 加载可用的类别
    private func loadAvailableCategories() async {
        guard let primaryType = getPrimaryPluginType(),
              let firstPlugin = plugins.first else { return }

        isLoadingCategories = true

        let categories = await pluginManager.getAvailableCategories(for: firstPlugin.type, subType: primaryType)

        await MainActor.run {
            allAvailableCategories = categories
            isLoadingCategories = false
        }
    }

}