//
//  BatchMergeDialog.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

// MARK: - 批量合并对话框
struct BatchMergeDialog: View {
    let bufferItems: [MergeBufferItem]
    @ObservedObject var mergeManager: BatchMergeManager
    let onComplete: () -> Void
    
    @State private var isAnalyzing = true
    @State private var mergeAnalysis: MergeAnalysis?
    @State private var selectedTargetName = ""
    @State private var useCustomName = false
    @State private var customTargetName = ""
    @State private var conflictResolutions: [String: ConflictResolution] = [:]
    @State private var isPerformingMerge = false
    @State private var mergeError: String?
    @Environment(\.dismiss) private var dismiss
    
    var finalTargetName: String {
        useCustomName ? customTargetName : selectedTargetName
    }
    
    var body: some View {
        VStack(spacing: 0) {
            // 标题栏
            HStack {
                Text("批量合并分析")
                    .font(.title2)
                    .fontWeight(.semibold)
                Spacer()
            }
            .padding()
            .background(Color(NSColor.controlBackgroundColor))

            Divider()

            if isAnalyzing {
                analyzingView
            } else if let analysis = mergeAnalysis {
                ScrollView {
                    VStack(spacing: 20) {
                        // 合并概览
                        mergeOverviewSection(analysis)

                        // 目标名称选择
                        targetNameSection(analysis)

                        // 冲突解决
                        if !analysis.conflicts.isEmpty {
                            conflictResolutionSection(analysis)
                        }
                    }
                    .padding()
                }
            }

            Spacer()

            // 底部按钮
            bottomButtonsSection
        }
        .frame(width: 700, height: 600)
        .task {
            await analyzeItems()
        }
    }
    
    // MARK: - 视图组件
    
    private var analyzingView: some View {
        VStack(spacing: 20) {
            ProgressView()
                .scaleEffect(1.5)
            
            Text("正在分析合并项目...")
                .font(.headline)
                .foregroundColor(.secondary)
            
            Text("检测冲突、分析插件类型、计算合并策略")
                .font(.caption)
                .foregroundColor(.secondary)
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
    }
    
    private func mergeOverviewSection(_ analysis: MergeAnalysis) -> some View {
        VStack(alignment: .leading, spacing: 12) {
            Text("合并概览")
                .font(.headline)
            
            LazyVGrid(columns: Array(repeating: GridItem(.flexible()), count: 2), spacing: 12) {
                InfoCard(
                    title: "总插件数",
                    value: "\(analysis.totalPlugins)",
                    icon: "doc.on.doc",
                    color: .blue
                )
                
                InfoCard(
                    title: "类别数",
                    value: "\(analysis.categoryCount)",
                    icon: "folder.fill",
                    color: .green
                )
                
                InfoCard(
                    title: "冲突数",
                    value: "\(analysis.conflicts.count)",
                    icon: "exclamationmark.triangle",
                    color: analysis.conflicts.isEmpty ? .secondary : .orange
                )
                
                InfoCard(
                    title: "插件类型",
                    value: analysis.primarySubType.displayName,
                    icon: analysis.primarySubType.icon,
                    color: .purple
                )
            }
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(12)
    }
    
    private func targetNameSection(_ analysis: MergeAnalysis) -> some View {
        VStack(alignment: .leading, spacing: 12) {
            Text("目标类别名称")
                .font(.headline)
            
            VStack(spacing: 8) {
                // 建议的名称选项
                if !analysis.suggestedNames.isEmpty {
                    Text("建议使用现有类别名称:")
                        .font(.callout)
                        .foregroundColor(.secondary)
                    
                    LazyVGrid(columns: Array(repeating: GridItem(.flexible()), count: 2), spacing: 8) {
                        ForEach(analysis.suggestedNames, id: \.self) { name in
                            Button(action: {
                                selectedTargetName = name
                                useCustomName = false
                            }) {
                                HStack {
                                    Image(systemName: selectedTargetName == name && !useCustomName ? "checkmark.circle.fill" : "circle")
                                        .foregroundColor(selectedTargetName == name && !useCustomName ? .accentColor : .secondary)
                                    Text(name)
                                        .lineLimit(1)
                                    Spacer()
                                }
                                .padding(.horizontal, 12)
                                .padding(.vertical, 8)
                                .background(
                                    RoundedRectangle(cornerRadius: 8)
                                        .fill(selectedTargetName == name && !useCustomName ? Color.accentColor.opacity(0.1) : Color.clear)
                                        .overlay(
                                            RoundedRectangle(cornerRadius: 8)
                                                .stroke(Color.secondary.opacity(0.3), lineWidth: 1)
                                        )
                                )
                            }
                            .buttonStyle(PlainButtonStyle())
                        }
                    }
                }
                
                // 自定义名称选项
                HStack {
                    Button(action: {
                        useCustomName = true
                    }) {
                        HStack {
                            Image(systemName: useCustomName ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(useCustomName ? .accentColor : .secondary)
                            Text("自定义名称:")
                        }
                    }
                    .buttonStyle(PlainButtonStyle())
                    
                    TextField("输入新的类别名称", text: $customTargetName)
                        .textFieldStyle(RoundedBorderTextFieldStyle())
                        .disabled(!useCustomName)
                }
            }
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(12)
    }
    
    private func conflictResolutionSection(_ analysis: MergeAnalysis) -> some View {
        VStack(alignment: .leading, spacing: 12) {
            Text("冲突解决 (\(analysis.conflicts.count) 个)")
                .font(.headline)
            
            LazyVStack(spacing: 8) {
                ForEach(analysis.conflicts, id: \.pluginName) { conflict in
                    ConflictResolutionRow(
                        conflict: conflict,
                        resolution: Binding(
                            get: { conflictResolutions[conflict.pluginName] ?? .keepBoth },
                            set: { conflictResolutions[conflict.pluginName] = $0 }
                        )
                    )
                }
            }
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(12)
    }
    
    private var bottomButtonsSection: some View {
        VStack(spacing: 8) {
            if let mergeError = mergeError {
                HStack {
                    Image(systemName: "exclamationmark.triangle")
                        .foregroundColor(.red)
                    Text(mergeError)
                        .font(.caption)
                        .foregroundColor(.red)
                    Spacer()
                }
                .padding(.horizontal)
            }
            
            HStack {
                Button("取消") {
                    dismiss()
                }
                .keyboardShortcut(.escape)
                .disabled(isPerformingMerge)
                
                Spacer()
                
                Button(isPerformingMerge ? "合并中..." : "开始合并") {
                    performMerge()
                }
                .buttonStyle(.borderedProminent)
                .disabled(
                    isAnalyzing ||
                    isPerformingMerge ||
                    finalTargetName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty
                )
                
                if isPerformingMerge {
                    ProgressView()
                        .scaleEffect(0.8)
                }
            }
            .padding()
        }
    }
    
    // MARK: - 操作方法
    
    private func analyzeItems() async {
        do {
            let analysis = await mergeManager.analyzeBufferItems(bufferItems)
            await MainActor.run {
                self.mergeAnalysis = analysis
                
                // 设置默认选择
                if let firstSuggested = analysis.suggestedNames.first {
                    selectedTargetName = firstSuggested
                    useCustomName = false
                } else {
                    useCustomName = true
                    customTargetName = "合并类别"
                }
                
                isAnalyzing = false
            }
        }
    }
    
    private func performMerge() {
        guard let analysis = mergeAnalysis else { return }
        
        isPerformingMerge = true
        mergeError = nil
        
        Task {
            do {
                try await mergeManager.performBatchMerge(
                    analysis: analysis,
                    targetName: finalTargetName,
                    conflictResolutions: conflictResolutions
                )
                
                await MainActor.run {
                    onComplete()
                    dismiss()
                }
            } catch {
                await MainActor.run {
                    mergeError = error.localizedDescription
                    isPerformingMerge = false
                }
            }
        }
    }
}

// MARK: - 辅助视图

struct InfoCard: View {
    let title: String
    let value: String
    let icon: String
    let color: Color
    
    var body: some View {
        VStack(spacing: 8) {
            Image(systemName: icon)
                .font(.title2)
                .foregroundColor(color)
            
            Text(value)
                .font(.title3)
                .fontWeight(.semibold)
            
            Text(title)
                .font(.caption)
                .foregroundColor(.secondary)
        }
        .frame(maxWidth: .infinity)
        .padding()
        .background(Color.secondary.opacity(0.05))
        .cornerRadius(8)
    }
}

#Preview {
    BatchMergeDialog(
        bufferItems: [],
        mergeManager: BatchMergeManager(),
        onComplete: {}
    )
}
