//
//  BatchOperationView.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-14.
//

import SwiftUI

struct BatchOperationView: View {
    @ObservedObject var batchOperationManager: BatchOperationManager
    @ObservedObject var pluginManager: PluginManager
    @State private var showingMergeDialog = false
    @State private var showingUninstallAlert = false
    @State private var isProcessing = false
    
    var body: some View {
        VStack(spacing: 16) {
            // 标题栏
            headerView
            
            Divider()
            
            // 缓冲区内容
            if batchOperationManager.bufferedPlugins.isEmpty {
                emptyStateView
            } else {
                VStack(spacing: 12) {
                    // 统计信息
                    statsView
                    
                    // 插件列表
                    pluginListView
                    
                    // 类型兼容性提示
                    if !batchOperationManager.bufferedPlugins.isEmpty {
                        typeCompatibilityView
                    }

                    // 操作按钮
                    actionButtonsView
                }
            }
        }
        .padding(16)
        .background(.regularMaterial, in: RoundedRectangle(cornerRadius: 12))
        .alert("批量卸载确认", isPresented: $showingUninstallAlert) {
            Button("取消", role: .cancel) { }
            Button("确认卸载", role: .destructive) {
                Task {
                    await performBatchUninstall()
                }
            }
        } message: {
            Text("确定要卸载缓冲区中的 \(batchOperationManager.bufferedPlugins.count) 个插件吗？此操作不可撤销。")
        }
        .sheet(isPresented: $showingMergeDialog) {
            BatchMergeCategoryDialog(
                plugins: batchOperationManager.bufferedPlugins,
                availableCategories: [], // 将在对话框内部加载
                onMerge: { targetCategory, _ in
                    // 执行合并操作
                    Task {
                        await performBatchMerge(targetCategory: targetCategory)
                    }
                }
            )
        }
    }
    
    // MARK: - 标题栏
    private var headerView: some View {
        HStack {
            Image(systemName: "tray.2")
                .foregroundColor(.blue)
                .font(.title2)
            
            VStack(alignment: .leading) {
                Text("批量操作缓冲区")
                    .font(.headline)
                Text("\(batchOperationManager.bufferedPlugins.count) 个插件")
                    .font(.caption)
                    .foregroundColor(.secondary)
            }
            
            Spacer()
            
            // 清空按钮
            if !batchOperationManager.bufferedPlugins.isEmpty {
                Button("清空") {
                    withAnimation(.easeInOut(duration: 0.3)) {
                        batchOperationManager.clearBuffer()
                    }
                }
                .buttonStyle(.bordered)
                .controlSize(.small)
            }
        }
    }
    
    // MARK: - 空状态视图
    private var emptyStateView: some View {
        VStack(spacing: 12) {
            Image(systemName: "tray")
                .font(.system(size: 32))
                .foregroundColor(.secondary)
            
            Text("缓冲区为空")
                .font(.body)
                .foregroundColor(.secondary)
            
            Text("点击插件卡片上的 + 按钮将插件添加到缓冲区")
                .font(.caption)
                .foregroundColor(.secondary)
                .multilineTextAlignment(.center)
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
        .frame(minHeight: 120)
    }
    
    // MARK: - 统计信息视图
    private var statsView: some View {
        HStack {
            // 插件类型统计
            let stats = batchOperationManager.getPluginTypeStats()
            ForEach(Array(stats.keys.sorted(by: { $0.rawValue < $1.rawValue })), id: \.self) { subType in
                HStack(spacing: 4) {
                    Image(systemName: subType.icon)
                        .foregroundColor(.blue)
                        .font(.caption)

                    Text("\(stats[subType] ?? 0)")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
            }
            
            Spacer()
            
            // 总大小
            Text(batchOperationManager.getFormattedTotalSize())
                .font(.caption)
                .foregroundColor(.secondary)
        }
        .padding(.horizontal, 8)
        .padding(.vertical, 4)
        .background(Color.secondary.opacity(0.1))
        .cornerRadius(6)
    }
    
    // MARK: - 插件列表视图
    private var pluginListView: some View {
        ScrollView {
            LazyVStack(spacing: 6) {
                ForEach(batchOperationManager.bufferedPlugins) { plugin in
                    BatchOperationItemView(
                        plugin: plugin,
                        onRemove: {
                            withAnimation(.easeInOut(duration: 0.2)) {
                                batchOperationManager.removePlugin(plugin)
                            }
                        }
                    )
                }
            }
            .padding(.horizontal, 4)
        }
        .frame(maxHeight: 200)
    }

    // MARK: - 类型兼容性提示视图
    private var typeCompatibilityView: some View {
        VStack(spacing: 8) {
            if batchOperationManager.areAllPluginsSameType() {
                // 所有插件类型相同，可以合并
                if batchOperationManager.bufferedPlugins.count >= 2 {
                    HStack {
                        Image(systemName: "checkmark.circle")
                            .foregroundColor(.green)
                        Text("所有插件类型相同，可以进行合并操作")
                            .font(.caption)
                            .foregroundColor(.green)
                    }
                    .padding(.horizontal, 12)
                    .padding(.vertical, 6)
                    .background(Color.green.opacity(0.1))
                    .cornerRadius(6)
                }
            } else {
                // 插件类型不同，不能合并
                VStack(spacing: 6) {
                    HStack {
                        Image(systemName: "exclamationmark.triangle")
                            .foregroundColor(.orange)
                        Text("插件类型不同，无法进行合并操作")
                            .font(.caption)
                            .foregroundColor(.orange)
                    }

                    Text("只有相同类型的插件才能合并到同一个类别中")
                        .font(.caption2)
                        .foregroundColor(.secondary)
                        .multilineTextAlignment(.center)
                }
                .padding(.horizontal, 12)
                .padding(.vertical, 8)
                .background(Color.orange.opacity(0.1))
                .cornerRadius(6)
            }
        }
    }

    // MARK: - 操作按钮视图
    private var actionButtonsView: some View {
        HStack(spacing: 12) {
            // 合并按钮
            Button("合并插件") {
                showingMergeDialog = true
            }
            .buttonStyle(.bordered)
            .disabled(!batchOperationManager.canPerformMerge() || isProcessing)
            .help(batchOperationManager.canPerformMerge() ? "将所有插件合并到一个类别" : "需要至少2个相同类型的插件才能合并")
            
            // 卸载按钮
            Button("卸载插件") {
                showingUninstallAlert = true
            }
            .buttonStyle(.bordered)
            .tint(.red)
            .disabled(!batchOperationManager.canPerformUninstall() || isProcessing)
        }
        .padding(.top, 8)
    }
    
    // MARK: - 批量卸载操作
    private func performBatchUninstall() async {
        isProcessing = true
        defer { isProcessing = false }

        let pluginsToUninstall = batchOperationManager.bufferedPlugins
        print("🔄 开始批量卸载 \(pluginsToUninstall.count) 个插件")

        do {
            // 使用批量卸载方法，只需要输入一次密码
            try await pluginManager.batchUninstallPlugins(pluginsToUninstall)

            // 清空缓冲区
            batchOperationManager.clearBuffer()

            print("🎉 批量卸载完成: 成功卸载 \(pluginsToUninstall.count) 个插件")
        } catch {
            print("❌ 批量卸载失败: \(error)")
            // 即使失败也清空缓冲区，避免重复操作
            batchOperationManager.clearBuffer()
        }
    }

    // MARK: - 批量合并操作
    private func performBatchMerge(targetCategory: String) async {
        isProcessing = true
        defer { isProcessing = false }

        let pluginsToMerge = batchOperationManager.bufferedPlugins
        print("🔄 开始批量合并 \(pluginsToMerge.count) 个插件到类别: \(targetCategory)")

        do {
            // 使用批量合并方法，只需要输入一次密码
            try await pluginManager.batchMergePluginsToCategory(pluginsToMerge, targetCategoryPath: targetCategory)

            // 清空缓冲区
            batchOperationManager.clearBuffer()

            print("🎉 批量合并完成: 成功合并 \(pluginsToMerge.count) 个插件到 \(targetCategory)")
        } catch {
            print("❌ 批量合并失败: \(error)")
            // 即使失败也清空缓冲区，避免重复操作
            batchOperationManager.clearBuffer()
        }
    }
}

// MARK: - 批量操作项目视图
struct BatchOperationItemView: View {
    let plugin: FCPXPlugin
    let onRemove: () -> Void
    
    var body: some View {
        HStack(spacing: 8) {
            // 插件类型图标
            if let subType = plugin.subType {
                Image(systemName: subType.icon)
                    .foregroundColor(.blue)
                    .frame(width: 16)
            }
            
            // 插件信息
            VStack(alignment: .leading, spacing: 2) {
                Text(plugin.displayName)
                    .font(.callout)
                    .lineLimit(1)
                
                HStack {
                    if let subType = plugin.subType {
                        Text(subType.displayName)
                            .font(.caption2)
                            .foregroundColor(.secondary)
                    }
                    
                    Spacer()
                    
                    Text(formatFileSize(plugin.fileSize))
                        .font(.caption2)
                        .foregroundColor(.secondary)
                }
            }
            
            // 移除按钮
            Button(action: onRemove) {
                Image(systemName: "xmark.circle.fill")
                    .foregroundColor(.secondary)
            }
            .buttonStyle(.plain)
            .help("从缓冲区移除")
        }
        .padding(.horizontal, 8)
        .padding(.vertical, 6)
        .background(Color.secondary.opacity(0.1))
        .cornerRadius(6)
    }

    private func formatFileSize(_ bytes: Int64) -> String {
        guard bytes > 0 else { return "0 KB" }

        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: bytes)
    }
}

#Preview {
    BatchOperationView(
        batchOperationManager: BatchOperationManager(),
        pluginManager: PluginManager()
    )
    .frame(width: 300, height: 400)
}
