//
//  CategoryMergeView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

// MARK: - 合并冲突解决策略
enum MergeConflictResolution: CaseIterable {
    case keepSource        // 保留源文件，覆盖目标文件
    case keepTarget        // 保留目标文件，跳过源文件
    case keepBoth          // 保留两个文件，自动重命名
    case askEachTime       // 每次都询问用户
    
    var displayName: String {
        switch self {
        case .keepSource: return "保留源文件（覆盖目标）"
        case .keepTarget: return "保留目标文件（跳过源）"
        case .keepBoth: return "保留两个文件（自动重命名）"
        case .askEachTime: return "每次询问"
        }
    }
    
    var icon: String {
        switch self {
        case .keepSource: return "arrow.right.circle"
        case .keepTarget: return "arrow.left.circle"
        case .keepBoth: return "plus.circle"
        case .askEachTime: return "questionmark.circle"
        }
    }
}

// MARK: - 合并操作数据模型
struct CategoryMergeOperation {
    let sourceCategory: String
    let targetCategory: String
    let sourceType: PluginType
    let subType: PluginSubType
    var conflictResolution: MergeConflictResolution = .askEachTime
    var newCategoryName: String? // 如果用户选择重命名合并后的类别
}

// MARK: - 文件冲突信息
struct FileConflict {
    let fileName: String
    let sourcePath: String
    let targetPath: String
    var resolution: MergeConflictResolution?
    var customName: String?
}

// MARK: - 类别合并视图
struct CategoryMergeView: View {
    @Binding var isPresented: Bool
    let mergeOperation: CategoryMergeOperation
    let categoryMapping: [String: String]
    @ObservedObject var pluginManager: PluginManager
    let onCategoryChanged: () async -> Void
    @State private var conflicts: [FileConflict] = []
    @State private var isAnalyzing = true
    @State private var defaultResolution: MergeConflictResolution = .askEachTime
    @State private var newCategoryName: String = ""
    @State private var keepOriginalName = true
    @State private var isPerformingMerge = false
    @State private var mergeError: String?
    @StateObject private var mergeManager = CategoryMergeManager()
    
    var body: some View {
        NavigationView {
            VStack(spacing: 20) {
                // 标题区域
                headerSection
                
                if isAnalyzing {
                    // 分析中
                    analyzingSection
                } else {
                    // 合并配置
                    ScrollView {
                        VStack(spacing: 16) {
                            // 合并后类别名称设置
                            categoryNameSection
                            
                            // 默认冲突解决策略
                            defaultResolutionSection
                            
                            // 冲突列表
                            if !conflicts.isEmpty {
                                conflictsSection
                            }
                        }
                        .padding()
                    }
                }
                
                Spacer()
                
                // 底部按钮
                bottomButtons
            }
            .navigationTitle("合并类别")
        }
        .frame(width: 600, height: 500)
        .task {
            await analyzeConflicts()
        }
    }
    
    // MARK: - 视图组件
    
    private var headerSection: some View {
        VStack(spacing: 8) {
            HStack {
                // 源类别
                VStack {
                    Image(systemName: "folder.fill")
                        .font(.title2)
                        .foregroundColor(.blue)
                    Text(mergeOperation.sourceCategory)
                        .font(.headline)
                        .multilineTextAlignment(.center)
                }
                
                // 箭头
                Image(systemName: "arrow.right")
                    .font(.title)
                    .foregroundColor(.secondary)
                
                // 目标类别
                VStack {
                    Image(systemName: "folder.fill")
                        .font(.title2)
                        .foregroundColor(.green)
                    Text(mergeOperation.targetCategory)
                        .font(.headline)
                        .multilineTextAlignment(.center)
                }
            }
            
            Text("将 \(mergeOperation.sourceCategory) 合并到 \(mergeOperation.targetCategory)")
                .font(.subheadline)
                .foregroundColor(.secondary)
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(8)
        .padding(.horizontal)
    }
    
    private var analyzingSection: some View {
        VStack(spacing: 16) {
            ProgressView()
                .scaleEffect(1.2)
            
            Text("正在分析文件冲突...")
                .font(.headline)
                .foregroundColor(.secondary)
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
    }
    
    private var categoryNameSection: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text("合并后的类别名称")
                .font(.headline)
            
            VStack(spacing: 8) {
                HStack {
                    Button(action: {
                        keepOriginalName = true
                        newCategoryName = mergeOperation.targetCategory
                    }) {
                        HStack {
                            Image(systemName: keepOriginalName ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(keepOriginalName ? .accentColor : .secondary)
                            Text("保留目标类别名称: \(mergeOperation.targetCategory)")
                        }
                    }
                    .buttonStyle(PlainButtonStyle())
                    
                    Spacer()
                }
                
                HStack {
                    Button(action: {
                        keepOriginalName = false
                    }) {
                        HStack {
                            Image(systemName: !keepOriginalName ? "checkmark.circle.fill" : "circle")
                                .foregroundColor(!keepOriginalName ? .accentColor : .secondary)
                            Text("自定义名称:")
                        }
                    }
                    .buttonStyle(PlainButtonStyle())
                    
                    TextField("输入新名称", text: $newCategoryName)
                        .textFieldStyle(RoundedBorderTextFieldStyle())
                        .disabled(keepOriginalName)
                }
            }
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(8)
    }
    
    private var defaultResolutionSection: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text("默认冲突解决策略")
                .font(.headline)
            
            LazyVGrid(columns: Array(repeating: GridItem(.flexible()), count: 2), spacing: 8) {
                ForEach(MergeConflictResolution.allCases, id: \.self) { resolution in
                    Button(action: {
                        defaultResolution = resolution
                        // 应用到所有未设置的冲突
                        for index in conflicts.indices {
                            if conflicts[index].resolution == nil {
                                conflicts[index].resolution = resolution
                            }
                        }
                    }) {
                        HStack {
                            Image(systemName: resolution.icon)
                                .foregroundColor(defaultResolution == resolution ? .white : .accentColor)
                            Text(resolution.displayName)
                                .font(.caption)
                                .foregroundColor(defaultResolution == resolution ? .white : .primary)
                        }
                        .padding(.horizontal, 8)
                        .padding(.vertical, 4)
                        .background(
                            RoundedRectangle(cornerRadius: 6)
                                .fill(defaultResolution == resolution ? Color.accentColor : Color.clear)
                                .overlay(
                                    RoundedRectangle(cornerRadius: 6)
                                        .stroke(Color.accentColor, lineWidth: 1)
                                )
                        )
                    }
                    .buttonStyle(PlainButtonStyle())
                }
            }
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(8)
    }
    
    private var conflictsSection: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text("文件冲突 (\(conflicts.count) 个)")
                .font(.headline)
            
            LazyVStack(spacing: 4) {
                ForEach(conflicts.indices, id: \.self) { index in
                    ConflictRowView(
                        conflict: $conflicts[index],
                        defaultResolution: defaultResolution
                    )
                }
            }
        }
        .padding()
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(8)
    }
    
    private var bottomButtons: some View {
        VStack(spacing: 8) {
            // 错误信息
            if let mergeError = mergeError {
                HStack {
                    Image(systemName: "exclamationmark.triangle")
                        .foregroundColor(.red)
                    Text(mergeError)
                        .font(.caption)
                        .foregroundColor(.red)
                    Spacer()
                }
                .padding(.horizontal)
            }

            HStack {
                Button("取消") {
                    isPresented = false
                }
                .keyboardShortcut(.escape)
                .disabled(isPerformingMerge)

                Spacer()

                Button(isPerformingMerge ? "合并中..." : "开始合并") {
                    performMerge()
                }
                .buttonStyle(.borderedProminent)
                .disabled(
                    isAnalyzing ||
                    isPerformingMerge ||
                    (!keepOriginalName && newCategoryName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty)
                )

                if isPerformingMerge {
                    ProgressView()
                        .scaleEffect(0.8)
                }
            }
            .padding()
        }
    }
    
    // MARK: - 操作方法
    
    private func analyzeConflicts() async {
        newCategoryName = mergeOperation.targetCategory

        do {
            conflicts = await mergeManager.analyzeConflicts(
                sourceCategory: mergeOperation.sourceCategory,
                targetCategory: mergeOperation.targetCategory,
                sourceType: mergeOperation.sourceType,
                subType: mergeOperation.subType,
                categoryMapping: categoryMapping
            )
        }

        isAnalyzing = false
    }
    
    private func performMerge() {
        isPerformingMerge = true
        mergeError = nil

        Task {
            do {
                // 确保所有冲突都有解决方案
                for index in conflicts.indices {
                    if conflicts[index].resolution == nil {
                        conflicts[index].resolution = defaultResolution
                    }
                }

                let finalName = keepOriginalName ? mergeOperation.targetCategory : newCategoryName

                try await mergeManager.performMerge(
                    operation: mergeOperation,
                    conflicts: conflicts,
                    finalCategoryName: finalName,
                    categoryMapping: categoryMapping
                )

                // 使用和移除操作一样的视图更新逻辑
                await MainActor.run {
                    // 在内存中处理类别合并
                    pluginManager.mergeCategoryInMemory(
                        sourceCategory: mergeOperation.sourceCategory,
                        targetCategory: mergeOperation.targetCategory,
                        finalCategoryName: finalName,
                        sourceType: mergeOperation.sourceType
                    )

                    isPresented = false
                }

                // 通知类别变化
                await onCategoryChanged()

            } catch {
                await MainActor.run {
                    mergeError = error.localizedDescription
                    isPerformingMerge = false
                }
            }
        }
    }
}

// MARK: - 冲突行视图
struct ConflictRowView: View {
    @Binding var conflict: FileConflict
    let defaultResolution: MergeConflictResolution
    
    var body: some View {
        HStack {
            Image(systemName: "exclamationmark.triangle")
                .foregroundColor(.orange)
            
            VStack(alignment: .leading, spacing: 2) {
                Text(conflict.fileName)
                    .font(.callout)
                    .fontWeight(.medium)
                
                Text("存在同名文件")
                    .font(.caption)
                    .foregroundColor(.secondary)
            }
            
            Spacer()
            
            Picker("解决方案", selection: Binding(
                get: { conflict.resolution ?? defaultResolution },
                set: { conflict.resolution = $0 }
            )) {
                ForEach(MergeConflictResolution.allCases, id: \.self) { resolution in
                    Text(resolution.displayName).tag(resolution)
                }
            }
            .pickerStyle(MenuPickerStyle())
            .frame(width: 150)
        }
        .padding(.horizontal, 8)
        .padding(.vertical, 4)
        .background(Color(NSColor.controlBackgroundColor).opacity(0.5))
        .cornerRadius(4)
    }
}

#Preview {
    CategoryMergeView(
        isPresented: .constant(true),
        mergeOperation: CategoryMergeOperation(
            sourceCategory: "源类别",
            targetCategory: "目标类别",
            sourceType: .user,
            subType: .effects
        ),
        categoryMapping: [:],
        pluginManager: PluginManager(),
        onCategoryChanged: {}
    )
}
