//
//  CompatibilityWarningView.swift
//  TemmplatesArchive
//
//  Created by AI Assistant on 2025/7/8.
//

import SwiftUI

struct CompatibilityWarningView: View {
    @ObservedObject var compatibilityManager = SystemCompatibilityManager.shared
    @State private var showDetails = false
    
    var body: some View {
        if !compatibilityManager.compatibilityIssues.isEmpty {
            VStack(spacing: 0) {
                // 警告横幅
                HStack {
                    Image(systemName: hasCriticalIssues ? "exclamationmark.triangle.fill" : "exclamationmark.triangle")
                        .foregroundColor(hasCriticalIssues ? .red : .orange)
                        .font(.title2)
                    
                    VStack(alignment: .leading, spacing: 2) {
                        Text(hasCriticalIssues ? "发现严重兼容性问题" : "发现兼容性警告")
                            .font(.headline)
                            .foregroundColor(hasCriticalIssues ? .red : .orange)
                        
                        Text("点击查看详情和解决建议")
                            .font(.caption)
                            .foregroundColor(.secondary)
                    }
                    
                    Spacer()
                    
                    Button(action: {
                        withAnimation(.easeInOut(duration: 0.3)) {
                            showDetails.toggle()
                        }
                    }) {
                        Image(systemName: showDetails ? "chevron.up" : "chevron.down")
                            .foregroundColor(.secondary)
                    }
                    .buttonStyle(PlainButtonStyle())
                }
                .padding()
                .background(
                    RoundedRectangle(cornerRadius: 8)
                        .fill(hasCriticalIssues ? Color.red.opacity(0.1) : Color.orange.opacity(0.1))
                )
                
                // 详细信息
                if showDetails {
                    VStack(alignment: .leading, spacing: 12) {
                        ForEach(compatibilityManager.compatibilityIssues) { issue in
                            CompatibilityIssueRow(issue: issue)
                        }
                        
                        // 系统信息
                        if let systemInfo = compatibilityManager.systemInfo {
                            SystemInfoView(systemInfo: systemInfo)
                        }
                    }
                    .padding()
                    .background(Color(NSColor.controlBackgroundColor))
                    .transition(.opacity.combined(with: .move(edge: .top)))
                }
            }
            .background(
                RoundedRectangle(cornerRadius: 10)
                    .fill(Color(NSColor.windowBackgroundColor))
                    .shadow(color: .black.opacity(0.1), radius: 5, x: 0, y: 2)
            )
            .padding()
        }
    }
    
    private var hasCriticalIssues: Bool {
        compatibilityManager.compatibilityIssues.contains { $0.severity == .critical }
    }
}

struct CompatibilityIssueRow: View {
    let issue: CompatibilityIssue
    
    var body: some View {
        HStack(alignment: .top, spacing: 12) {
            Image(systemName: iconName)
                .foregroundColor(iconColor)
                .font(.title3)
                .frame(width: 20)
            
            VStack(alignment: .leading, spacing: 4) {
                Text(issue.message)
                    .font(.body)
                    .foregroundColor(.primary)
                
                Text("建议: \(issue.suggestion)")
                    .font(.caption)
                    .foregroundColor(.secondary)
                    .padding(.leading, 8)
            }
            
            Spacer()
        }
        .padding(.vertical, 4)
    }
    
    private var iconName: String {
        switch issue.type {
        case .osVersion:
            return "desktopcomputer"
        case .memory:
            return "memorychip"
        case .directoryAccess:
            return "folder.badge.questionmark"
        case .architecture:
            return "cpu"
        case .other:
            return "questionmark.circle"
        }
    }
    
    private var iconColor: Color {
        switch issue.severity {
        case .critical:
            return .red
        case .warning:
            return .orange
        case .info:
            return .blue
        }
    }
}

struct SystemInfoView: View {
    let systemInfo: SystemInfo
    @State private var showSystemInfo = false
    
    var body: some View {
        VStack(alignment: .leading, spacing: 8) {
            Button(action: {
                withAnimation(.easeInOut(duration: 0.2)) {
                    showSystemInfo.toggle()
                }
            }) {
                HStack {
                    Image(systemName: "info.circle")
                        .foregroundColor(.blue)
                    
                    Text("系统信息")
                        .font(.headline)
                        .foregroundColor(.blue)
                    
                    Spacer()
                    
                    Image(systemName: showSystemInfo ? "chevron.up" : "chevron.down")
                        .foregroundColor(.secondary)
                        .font(.caption)
                }
            }
            .buttonStyle(PlainButtonStyle())
            
            if showSystemInfo {
                VStack(alignment: .leading, spacing: 4) {
                    InfoRow(label: "应用版本", value: systemInfo.appVersion)
                    InfoRow(label: "系统版本", value: systemInfo.osVersionString)
                    InfoRow(label: "架构", value: systemInfo.architecture)
                    InfoRow(label: "内存", value: "\(systemInfo.memoryGB)GB")
                    InfoRow(label: "处理器核心", value: "\(systemInfo.processorCount)")
                    InfoRow(label: "沙盒状态", value: systemInfo.isInSandbox ? "启用" : "禁用")
                }
                .padding(.leading, 24)
                .transition(.opacity.combined(with: .move(edge: .top)))
            }
        }
        .padding()
        .background(
            RoundedRectangle(cornerRadius: 6)
                .fill(Color.blue.opacity(0.05))
        )
    }
}

struct InfoRow: View {
    let label: String
    let value: String
    
    var body: some View {
        HStack {
            Text(label + ":")
                .font(.caption)
                .foregroundColor(.secondary)
                .frame(width: 80, alignment: .leading)
            
            Text(value)
                .font(.caption)
                .foregroundColor(.primary)
            
            Spacer()
        }
    }
}

#Preview {
    CompatibilityWarningView()
        .frame(width: 600, height: 400)
}
