//
//  ConflictResolutionRow.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

// MARK: - 冲突解决策略
enum ConflictResolution: String, CaseIterable {
    case keepBoth = "keepBoth"
    case keepFirst = "keepFirst"
    case keepSecond = "keepSecond"
    case rename = "rename"
    
    var displayName: String {
        switch self {
        case .keepBoth: return "保留两个（自动重命名）"
        case .keepFirst: return "保留第一个"
        case .keepSecond: return "保留第二个"
        case .rename: return "自定义重命名"
        }
    }
    
    var icon: String {
        switch self {
        case .keepBoth: return "plus.circle"
        case .keepFirst: return "1.circle"
        case .keepSecond: return "2.circle"
        case .rename: return "pencil.circle"
        }
    }
    
    var color: Color {
        switch self {
        case .keepBoth: return .blue
        case .keepFirst: return .green
        case .keepSecond: return .orange
        case .rename: return .purple
        }
    }
}

// MARK: - 冲突解决行视图
struct ConflictResolutionRow: View {
    let conflict: PluginConflict
    @Binding var resolution: ConflictResolution
    @State private var customName = ""
    @State private var isExpanded = false
    
    var body: some View {
        VStack(alignment: .leading, spacing: 12) {
            // 冲突信息头部
            HStack {
                Image(systemName: "exclamationmark.triangle.fill")
                    .foregroundColor(.orange)
                
                VStack(alignment: .leading, spacing: 2) {
                    Text("插件名称冲突")
                        .font(.callout)
                        .fontWeight(.medium)
                    
                    Text(conflict.pluginName)
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
                
                Spacer()
                
                Button(action: {
                    withAnimation(.easeInOut(duration: 0.2)) {
                        isExpanded.toggle()
                    }
                }) {
                    Image(systemName: isExpanded ? "chevron.up" : "chevron.down")
                        .font(.caption)
                        .foregroundColor(.secondary)
                }
                .buttonStyle(PlainButtonStyle())
            }
            
            if isExpanded {
                // 冲突详情
                conflictDetailsSection
                
                // 解决方案选择
                resolutionSelectionSection
                
                // 自定义重命名（如果选择了重命名选项）
                if resolution == .rename {
                    customRenameSection
                }
            }
        }
        .padding()
        .background(
            RoundedRectangle(cornerRadius: 8)
                .fill(Color.orange.opacity(0.05))
                .overlay(
                    RoundedRectangle(cornerRadius: 8)
                        .stroke(Color.orange.opacity(0.3), lineWidth: 1)
                )
        )
        .onAppear {
            customName = conflict.pluginName
        }
    }
    
    private var conflictDetailsSection: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text("冲突详情")
                .font(.caption)
                .fontWeight(.medium)
                .foregroundColor(.secondary)
            
            HStack(spacing: 16) {
                // 第一个插件
                conflictPluginCard(
                    title: "插件 1",
                    plugin: conflict.plugins[0],
                    isSelected: resolution == .keepFirst
                )
                
                Image(systemName: "arrow.left.arrow.right")
                    .foregroundColor(.secondary)
                
                // 第二个插件
                conflictPluginCard(
                    title: "插件 2",
                    plugin: conflict.plugins[1],
                    isSelected: resolution == .keepSecond
                )
            }
        }
    }
    
    private func conflictPluginCard(title: String, plugin: FCPXPlugin, isSelected: Bool) -> some View {
        VStack(spacing: 8) {
            Text(title)
                .font(.caption)
                .fontWeight(.medium)
                .foregroundColor(.secondary)
            
            // 插件缩略图
            AsyncImage(url: plugin.thumbnailURL) { image in
                image
                    .resizable()
                    .aspectRatio(contentMode: .fill)
            } placeholder: {
                Image(systemName: plugin.subType?.icon ?? "doc")
                    .font(.title2)
                    .foregroundColor(.secondary)
            }
            .frame(width: 60, height: 60)
            .clipShape(RoundedRectangle(cornerRadius: 8))
            .overlay(
                RoundedRectangle(cornerRadius: 8)
                    .stroke(isSelected ? Color.accentColor : Color.clear, lineWidth: 2)
            )
            
            VStack(spacing: 2) {
                Text(plugin.displayName)
                    .font(.caption)
                    .fontWeight(.medium)
                    .lineLimit(2)
                    .multilineTextAlignment(.center)
                
                Text(formatFileSize(plugin.fileSize))
                    .font(.caption2)
                    .foregroundColor(.secondary)
                
                Text(formatDate(plugin.modifiedDate))
                    .font(.caption2)
                    .foregroundColor(.secondary)
            }
        }
        .frame(maxWidth: .infinity)
        .padding(8)
        .background(
            RoundedRectangle(cornerRadius: 6)
                .fill(isSelected ? Color.accentColor.opacity(0.1) : Color.secondary.opacity(0.05))
        )
    }
    
    private var resolutionSelectionSection: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text("解决方案")
                .font(.caption)
                .fontWeight(.medium)
                .foregroundColor(.secondary)
            
            LazyVGrid(columns: Array(repeating: GridItem(.flexible()), count: 2), spacing: 8) {
                ForEach(ConflictResolution.allCases, id: \.self) { option in
                    Button(action: {
                        resolution = option
                    }) {
                        HStack(spacing: 8) {
                            Image(systemName: option.icon)
                                .foregroundColor(resolution == option ? .white : option.color)
                            
                            Text(option.displayName)
                                .font(.caption)
                                .foregroundColor(resolution == option ? .white : .primary)
                        }
                        .frame(maxWidth: .infinity)
                        .padding(.horizontal, 8)
                        .padding(.vertical, 6)
                        .background(
                            RoundedRectangle(cornerRadius: 6)
                                .fill(resolution == option ? option.color : Color.clear)
                                .overlay(
                                    RoundedRectangle(cornerRadius: 6)
                                        .stroke(option.color, lineWidth: 1)
                                )
                        )
                    }
                    .buttonStyle(PlainButtonStyle())
                }
            }
        }
    }
    
    private var customRenameSection: some View {
        VStack(alignment: .leading, spacing: 8) {
            Text("自定义名称")
                .font(.caption)
                .fontWeight(.medium)
                .foregroundColor(.secondary)
            
            TextField("输入新的插件名称", text: $customName)
                .textFieldStyle(RoundedBorderTextFieldStyle())
        }
    }
    
    // MARK: - 辅助方法
    
    private func formatFileSize(_ bytes: Int64) -> String {
        let formatter = ByteCountFormatter()
        formatter.allowedUnits = [.useKB, .useMB, .useGB]
        formatter.countStyle = .file
        return formatter.string(fromByteCount: bytes)
    }
    
    private func formatDate(_ date: Date) -> String {
        let formatter = DateFormatter()
        formatter.dateStyle = .short
        formatter.timeStyle = .none
        return formatter.string(from: date)
    }
}

#Preview {
    ConflictResolutionRow(
        conflict: PluginConflict(
            pluginName: "测试插件",
            plugins: [
                FCPXPlugin(
                    name: "测试插件",
                    path: "/path1",
                    type: .user,
                    subType: .effects,
                    categoryPath: "/cat1"
                ),
                FCPXPlugin(
                    name: "测试插件",
                    path: "/path2",
                    type: .user,
                    subType: .effects,
                    categoryPath: "/cat2"
                )
            ]
        ),
        resolution: .constant(.keepBoth)
    )
    .padding()
}
