//
//  FxFactoryOperationView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/5.
//

import SwiftUI

// MARK: - FxFactory操作进度视图
struct FxFactoryOperationView: View {
    @ObservedObject var protectionManager = FxFactoryProtectionManager.shared
    @Environment(\.dismiss) private var dismiss

    let plugin: FCPXPlugin
    let operation: PluginOperation
    let pluginManager: PluginManager
    let onComplete: () -> Void

    @State private var hasStarted = false
    @State private var operationError: Error?
    @State private var showingError = false
    @State private var newName = ""
    @State private var autoStarted = false
    
    var body: some View {
        VStack(spacing: 20) {
            // 标题
            VStack(spacing: 8) {
                Image(systemName: operationIcon)
                    .font(.system(size: 48))
                    .foregroundColor(.accentColor)
                
                Text(operationTitle)
                    .font(.title2)
                    .fontWeight(.semibold)
                
                Text("插件: \(plugin.displayName)")
                    .font(.headline)
                    .foregroundColor(.secondary)
            }
            
            Divider()
            
            // 进度区域
            VStack(spacing: 16) {
                if protectionManager.isProcessing {
                    // 进度指示器
                    VStack(spacing: 12) {
                        ProgressView()
                            .scaleEffect(1.2)

                        Text(protectionManager.progressMessage)
                            .font(.body)
                            .multilineTextAlignment(.center)
                            .foregroundColor(.primary)
                    }
                    .frame(minHeight: 80)

                } else if autoStarted && !hasStarted {
                    // 自动开始等待状态
                    VStack(spacing: 12) {
                        ProgressView()
                            .scaleEffect(1.2)

                        Text("正在启动FxFactory自动重装防护措施...")
                            .font(.body)
                            .multilineTextAlignment(.center)
                            .foregroundColor(.primary)
                    }
                    .frame(minHeight: 80)
                    
                } else if hasStarted && operationError == nil {
                    // 完成状态
                    VStack(spacing: 12) {
                        Image(systemName: "checkmark.circle.fill")
                            .font(.system(size: 32))
                            .foregroundColor(.green)

                        Text("操作完成")
                            .font(.headline)
                            .foregroundColor(.green)

                        // 如果是卸载操作，显示防护完成信息
                        if case .uninstall = operation {
                            Text("FxFactory自动重装防护已完成")
                                .font(.caption)
                                .foregroundColor(.secondary)
                        }
                    }
                    .frame(minHeight: 80)
                    
                } else if !hasStarted || (autoStarted && !hasStarted) {
                    // 准备状态或自动开始等待状态
                    VStack(spacing: 12) {
                        statusIndicator

                        Text(statusMessage)
                            .font(.body)
                            .multilineTextAlignment(.center)
                            .foregroundColor(.secondary)

                        // 如果是重命名操作，显示输入框
                        if case .rename = operation {
                            VStack(alignment: .leading, spacing: 8) {
                                Text("新名称:")
                                    .font(.callout)
                                    .foregroundColor(.secondary)

                                TextField("输入新的插件名称", text: $newName)
                                    .textFieldStyle(.roundedBorder)
                                    .frame(maxWidth: 300)
                            }
                        }
                    }
                    .frame(minHeight: 80)
                }
            }
            
            Spacer()
            
            // 底部按钮
            HStack {
                Button("取消") {
                    dismiss()
                }
                .disabled(protectionManager.isProcessing || (hasStarted && operation == .uninstall))
                
                Spacer()
                
                if !hasStarted {
                    Button(actionButtonTitle) {
                        performOperation()
                    }
                    .buttonStyle(.borderedProminent)
                    .disabled(!canPerformOperation)
                } else if hasStarted && !protectionManager.isProcessing {
                    // 对于卸载操作，不显示完成按钮（会自动关闭）
                    if case .uninstall = operation {
                        // 卸载操作完成后会自动关闭，不需要按钮
                        EmptyView()
                    } else {
                        Button("完成") {
                            onComplete()
                            dismiss()
                        }
                        .buttonStyle(.borderedProminent)
                    }
                }
            }
        }
        .padding()
        .frame(width: 500, height: 400)
        .alert("操作失败", isPresented: $showingError) {
            Button("确定") {
                showingError = false
            }
        } message: {
            if let error = operationError {
                Text(error.localizedDescription)
            }
        }
        .onAppear {
            Task {
                // 初始化时更新FxFactory状态
                _ = await protectionManager.checkFxFactoryStatus()

                // 如果是重命名操作，设置默认名称
                if case .rename = operation {
                    newName = plugin.displayName
                }

                // 如果是卸载操作，自动开始（无感操作）
                if case .uninstall = operation, !autoStarted {
                    autoStarted = true
                    // 延迟一点时间让UI显示，然后自动开始
                    try? await Task.sleep(nanoseconds: 500_000_000) // 0.5秒

                    // 确保在主线程上调用performOperation
                    await MainActor.run {
                        performOperation()
                    }
                }
            }
        }
    }
    
    // MARK: - 计算属性
    
    private var operationIcon: String {
        switch operation {
        case .rename:
            return "pencil.circle"
        case .uninstall:
            return "trash.circle"
        case .merge:
            return "arrow.triangle.merge"
        case .duplicate:
            return "doc.on.doc"
        case .export:
            return "square.and.arrow.up"
        }
    }
    
    private var operationTitle: String {
        switch operation {
        case .rename:
            return "重命名FxFactory插件"
        case .uninstall:
            return "卸载FxFactory插件"
        case .merge:
            return "合并FxFactory插件"
        case .duplicate:
            return "复制FxFactory插件"
        case .export:
            return "导出FxFactory插件"
        }
    }
    
    private var actionButtonTitle: String {
        switch operation {
        case .rename:
            return "开始重命名"
        case .uninstall:
            return "开始卸载"
        case .merge:
            return "开始合并"
        case .duplicate:
            return "开始复制"
        case .export:
            return "开始导出"
        }
    }
    
    private var statusIndicator: some View {
        // 使用 @ViewBuilder 而不是 Group 来避免泛型推断问题
        switch protectionManager.currentStatus {
        case .notInstalled:
            Image(systemName: "info.circle")
                .font(.system(size: 32))
                .foregroundColor(.blue)

        case .ready:
            Image(systemName: "checkmark.circle")
                .font(.system(size: 32))
                .foregroundColor(.green)

        case .running:
            Image(systemName: "exclamationmark.triangle")
                .font(.system(size: 32))
                .foregroundColor(.orange)

        case .disabled:
            Image(systemName: "pause.circle")
                .font(.system(size: 32))
                .foregroundColor(.gray)
        }
    }
    
    private var statusMessage: String {
        // 为卸载操作提供特殊的信息提示
        if case .uninstall = operation {
            if autoStarted && !hasStarted {
                return "正在启动FxFactory自动重装防护措施..."
            } else if autoStarted && hasStarted {
                return "FxFactory自动重装防护措施已启动"
            } else {
                switch protectionManager.currentStatus {
                case .notInstalled:
                    return "FxFactory未安装，将直接卸载插件"
                case .ready:
                    return "将启用FxFactory自动重装防护，确保插件完全卸载"
                case .running:
                    return "FxFactory正在运行，将自动关闭后执行卸载"
                case .disabled:
                    return "FxFactory监控已被临时禁用"
                }
            }
        }

        // 其他操作的常规信息
        switch protectionManager.currentStatus {
        case .notInstalled:
            return "FxFactory未安装，将直接执行操作"

        case .ready:
            return "FxFactory已准备就绪，可以安全执行操作"

        case .running:
            return "FxFactory正在运行，请先关闭FxFactory应用程序后再继续"

        case .disabled:
            return "FxFactory监控已被临时禁用"
        }
    }
    
    private var canPerformOperation: Bool {
        switch protectionManager.currentStatus {
        case .notInstalled, .ready:
            // 如果是重命名操作，还需要检查名称是否有效
            if case .rename = operation {
                return !newName.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty
            }
            return true
        case .running, .disabled:
            return false
        }
    }
    
    // MARK: - 操作方法
    
    private func performOperation() {
        hasStarted = true
        operationError = nil

        Task {
            do {
                // 获取类别的真实名称
                let categoryRealName = await protectionManager.getCategoryRealName(from: plugin.path)

                // 根据操作类型执行相应的防护操作
                let fxFactoryOperation: FxFactoryOperation
                switch operation {
                case .rename:
                    fxFactoryOperation = .rename
                case .uninstall:
                    fxFactoryOperation = .remove
                default:
                    fxFactoryOperation = .remove
                }

                // 执行FxFactory防护操作
                let _ = try await protectionManager.protectFxFactoryPlugin(
                    categoryRealName: categoryRealName,
                    operation: fxFactoryOperation
                )

                // 执行实际的插件操作
                if case .rename(let newName) = operation {
                    // 重命名操作需要调用PluginManager
                    try await pluginManager.renamePlugin(plugin, newName: newName.trimmingCharacters(in: .whitespacesAndNewlines))
                } else if case .uninstall = operation {
                    // 卸载操作需要调用PluginManager
                    try await pluginManager.uninstallPlugin(plugin)
                }

                // 操作成功完成
                await MainActor.run {
                    // 如果是卸载操作，实现无感化：自动完成并关闭
                    if case .uninstall = operation {
                        // 延迟1秒让用户看到完成状态，然后自动关闭
                        DispatchQueue.main.asyncAfter(deadline: .now() + 1.0) {
                            onComplete()
                            dismiss()
                        }
                    }
                    // 其他操作保持原有行为，等待用户点击完成按钮
                }

            } catch {
                await MainActor.run {
                    // 检查是否是用户取消操作
                    if let fxError = error as? FxFactoryError, fxError == .userCancelled {
                        // 用户取消操作，直接关闭对话框，不显示错误
                        onComplete()
                        dismiss()
                    } else {
                        // 其他错误，显示错误信息
                        operationError = error
                        showingError = true
                    }
                }
            }
        }
    }
}

// MARK: - 预览
#Preview {
    FxFactoryOperationView(
        plugin: FCPXPlugin(
            name: "Test Plugin",
            path: "/test/path",
            type: .user,
            subType: .effects,
            categoryPath: "/test"
        ),
        operation: .rename(newName: "New Name"),
        pluginManager: PluginManager(),
        onComplete: {}
    )
}
