//
//  FxFactoryUninstallProgressView.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-01-05.
//

import SwiftUI

/// FxFactory插件卸载进度提示视图
struct FxFactoryUninstallProgressView: View {
    let plugin: FCPXPlugin
    let pluginManager: PluginManager
    let onComplete: () -> Void

    @Environment(\.dismiss) private var dismiss
    @StateObject private var protectionManager = FxFactoryProtectionManager.shared
    @State private var hasStarted = false
    @State private var isCompleted = false
    @State private var operationError: Error?
    @State private var showingError = false
    
    var body: some View {
        VStack(spacing: 20) {
            // 图标
            Image(systemName: "trash.circle.fill")
                .font(.system(size: 48))
                .foregroundColor(.blue)
            
            // 标题
            Text("卸载 FxFactory 插件")
                .font(.title2)
                .fontWeight(.semibold)
            
            // 插件名称
            Text("插件: \(plugin.displayName)")
                .font(.body)
                .foregroundColor(.secondary)
            
            // 状态区域
            VStack(spacing: 12) {
                if isCompleted {
                    // 完成状态
                    Image(systemName: "checkmark.circle.fill")
                        .font(.system(size: 32))
                        .foregroundColor(.green)
                    
                    Text("FxFactory自动重装防护已完成")
                        .font(.headline)
                        .foregroundColor(.green)
                    
                    Text("插件已安全卸载")
                        .font(.caption)
                        .foregroundColor(.secondary)
                        
                } else if let error = operationError {
                    // 错误状态
                    Image(systemName: "exclamationmark.triangle.fill")
                        .font(.system(size: 32))
                        .foregroundColor(.red)
                    
                    Text("操作失败")
                        .font(.headline)
                        .foregroundColor(.red)
                    
                    Text(error.localizedDescription)
                        .font(.caption)
                        .foregroundColor(.secondary)
                        .multilineTextAlignment(.center)
                        
                } else {
                    // 进行中状态
                    ProgressView()
                        .scaleEffect(1.2)
                    
                    Text(progressMessage)
                        .font(.body)
                        .multilineTextAlignment(.center)
                        .foregroundColor(.primary)
                }
            }
            .frame(minHeight: 100)
            
            // 按钮区域
            HStack(spacing: 12) {
                if isCompleted || operationError != nil {
                    Button("完成") {
                        onComplete()
                        dismiss()
                    }
                    .buttonStyle(.borderedProminent)
                } else {
                    Button("取消") {
                        dismiss()
                    }
                    .disabled(hasStarted)
                }
            }
        }
        .padding(24)
        .frame(width: 400)
        .background(Color(NSColor.windowBackgroundColor))
        .cornerRadius(12)
        .shadow(radius: 10)
        .task {
            // 自动开始卸载操作
            await startUninstallOperation()
        }
        .alert("操作失败", isPresented: $showingError) {
            Button("确定") {
                dismiss()
            }
        } message: {
            if let error = operationError {
                Text(error.localizedDescription)
            }
        }
    }
    
    /// 当前进度消息
    private var progressMessage: String {
        if hasStarted {
            return protectionManager.progressMessage.isEmpty ? 
                "正在进行FxFactory自动重装防护..." : 
                protectionManager.progressMessage
        } else {
            return "正在启动FxFactory自动重装防护措施..."
        }
    }
    
    /// 开始卸载操作
    private func startUninstallOperation() async {
        // 延迟一点时间让UI显示
        try? await Task.sleep(nanoseconds: 500_000_000) // 0.5秒
        
        await MainActor.run {
            hasStarted = true
        }
        
        do {
            // 获取类别的真实名称
            let categoryRealName = await protectionManager.getCategoryRealName(from: plugin.path)

            // 执行FxFactory防护卸载
            let _ = try await protectionManager.protectFxFactoryPlugin(
                categoryRealName: categoryRealName,
                operation: .remove
            )

            // 执行实际的卸载操作
            try await pluginManager.uninstallPlugin(plugin)
            
            // 操作成功
            await MainActor.run {
                isCompleted = true
                
                // 延迟2秒后自动关闭
                DispatchQueue.main.asyncAfter(deadline: .now() + 2.0) {
                    onComplete()
                    dismiss()
                }
            }
            
        } catch {
            // 操作失败
            await MainActor.run {
                // 检查是否是用户取消操作
                if let fxError = error as? FxFactoryError {
                    switch fxError {
                    case .userCancelled:
                        // 用户取消操作，直接关闭
                        onComplete()
                        dismiss()
                    default:
                        // 其他错误，显示错误信息
                        operationError = error
                        showingError = true
                    }
                } else {
                    // 其他错误，显示错误信息
                    operationError = error
                    showingError = true
                }
            }
        }
    }
}

#Preview {
    FxFactoryUninstallProgressView(
        plugin: FCPXPlugin(
            name: "Test Plugin",
            path: "/test/path",
            type: .user,
            subType: .effects,
            categoryPath: "Test Category"
        ),
        pluginManager: PluginManager(),
        onComplete: {}
    )
}
